@@ -173,7 +173,7 @@ puts [
 
 shell.run { |l|
   l.gsub!(/(\r|\n)/, '')
-  l.gsub!(/\\n/, "\n")
+  l.gsub!("\\n", "\n")
   l.gsub!(';', "\n")
 
   break if %w[quit exit].include? l.chomp
