@@ -1,5 +1,5 @@
 require 'digest'
-
+require 'metasploit/framework/data_service/remote/http/error'
 #
 # HTTP response helper class
 #
@@ -56,8 +56,7 @@ module ResponseDataHelper
           raise "Mdm Object conversion failed #{e.message}"
         end
       elsif response_wrapper.is_a?(Metasploit::Framework::DataService::RemoteHTTPDataService::ErrorResponse)
-        # raise a local exception with the message of the server-side error
-        raise parsed_body[:error][:message]
+        handle_error_response(parsed_body)
       end
     elsif response_wrapper.is_a?(Metasploit::Framework::DataService::RemoteHTTPDataService::FailedResponse)
       raise response_wrapper.to_s
@@ -77,7 +76,7 @@ module ResponseDataHelper
     begin
       # If we are running the data service on the same box this will ensure we only write
       # the file if it is somehow not there already.
-      unless File.exists?(save_path) && File.read(save_path, mode: 'rb') == decoded_file
+      unless File.exist?(save_path) && File.read(save_path, mode: 'rb') == decoded_file
         File.write(save_path, decoded_file, mode: 'wb')
       end
     rescue => e
@@ -146,4 +145,21 @@ module ResponseDataHelper
     obj
   end
 
+  private
+
+  def handle_error_response(parsed_body)
+    error = parsed_body[:error]
+    error_code = error[:code]
+    case error_code
+    when 404
+      raise Metasploit::Framework::DataService::Remote::NotFound.new(error: error)
+    when 400..499
+      raise Metasploit::Framework::DataService::Remote::ClientError.new(error: error, status_code: error_code)
+    when 500..599
+      raise Metasploit::Framework::DataService::Remote::ServerError.new(error: error, status_code: error_code)
+    else
+      raise Metasploit::Framework::DataService::Remote::HttpError.new(error: error, status_code: error_code)
+    end
+  end
+
 end
