@@ -65,6 +65,7 @@ module Exploit
 
       # Import options from the OptionStr or Option hash.
       exploit._import_extra_options(opts)
+      exploit.datastore['ACTION'] = opts['Action'] if opts['Action']
       opts['Payload'] ||= exploit.datastore['Payload']
 
       unless opts['Quiet']
@@ -79,7 +80,7 @@ module Exploit
       end
 
       # Verify the options
-      exploit.options.validate(exploit.datastore)
+      exploit.validate
 
       # Start it up
       driver = Msf::ExploitDriver.new(exploit.framework)
@@ -222,7 +223,7 @@ module Exploit
   #
   # Calls the class method.
   #
-  def check_simple(opts)
+  def check_simple(opts = {})
     Msf::Simple::Exploit.check_simple(self, opts)
   end
 
