@@ -1460,34 +1460,6 @@ class Exploit < Msf::Module
     return self.fail_reason
   end
 
-  def report_failure
-    return unless framework.db and framework.db.active
-
-    info = {
-      :timestamp   => Time.now.utc,
-      :workspace   => framework.db.find_workspace(self.workspace),
-      :module      => self.fullname,
-      :fail_reason => self.fail_reason,
-      :fail_detail => self.fail_detail,
-      :target_name => self.target.name,
-      :username    => self.owner,
-      :refs        => self.references,
-      :run_id      => self.datastore['RUN_ID']
-    }
-
-    if self.datastore['RHOST'] && (self.options['RHOST'] || self.options['RHOSTS'])
-      info[:host] = self.datastore['RHOST']
-    end
-
-    if self.datastore['RPORT'] and self.options['RPORT']
-      info[:port] = self.datastore['RPORT']
-      if self.class.ancestors.include?(Msf::Exploit::Remote::Tcp)
-        info[:proto] = 'tcp'
-      end
-    end
-
-    framework.db.report_exploit_failure(info)
-  end
 
   ##
   #
