@@ -8,8 +8,8 @@ module Msf
           module AsRequest
             # Builds a kerberos AS request
             #
-            # @param opts [Hash{Symbol => <Array<Rex::Proto::Kerberos::Model::PreAuthData>, Rex::Proto::Kerberos::Model::KdcRequestBody>}]
-            # @option opts [Array<Rex::Proto::Kerberos::Model::PreAuthData>] :pa_data
+            # @param opts [Hash{Symbol => <Array<Rex::Proto::Kerberos::Model::PreAuthDataEntry>, Rex::Proto::Kerberos::Model::KdcRequestBody>}]
+            # @option opts [Array<Rex::Proto::Kerberos::Model::PreAuthDataEntry>] :pa_data
             # @option opts [Rex::Proto::Kerberos::Model::KdcRequestBody] :body
             # @return [Rex::Proto::Kerberos::Model::KdcRequest]
             # @see [Rex::Proto::Kerberos::Model::KdcRequest]
@@ -36,14 +36,14 @@ module Msf
             # @option opts [Integer] :pausec
             # @option opts [Integer] :etype
             # @option opts [String] :key
-            # @return [Rex::Proto::Kerberos::Model::PreAuthData]
+            # @return [Rex::Proto::Kerberos::Model::PreAuthDataEntry]
             # @see Rex::Proto::Kerberos::Model::PreAuthEncTimeStamp
             # @see Rex::Proto::Kerberos::Model::EncryptedData
-            # @see Rex::Proto::Kerberos::Model::PreAuthData
+            # @see Rex::Proto::Kerberos::Model::PreAuthDataEntry
             def build_as_pa_time_stamp(opts = {})
               time_stamp = opts[:time_stamp] || Time.now
-              pausec = opts[:pausec] || 0
-              etype = opts[:etype] || Rex::Proto::Kerberos::Crypto::RC4_HMAC
+              pausec = opts[:pausec] || time_stamp&.usec || 0
+              etype = opts[:etype] || Rex::Proto::Kerberos::Crypto::Encryption::DefaultEncryptionType
               key = opts[:key] || OpenSSL::Random.random_bytes(16)
 
               pa_time_stamp = Rex::Proto::Kerberos::Model::PreAuthEncTimeStamp.new(
@@ -56,8 +56,8 @@ module Msf
                   cipher: pa_time_stamp.encrypt(etype, key)
               )
 
-              pa_enc_time_stamp = Rex::Proto::Kerberos::Model::PreAuthData.new(
-                  type: Rex::Proto::Kerberos::Model::PA_ENC_TIMESTAMP,
+              pa_enc_time_stamp = Rex::Proto::Kerberos::Model::PreAuthDataEntry.new(
+                  type: Rex::Proto::Kerberos::Model::PreAuthType::PA_ENC_TIMESTAMP,
                   value: enc_time_stamp.encode
               )
 
@@ -81,15 +81,15 @@ module Msf
             # @see #build_server_name
             # @see Rex::Proto::Kerberos::Model::KdcRequestBody
             def build_as_request_body(opts = {})
-              options = opts[:options] || 0x50800000 # Forwardable, Proxiable, Renewable
-              from = opts[:from] || Time.at(0)
-              till = opts[:till] || Time.at(0)
-              rtime = opts[:rtime] || Time.at(0)
-              nonce = opts[:nonce] || Rex::Text.rand_text_numeric(6).to_i
-              etype = opts[:etype] || [Rex::Proto::Kerberos::Crypto::RC4_HMAC]
-              cname = opts[:cname] || build_client_name(opts)
-              realm = opts[:realm] || ''
-              sname = opts[:sname] || build_server_name(opts)
+              options = opts.fetch(:options) { 0x50800000 } # Forwardable, Proxiable, Renewable
+              from = opts.fetch(:from) { Time.at(0).utc }
+              till = opts.fetch(:till) { Time.at(0).utc }
+              rtime = opts.fetch(:rtime) { Time.at(0).utc }
+              nonce = opts.fetch(:nonce) { rand(1 << 24) }
+              etype = opts.fetch(:etype) { Rex::Proto::Kerberos::Crypto::Encryption::DefaultOfferedEtypes }
+              cname = opts.fetch(:cname) { build_client_name(opts) }
+              realm = opts.fetch(:realm) { '' }
+              sname = opts.fetch(:sname) { build_server_name(opts) }
 
               body = Rex::Proto::Kerberos::Model::KdcRequestBody.new(
                 options: options,
