@@ -67,7 +67,7 @@ module Msf
               certificate.extensions.select { |ext| ext.oid == 'subjectAltName' }.each do |san_extension|
                 begin
                   asn_san = OpenSSL::ASN1.decode(san_extension)
-                  asn_san_value = asn_san.value.find {|value| value.is_a? OpenSSL::ASN1::OctetString }
+                  asn_san_value = asn_san.value.find { |value| value.is_a? OpenSSL::ASN1::OctetString }
 
                   if asn_san_value.nil?
                     raise ArgumentError, 'Invalid certificate provided: unable to decode SAN'
@@ -95,7 +95,7 @@ module Msf
                   elsif san_entry.tag == 2 # dNSName
                     parts = san_entry.value.split('.')
                     if parts.length == 1
-                      user = san_entry
+                      user = san_entry.value  # Corrected to extract string value
                       domain = ''
                     else
                       user = parts[0] + '$'
@@ -110,15 +110,26 @@ module Msf
               end
 
               unless realm.nil? # and also username, since it's both or neither
-                unless results.map { |x| x.map(&:downcase) }.include?([username.downcase, realm.downcase])
-                  # If we've been provided an override but can't find them in a SAN, give a warning
+                normalized_results = results.map do |pair|
+                  pair.map do |value|
+                    if value.is_a?(String)
+                      value.downcase
+                    elsif value.is_a?(OpenSSL::ASN1::ASN1Data) && value.respond_to?(:value)
+                      val = value.value
+                      val.is_a?(String) ? val.downcase : val.to_s.downcase
+                    else
+                      value.to_s.downcase
+                    end
+                  end
+                end
+
+                unless normalized_results.include?([username.downcase, realm.downcase])
                   print_warning("Warning: Provided principal and realm (#{username}@#{realm}) do not match entries in certificate:")
                   results.each do |cert_username, cert_realm|
                     print_warning("  * #{cert_username}@#{cert_realm}")
                   end
                 end
 
-                # But hey, they've overridden it, so off we go
                 return [username, realm]
               end
 
@@ -220,16 +231,21 @@ module Msf
                 client_dh_nonce: RASN1::Types::OctetString.new(value: dh_nonce)
               )
 
+
               auth_pack[:client_public_value][:subject_public_key].bit_length = pub_key_encoded.length * 8
 
+
               signed_auth_pack = sign_auth_pack(auth_pack, pfx.key, certificate)
 
+
               pa_as_req = Rex::Proto::Kerberos::Model::PreAuthPkAsReq.new
 
+
               pa_as_req.signed_auth_pack = signed_auth_pack
 
+
               Rex::Proto::Kerberos::Model::PreAuthDataEntry.new(type: Rex::Proto::Kerberos::Model::PreAuthType::PA_PK_AS_REQ,
-                                                                value: pa_as_req.to_der)
+                                                                  value: pa_as_req.to_der)
             end
 
             # Calculate the cryptographic signatures over the AuthPack, and create the appropriate
@@ -238,9 +254,9 @@ module Msf
             # @param auth_pack [Rex::Proto::Kerberos::Model::Pkinit::AuthPack] The AuthPack to sign
             # @param key [OpenSSL::PKey] The private key to digitally sign the data
             # @param dh [OpenSSL::X509::Certificate] The certificate associated with the private key
-            # @return [Rex::Proto::Kerberos::Model::Pkinit::ContentInfo] The signed AuthPack
+            # @return [Rex::Proto::CryptoAsn1::Cms::ContentInfo] The signed AuthPack
             def sign_auth_pack(auth_pack, key, certificate)
-              signer_info = Rex::Proto::Kerberos::Model::Pkinit::SignerInfo.new(
+              signer_info = Rex::Proto::CryptoAsn1::Cms::SignerInfo.new(
                 version: 1,
                 sid: {
                   issuer: certificate.issuer,
@@ -268,7 +284,7 @@ module Msf
 
               signer_info[:signature] = signature
 
-              signed_data = Rex::Proto::Kerberos::Model::Pkinit::SignedData.new(
+              signed_data = Rex::Proto::CryptoAsn1::Cms::SignedData.new(
                 version: 3,
                 digest_algorithms: [
                   {
@@ -283,9 +299,9 @@ module Msf
                 signer_infos: [signer_info]
               )
 
-              Rex::Proto::Kerberos::Model::Pkinit::ContentInfo.new(
+              Rex::Proto::CryptoAsn1::Cms::ContentInfo.new(
                 content_type: Rex::Proto::Kerberos::Model::OID::SignedData,
-                signed_data: signed_data
+                data: signed_data
               )
             end
           end
