@@ -7,6 +7,8 @@ module Msf
 module Exploit::Remote::SMB::Client::Authenticated
 
   include Msf::Exploit::Remote::SMB::Client
+  include Msf::Exploit::Remote::Kerberos::Ticket::Storage
+  include Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Options
 
   def initialize(info = {})
     super
@@ -16,6 +18,14 @@ module Exploit::Remote::SMB::Client::Authenticated
         OptString.new('SMBPass', [ false, 'The password for the specified username', ''], fallbacks: ['PASSWORD']),
         OptString.new('SMBDomain',  [ false, 'The Windows domain to use for authentication', '.'], fallbacks: ['DOMAIN']),
       ], Msf::Exploit::Remote::SMB::Client::Authenticated)
+
+    register_advanced_options(
+      [
+        *kerberos_storage_options(protocol: 'SMB'),
+        *kerberos_auth_options(protocol: 'SMB', auth_methods: Msf::Exploit::Remote::AuthOption::SMB_OPTIONS),
+      ],
+      Msf::Exploit::Remote::SMB::Client::Authenticated
+    )
   end
 end
 
