@@ -3,54 +3,16 @@
 module Msf::Exploit::Remote::SMB::LogAdapter
   # API inherited from ::Rex::Ui::Output, but as it is a class - it can not be included as a mixin
   class Logger < ::Logger
+    extend Forwardable
+
+    def_delegators :@mod, :datastore, :print
+    def_delegators :@mod, :vprint_bad, :vprint_error, :vprint_good, :vprint_line, :vprint_status, :vprint_warning
+    def_delegators :@mod,  :print_bad,  :print_error,  :print_good,  :print_line,  :print_status,  :print_warning
+
     def initialize(mod, log_device)
       super(log_device)
       @mod = mod
     end
-
-    #
-    # Prints an error message.
-    #
-    def print_error(msg = '')
-      @mod.print_error(msg)
-    end
-
-    alias print_bad print_error
-
-    #
-    # Prints a 'good' message.
-    #
-    def print_good(msg = '')
-      @mod.print_good(msg)
-    end
-
-    #
-    # Prints a status line.
-    #
-    def print_status(msg = '')
-      @mod.print_status(msg)
-    end
-
-    #
-    # Prints an undecorated line of information.
-    #
-    def print_line(msg = '')
-      @mod.print_line(msg)
-    end
-
-    #
-    # Prints a warning
-    #
-    def print_warning(msg = '')
-      @mod.print_warning(msg)
-    end
-
-    #
-    # Prints a message with no decoration.
-    #
-    def print(msg = '')
-      @mod.print(msg)
-    end
   end
 
   # Log devices to be used with Ruby's default Logging
