@@ -45,7 +45,6 @@ module Exploit::Remote::WinRM
     if datastore['Winrm::Auth'] == Msf::Exploit::Remote::AuthOption::KERBEROS
       fail_with(Msf::Exploit::Failure::BadConfig, 'The Winrm::Rhostname option is required when using Kerberos authentication.') if datastore['Winrm::Rhostname'].blank?
       fail_with(Msf::Exploit::Failure::BadConfig, 'The DOMAIN option is required when using Kerberos authentication.') if datastore['DOMAIN'].blank?
-      fail_with(Msf::Exploit::Failure::BadConfig, 'The DomainControllerRhost is required when using Kerberos authentication.') if datastore['DomainControllerRhost'].blank?
       offered_etypes = Msf::Exploit::Remote::AuthOption.as_default_offered_etypes(datastore['Winrm::KrbOfferedEncryptionTypes'])
       fail_with(Msf::Exploit::Failure::BadConfig, 'At least one encryption type is required when using Kerberos authentication.') if offered_etypes.empty?
     else
@@ -80,7 +79,7 @@ module Exploit::Remote::WinRM
     case datastore['Winrm::Auth']
     when Msf::Exploit::Remote::AuthOption::KERBEROS
       kerberos_authenticator = Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::HTTP.new(
-        host: datastore['DomainControllerRhost'],
+        host: datastore['DomainControllerRhost'].blank? ? nil : datastore['DomainControllerRhost'],
         hostname: datastore['Winrm::Rhostname'],
         proxies: datastore['Proxies'],
         realm: datastore['DOMAIN'],
