@@ -3,7 +3,7 @@ require 'base64'
 #
 # This class represents a MySQL/MariaDB Injection object, its primary purpose is to provide the common SQL queries
 # needed when performing SQL injection.
-# This class should not be instanciated directly, refer to Msf::Exploit::SQLi#create_sqli.
+# This class should not be instantiated directly, refer to Msf::Exploit::SQLi#create_sqli.
 #
 module Msf::Exploit::SQLi::MySQLi
   class Common < Msf::Exploit::SQLi::Common
@@ -134,11 +134,11 @@ module Msf::Exploit::SQLi::MySQLi
       one_column = columns.length == 1
       if one_column
         columns = "ifnull(#{columns.first},'#{@null_replacement}')"
-        columns = @encoder[:encode].sub(/\^DATA\^/, columns) if @encoder
+        columns = @encoder[:encode].sub('^DATA^', columns) if @encoder
       else
         columns = "concat_ws('#{@second_concat_separator}'," + columns.map do |col|
           col = "ifnull(#{col},'#{@null_replacement}')"
-          @encoder ? @encoder[:encode].sub(/\^DATA\^/, col) : col
+          @encoder ? @encoder[:encode].sub('^DATA^', col) : col
         end.join(',') + ')'
       end
       unless condition.empty?
@@ -198,7 +198,7 @@ module Msf::Exploit::SQLi::MySQLi
       random_string_len = @truncation_length ? [rand(2..10), @truncation_length].min : rand(2..10)
       random_string = Rex::Text.rand_text_alphanumeric(random_string_len)
       query_string = "'#{random_string}'"
-      query_string = @encoder[:encode].sub(/\^DATA\^/, query_string) if @encoder
+      query_string = @encoder[:encode].sub('^DATA^', query_string) if @encoder
       output = run_sql("select #{query_string}")
       return false if output.nil?
       (@encoder ? @encoder[:decode].call(output) : output) == random_string
@@ -235,7 +235,7 @@ module Msf::Exploit::SQLi::MySQLi
       result = [ ]
       offset = 1
       loop do
-        slice = run_sql(query.sub(/\^OFFSET\^/, offset.to_s))
+        slice = run_sql(query.sub('^OFFSET^', offset.to_s))
         offset += @truncation_length # should be same as @truncation_length for most cases
         result << slice
         vprint_status "{SQLi} Truncated output: #{slice} of size #{slice.size}"
@@ -262,7 +262,7 @@ module Msf::Exploit::SQLi::MySQLi
     # @return [String] What the function call returns
     #
     def call_function(function)
-      function = @encoder[:encode].sub(/\^DATA\^/, function) if @encoder
+      function = @encoder[:encode].sub('^DATA^', function) if @encoder
       output = nil
       if @truncation_length
         output = truncated_query("select mid(#{function},^OFFSET^,#{@truncation_length})")
