@@ -400,8 +400,7 @@ protected
             resp.body = blob
 
           rescue NoMethodError => e
-          rescue NoMethodError => e
-            print_error('Staging failed. This can occur when stageless listeners are used with staged payloads.''')
+            print_error('Staging failed. This can occur when stageless listeners are used with staged payloads.')
             elog('Staging failed. This can occur when stageless listeners are used with staged payloads.', error: e)
             return
           end
