@@ -8,6 +8,8 @@ module Modules
 module Metadata
 
 class Obj
+  # @return [Hash]
+  attr_reader :actions
   # @return [String]
   attr_reader :name
   # @return [String]
@@ -26,8 +28,10 @@ class Obj
   attr_reader :description
   # @return [Array<String>]
   attr_reader :references
-  # @return [Boolean]
+  # @return [String]
   attr_reader :platform
+  # @return [Msf::Module::PlatformList]
+  attr_reader :platform_list
   # @return [String]
   attr_reader :arch
   # @return [Integer]
@@ -88,6 +92,7 @@ class Obj
     @default_credential = module_instance.default_cred?
 
     @platform           = module_instance.platform_to_s
+    @platform_list      = module_instance.platform
     # Done to ensure that differences do not show up for the same array grouping
     sort_platform_string
 
@@ -98,6 +103,15 @@ class Obj
     @ref_name           = module_instance.class.refname
     @needs_cleanup      = module_instance.respond_to?(:needs_cleanup) && module_instance.needs_cleanup
 
+    if module_instance.respond_to?(:actions)
+      @actions = module_instance.actions.sort_by(&:name).map do |action|
+        {
+          'name' => action.name,
+          'description' => action.description
+        }
+      end
+    end
+
     if module_instance.respond_to?(:autofilter_ports)
       @autofilter_ports = module_instance.autofilter_ports
     end
@@ -171,6 +185,8 @@ class Obj
       'needs_cleanup'      => @needs_cleanup,
     }
 
+    data['actions'] = @actions if @actions
+
     if @payload_type
       payload_data = {
         'payload_type'       => @payload_type,
@@ -211,6 +227,7 @@ class Obj
   #######
 
   def init_from_hash(obj_hash)
+    @actions             = obj_hash['actions']
     @name                = obj_hash['name']
     @fullname            = obj_hash['fullname']
     @aliases             = obj_hash['aliases'] || []
@@ -221,6 +238,7 @@ class Obj
     @author              = obj_hash['author'].nil? ? [] : obj_hash['author']
     @references          = obj_hash['references']
     @platform            = obj_hash['platform']
+    @platform_list       = parse_platform_list(@platform)
     @arch                = obj_hash['arch']
     @rport               = obj_hash['rport']
     @mod_time            = Time.parse(obj_hash['mod_time'])
@@ -257,6 +275,16 @@ class Obj
   end
 
   def force_encoding(encoding)
+    if @actions
+      # Encode the actions hashes, assumes that there are no nested hashes
+      @actions = @actions.map do |action|
+        action.map do |k, v|
+          new_key = k.dup.force_encoding(encoding)
+          new_value = v.is_a?(String) ? v.dup.force_encoding(encoding) : v
+          [new_key, new_value]
+        end.to_h
+      end
+    end
     @name = @name.dup.force_encoding(encoding)
     @fullname = @fullname.dup.force_encoding(encoding)
     @description = @description.dup.force_encoding(encoding)
@@ -264,6 +292,18 @@ class Obj
     @references = @references.map {|r| r.dup.force_encoding(encoding)}
   end
 
+  def parse_platform_list(platform_string)
+    return nil if platform_string.nil?
+
+    if platform_string.casecmp?('All')
+      # empty string represents all platforms in Msf::Module::PlatformList
+      platforms = ['']
+    else
+      platforms = platform_string.split(',')
+    end
+    Msf::Module::PlatformList.transform(platforms)
+  end
+
 end
 end
 end
