@@ -178,7 +178,7 @@ package com.metasploit.meterpreter.command;
 /**
  * All supported Command Identifiers
  *
- * @author Genereated by a tool @ #{::Time.now.utc}
+ * @author Generated by a tool @ #{::Time.now.utc}
  */
 public interface CommandId {
 #{command_ids.join("\n")}
@@ -459,7 +459,7 @@ class Tlv
       # compress the raw data
       raw_compressed = Rex::Text.zlib_deflate( raw_uncompressed )
       # check we have actually made the raw data smaller...
-      # (small blobs often compress slightly larger then the origional)
+      # (small blobs often compress slightly larger then the original)
       # if the compressed data is not smaller, we dont use the compressed data
       if( raw_compressed.length < raw_uncompressed.length )
         # if so, set the TLV's type to indicate compression is used
@@ -486,7 +486,7 @@ class Tlv
       # set this TLV as using compression
       @compress = true
       # remove the TLV_META_TYPE_COMPRESSED flag from the tlv type to restore the
-      # tlv type to its origional, allowing for transparent data compression.
+      # tlv type to its original, allowing for transparent data compression.
       self.type = self.type ^ TLV_META_TYPE_COMPRESSED
       # decompress the compressed data (skipping the length and type DWORD's)
       raw_decompressed = Rex::Text.zlib_inflate( raw[HEADER_SIZE..length-1] )
