@@ -141,7 +141,7 @@ module Rex::Proto::Kerberos::CredentialCache
         end
       end
 
-      # calculate the bit length; we can't rely on BinData's `num_bytes` in the senario of the model being 4 bits wide.
+      # calculate the bit length; we can't rely on BinData's `num_bytes` in the scenario of the model being 4 bits wide.
       calculated_bit_length = values.sum { |value| BIN_DATA_BIT_LENGTHS.fetch(value.class) }
       bit_length ||= calculated_bit_length
 
@@ -250,6 +250,17 @@ module Rex::Proto::Kerberos::CredentialCache
       output.join("\n")
     end
 
+    def present_credential_info(credential_info)
+      output = []
+
+      output << 'Credential Information:'
+      output << "Version: #{credential_info.version}".indent(2)
+      output << "Encryption Type: #{credential_info.encryption_type} (#{Rex::Proto::Kerberos::Crypto::Encryption.const_name(credential_info.encryption_type)})".indent(2)
+      output << "Serialized Data: #{credential_info.serialized_data.map { |x| x.to_i.to_s(16).rjust(2, '0').to_s }.join}".indent(2)
+
+      output.join("\n")
+    end
+
     # @param [Rex::Proto::Kerberos::Pac::Krb5ClientInfo] client_info
     # @return [String] A human readable representation of a Client Info
     def present_client_info(client_info)
@@ -324,6 +335,23 @@ module Rex::Proto::Kerberos::CredentialCache
       output.join("\n")
     end
 
+    def present_pac_requestor(pac_requestor)
+      output = []
+      output << 'Pac Requestor:'
+      output << "SID: #{pac_requestor.user_sid}".indent(2)
+      output.join("\n")
+    end
+
+    def present_pac_attributes(pac_attributes)
+      output = []
+      output << 'Pac Attributes:'
+      output << "Flag length: #{pac_attributes.flags_length}".indent(2)
+      output << "Flags: #{pac_attributes.flags}".indent(2)
+      attribute_attributes = Rex::Proto::Kerberos::Pac::PacAttributesFlags.read([pac_attributes.flags].pack('N'))
+      output << print_bin_data_model(attribute_attributes, bit_length: 32).to_s.indent(4)
+      output.join("\n")
+    end
+
     # @param [Rex::Proto::Kerberos::Pac::Krb5PacInfoBuffer] info_buffer
     # @return [String] A human readable representation of a Pac Info Buffer
     def present_pac_info_buffer(info_buffer)
@@ -332,6 +360,8 @@ module Rex::Proto::Kerberos::CredentialCache
       case ul_type
       when Rex::Proto::Kerberos::Pac::Krb5PacElementType::LOGON_INFORMATION
         present_logon_info(pac_element)
+      when Rex::Proto::Kerberos::Pac::Krb5PacElementType::CREDENTIAL_INFORMATION
+        present_credential_info(pac_element)
       when Rex::Proto::Kerberos::Pac::Krb5PacElementType::CLIENT_INFORMATION
         present_client_info(pac_element)
       when Rex::Proto::Kerberos::Pac::Krb5PacElementType::SERVER_CHECKSUM
@@ -340,6 +370,10 @@ module Rex::Proto::Kerberos::CredentialCache
         present_priv_server_checksum(pac_element)
       when Rex::Proto::Kerberos::Pac::Krb5PacElementType::USER_PRINCIPAL_NAME_AND_DNS_INFORMATION
         present_upn_and_dns_information(pac_element)
+      when Rex::Proto::Kerberos::Pac::Krb5PacElementType::PAC_REQUESTOR
+        present_pac_requestor(pac_element)
+      when Rex::Proto::Kerberos::Pac::Krb5PacElementType::PAC_ATTRIBUTES
+        present_pac_attributes(pac_element)
       when Rex::Proto::Kerberos::Pac::Krb5PacElementType::TICKET_CHECKSUM
         present_ticket_checksum(pac_element)
       when Rex::Proto::Kerberos::Pac::Krb5PacElementType::FULL_PAC_CHECKSUM
