@@ -232,6 +232,7 @@ module DispatcherShell
     #
     # Return a pretty, user-readable table of commands provided by this
     # dispatcher.
+    # The command column width can be modified by passing in :command_width.
     #
     def help_to_s(opts={})
       # If this dispatcher has no commands, we can't do anything useful.
@@ -250,7 +251,7 @@ module DispatcherShell
           {
             'Command' =>
               {
-                'Width' => 12
+                'Width' => opts[:command_width]
               }
           })
 
@@ -393,7 +394,7 @@ module DispatcherShell
   def initialize(prompt, prompt_char = '>', histfile = nil, framework = nil, name = nil)
     super
 
-    # Initialze the dispatcher array
+    # Initialize the dispatcher array
     self.dispatcher_stack = []
 
     # Initialize the tab completion array
@@ -588,7 +589,15 @@ module DispatcherShell
   # If the command is unknown...
   #
   def unknown_command(method, line)
-    print_error("Unknown command: #{method}")
+    # Map each dispatchers commands to valid_commands
+    valid_commands = dispatcher_stack.flat_map { |dispatcher| dispatcher.commands.keys }
+
+    message = "Unknown command: #{method}."
+    suggestion = DidYouMean::SpellChecker.new(dictionary: valid_commands).correct(method).first
+    message << " Did you mean %grn#{suggestion}%clr?" if suggestion
+    message << ' Run the %grnhelp%clr command for more details.'
+
+    print_error(message)
   end
 
   #
@@ -648,11 +657,13 @@ module DispatcherShell
   def help_to_s(opts = {})
     str = ''
 
+    max_command_length = dispatcher_stack.flat_map { |dispatcher| dispatcher.commands.to_a }.map { |(name, _description)| name.length }.max
+
     dispatcher_stack.reverse.each { |dispatcher|
-      str << dispatcher.help_to_s
+      str << dispatcher.help_to_s(opts.merge({ command_width: [max_command_length, 12].max }))
     }
 
-    return str
+    return str << "For more info on a specific command, use %grn<command> -h%clr or %grnhelp <command>%clr.\n\n"
   end
 
 
