@@ -27,6 +27,7 @@ class MetasploitModule < Msf::Auxiliary
         ],
         'License' => MSF_LICENSE,
         'References' => [
+          ['CVE', '2023-5350'],
           ['URL', 'https://blog.exodusintel.com/2022/06/09/salesagility-suitecrm-export-request-sql-injection-vulnerability/'],
           ['URL', 'https://docs.suitecrm.com/admin/releases/7.12.x/#_7_12_6']
         ],
@@ -134,7 +135,7 @@ class MetasploitModule < Msf::Auxiliary
     end
   end
 
-  # This module sends this same request multiple times. In order to reduce code it has beed moved it into it's owm method
+  # This module sends this same request multiple times. In order to reduce code it has been moved it into it's owm method
   def send_injection_request_cgi(payload)
     res = send_request_cgi({
       'method' => 'POST',
