@@ -26,10 +26,9 @@ class MetasploitModule < Msf::Auxiliary
     -----END RSA PRIVATE KEY-----
   EOF
 
-
   def initialize
     super(
-      'Name'        => 'Supermicro Onboard IPMI Static SSL Certificate Scanner',
+      'Name' => 'Supermicro Onboard IPMI Static SSL Certificate Scanner',
       'Description' => %q{
         This module checks for a static SSL certificate shipped with Supermicro Onboard IPMI
         controllers. An attacker with access to the publicly-available firmware can perform
@@ -37,30 +36,29 @@ class MetasploitModule < Msf::Auxiliary
         This module has been on a Supermicro Onboard IPMI (X9SCL/X9SCM) with firmware
         version SMT_X9_214.
       },
-      'Author'       =>
-        [
-          'hdm', # Discovery and analysis
-          'juan' # Metasploit module
-        ],
-      'License'     => MSF_LICENSE,
-      'References'  =>
-        [
-          [ 'CVE', '2013-3619' ],
-          [ 'URL', 'https://www.rapid7.com/blog/post/2013/11/06/supermicro-ipmi-firmware-vulnerabilities/']
-        ],
+      'Author' => [
+        'hdm', # Discovery and analysis
+        'juan' # Metasploit module
+      ],
+      'License' => MSF_LICENSE,
+      'References' => [
+        [ 'CVE', '2013-3619' ],
+        [ 'URL', 'https://www.rapid7.com/blog/post/2013/11/06/supermicro-ipmi-firmware-vulnerabilities/']
+      ],
       'DisclosureDate' => 'Nov 06 2013'
     )
 
     register_options(
       [
         Opt::RPORT(443),
-      ])
+      ]
+    )
   end
 
   # Fingerprint a single host
   def run_host(ip)
-    connect(true, {"SSL" => true}) #Force SSL
-    cert  = OpenSSL::X509::Certificate.new(sock.peer_cert)
+    connect(true, { "SSL" => true }) # Force SSL
+    cert = OpenSSL::X509::Certificate.new(sock.peer_cert)
     disconnect
 
     unless cert
@@ -76,19 +74,19 @@ class MetasploitModule < Msf::Auxiliary
       # Report with the SSL Private Key hash for the host
       digest = OpenSSL::Digest::SHA1.new(pkey.public_key.to_der).to_s.scan(/../).join(":")
       report_note(
-        :host  => ip,
+        :host => ip,
         :proto => 'tcp',
-        :port  => rport,
-        :type  => 'supermicro.ipmi.ssl.certificate.pkey_hash',
-        :data  => { :digest => digest }
+        :port => rport,
+        :type => 'supermicro.ipmi.ssl.certificate.pkey_hash',
+        :data => { :digest => digest }
       )
 
       report_vuln({
-        :host  => rhost,
-        :port  => rport,
+        :host => rhost,
+        :port => rport,
         :proto => 'tcp',
-        :name  => "Supermicro Onboard IPMI Static SSL Certificate",
-        :refs  => self.references
+        :name => "Supermicro Onboard IPMI Static SSL Certificate",
+        :refs => self.references
       })
     end
   end
