@@ -12,34 +12,41 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Report
   include Msf::Auxiliary::Scanner
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => 'Nessus RPC Interface Login Utility',
-      'Description'    => %q{
-        This module will attempt to authenticate to a Nessus server RPC interface.
-      },
-      'Author'         => [ 'void_in' ],
-      'License'        => MSF_LICENSE,
-      'DefaultOptions' =>
-      {
-        'SSL'        => true,
-      }
-    ))
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'Nessus RPC Interface Login Utility',
+        'Description' => %q{
+          This module will attempt to authenticate to a Nessus server RPC interface.
+        },
+        'Author' => [ 'void_in' ],
+        'License' => MSF_LICENSE,
+        'DefaultOptions' => {
+          'SSL' => true,
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
     register_options(
       [
         Opt::RPORT(8834),
-        OptString.new('TARGETURI', [ true,  'The path to the Nessus server login API', '/session']),
-      ])
+        OptString.new('TARGETURI', [ true, 'The path to the Nessus server login API', '/session']),
+      ]
+    )
 
-    deregister_options('HttpUsername', 'HttpPassword', 'PASSWORD_SPRAY')
+    deregister_options('HttpUsername', 'HttpPassword')
   end
 
-
   # Initializes CredentialCollection and Nessus Scanner
   def init(ip)
     @cred_collection = build_credential_collection(
-      password:        datastore['PASSWORD'],
-      username:        datastore['USERNAME']
+      password: datastore['PASSWORD'],
+      username: datastore['USERNAME']
     )
 
     @scanner = Metasploit::Framework::LoginScanner::Nessus.new(
@@ -48,17 +55,16 @@ class MetasploitModule < Msf::Auxiliary
         port: datastore['RPORT'],
         uri: datastore['TARGETURI'],
         proxies: datastore['PROXIES'],
-        cred_details:       @cred_collection,
-        stop_on_success:    datastore['STOP_ON_SUCCESS'],
-        bruteforce_speed:   datastore['BRUTEFORCE_SPEED'],
+        cred_details: @cred_collection,
+        stop_on_success: datastore['STOP_ON_SUCCESS'],
+        bruteforce_speed: datastore['BRUTEFORCE_SPEED'],
         connection_timeout: 5
       )
     )
-    @scanner.ssl         = datastore['SSL']
+    @scanner.ssl = datastore['SSL']
     @scanner.ssl_version = datastore['SSLVERSION']
   end
 
-
   # Reports a good login credential
   def do_report(ip, port, result)
     service_data = {
@@ -87,7 +93,6 @@ class MetasploitModule < Msf::Auxiliary
     create_credential_login(login_data)
   end
 
-
   # Attempts to login
   def bruteforce(ip)
     @scanner.scan! do |result|
@@ -98,34 +103,33 @@ class MetasploitModule < Msf::Auxiliary
       when Metasploit::Model::Login::Status::UNABLE_TO_CONNECT
         vprint_brute :level => :verror, :ip => ip, :msg => result.proof
         invalidate_login(
-            address: ip,
-            port: rport,
-            protocol: 'tcp',
-            public: result.credential.public,
-            private: result.credential.private,
-            realm_key: result.credential.realm_key,
-            realm_value: result.credential.realm,
-            status: result.status,
-            proof: result.proof
+          address: ip,
+          port: rport,
+          protocol: 'tcp',
+          public: result.credential.public,
+          private: result.credential.private,
+          realm_key: result.credential.realm_key,
+          realm_value: result.credential.realm,
+          status: result.status,
+          proof: result.proof
         )
       when Metasploit::Model::Login::Status::INCORRECT
         vprint_brute :level => :verror, :ip => ip, :msg => "Failed: '#{result.credential}'"
         invalidate_login(
-            address: ip,
-            port: rport,
-            protocol: 'tcp',
-            public: result.credential.public,
-            private: result.credential.private,
-            realm_key: result.credential.realm_key,
-            realm_value: result.credential.realm,
-            status: result.status,
-            proof: result.proof
+          address: ip,
+          port: rport,
+          protocol: 'tcp',
+          public: result.credential.public,
+          private: result.credential.private,
+          realm_key: result.credential.realm_key,
+          realm_value: result.credential.realm,
+          status: result.status,
+          proof: result.proof
         )
       end
     end
   end
 
-
   # Start here
   def run_host(ip)
     init(ip)
