@@ -41,6 +41,11 @@ class MetasploitModule < Msf::Auxiliary
         'DefaultOptions' => {
           'DCERPC::fake_bind_multi' => false
         },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
       )
     )
 
