@@ -3,30 +3,26 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Auxiliary
   include Msf::Exploit::Remote::DHCPServer
   include Msf::Auxiliary::Report
 
   def initialize
     super(
-      'Name'        => 'DHCP Server',
-      'Description'    => %q{
+      'Name' => 'DHCP Server',
+      'Description' => %q{
         This module provides a DHCP service
       },
-      'Author'      => [ 'scriptjunkie', 'apconole@yahoo.com' ],
-      'License'     => MSF_LICENSE,
-      'Actions'     =>
-        [
-          [ 'Service', 'Description' => 'Run DHCP server' ]
-        ],
-      'PassiveActions' =>
-        [
-          'Service'
-        ],
-      'DefaultAction'  => 'Service'
+      'Author' => [ 'scriptjunkie', 'apconole@yahoo.com' ],
+      'License' => MSF_LICENSE,
+      'Actions' => [
+        [ 'Service', 'Description' => 'Run DHCP server' ]
+      ],
+      'PassiveActions' => [
+        'Service'
+      ],
+      'DefaultAction' => 'Service'
     )
-
   end
 
   def run
