@@ -32,6 +32,9 @@ class MetasploitModule < Msf::Exploit::Remote
           'Payload' => 'linux/x86/meterpreter/reverse_tcp'
         },
         'DefaultTarget' => 0,
+        'References' => [
+          [ 'CVE', '2025-34088' ]
+        ],
         'Notes' => {
           'Stability' => [ CRASH_SAFE ],
           'SideEffects' => [ ARTIFACTS_ON_DISK, IOC_IN_LOGS ],
