@@ -73,7 +73,8 @@ class MetasploitModule < Msf::Exploit::Local
         'Notes' => {
           'AKA' => ['subuid_shell.c'],
           'Reliability' => [ REPEATABLE_SESSION ],
-          'Stability' => [ CRASH_SAFE ]
+          'Stability' => [ CRASH_SAFE ],
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         },
         'DefaultTarget' => 0,
         'Compat' => {
@@ -150,10 +151,9 @@ class MetasploitModule < Msf::Exploit::Local
 
   def check
     ['/usr/bin/newuidmap', '/usr/bin/newgidmap'].each do |path|
-      unless setuid? path
-        vprint_error "#{path} is not set-uid"
-        return CheckCode::Safe
-      end
+      return CheckCode::Safe("#{path} file not found") unless file? path
+      return CheckCode::Safe("#{path} is not setuid") unless setuid? path
+
       vprint_good "#{path} is set-uid"
     end
 
@@ -201,10 +201,8 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def exploit
-    if is_root?
-      unless datastore['ForceExploit']
-        fail_with Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.'
-      end
+    if !datastore['ForceExploit'] && is_root?
+      fail_with(Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.')
     end
 
     unless writable? base_dir
