@@ -22,11 +22,11 @@ class MetasploitModule < Msf::Exploit::Remote
         },
         'License' => MSF_LICENSE,
         'Author' => [
-          'Mehmet Ince <mehmet@mehmetince.net>',  # discovery & msf module
+          'Mehmet Ince <mehmet@mehmetince.net>', # discovery & msf module
         ],
         'References' => [
           ['CVE', '2017-7722'],
-          ['URL', 'http://pentest.blog/unexpected-journey-4-escaping-from-restricted-shell-and-gaining-root-access-to-solarwinds-log-event-manager-siem-product/']
+          ['URL', 'http://web.archive.org/web/20250221015511/https://pentest.blog/unexpected-journey-4-escaping-from-restricted-shell-and-gaining-root-access-to-solarwinds-log-event-manager-siem-product/']
         ],
         'DefaultOptions' => {
           'Payload' => 'python/meterpreter/reverse_tcp'
