@@ -41,7 +41,12 @@ class MetasploitModule < Msf::Exploit::Remote
         'Targets' => [ [ 'Universal', {} ] ],
         'Privileged' => true,
         'DisclosureDate' => '2019-01-25',
-        'DefaultTarget' => 0
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
       )
     )
 
@@ -141,7 +146,7 @@ class MetasploitModule < Msf::Exploit::Remote
       print_error "#{rhost}:22 SSH Error: #{e.class} : #{e.message}"
     end
     if ssh
-      conn = Net::SSH::CommandStream.new(ssh)
+      conn = Net::SSH::CommandStream.new(ssh, logger: self)
       return conn
     end
   end
