@@ -55,6 +55,11 @@ class MetasploitModule < Msf::Exploit::Local
                 stdapi_sys_config_driver_list
               ]
             }
+          },
+          'Notes' => {
+            'Reliability' => UNKNOWN_RELIABILITY,
+            'Stability' => UNKNOWN_STABILITY,
+            'SideEffects' => UNKNOWN_SIDE_EFFECTS
           }
         }
       )
