@@ -4,7 +4,7 @@
 ##
 
 class MetasploitModule < Msf::Exploit::Local
-  Rank = ExcellentRanking
+  Rank = GreatRanking
 
   include Msf::Exploit::EXE
   include Msf::Exploit::FileDropper
@@ -64,6 +64,7 @@ class MetasploitModule < Msf::Exploit::Local
         'Notes' => {
           'Stability' => [ CRASH_SERVICE_RESTARTS, ],
           'SideEffects' => [ ARTIFACTS_ON_DISK, ],
+          'Reliability' => UNKNOWN_RELIABILITY,
         },
         'Compat' => {
           'Meterpreter' => {
@@ -71,7 +72,7 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_sys_config_getenv
             ]
           }
-        },
+        }
       )
     )
 
