@@ -90,6 +90,11 @@ class MetasploitModule < Msf::Exploit::Local
                 stdapi_sys_process_memory_write
               ]
             }
+          },
+          'Notes' => {
+            'Reliability' => UNKNOWN_RELIABILITY,
+            'Stability' => UNKNOWN_STABILITY,
+            'SideEffects' => UNKNOWN_SIDE_EFFECTS
           }
         }
       )
