@@ -42,7 +42,12 @@ class MetasploitModule < Msf::Exploit::Remote
         'Arch' => [ARCH_X86, ARCH_X64],
         'Targets' => [['Automatic', {}]],
         'DefaultTarget' => 0,
-        'DisclosureDate' => '1999-01-01'
+        'DisclosureDate' => '1999-01-01',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
       )
     )
 
