@@ -9,39 +9,39 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::MSSQL
   include Msf::Exploit::CmdStager
   include Msf::OptionalSession::MSSQL
-  #include Msf::Exploit::CmdStagerDebugAsm
-  #include Msf::Exploit::CmdStagerDebugWrite
-  #include Msf::Exploit::CmdStagerTFTP
+  # include Msf::Exploit::CmdStagerDebugAsm
+  # include Msf::Exploit::CmdStagerDebugWrite
+  # include Msf::Exploit::CmdStagerTFTP
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Microsoft SQL Server Payload Execution',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Microsoft SQL Server Payload Execution',
+        'Description' => %q{
           This module executes an arbitrary payload on a Microsoft SQL Server by using
-        the "xp_cmdshell" stored procedure. Currently, three delivery methods are supported.
+          the "xp_cmdshell" stored procedure. Currently, three delivery methods are supported.
 
-        First, the original method uses Windows 'debug.com'. File size restrictions are
-        avoided by incorporating the debug bypass method presented by SecureStat at
-        Defcon 17. Since this method invokes ntvdm, it is not available on x64 systems.
+          First, the original method uses Windows 'debug.com'. File size restrictions are
+          avoided by incorporating the debug bypass method presented by SecureStat at
+          Defcon 17. Since this method invokes ntvdm, it is not available on x64 systems.
 
-        A second method takes advantage of the Command Stager subsystem. This allows using
-        various techniques, such as using a TFTP server, to send the executable. By default
-        the Command Stager uses 'wcsript.exe' to generate the executable on the target.
+          A second method takes advantage of the Command Stager subsystem. This allows using
+          various techniques, such as using a TFTP server, to send the executable. By default
+          the Command Stager uses 'wcsript.exe' to generate the executable on the target.
 
-        Finally, ReL1K's latest method utilizes PowerShell to transmit and recreate the
-        payload on the target.
+          Finally, ReL1K's latest method utilizes PowerShell to transmit and recreate the
+          payload on the target.
 
-        NOTE: This module will leave a payload executable on the target system when the
-        attack is finished.
-      },
-      'Author'         =>
-        [
-          'David Kennedy "ReL1K" <kennedyd013[at]gmail.com>',  # original module, debug.exe method, powershell method
-          'jduck'  # command stager mods
+          NOTE: This module will leave a payload executable on the target system when the
+          attack is finished.
+        },
+        'Author' => [
+          'David Kennedy "ReL1K" <kennedyd013[at]gmail.com>', # original module, debug.exe method, powershell method
+          'jduck' # command stager mods
         ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           # 'sa' password in logs
           [ 'CVE', '2000-0402' ],
           [ 'OSVDB', '557' ],
@@ -52,20 +52,26 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'OSVDB', '15757' ],
           [ 'BID', '4797' ]
         ],
-      'Platform'       => 'win',
-      'Arch'           => [ ARCH_X86, ARCH_X64 ],
-      'Targets'        =>
-        [
-          [ 'Automatic', { } ],
+        'Platform' => 'win',
+        'Arch' => [ ARCH_X86, ARCH_X64 ],
+        'Targets' => [
+          [ 'Automatic', {} ],
         ],
-      'CmdStagerFlavor' => 'vbs',
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2000-05-30'
-      ))
+        'CmdStagerFlavor' => 'vbs',
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2000-05-30',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
     register_options(
       [
         OptString.new('METHOD', [ true, 'Which payload delivery method to use (ps, cmd, or old)', 'cmd' ])
-      ])
+      ]
+    )
   end
 
   def check
