@@ -3,7 +3,8 @@ require 'rubocop/cop/lint/deprecated_gem_version'
 
 RSpec.describe RuboCop::Cop::Lint::DeprecatedGemVersion do
   subject(:cop) { described_class.new(config) }
-  let(:config) { RuboCop::Config.new }
+  let(:empty_rubocop_config) { { } }
+  let(:config) { RuboCop::Config.new(empty_rubocop_config) }
 
   it 'corrects `Gem::Version`' do
     expect_offense(<<~RUBY)
