@@ -13,7 +13,8 @@ RSpec.shared_context 'Msf::UIDriver' do
   let(:driver_output) do
     instance = double(
       Rex::Ui::Text::Output,
-      prompting?: false
+      prompting?: false,
+      prompting: false
     )
 
     capture_logging(instance)
@@ -26,7 +27,7 @@ RSpec.shared_context 'Msf::UIDriver' do
     @combined_output = []
   end
 
-  def capture_logging(target)
+  def capture_logging(target, capture_verbose: false)
     append_output = proc do |string = ''|
       lines = string.split("\n")
       @output ||= []
@@ -47,6 +48,11 @@ RSpec.shared_context 'Msf::UIDriver' do
     allow(target).to receive(:print_status, &append_output)
     allow(target).to receive(:print_good, &append_output)
 
+    if capture_verbose
+      allow(target).to receive(:vprint_status, &append_output)
+      allow(target).to receive(:vprint_error, &append_error)
+    end
+
     allow(target).to receive(:print_warning, &append_error)
     allow(target).to receive(:print_error, &append_error)
     allow(target).to receive(:print_bad, &append_error)
