@@ -2,12 +2,13 @@ require 'rex/post/meterpreter/extensions/stdapi/command_ids'
 require 'rex'
 
 lib = File.join(Msf::Config.install_root, "test", "lib")
-$:.push(lib) unless $:.include?(lib)
+$LOAD_PATH.push(lib) unless $LOAD_PATH.include?(lib)
 require 'module_test'
 
 class MetasploitModule < Msf::Post
 
   include Msf::ModuleTest::PostTest
+  include Msf::ModuleTest::PostTestFileSystem
 
   def initialize(info = {})
     super(
@@ -17,28 +18,19 @@ class MetasploitModule < Msf::Post
         'Description' => %q{ This module will test the meterpreter search method },
         'License' => MSF_LICENSE,
         'Author' => [ 'timwr'],
-        'Platform' => [ 'windows', 'linux', 'java' ],
+        'Platform' => [ 'windows', 'linux', 'java', 'osx' ],
         'SessionTypes' => [ 'meterpreter' ]
       )
     )
-    register_options(
-      [
-        OptBool.new("AddEntropy", [false, "Add entropy token to file and directory names.", false]),
-        OptString.new("BaseFileName", [true, "File/dir base name", "meterpreter-test"])
-      ], self.class
-    )
   end
 
+  #
+  # Change directory into a place that we have write access.
+  #
+  # The +cleanup+ method will change it back
+  #
   def setup
-    @old_pwd = session.fs.dir.getwd
-    stat = session.fs.file.stat("/tmp") rescue nil
-    if (stat and stat.directory?)
-      tmp = "/tmp"
-    else
-      tmp = session.sys.config.getenv('TEMP')
-    end
-    vprint_status("Setup: changing working directory to #{tmp}")
-    session.fs.dir.chdir(tmp)
+    push_test_directory
 
     if datastore["AddEntropy"]
       entropy_value = '-' + ('a'..'z').to_a.shuffle[0, 8].join
@@ -55,6 +47,12 @@ class MetasploitModule < Msf::Post
     super
   end
 
+  def cleanup
+    pop_test_directory
+    session.fs.file.rm(@file_name) rescue nil
+    super
+  end
+
   def test_fs_search
     vprint_status("Starting search tests")
 
@@ -185,11 +183,4 @@ class MetasploitModule < Msf::Post
     end
   end
 
-  def cleanup
-    session.fs.file.rm(@file_name) rescue nil
-    vprint_status("Cleanup: changing working directory back to #{@old_pwd}")
-    session.fs.dir.chdir(@old_pwd)
-    super
-  end
-
 end
