@@ -5,7 +5,7 @@
 require 'rex'
 
 lib = File.join(Msf::Config.install_root, "test", "lib")
-$:.push(lib) unless $:.include?(lib)
+$LOAD_PATH.push(lib) unless $LOAD_PATH.include?(lib)
 require 'module_test'
 
 class MetasploitModule < Msf::Post
@@ -22,7 +22,7 @@ class MetasploitModule < Msf::Post
         'License' => MSF_LICENSE,
         'Author' => [ 'kernelsmith', 'egypt' ],
         'Platform' => [ 'windows' ],
-        'SessionTypes' => [ 'meterpreter', 'shell' ]
+        'SessionTypes' => [ 'meterpreter', 'shell', 'powershell' ]
       )
     )
     register_options(
@@ -41,6 +41,8 @@ class MetasploitModule < Msf::Post
   end
 
   def test_start
+    return skip('session platform is not windows') unless session.platform == 'windows'
+
     it "should start #{datastore["SSERVICE"]}" do
       ret = true
       results = service_start(datastore['SSERVICE'])
@@ -63,6 +65,11 @@ class MetasploitModule < Msf::Post
   end
 
   def test_list
+    return skip('session platform is not windows') unless session.platform == 'windows'
+    if !session.commands.include?(Rex::Post::Meterpreter::Extensions::Stdapi::COMMAND_ID_STDAPI_RAILGUN_API)
+      return skip('reg query support skipped for now as the query takes more than two minutes')
+    end
+
     it "should list services" do
       ret = true
       results = service_list
@@ -76,17 +83,19 @@ class MetasploitModule < Msf::Post
   end
 
   def test_info
-    it "should return info on a given service  #{datastore["QSERVICE"]}" do
+    return skip('session platform is not windows') unless session.platform == 'windows'
+
+    it "should return info on a given service #{datastore["QSERVICE"]}" do
       ret = true
       results = service_info(datastore['QSERVICE'])
+      vprint_status("Service details: #{results}")
 
       ret &&= results.kind_of? Hash
       if ret
-        ret &&= results.has_key? :display
-        ret &&= (results[:display] == "Windows Management Instrumentation")
-        ret &&= results.has_key? :starttype
-        ret &&= results.has_key? :path
-        ret &&= results.has_key? :startname
+        ret &&= results[:display].is_a?(String)
+        ret &&= results[:starttype].is_a?(Integer)
+        ret &&= results[:path].is_a?(String)
+        ret &&= results[:startname].is_a?(String)
       end
 
       ret
@@ -94,7 +103,9 @@ class MetasploitModule < Msf::Post
   end
 
   def test_create
-    it "should create a service  #{datastore["NSERVICE"]}" do
+    return skip('session platform is not windows') unless session.platform == 'windows'
+
+    it "should create a service #{datastore["NSERVICE"]}" do
       mode = case datastore["MODE"]
              when "disable"; START_TYPE_DISABLED
              when "manual"; START_TYPE_MANUAL
@@ -133,6 +144,8 @@ class MetasploitModule < Msf::Post
   end
 
   def test_status
+    return skip('session platform is not windows') unless session.platform == 'windows'
+
     it "should return status on a given service #{datastore["QSERVICE"]}" do
       ret = true
       results = service_status(datastore['QSERVICE'])
@@ -148,12 +161,15 @@ class MetasploitModule < Msf::Post
   end
 
   def test_change
+    return skip('session platform is not windows') unless session.platform == 'windows'
+
     service_name = "a" << Rex::Text.rand_text_alpha(5)
     display_name = service_name
 
-    it "should modify config on a given service #{service_name}" do
+    it "should modify config on a given service" do
       ret = true
 
+      vprint_status("creating new service #{service_name}")
       results = service_create(service_name,
                                display: display_name,
                                path: datastore['BINPATH'],
@@ -179,11 +195,14 @@ class MetasploitModule < Msf::Post
   end
 
   def test_restart_disabled
+    return skip('session platform is not windows') unless session.platform == 'windows'
+
     service_name = "a" << Rex::Text.rand_text_alpha(5)
     display_name = service_name
 
-    it "should start a disabled service #{service_name}" do
+    it "should start a disabled service" do
       ret = true
+      vprint_status("creating new service #{service_name}")
       results = service_create(service_name,
                                display: display_name,
                                path: datastore['BINPATH'],
@@ -204,13 +223,14 @@ class MetasploitModule < Msf::Post
   end
 
   def test_restart_start
+    return skip('session platform is not windows') unless session.platform == 'windows'
     service_name = datastore['SSERVICE']
 
     it "should restart a started service #{service_name}" do
       ret = true
 
       results = service_start(service_name)
-      ret &&= (results == Windows::Error::SUCCESS)
+      ret &&= (results == Windows::Error::SUCCESS || results == Windows::Error::SERVICE_ALREADY_RUNNING)
       if ret
         results = service_restart(service_name)
         ret &&= results
@@ -221,6 +241,7 @@ class MetasploitModule < Msf::Post
   end
 
   def test_noaccess
+    return skip('session platform is not windows') unless session.platform == 'windows'
     it "should raise a runtime exception if no access to service" do
       ret = false
       begin
@@ -234,6 +255,7 @@ class MetasploitModule < Msf::Post
   end
 
   def test_no_service
+    return skip('session platform is not windows') unless session.platform == 'windows'
     it "should raise a runtime exception if services doesnt exist" do
       ret = false
       begin
